-- Этот скрипт создает те объекты базы данных, с которых
-- начинают работу слушатели курса.
-- Роли создаются заранее при инициализации ВМ.

-- Все остальное создается постепенно в процессе выполнения
-- "книжных" практик.

DROP DATABASE bookstore2;
CREATE DATABASE bookstore2;
\c bookstore2

CREATE EXTENSION pgcrypto; -- gen_random_uuid()
CREATE EXTENSION pg_background;
CREATE EXTENSION plpython3u;

-- интерфейсные функции для веб-магазина

CREATE SCHEMA webapi;
GRANT USAGE ON SCHEMA webapi TO web;

-- интерфейсные функции для админки

CREATE SCHEMA empapi;
GRANT USAGE ON SCHEMA empapi TO emp;

----
---- права
----

ALTER DEFAULT PRIVILEGES
    IN SCHEMA public
    REVOKE ALL ON FUNCTIONS FROM public;
ALTER DEFAULT PRIVILEGES
    IN SCHEMA webapi
    GRANT EXECUTE ON FUNCTIONS TO web;
ALTER DEFAULT PRIVILEGES 
    IN SCHEMA empapi 
    GRANT EXECUTE ON FUNCTIONS TO emp;

----
---- Таблицы
----

-- авторы

CREATE TABLE public.authors (
    author_id bigint GENERATED ALWAYS AS IDENTITY PRIMARY KEY,
    last_name text NOT NULL,
    first_name text NOT NULL,
    middle_name text NOT NULL, -- пустая строка для ех, у кого нет отчества
    UNIQUE (last_name, first_name, middle_name)
);

-- книги

CREATE TABLE public.books (
    book_id bigint GENERATED ALWAYS AS IDENTITY PRIMARY KEY,
    title text NOT NULL,
    format text NOT NULL,
    pages integer NOT NULL,
    rating float CHECK (rating BETWEEN 0.0 AND 1.0),
    votes_up integer NOT NULL DEFAULT 0,
    votes_down integer NOT NULL DEFAULT 0,
    onhand_qty integer NOT NULL DEFAULT 0 CHECK ((onhand_qty >= 0)),
    isbn text,
    abstract text,
    publisher text,
    year text,
    typeface text,
    edition integer,
    series text,
    cover_filename text
);

-- авторство

CREATE TABLE public.authorships (
    author_id bigint NOT NULL REFERENCES public.authors(author_id),
    book_id bigint NOT NULL REFERENCES public.books(book_id),
    seq_num integer NOT NULL,
    PRIMARY KEY (book_id, author_id)
);

-- операции

CREATE TABLE public.operations (
    operation_id bigint GENERATED ALWAYS AS IDENTITY PRIMARY KEY,
    book_id bigint NOT NULL REFERENCES public.books(book_id),
    qty integer NOT NULL,
    price numeric NOT NULL,
    at timestamptz NOT NULL DEFAULT current_timestamp
);

CREATE FUNCTION public.update_onhand_qty() RETURNS trigger
AS $$
BEGIN
    UPDATE books
    SET onhand_qty = onhand_qty + NEW.qty
    WHERE book_id = NEW.book_id;
    RETURN NEW;
END;
$$ LANGUAGE plpgsql;

CREATE TRIGGER update_onhand_qty_trigger
    BEFORE INSERT ON public.operations
    FOR EACH ROW
    EXECUTE FUNCTION public.update_onhand_qty();

-- розничные цены

CREATE TABLE public.retail_prices (
    book_id bigint NOT NULL REFERENCES public.books(book_id),
    price numeric NOT NULL
);

-- пользователи (покупатели)

CREATE TABLE public.users (
    user_id bigint GENERATED ALWAYS AS IDENTITY PRIMARY KEY,
    username text NOT NULL UNIQUE,
    email text NOT NULL
);

-- корзины

CREATE TABLE public.cart_items (
    user_id bigint REFERENCES public.users(user_id),
    book_id bigint REFERENCES public.books(book_id),
    qty integer NOT NULL,
    PRIMARY KEY (user_id, book_id)
);

-- сеансы

CREATE TABLE public.sessions (
    auth_token uuid PRIMARY KEY,
    user_id bigint NOT NULL REFERENCES public.users(user_id)
);

-- программы

CREATE TABLE public.programs (
    program_id bigint GENERATED ALWAYS AS IDENTITY PRIMARY KEY,
    name text NOT NULL UNIQUE,
    func text NOT NULL
);

-- задания

CREATE TABLE public.tasks (
    task_id bigint GENERATED ALWAYS AS IDENTITY PRIMARY KEY,
    program_id bigint NOT NULL REFERENCES public.programs(program_id),
    status text NOT NULL DEFAULT 'scheduled' CHECK (status IN ('scheduled','running','finished','error')),
    params jsonb,
    pid integer,
    started timestamptz,
    finished timestamptz,
    result text,
    host text,
    port text,
    CHECK ( (host IS NOT NULL AND port IS NOT NULL) OR (host IS NULL AND port IS NULL) )
);

----
---- Аутентификация
----

-- интерфейсные функции веб-магазина

CREATE FUNCTION webapi.register_user(username text, email text) RETURNS void
AS $$
    INSERT INTO users(username, email) VALUES (username, email);
$$ LANGUAGE sql VOLATILE SECURITY DEFINER;

CREATE FUNCTION webapi.login(username text) RETURNS uuid
AS $$
DECLARE
    auth_token uuid;
BEGIN
    INSERT INTO sessions AS s(auth_token, user_id)
        SELECT gen_random_uuid(), u.user_id
        FROM users u
        WHERE u.username = login.username
    RETURNING s.auth_token INTO STRICT auth_token; -- ошибка, если пользователя нет
    RETURN auth_token;
END;
$$ LANGUAGE plpgsql VOLATILE SECURITY DEFINER;

CREATE FUNCTION webapi.logout(auth_token uuid) RETURNS void
AS $$
    DELETE FROM sessions s
    WHERE s.auth_token = logout.auth_token;
$$ LANGUAGE sql VOLATILE SECURITY DEFINER;

-- внутренние функции

CREATE FUNCTION check_auth(auth_token uuid) RETURNS bigint
AS $$
DECLARE
    user_id bigint;
BEGIN
    user_id := current_setting('check_auth.user_id', /* missing_ok */true);
    IF user_id IS NULL THEN
        SELECT s.user_id
        INTO STRICT user_id
        FROM sessions s
        WHERE s.auth_token = check_auth.auth_token;
        PERFORM set_config('check_auth.user_id', user_id::text, /* is_local */false);
    END IF;
    RETURN user_id;
END;
$$ LANGUAGE plpgsql STABLE;

----
---- Каталог
----

-- внутренние функции

CREATE FUNCTION public.get_additional(book books) RETURNS jsonb
AS $$
    SELECT NULL::jsonb;
$$ LANGUAGE sql IMMUTABLE;

CREATE FUNCTION public.search_cond(search text) RETURNS text
AS $$
    SELECT format('b.title ILIKE %L', '%'||search||'%');
$$ LANGUAGE sql IMMUTABLE;

-- Комментарий для себя
-- вот такое "b.format::text format_text" необходимо:
-- 1) преобразование типов - чтобы после замены текстового формата
--    на тип book_format выводить его в прежнем виде;
-- 2) alias - чтобы ORDER BY fоrmat сортировал не по "format::text",
--    а просто по format.
CREATE FUNCTION public.get_catalog(search text, orderby text, direction text)
RETURNS TABLE(
    book_id bigint, 
    title text, 
    authors_list authors[],
    format text,
    rating float,
    price numeric,
    votes_up integer,
    votes_down integer,
    onhand_qty integer,
    additional jsonb,
    pages integer
)
AS $$
BEGIN
    IF orderby IS NULL OR lower(orderby) NOT IN ('format','rating','price') THEN
        orderby := 'price';
    END IF;
    IF direction IS NULL OR lower(direction) NOT IN ('asc','desc') THEN
        direction := 'asc';
    END IF;
    RETURN QUERY EXECUTE format($query$
        SELECT b.book_id,
               b.title,
               array_agg(a ORDER BY ash.seq_num) authors_list,
               b.format::text format_text,
               b.rating,
               get_retail_price(b.book_id) price,
               b.votes_up,
               b.votes_down,
               b.onhand_qty,
               get_additional(b) additional,
               b.pages
        FROM books b
            JOIN authorships ash ON ash.book_id = b.book_id
            JOIN authors a ON a.author_id = ash.author_id
        WHERE %s
        GROUP BY b.book_id 
        ORDER BY %I %s
    $query$, search_cond(search), orderby, direction);
END;
$$ LANGUAGE plpgsql STABLE SECURITY DEFINER;

CREATE FUNCTION public.get_retail_price(book_id bigint) RETURNS numeric
AS $$
    SELECT rp.price
    FROM retail_prices rp
    WHERE rp.book_id = get_retail_price.book_id;
$$ LANGUAGE sql STABLE SECURITY DEFINER;

CREATE FUNCTION public.before_checkout(user_id bigint)
RETURNS void
AS $$
BEGIN
    -- вызывается перед совершением покупки
END;
$$ LANGUAGE plpgsql VOLATILE;

-- интерфейсные функции веб-магазина

CREATE FUNCTION webapi.get_catalog(search text, orderby text, direction text)
RETURNS TABLE(
    book_id bigint, 
    title text, 
    authors_list authors[],
    format text,
    rating float,
    price numeric,
    votes_up integer,
    votes_down integer,
    additional jsonb,
    pages integer
)
AS $$
    SELECT book_id,
           title,
           authors_list,
           format,
           rating,
           price,
           votes_up,
           votes_down,
           additional,
           pages
    FROM public.get_catalog(search, orderby, direction);
$$ LANGUAGE sql STABLE SECURITY DEFINER;

CREATE FUNCTION webapi.get_image(book_id bigint) RETURNS bytea
AS $$
BEGIN
    -- TODO
    RETURN NULL;
END;
$$ LANGUAGE plpgsql;

CREATE FUNCTION webapi.get_cart(auth_token uuid)
RETURNS TABLE(
    book_id bigint,
    title text,
    authors_list authors[],
    qty integer,
    onhand_qty integer,
    price numeric
)
AS $$
<<local>>
DECLARE
    user_id bigint;
BEGIN
    user_id := check_auth(auth_token);
    RETURN QUERY
        SELECT ci.book_id,
               b.title,
               array_agg(a ORDER BY ash.seq_num),
               ci.qty,
               b.onhand_qty, -- никак не учитываем другие корзины
               get_retail_price(ci.book_id)
        FROM books b
            JOIN authorships ash ON ash.book_id = b.book_id
            JOIN authors a ON a.author_id = ash.author_id 
            JOIN cart_items ci ON ci.book_id = b.book_id
        WHERE ci.user_id = local.user_id
        GROUP BY b.book_id, ci.book_id, ci.user_id;
END;
$$ LANGUAGE plpgsql VOLATILE SECURITY DEFINER;

CREATE FUNCTION webapi.add_to_cart(auth_token uuid, book_id bigint, qty integer DEFAULT 1) RETURNS void
AS $$
BEGIN
    RAISE EXCEPTION 'Не реализовано';
END;
$$ LANGUAGE plpgsql VOLATILE SECURITY DEFINER;

CREATE FUNCTION webapi.remove_from_cart(auth_token uuid, book_id bigint) RETURNS void
AS $$
<<local>>
DECLARE
    user_id bigint;
BEGIN
    user_id := check_auth(auth_token);
    DELETE FROM cart_items ci
    WHERE ci.user_id = local.user_id
    AND ci.book_id = remove_from_cart.book_id;
END;
$$ LANGUAGE plpgsql VOLATILE SECURITY DEFINER;

CREATE FUNCTION webapi.checkout(auth_token uuid) returns void
AS $$
<<local>>
DECLARE
    user_id bigint;
BEGIN
    user_id := check_auth(auth_token);
    PERFORM before_checkout(user_id);
    WITH cart AS (
        DELETE FROM cart_items ci
        WHERE ci.user_id = local.user_id 
        RETURNING *
    )
    INSERT INTO operations(
        book_id,
        qty,
        price
    )
    SELECT
        c.book_id,
       -c.qty,
        get_retail_price(c.book_id)
    FROM cart c;
    -- если не хватит количества, то будет ошибка
END;
$$ LANGUAGE plpgsql VOLATILE SECURITY DEFINER;

CREATE FUNCTION webapi.cast_vote(auth_token uuid, book_id bigint, vote integer) returns void
AS $$
DECLARE
    user_id bigint;
BEGIN
    user_id := check_auth(auth_token);
    IF vote = 1 THEN
        UPDATE books b
        SET votes_up = votes_up + cast_vote.vote
        WHERE b.book_id = cast_vote.book_id;
    ELSIF vote = -1 THEN
        UPDATE books b
        SET votes_down = votes_down - cast_vote.vote
        WHERE b.book_id = cast_vote.book_id;
    ELSE
        -- какое кинуть исключение?
    END IF;
END;
$$ LANGUAGE plpgsql VOLATILE SECURITY DEFINER;

----
---- Админка
----

CREATE FUNCTION empapi.get_catalog(search text, orderby text, direction text)
    RETURNS table(
        book_id bigint,
        title text,
        authors_list authors[],
        onhand_qty integer,
        price numeric,
        pages integer
    )
AS $$
    SELECT book_id,
           title,
           authors_list,
           onhand_qty,
           price,
           pages
    FROM public.get_catalog(search, orderby, direction);
$$ LANGUAGE sql STABLE SECURITY DEFINER;

CREATE FUNCTION empapi.receipt(book_id bigint, qty integer, price numeric) RETURNS void
AS $$
    INSERT INTO operations(
        book_id, 
        qty, 
        price
    )
    VALUES (
        receipt.book_id, 
        receipt.qty, 
        receipt.price
    );
$$ LANGUAGE sql VOLATILE SECURITY DEFINER;

CREATE FUNCTION empapi.set_retail_price(book_id bigint, price numeric, at timestamptz) RETURNS void
AS $$
UPDATE retail_prices rp
SET price = set_retail_price.price
WHERE rp.book_id = set_retail_price.book_id;
$$ LANGUAGE sql VOLATILE SECURITY DEFINER;

----
---- Фоновые задания
----

CREATE FUNCTION empapi.get_tasks()
    RETURNS TABLE (
        task_id bigint,
        program_id bigint,
        name text,
        host text,
        port text,
        started timestamptz,
        finished timestamptz,
        status text
    )
AS $$
    SELECT t.task_id,
           t.program_id,
           p.name,
           t.host,
           t.port,
           t.started,
           t.finished,
           t.status
    FROM tasks t
        JOIN programs p ON p.program_id = t.program_id
    ORDER BY task_id DESC;
$$ LANGUAGE sql STABLE SECURITY DEFINER;

CREATE FUNCTION empapi.get_programs()
    RETURNS TABLE (
        program_id bigint,
        name text,
        func text
    )
AS $$
    SELECT p.program_id,
           p.name,
           p.func
    FROM programs p
    ORDER BY name;
$$ LANGUAGE sql STABLE SECURITY DEFINER;

CREATE FUNCTION empapi.task_results(task_id bigint) RETURNS text
AS $$
    SELECT t.result
    FROM tasks t
    WHERE t.task_id = task_results.task_id;
$$ LANGUAGE sql STABLE SECURITY DEFINER;

CREATE FUNCTION empapi.run_program(
    program_id bigint, 
    params jsonb DEFAULT NULL, 
    host text DEFAULT NULL,
    port text DEFAULT NULL
) RETURNS bigint
AS $$
    INSERT INTO tasks(program_id, status, params, host, port)
    VALUES (program_id, 'scheduled', params, host, port)
    RETURNING task_id;
$$ LANGUAGE sql VOLATILE SECURITY DEFINER;

CREATE FUNCTION empapi.run(task tasks) RETURNS text
AS $$
    # получаем параметры задания
    p = plpy.prepare("SELECT func FROM empapi.get_programs() WHERE program_id = $1", ["bigint"])
    r = p.execute([task["program_id"]])
    func = r[0]["func"]
    # выполняем функцию и получаем результат
    p = plpy.prepare("SELECT * FROM " + plpy.quote_ident(func) + "($1)", ["jsonb"])
    r = p.execute([task["params"]])
    # вычисляем максимальную ширину каждого столбца
    cols = r.colnames()
    collen = {col: len(col) for col in cols}
    for i in range(len(r)):
        for col in cols:
            if len( str(r[i][col]) ) > collen[col]:
                collen[col] = len( str(r[i][col]) )
    # выводим названия столбцов с учетом ширины
    res = ""
    res += " ".join( [col.center(collen[col]," ") for col in cols] ) + "\n"
    # отбивка из минусов
    res += " ".join( ["-"*collen[col] for col in cols] ) + "\n"
    # выводим результат
    for i in range(len(r)):
        res += " ".join( [str(r[i][col]).ljust(collen[col]," ") for col in cols] ) + "\n"
    return res
$$ LANGUAGE plpython3u VOLATILE;

-- внутренние функции

CREATE FUNCTION public.register_program(name text, func text) RETURNS bigint AS $$
    INSERT INTO programs(name, func) VALUES (name, func)
	RETURNING program_id;
$$ LANGUAGE sql VOLATILE;

-- тестовая программа - фоновое задание
CREATE FUNCTION public.greeting_task(params jsonb DEFAULT NULL)
RETURNS TABLE(num integer, greeting text)
AS $$
    SELECT i, 'Hello, world!' FROM generate_series(1,3) g(i);
$$ LANGUAGE sql IMMUTABLE;

SELECT empapi.run_program(
    register_program('Приветствие', 'greeting_task')
);

-- расчет рейтинга

CREATE FUNCTION public.rating(up integer, down integer) RETURNS float AS $$
-- нижняя граница доверительного интервала Вильсона для параметра Бернулли
-- https://habr.com/ru/company/darudar/blog/143188/
SELECT CASE WHEN up + down = 0
    THEN 0
    ELSE (
           (up + 1.9208) / (up + down) - 
           1.96 * sqrt((up * down) / (up + down) + 0.9604) / (up + down)
         ) / (1 + 3.8416 / (up + down))
    END::float;
$$ LANGUAGE sql IMMUTABLE;

-- Заготовка для практики к теме Языки программирования

-- TODO без encode('utf-8') падает:
--      UnicodeEncodeError: 'ascii' codec can't encode characters
--      Почему? Вроде 3-й Питон должен работать с UTF-8 по умолчанию?
--      Установка LC_CTYPE или PYTHONIOENCODING в envirinment не помогает.
CREATE OR REPLACE FUNCTION public.sendmail(
    from_addr text,
    to_addr text,
    subj text,
    msg text
) RETURNS void
AS $$
    import smtplib
    server = smtplib.SMTP('localhost')
    server.sendmail(
        from_addr,
        to_addr,
        "\r\n".join([
            "From: %s" % from_addr,
            "To: %s" % to_addr,
            "Content-Type: text/plain; charset=\"UTF-8\"",
            "Subject: %s" % subj,
            "\r\n%s" % msg
        ]).encode('utf-8')
    )
    server.quit()
$$ LANGUAGE plpython3u VOLATILE;

-- Проверки связи
-- s 1 "SELECT sendmail(
--     from_addr => 'bookstore@localhost',
--     to_addr => 'student@localhost',
--     subj => 'Тест',
--     msg => 'Привет!'
-- );"


----
---- трассировка
----

CREATE OR REPLACE FUNCTION webapi.trace(auth_token uuid) RETURNS void AS $$
    -- TODO
$$ LANGUAGE sql SECURITY DEFINER;

CREATE OR REPLACE FUNCTION empapi.trace() RETURNS void AS $$
    -- TODO
$$ LANGUAGE sql SECURITY DEFINER;

----
---- начальное наполнение
----

INSERT INTO users (username, email)
VALUES
    ('alice', 'alice@localhost'),
    ('bob', 'bob@localhost');

COPY public.authors (author_id, last_name, first_name, middle_name) FROM stdin;
2	Горшкова	Екатерина	Александровна
1	Новиков	Борис	Асенович
4	Моргунов	Евгений	Павлович
5	Дейт	Кристофер	
7	Фаро	Стефан	
8	Лерми	Паскаль	
9	Льюис	Джонатан	
10	Миллсап	Кэри	
11	Хольт	Джерфф	
12	Кайт	Том	
14	Кузнецов	Сергей	Дмитриевич
16	Уидом	Дженнифер	
17	Такахаси	Мана	
18	Мартин	Роберт	
19	Гудлиф	Питер	
20	Бен-Ари	Мордехай	
21	Кауфман	Виталий	Шахнович
22	Йенсен	Кэтлин	
27	Керниган	Бриан	
30	Хопкрофт	Джон	
29	Ахо	Альфред	
33	Лам	Моника	
34	Сети	Рави	
15	Ульман	Джеффри	
36	Серебряков	Владимир	Алексеевич
37	Галочкин	Максим	Павлович
38	Абельсон	Харольд	
39	Сассман	Джеральд	
40	Сассман	Джули	
41	Босуэлл	Дастин	
42	Фаучер	Тревор	
44	Гуткнехт	Юрг	
45	Пёрсиг	Роберт	
47	ДеМарко	Том	
48	Друкер	Питер	
49	Кэмп	Джим	
50	Хант	Эндрю	
51	Томас	Дэвид	
52	Спольски	Джоэл	
55	Константин	Ларри	
56	Брукс	Фредерик	
57	Демарко	Том	
58	Листер	Тимоти	
59	Роббинс	Арнольд	
60	Ханна	Элберт	
61	Лэмб	Линда	
62	Курячий	Георгий	Владимирович
25	Керниган	Брайан	
26	Пайк	Роб	
65	Адельсон-Вельский	Георгий	Максимович
66	Арлазаров	Владимир	Львович
67	Битман	Александр	Рафаилович
68	Донской	Михаил	Владимирович
69	Кронрод	Александр	Семенович
70	Перлис	Алан	
71	Дейкстра	Э́дсгер	
73	Скотт	Дана	
74	Бэкус	Джон	
75	Флойд	Роберт	
76	Хоар	Чарльз	
28	Ритчи	Деннис	
78	Томпсон	Кен	
23	Вирт	Никлаус	
80	Уилкс	Морис	
81	Хэмминг	Ричард	
82	Минский	Марвин	
83	Уилкинсон	Джеймс	
84	Маккарти	Джон	
85	Бахман	Чарльз	
86	Ньюэлл	Аллен	
87	Саймон	Герберт	
88	Рабин	Майкл	
89	Айверсон	Кеннет	
90	Кодд	Эдгар	
91	Кук	Стивен	
92	Карп	Ричард	
93	Френкель	Карен	
94	Норман	Дональд	
95	Нильсен	Якоб	
96	Круг	Стив	
97	Кирсанов	Дмитрий	
98	Купер	Алан	
100	Рейнман	Роберт	
101	Кронин	Дэвид	
102	Раскин	Джеф	
72	Кнут	Дональд	
109	Каров	Петер	
110	Гуссенс	Мишель	
111	Ратц	Себастиан	
112	Миттельбах	Франк	
113	Львовский	Сергей	Михайлович
114	Брингхерст	Роберт	
115	Феличи	Джеймс	
116	Птахова	Ирина	Ивановна
117	Шпикерман	Эрик	
118	Королькова	Александра	
119	Герчук	Елена	Юрьевна
120	Богдеско	Илья	Трофимович
121	Шуази	Огюст	
122	Витрувий	Марк	
123	Пилявский	Владимир	Иванович
124	Тиц	Алексей	Алексеевич
125	Ушаков	Юрий	Сергеевич
126	Голдбергер	Пол	
127	Джекобс	Джейн	
128	Хьюбел	Дэвид	
129	Хокинс	Джефф	
130	Блейксли	Сандра	
131	Рамачандран	Вилейанур	
134	Казанцева	Ася	
135	Фрит	Крис	
136	Докинс	Ричард	
137	Чангизи	Марк	
138	Марков	Александр	Владимирович
140	Наймарк	Елена	Борисовна
145	Кунин	Евгения	Викторович
146	Шубин	Нил	
147	Кандель	Эрик	
148	Кэрролл	Шон	
149	Лейн	Ник	
150	Пэабло	Сванте	
151	Лоренц	Конрад	
152	Даймонд	Джаред	
153	Хокинг	Стивен	
132	Млодинов	Леонард	
155	Уотсон	Джеймс	
\.
SELECT setval('authors_author_id_seq', 155, true);

COPY public.books (book_id, title, format, pages, rating, votes_up, votes_down, onhand_qty, isbn, abstract, publisher, year, typeface, edition, series, cover_filename) FROM stdin;
36	Руководство Джоэла Спольски по подбору программистов и управлению ими	84x108/32	144	\N	0	0	29	978-5-8459-1354-8	Известный эксперт по вопросам организации работы компаний по разработке программного обеспечения Джоэл Спольски легко и понятно объясняет, как найти, отобрать, увлечь и нанять на работу лучших технических специалистов. Кроме того, много внимания уделяется созданию хороших условий труда для людей, которые этого действительно заслуживают.\nКнига будет полезна всем, кто нанимает на работу программистов или руководит ими в организации.	Вильямс	2008	\N	\N	\N	joel_smart.jpg
66	Живая типографика	70x100/16	224	\N	0	0	11	978-5-9901107-1-7	В книге живым и доступным языком изложены основные правила и закономерности типографики - "искусства расположения наборного материала на плоскости листа". Рассмотрены история и различные классификации наборных шрифтов и основные принципы их подбора и применения, способы размещения материала на развороте, принципы и правила набора.\nКнига предназначена для студентов высших учебных заведений, изучающих графический и книжный дизайн. Кроме того, она будет полезна практикующим дизайнерам (в том числе, дизайнерам книги и начинающим дизайнерам наборного шрифта).	IndexMarket	2007	Leksa, LeksaSans	\N	\N	korolkova_typo.jpg
91	Вопрос жизни. Энергия, эволюция и происхождение сложности	60x88/16	480	\N	0	0	33	978-5-17-983126-6	Почему мы стареем и умираем? Зачем нужно половое размножение? И почему полов два, а не больше? У известного английского биохимика есть ответы и на эти вопросы, но главное - он предлагает неожиданный подход к основным проблемам биологии: как из камней, воды и воздуха появилась жизнь.	АСТ	2018	MetaNormalC	\N	Элементы	lane_vital.jpg
3	PostgreSQL: Основы языка SQL	70x100/16	336	\N	0	0	24	978-5-9775-4022-3	Учебно-практическое пособие охватывает первую, базовую, часть учебного курса по языку SQL, созданного при участии российской компании Postgres Professional. Учебный материал излагается в расчете на использование системы управления базами данных PostgreSQL. Рассмотрено создание рабочей среды, описаны языки определения данных и основные операции выборки и изменения данных. Показаны примеры использования транзакций, уделено внимание методам оптимизации запросов. Материал сопровождается многочисленными практическими примерами. Пособие может использоваться как для самостоятельного обучения, так и при проведении занятий под руководством преподавателя.	БХВ-Петербург	2018	\N	\N	\N	morgunov_sql.jpg
79	Мозг материален. О пользе томографа, транскраниального стимулятора и клеток улитки для понимания человеческого поведения	60x88/16	368	\N	0	0	23	978-5-17-114664-1	Ася Казанцева - известный научный журналист, популяризатор науки, лауреат премии "Просветитель" (2014). Ее третья книга посвящена строению и работе мозга, связям нейробиологии и психологии, "описанию разных экспериментов, старинных и современных, которые в совокупности формируют представление о том, что мозг познаваем". Автор, как всегда, ссылается на серьезные научные источники и в своем фирменном стиле старается донести до широкого круга читателей главные идеи: мозг - "наш главный рабочий инструмент" - материален, изменчив и неоднороден, "и осознание этих его свойств полезно в повседневной жизни".	АСТ	2019	\N	\N	\N	kazanceva_brain.jpg
57	Все про TeX	70x100/16	592	\N	0	0	47	5-900614-01-8	Полное описание одной из самых популярных систем авторской подготовки текстов на ЭВМ, и особенно научных работ, содержащих много математических формул - системы TeX, прекрасно написанное ее автором известнейшим американским программистом проф. Дональдом Е. Кнутом.	RDTeX	1993	Computer Modern	\N	\N	knuth_texbook.jpg
51	Алан Купер об интерфейсе. Основы проектирования взаимодействия	70x100/16	688	\N	0	0	34	978-5-93286-132-5	Когда в 1995 году увидело свет первое издание "About Face", идея проектировать продукты исходя из целей людей казалась революционной. Благодаря работам Алана Купера и других первопроходцев, проектирование взаимодействия получило сегодня широкое признание как уникальная и крайне важная дисциплина, однако эта работа далека от завершения.\nАвторы полностью обновленного издания, признанные мировые эксперты в вопросах создания интерфейсов, детально описывают разработанный в компании Cooper и примененный во множестве проектов целостный подход к проектированию взаимодействия, ориентированный на цели пользователя. Отличительной чертой книги является ее практическая направленность - значительную часть издания занимает подробный разбор принципов и шаблонов проектирования взаимодействия. Большое внимание уделено новым информационным средам: веб-приложениям, мобильным приложениям, киоскам и т. п.\nКнига адресована всем специалистам, по роду деятельности соприкасающимся с процессом создания цифровых продуктов. Проектировщикам взаимодействия и дизайнерам интерфейсов она послужит настольным справочником по организации процесса и повседневным подручным инструментарием.	Символ-Плюс	2009	\N	\N	Профессионально	cooper_interface.jpg
22	Структуры данных и алгоритмы	70x100/16	384	\N	0	0	33	5-8459-0122-7	В этой книге подробно рассмотрены структуры данных и алгоритмы, которые являются фундаментом современной методологии разработки программ. Показаны разнообразные реализации абстрактных типов данных, начиная от стандартных списков, стеков, очередей и заканчивая множествами и отображениями, которые используются для неформального описания и реализации алгоритмов. Две главы книги посвящены методам анализа и построения алгоритмов; приведено и исследовано множество различных алгоритмов для работы с графами, внутренней и внешней сортировки, управления памятью.\nКнига не требует от читателя специальной подготовки, только предполагает его знакомство с какими-либо языками программирования высокого уровня, такими как Pascal. Вместе с тем она будет полезна специалистам по разработке программ и алгоритмов и может быть использована как учебное пособие для студентов и аспирантов, специализирующихся в области компьютерных наук.	Вильямс	2000	SchoolBook	\N	\N	aho_structalgo.jpg
54	Искусство программирования, том 2. Получисленные алгоритмы	70x100/16	832	\N	0	0	41	5-8459-0081-6	В третьем издании второго тома представлено полное введение в теорию получисленных алгоритмов, причем случайным числам и арифметике посвящены отдельные главы. В книге даны основы теории получисленных алгоритмов, а также примеры этих алгоритмов. Тем самым установлено прочное связующее звено между компьютерным программированием и численным анализом. Особого упоминания заслуживают предложенная Кнутом в настоящем издании новая трактовка генераторов случайных чисел, а также рассмотрение способов вычислений с помощью формальных степенных рядов.	Вильямс	2000	LH	3	\N	knuth_art2.jpg
80	Мозг и душа. Как нервная деятельность формирует наш внутренний мир	60x90/16	335	\N	0	0	16	978-5-17-083015-2	Знаменитый британский нейрофизиолог Крис Фрит хорошо известен умением говорить просто об очень сложных проблемах психологии - таких как психическая деятельность, социальное поведение, аутизм и шизофрения. Именно в этой сфере, наряду с изучением того, как мы воспринимаем окружающий мир, действуем, делаем выбор, помним и чувствуем, сегодня и происходит научная революция, связанная с внедрением методов нейровизуализации. В книге "Мозг и душа" Крис Фрит рассказывает обо всем этом самым доступным и занимательным образом.	АСТ	2014	MetaNormalC	\N	Элементы	frith_mind.jpg
64	Простая красота буквы	70x100/16	288	\N	0	0	36	5-901042-01-8	Издание, посвященное истории шрифта, последовательно и полно раскрывает перед читателями тайны современного дизайна, гармонии и красоты привычной типографской буквы. Читателю станут понятны исторические связи и пути возникновения новых шрифтовых стилей, их преемственность и самоценность.  Книга будет полезна всем, кого интересует книгоиздание, дизайн, реклама, всем, кто по роду своей деятельности связан с проблемами использования шрифта. Она безусловно необходима студентам художественных вузов и училищ.	Русская графика	1997	Академическая	\N	\N	ptahova_letter.jpg
90	Бесконечное число самых прекрасных форм. Новая наука эво-дево и эволюция царства животных	60x90/16	432	\N	0	0	35	978-5-17-090263-7	Как из одной клетки образуются сложные существа, состоящие из миллионов клеток? Человечество со времен Дарвина пыталось разгадать эту тайну. Ученые понимали, что это поможет ответить и на другой вопрос - как из самых первых многоклеточных животных получилось сегодняшнее "бесконечное число самых прекрасных форм".\nНовая область науки - эволюционная биология развития, или эво-дево, объединившая эмбриологию, палеонтологию и молекулярную генетику, сумела объяснить, как на ранних стадиях развития закладывается будущая форма животных. В своей книге американский биолог, ведущий специалист в области эво-дево Шон Б. Кэрролл увлекательно и просто, на примере самых разных представителей земной фауны - от плодовой мушки до человека - показывает, как действуют законы развития и эволюции, будь то несколько часов, за которые личинка дрозофилы развивается из яйца, или сотни миллионов лет, за которые формируется новый таксон животных.	АСТ	2015	MetaNormalC	\N	Элементы	carroll_forms.jpg
31	Практика менеджмента	70x100/16	400	\N	0	0	36	978-5-8459-0085-2	Эту книгу можно назвать практической, хотя в ней не описываются конкретные методики. Она написана на основе многолетнего опыта практической работы в менеджменте - как малых предприятий, так больших и очень больших компаний. Эта книга должна стать руководством для людей, занимающих высшие руководящие должности. Она должна помочь им оценить свою работу, определить свои слабые стороны, повысить эффективность и соответственно улучшить конечный результат деятельности предприятия, за которое они отвечают. Начинающим менеджерам и всем, кто планирует работать в сфере менеджмента, эта книга поможет сформировать целостное понимание того, что такое менеджмент. Она станет конкретным руководством, способствующим получению высших руководящих должностей.	Вильямс	2009	Times	\N	\N	drucker_practice.jpg
44	Беседы о программировании	60x90/16	248	\N	0	0	13	5-484-00413-6	Эта книга была написана замечательным ученым-математиком А. С. Кронродом почти 40 лет тому назад, впервые опубликована в 2001 году. Один из зачинателей программирования у нас в стране и основателей целой школы программирования, А. С. Кронрод в доступной и интересной форме обсуждает вопросы организации системного программирования, отладки программ и архитектуры ЭВМ. Значительная часть книги посвящена различным задачам искусственного интеллекта и использованию "интеллектуальных" подходов для решения вычислительных задач.\nКнига будет интересна программистам, историкам науки и специалистам в области искусственного интеллекта.	КомКнига	2006	\N	3	\N	kronrod_prog.jpg
9	Oracle для профессионалов. Книга 1. Архитектура и основные особенности	70x100/16	656	\N	0	0	38	5-93772-129-2	Выход в свет в конце прошлого года этой книги издательства Wrox стал эпохальным событием: впервые доходчиво и исчерпывающе раскрыты основные особенности архитектуры СУБД Oracle, принципиально отличающие ее от других популярных систем управления базами данных. Причем подробно описаны и проиллюстрированы множеством примеров именно те возможности, средства и особенности Oracle, которые обеспечивают разработку эффективных приложений для этой СУБД и ее успешную эксплуатацию.\nАвтор книги, Том Кайт, давно работает с СУБД Oracle, создает приложения и администрирует базы данных. Многие годы он профессионально занимается решением проблем, возникающих при использовании СУБД Oracle у администраторов и разработчиков по всему миру. На специализированном сайте корпорации Oracle (http://asktom.oracle.com) Том Кайт отвечает на десятки вопросов в день. Он не только делится знаниями, но и умело подталкивает читателя к самостоятельным экспериментам. Следуя по указанному им пути, становишься Профессионалом.\nЕсли вы приступаете к изучению СУБД Oracle, - начните с этой книги. Если вы опытный разработчик приложений или администратор баз данных Oracle, - прочтите ее и проверьте, достаточно ли глубоко вы знаете эту СУБД и умеете ли использовать ее возможности. Вы найдете в книге десятки советов, описаний приемов и методов решения задач, о которых никогда не подозревали.	ДиаСофтЮП	2005	Таймс	3	\N	kyte_oracle_1.jpg
68	Каллиграфия	60x90/8	176	\N	0	0	28	5-91044-001-2	\N	Агат	2005	Petersburg	\N	\N	bogdesko_calligraphy.jpg
24	Основы конструирования компиляторов	60x84/16	224	\N	0	0	25	5-8360-0242-8	Предлагаемая вниманию читателя книга основана на курсе лекций, прочитанных на факультете вычислительной математики и кибернетики Московского государственного университета и факультете управления и прикладной математики Московского физико-технического института в 1991-1999 гг. Авторы надеются, что издание книги восполнит существенный пробел в литературе на русском языке по разработке компиляторов. Содержание книги представляет собой "классические" разделы предмета: лексический и синтаксический анализ, организация памяти компилятора (таблицы символов) и периода исполнения (магазина), генерация кода. Рассматриваются некоторые средства автоматизации процесса разработки трансляторов, такие как LEX, YACC, СУПЕР, методы генерации оптимального кода. Сделана попытка на протяжении всего изложения провести единую "атрибутную" точку зрения на процесс разработки компилятора. В книге не затрагиваются чрезвычайно важные вопросы глобальной оптимизации и разработки компиляторов для машин с параллельной архитектурой. Авторы надеются восполнить эти пробелы в будущем. Книга будет полезной как студентам и аспирантам программистских специальностей, так и профессионалам в этих областях.	Эдиториал УЗСС	2001	\N	\N	\N	serebryakov_compilers.jpg
16	Языки программирования	70x100/16	366	\N	0	0	16	5-03-003314-9	В книге рассматриваются базовые понятия языков программирования: среды программирования, подпрограммы, указатели, полиморфизм и наследование, исключения, параллелизм и декомпозиция программы. Обсуждается языковая поддержка объектно-ориентированного программирования. Приведенные языковые конструкции богато иллюстрированы примерами. Основное внимание уделяется языкам C++ и Ada 95, однако не остаются забытыми Pascal, Fortran, PL/I, Lisp и другие. Концепции функционального и логического программирования показаны на примере языков ML и Prolog. Отдельная глава посвящена модели и языку Java.\nДля студентов, изучающих языки программирования, преподавателей и профессиональных программистов.	Мир	2000	\N	\N	\N	ben-ari_pl.jpg
84	Эволюция. Классические идеи в свете новых открытий	60x90/16	656	\N	0	0	48	978-5-17-083218-7	Что такое польза? Как случайная мутация превращает аутсайдеров в процветающих победителей? Что важнее для эволюции - война или сотрудничество?\nКнига Александра Маркова и Елены Наймарк рассказывает о новейших исследованиях молекулярных генетиков и находках палеонтологов, которые дают ответы на эти и многие другие вопросы о видоизменениях в природе. Тысячи открытий, совершенных со времен Дарвина, подтверждают догадки родоначальников теории эволюции; новые данные ничуть не разрушают основы эволюционной теории, а напротив, лишь укрепляют их.\nАлександр Марков, заведующий кафедрой биологической эволюции биофака МГУ, и Елена Наймарк, ведущий научный сотрудник Палеонтологического института им. А. А. Борисяка, - известные ученые и популяризаторы науки. Двухтомник "Эволюция человека" (2011), написанный ими в соавторстве, стал настольной книгой не только для студентов и ученых-биологов, но и для множества людей за пределами профессионального сообщества.	АСТ	2014	OriginalGaramondC	\N	Элементы	markov_evolution.jpg
21	Язык программирования Си	70x100/16	272	\N	0	0	22	5-279-00473-1	Новое издание книги широко известных авторов, разработчиков языка Си, переработанное и дополненное с учетом подготовленного стандарта ANSI для языка Си. Включает введение в язык, подробный учебник по языку и справочное руководство для программистов.	Финансы и статистика	1992	Литературная	2	\N	kr_c.jpg
18	Паскаль: Руководство для пользователя	84x108/32	356	\N	0	0	25	5-88201-005-5	Книга представляет собой руководство для пользователя и описание Стандарта популярнейшего языка программирования - Паскаля. В настоящем - четвертом - издании нашли отражения все коррективы, внесенные в Стандарт ISO ее второй рабочей группой. Эти коррективы устранили противоречия между Стандартом на Паскаль, разработанном ISO, и американским стандартом ANSI/IEEE.	Компьютер	1993	\N	\N	\N	wirth_pascal.jpg
92	Неандерталец. В поисках исчезнувших геномов	60x88/16	416	\N	0	0	33	978-5-17-091066-3	Шведский генетик Сванте Пэабо давно лелеял мечту, казавшуюся несбыточной: выделить ДНК из египетских мумий и, таким образом, "поближе познакомиться" с людьми, жившими тысячи лет назад. Юношеская одержимость повела его тернистым путем - через мучительный научный поиск, борьбу за чистоту экспериментов и интеллектуальную честность, дипломатические маневры и бюрократические войны... И завела намного дальше в глубину веков, к прочтению неандертальского генома, радикально меняющему все представления и о самих неандертальцах, и об их взаимодействии с предками современного человечества.\n"Неандерталец" - это не только увлекательный рассказ о сенсационном прорыве, но и документ, фиксирующий важную веху в истории науки: становление палеогеномики, новой дисциплины, позволяющей методом исследования древних ДНК восстанавливать картину эволюции нашего вида в таких подробностях, о каких мы раньше не смели и мечтать.	АСТ	2018	MetaNormalC	\N	Элементы	paablo_neanderthal.jpg
5	Введение в системы баз данных	70x100/16	848	\N	0	0	27	5-8459-0019-0	В настоящее время назрела реальная потребность в фундаментальном учебнике, где ясно и точно были бы изложены основные принципы построения систем управления базами данных. Данная книга послужит хорошим руководством для тех, кто использует или разрабатывает базы данных, а также для всех, кто хочет расширить свои знания в сфере применения компьютеров.\nКнига рассчитана в основном на специалистов в области обработки данных, системных аналитиков, разработчиков баз данных и прикладных программистов, а также на преподавателей и студентов.	Вильямс	1999	\N	6	\N	date_dbms_6.jpg
12	Реляционные базы данных	70x100/16	374	\N	0	0	62	978-5-85582-375-2	\N	Лори	2014	Ньютон	\N	\N	ullman_databases.jpg
59	Шрифтовые технологии. Описание и инструментарий	70x100/16	454	\N	0	0	41	5-03-003360-2	Книга написана немецким специалистом с мировым именем. Освещаются такие темы, как история и технология производства шрифтов, шрифтовой рынок, методы определения качества шрифта, удобочитаемость, классификация шрифтовой формы и проблемы защиты авторского права. Издание дополнено материалом, отражающим историю кириллического шрифта, написанным В. В. Ефимовым.\nПредставляет интерес для полиграфистов, дизайнеров-шрифтовиков, программистов, связанных с разработкой и использованием цифровых шрифтов, а также студентов и аспирантов соответствующих специальностей.	Мир	2001	\N	\N	Библиотека издательских технологий	karow_font.jpg
17	Языки программирования. Концепции и принципы	60x88/16	432	\N	0	0	40	5-256-00643-6	Рассмотрены основные концепции и принципы, воплощенные в современных и перспективных языках программирования (Фортран, Паскаль, ПЛ/1, Алгол-68, Симула-67, Смолток, Рефал, Ада, Модула-2, Оберон, Оккам-2, Турбо Паскаль 5.5 и др.), представлены разные стили программирования (операционный, ситуационный, функциональный, реляционный, параллельный, объектно-ориентированный), освещены тенденции и перспективы развития языков и стилей программирования.\nВпервые удалось разработать и представить в одной книге цельную систему концепций и принципов, создающий достаточно четкие ориентиры в области языков программирования. На основе этой системы сформулированы оригинальные положения, указывающие перспективы развития языков программирования (модули исключительных ситуаций, модули управления представлением, входовые типы и др.). \nНовые подходы применены при изложении известных фактов (пошаговая модификация нормальных алгоритмов Маркова сначала до Рефала, а затем до реляционных языков, систематическое сопоставление концепции параллелизма в Аде и Оккаме-2, концепций создания Ады, Модулы-2 и Оберона, развитие концепции наследуемости от модульности до объектной ориентации и др.).\nДля научных работников, будет полезной программистам, а также преподавателям и студентам, серьезно интересующимся языками программирования.	Радио и связь	1993	Таймс	\N	\N	kaufman_pl.jpg
60	Путеводитель по пакету LaTeX и его графическим расширениям. Иллюстрирование документов при помощи TeX'а и PostScript'а	70x100/16	621	\N	0	0	15	5-03-003388-2	Исчерпывающий справочник по стандартным графическим расширениям LaTeX`а, позволяющим сопроводить текст черно-белыми и цветными иллюстрациями высокого качества. Приводятся подробные описания пакетов XY-pic, PSTricks, METAPOST и PostScript-шрифтов, описываются средства для представления фейнмановских диаграмм, структурных химических формул, электрических схем, музыкальных партитур и настольных игр. Объясняется, как при помощи программы Ghostscript распечатывать PS-файлы на принтерах, не поддерживающих PostScript. Для упомянутых в книге пакетов приводятся адреса в Интернете.\nПредставляет интерес для всех TeX-пользователей: научных работников, самостоятельно готовящих свои работы к изданию, профессиональных наборщиков и дизайнеров, специалистов по издательским системам и студентов соответствующих специальностей.	Мир	2002	Computer Modern	\N	Библиотека издательских технологий	goossens_latex.jpg
27	Разработка операционной системы и компилятора. Проект Оберон	60x90/16	560	\N	0	0	23	978-5-94074-672-0	В книге описан проект Оберон, представляющий полную программную среду для современной рабочей станции. Главная цель, поставленная авторами - спроектировать и реализовать всю систему с нуля и построить се так, чтобы она могла быть описана, объяснена и понята как единое целое.\nВ дополнение к основной системе во всех деталях описан компилятор языка Оберон и графическая подсистема.\nДля программистов, преподавателей и студентов, изучающих теорию и практику построения операционных систем.	ДМК Пресс	2012	\N	\N	\N	wirth_oberon.jpg
82	Революция в зрении: что, как и почему мы видим на самом деле	60x90/16	304	\N	0	0	11	978-5-17-080467-2	Как вышло так, что наши глаза смотрят вперед, и почему у нас нет глаз на затылке? Каким образом зрение нас обманывает? Почему человек видит мир в цвете? Как родилась письменность, почему буквы именно такие, и при чем здесь естественный отбор? Неожиданные ответы на эти и другие вопросы дает известный американский нейробиолог.	АСТ	2014	MetaNormalC	\N	Элементы	changizi_vision.jpg
7	Oracle. Основы стоимостной оптимизации	70x100/16	528	\N	0	0	24	978-5-469-01309-9	Стоимостный оптимизатор - это всего лишь фрагмент кода, содержащий модель обработки данных Oracle. Применяя эту модель к статистике по вашим данным, оптимизатор пытается эффективно преобразовать созданный вами запрос в исполняемый план. К сожалению, модель не может быть идеальной, статистика тоже не всегда безупречна, так что получившийся план исполнения порой оказывается далеким от совершенства.\nВ этой книге Джонатан Льюис - один из крупнейших специалистов в своей области - описывает наиболее часто используемые компоненты модели, рассказывает, что именно оптимизатор делает с предоставленной ему статистикой и почему его работа может разладиться. Имея такую информацию, вы сможете не просто исправить отдельные операторы SQL, но и усовершенствовать проблемные области целиком, отрегулировав модель или создав более надежную статистику.	Питер	2007	\N	\N	\N	lewis_cbo.jpg
72	Зачем нужна архитектура	84x108/32	264	\N	0	0	16	978-5-906264-70-1	Здания нужны, чтобы защищать людей от непогоды, но это не все. У архитектуры есть еще много важных функций, напоминает архитектурный обозреватель New Yorker и Vanity Fair, лауреат Пулитцеровской премии Пол Голдбергер. Она рассказывает нам о нас самих и устройстве окружающего нас мира. Нужно только научиться это видеть.	Strelka Press	2017	Brioni, Fugue	\N	\N	goldberger_why.jpg
47	Веб-дизайн: книга Якоба Нильсена	70x90/16	512	\N	0	0	66	5-93286-004-9	Книга, которую вы держите в руках - самая известная на сегодняшний день книга по веб-дизайну. Ее автор, доктор физических наук Якоб Нильсен - признанный во всем мире специалист в области интерфейсов и удобства эксплуатации, - делится с читателем своими знаниями и опытом. Им был разработан ряд методик, направленных на быстрое и экономичное усовершенствование пользовательского интерфейса, включая эвристическую оценку. Он является обладателем 38 патентов США на разработки, ориентированные, главным образом, на повышение удобства работы пользователей с Интернетом. Книга содержит исчерпывающее руководство по построению эффективного взаимодействия с любым пользователем в любой ситуации: от подготовки информационного наполнения и оформления страниц до упрощения структуры навигации и создания профессиональных сайтов.\nВ книге вы не найдете описаний каких-то конкретных программ и кодов на HTML. Она отвечает на самый главный вопрос дизайна: "Что именно нужно сделать, чтобы посетителям сайта было удобно с ним работать?"	Символ-Плюс	2000	\N	\N	Библиотека дизайнера	nilsen_webdesign.jpg
23	Компиляторы: принципы, технологии и инструментарий	70x100/16	1184	\N	0	0	39	978-5-8459-1349-4	Эта книга, как и предыдущее издание, начинается с изложения основных принципов разработки компиляторов, включая детальное рассмотрение лексического и синтаксического анализа и генерации кода. Особенностью данного издания является широкое освещение вопросов оптимизации кода, в том числе для работы в многопроцессорных системах.\nСтрогость изложения материала смягчается большим количеством практических примеров. Написание компиляторов охватывает такие области знаний, как языки программирования, архитектура вычислительных систем, теория языков, алгоритмы и технология создания программного обеспечения. Помочь в освоении этих технологий и соответствующего инструментария и призвана данная книга. Несмотря на ее учебную ориентацию - в первую очередь, она предназначена для студентов и преподавателей соответствующих специальностей - книга будет полезна всем, кто работает над созданием компиляторов или просто интересуется данной темой.	Вильямс	2011	Times	2	\N	aho_compilers.jpg
86	Эволюция человека. В 2 кн. Кн. 2. Обезьяны, нейроны и душа	60x90/16	512	\N	0	0	24	978-5-17-078089-1	Новая книга Александра Маркова - это увлекательный рассказ о происхождении и устройстве человека, основанный на последних исследованиях в антропологии, генетике и эволюционной психологии. Двухтомник "Эволюция человека" отвечает на многие вопросы, давно интересующие человека разумного. Что значит - быть человеком? Когда и почему мы стали людьми? В чем мы превосходим наших соседей по планете, а в чем - уступаем им? И как нам лучше использовать главное свое отличие и достоинство - огромный, сложно устроенный мозг? Один из способов - вдумчиво прочесть эту книгу.\nАлександр Марков - доктор биологических наук, ведущий научный сотрудник Палеонтологического института РАН. Его книга об эволюции живых существ "Рождение сложности" (2010) стала событием в научно-популярной литературе и получила широкое признание читателей.	АСТ	2017	OriginalGaramondC, MetaC	\N	\N	markov_human2.jpg
67	Архитектура книги	60x90/16	208	\N	0	0	42	978-5-9901107-6-2	Дизайн книги - самая интересная, но и самая сложная область графического дизайна. Елена Герчук занимается искусством книжного дизайна всю жизнь - как художник, как журналист и как преподаватель.\nВ книге нет готовых рецептов: вместо них автор погружает читателя в тонкости и хитрости профессии, рассказывая, как читать авторский текст, как выбрать шрифт, предпочесть ли обложку или переплет, куда девать картинки и даже как общаться с редактором. Елена Герчук полагает, что дизайнер, работая над книгой, может позволить себе не "выполнить заказ", а придумать книгу с начала до конца.\n"Архитектура книги" может быть использована как учебник для студентов ВУЗов по специальности "Графический дизайн", а может стать хорошим дополнением к уже полученным по этой специальности знаниям.	IndexMarket	2011	Charter	\N	\N	gerchuk_arch.jpg
76	Мозг рассказывает. Что делает нас людьми	70x100/16	422	\N	0	0	30	978-5-904946-35-7	Непостижимые загадки (как человек может хотеть ампутировать себе руку? почему рисунки аутичного ребенка превосходят по своему мастерству рисунки Леонардо? что такое чувство прекрасного? откуда берется в нас сострадание? как может человечество передавать культуру от поколения к поколению? что породило речь? где живет самосознание?) находят свое объяснение на уровне нейронов мозга - благодаря простым и гениальным экспериментам B. C. Рамачандрана. Он великий ученый современности, но у него еще и искрометное чувство юмора - и вот вам, пожалуйста, блестящее повествование о странном человеческом поведении и работе мозга.\nСамые последние достижения науки о мозге. Где в мозге кроется то, что делает человека человеком?\nВ. C. Рамачандран назван одним из ста самых выдающихся людей XX века.	Карьера Пресс	2012	GaramondC	\N	\N	ramachandran_brain.jpg
65	О шрифте	60x90/16	192	\N	0	0	22	5-98695-016-x	Фредерик Гауди (1865-1947), американский дизайнер шрифта, однажды сказал: "Набирать строчными вразрядку - все равно, что красть овец". Для большинства людей это замечание лишь подтверждает наличие таинственного мира шрифтов со своей терминологией и сложными правилами. Об этом говорят и тысячи шрифтов, которые кажутся похожими друг на друга. При этом никто не объясняет, что такое шрифт и как им пользоваться.\nПоэтому Эрик Шпикерман обобщил своде многолетний опыт в области типографики и создал уникальное и живое руководство, в котором показано, что шрифтом легко пользоваться, его легко понять, и что в умелых руках шрифт становится мощным инструментом коммуникации.\nВам не потребуется никаких предварительных знаний в области типографики, чтобы получить удовольствие от чтения этой книги. Не имеют значения также тип вашего компьютера, его программное обеспечение, род ваших занятий, потому что хороший шрифт преодолевает любые технические и профессиональные ограничения.\nЭто перевод второго издания этой классической книги, затрагивающей новые шрифтовые технологии, современные шрифты, а также проблемы выбора шрифтов для Web-дизайна, электронной почты и экранов всех размеров.	ПараТайп	2005	Octava, FreeSet	\N	\N	spiekermann_type.jpg
73	Смерть и жизнь больших американских городов	60x90/16	512	\N	0	0	15	978-5-98379-185-5	Самая влиятельная книга в истории урбанистики написана не архитектором или градостроителем, а журналистом и городским активистом - патриот Гринвич-Виллидж, Джейн Джекобс зарабатывала статьями об архитектуре и боролась против новой застройки Манхэттена. В "Смерти и жизни больших американских городов" были впервые сформулированы аргументы против городского планирования, руководствующегося абстрактными идеями и игнорирующего повседневную жизнь горожан. По мнению Джекобс, живой и разнообразный город, основанный на спонтанном порядке и различных механизмах саморегулирования, куда более пригоден для жизни, чем реализация любой градостроительной теории, сколь бы продуманной она ни выглядела.	Новое издательство	2015	Figgins Sans, Scotch Micro	2	Библиотека свободы	jacobs_deathlive.jpg
56	Искусство программирования, том 4, А. Комбинаторные алгоритмы, часть 1	70x100/16	960	\N	0	0	22	978-5-8459-1744-7	\N	Вильямс	2013	LH	\N	\N	knuth_art4a.jpg
38	Мифический человеко-месяц или как создаются программные системы	70x90/16	304	\N	0	0	50	5-93286-005-7	Эта книга - юбилейное (дополненное и исправленное) издание своего рода библии для разработчиков программного обеспечения во всем мире, написанное Бруксом еще в 1975 году. Тогда же книга была издана на русском языке и давно уже стала библиографической редкостью. В США полагают, что без прочтения книги Брукса не может состояться ни один крупный руководитель программного проекта.	Символ-Плюс	2001	\N	\N	Профессионально	brooks_myth.jpg
96	ДНК. История генетической революции	76x100/16	512	\N	0	0	24	978-5-4461-0549-6	Познакомьтесь с историей генетической революции, рассказанной Джеймсом Д. Уотсоном, лауреатом Нобелевской премии. Гениальный ученый отправляет нас в величайшее научное путешествие, охватывающее все вехи генетической революции - от открытия двойной спирали до открытий последнего десятилетия.\nОткрытие человечеством двойной спирали ДНК по значимости можно сравнить только со свершениями эпохи Просвещения. Естественный отбор все еще действует, но генная терапия уже стала реальностью. Что ждет нас дальше?\nПрактически не осталось областей науки и деятельности, которые в той или иной степени не были бы связаны с генетикой: редактирование генов, эпигенетика, агрохимия, геномика и исследования рака - только вершина айсберга.	Питер	2019	\N	\N	New Science	watson_dna.jpg
94	Ружья, микробы и сталь: история человеческих сообществ	76x100/32	768	\N	0	0	23	978-5-17-101162-8	Почему европейская, а позже и евро-атлантическая цивилизация добились самых грандиозных успехов в истории человечества?\nПочему именно Европа, сначала самостоятельно, а позднее - вместе с Соединенными Штатами Америки, создала тот мир, в котором мы живем сейчас?\nЧто предопределило мировую гегемонию европейского мировоззрения - промышленность, сила оружия или нечто иное?\nИ какое влияние на мировоззрение не только отдельного человека, но и целых народов и даже рас оказывает окружающая среда?\nОбо всем этом и многом другом рассуждает в своей книге Джаред Даймонд – автор, удостоенный Пулитцеровской премии.	АСТ	2018	Newton	\N	Эксклюзивная классика	diamond_guns.jpg
39	Человеческий фактор: успешные проекты и команды	70x90/16	256	\N	0	0	27	5-93286-061-8	Книга Тома Демарко и Тимоти Листера "Человеческий фактор. Успешные проекты и команды" - перевод 2-го издания всемирно известного бестселлера об управлении проектами разработки ПО. Первое издание содержало революционные по тем временам (1987 г.) идеи, которые выдержали проверку временем. Авторы скорректировали свои выводы и добавили несколько новых глав. Ценность этой книги в том, что в ней описываются принципы, за каждым из которых стоит реальная история. Все главы содержат наблюдения и новаторские подходы, которые заставят читателей и руководителей увидеть важные вопросы в новом, более разумном ракурсе. С юмором и мудростью, обретенными за годы руководства и консультирования, Демарко и Листер демонстрируют, что сложнейшие проблемы разработки ПО имеют человеческую, а не техническую природу. Они не дают простых ответов, но дают правильные, подкрепленные научными исследованиями. Издание предназначено в первую очередь руководителям проектов, но будет полезно и рядовым программистам.	Символ-Плюс	2005	\N	2	Профессионально	demarco_peopleware.jpg
88	Внутренняя рыба. История человеческого тела с древнейших времен до наших дней	60x90/16	304	\N	0	0	24	978-5-17-093897-1	Почему мы выглядим так, как выглядим? Что общего между человеческими руками и, допустим, крылышками бабочки? И как связаны между собой волосы, молочные железы и сложное устройство нашего уха? Эти вопросы только кажутся праздными - на деле ответы на них позволят нам лучше понять строение человеческого организма, а значит, найти причину его слабостей и болезней. Нил Шубин, профессор анатомии, известный палеонтолог и один из первооткрывателей легендарного тиктаалика (промежуточного звена между рыбами и наземными животными), предлагает читателю совершить увлекательное путешествие к истокам эволюции и посмотреть, как на протяжении трех с половиной миллиардов лет формировалось и совершенствовалось наше тело.	АСТ	2015	MetaNormalC	\N	Элементы	shubin_fish.jpg
14	Чистый код: создание, анализ и рефакторинг	70x100/16	464	\N	0	0	25	978-5-49807-381-1	Даже плохой программный код может работать. Однако если код не является "чистым", это всегда будет мешать развитию проекта и компании-разработчика, отнимая значительные ресурсы на его поддержку и "укрощение".\nЭта книга посвящена хорошему программированию. Она полна реальных примеров кода. Мы будем рассматривать код с различных направлений: сверху вниз, снизу вверх и даже изнутри. Прочитав книгу, вы узнаете много нового о коде. Более того, вы научитесь отличать хороший код от плохого. Вы узнаете, как писать хороший код и как преобразовать плохой код в хороший.\nКнига состоит из трех частей. В первой части излагаются принципы, паттерны и приемы написания чистого кода; приводится большой объем примеров кода. Вторая часть состоит из практических сценариев нарастающей сложности. Каждый сценарий представляет собой упражнение по чистке кода или преобразованию проблемного кода в код с меньшим количеством проблем. Третья часть книги - концентрированное выражение ее сути. Она состоит из одной главы с перечнем эвристических правил и "запахов кода", собранных во время анализа. Эта часть представляет собой базу знаний, описывающую наш путь мышления в процессе чтения, написания и чистки кода.	Питер	2010	\N	\N	Библиотека программиста	martin_cleancode.jpg
29	Лайла. Исследование морали	84x108/32	575	\N	0	0	61	978-5-17-080469-6	Роман Роберта Персига "Дзэн и искусство ухода за мотоциклом" стал литературной сенсацией, принес писателю культовый статус и международную славу.\nЭта книга, возродившая во второй половине XX века жанр "философского романа-путешествия" века XVIII, и в наши дни не утратила своей актуальности, - напротив, стала ясна ее поистине провидческая сила.\nВ "Лайле" Персиг продолжает развивать тему, начатую первым романом.\nФедр, философ-бунтарь, пытавшийся в романе "Дзэн и искусство ухода за мотоциклом" совместить несовместимые философские течения Запада и Востока, снова отправляется в дорогу - на этот раз не на мотоцикле, а на яхте. Его направляет дерзкая идея создания собственной, личной метафизики, личной теории эволюции. Однако теориям зачастую свойственно разбиваться о реальность - в данном случае, о реальность встречи Федра со странной женщиной...	АСТ	2014	\N	\N	\N	pirsig_lila.jpg
46	Дизайн привычных вещей	84x108/32	384	\N	0	0	29	5-8459-0872-8	В своей повседневной жизни человек сталкивается с массой вещей, ставших для него привычными: двери, выключатели, водопроводные краны, клавиатуры компьютеров и т. п. Далеко не все эти изделия сконструированы таким образом, чтобы облегчить потребителю пользование ими. Автор книги "Дизайн привычных вещей" в увлекательной форме анализирует данный феномен, приводя разнообразнейшие примеры дизайнерских просчетов.\nКнига будет интересна как профессиональным дизайнерам и психологам, так и любому вдумчивому читателю.	Вильямс	2006	PetersburgC	\N	\N	norman_everyday.jpg
19	Алгоритмы и структуры данных	60x90/16	352	\N	0	0	32	5-7490-0065-1	Книга известного швейцарского специалиста посвящена изложению фундаментальных принципов построения эффективных и надежных программ. В ней содержатся также описание и анализ основных алгоритмов. Изложение ведется с использованием языка Модула-2, что, однако, не снижает ценность излагаемого материала для пользователей других языков программирования.\nДля настоящего издания текст заново сверен с оригиналом; в нем исправлены замеченные опечатки.	Невский Диалект	2001	\N	\N	Библиотека программиста	wirth_algo.jpg
25	Структура и интерпретация компьютерных программ	70x100/16	608	\N	0	0	19	978-5-98227-708-4	Книга посвящена описанию различных систем программного синтаксиса, анализу перехода от набора алгоритмов к программному коду. Значительное место уделяется обсуждению набора "элементарных программ", использующихся в качестве элементов конструкции программ более высоких уровней сложности, оптимизации соотношения их "веса" и эффективности. Особое внимание авторы уделяют анализу проблемы взаимодействия компьютера как физического объекта и программного кода, обеспечивающего информационную составляющую вычисления.\nКнига будет полезна всем, кому приходится иметь дело с программированием, в том числе и в гуманитарных областях знания.	Добросвет	2010	\N	\N	\N	abelson_prog.jpg
13	Занимательное программирование. Базы данных. Манга	70x90/16	238	\N	0	0	45	978-5-97060-044-3	У принцессы Руруны и Кейна возникла проблема: в их торгующей фруктами империи царит неразбериха из-за противоречивых данных, и поэтому дыни подменяются яблоками и клубникой, что вызывает большие трудности в работе. И что же им делать? Конечно же, построить реляционную базу данных, и поможет им в этом Тико, чудесная фея баз данных. Она покажет Руруне и Кейну, как создать базу данных, которая поможет управлять продажами, реализацией товара и его экспортом. Вы узнаете, как работает база данных, и поймёте значение таких терминов, как схемы, ключи, нормализация и транзакции.\nЕсли у вас голова идёт кругом, когда речь заходит о базах данных, или же вы просто заплутали в лабиринте чисел и данных, которые, как вам кажется, неподвластны контролю, присоединяйтесь к Руруне и Кейну.	ДМК Пресс	2015	\N	\N	Образовательная манга	takahashi_manga.jpg
75	Об интеллекте	70x100/16	240	\N	0	0	31	978-5-8459-1139-1	В книге Об интеллекте Джефф Хокинс представляет революционную теорию на стыке нейробиологии, психологии и кибернетики и описывающую систему "память–предсказание" как основу человеческого интеллекта. Автор отмечает, что все предшествующие попытки создания разумных машин провалились из-за фундаментальной ошибки разработчиков, стремившихся воссоздать человеческое поведение, но не учитывавших природу биологического разума. Джефф Хокинс предполагает, что идеи, сформулированные им в книге Об интеллекте, лягут в основу создания истинного искусственного интеллекта — не копирующего, а превосходящего человеческий разум. Кроме этого, книга содержит рассуждения о последствиях и возможностях создания разумных машин, взгляды автора на природу и отличительные особенности человеческого интеллекта.\nКнига рекомендуется всем, кого интересует устройство человеческого мозга и принципы его функционирования, а также тем, кто занимается проблемами разработки искусственного интеллекта.	Вильямс	2007	Times	\N	\N	hawkins_intelligence.jpg
33	Программист-прагматик. Путь от подмастерья к мастеру	70x100/16	270	\N	0	0	31	5-85582-213-3	Находясь на переднем крае программирования, книга "Программист-прагматик" абстрагируется от всевозрастающей специализации и технических тонкостей разработки программ на современном уровне, чтобы исследовать суть процесса - требования к работоспособной и поддерживаемой программе, приводящей пользователей в восторг. Книга охватывает различные темы - от личной ответственности и карьерного роста до архитектурных методик, придающих программам гибкость и простоту в адаптации и повторном использовании.	Лори	2007	\N	\N	Библиотека программиста	hunt_pragmatic.jpg
58	Компьютерная типография	70x100/16	668	\N	0	0	28	5-03-003361-0	Сборник работ Д. Кнута, написанных им за время работы над созданием всемирно известных систем TeX и METAFONT, в который вошли также статьи последних лет по этой тематике. Книга состоит из 34 глав, разделенных условно на три части: TeX и относящиеся к нему темы; METAFONT и родственные вопросы; TeX и METAFONT в историческом аспекте. Представлен богатый иллюстративный материал и приводятся листинги программ.\nКак и во всех книгах Д. Кнута, весьма серьезные вопросы излагаются просто и увлекательно, что, учитывая междисциплинарную направленность книги, делает ее доступной для специалистов в разных областях науки.\nКнига представляет интерес для научных работников всех специальностей, самостоятельно готовящих свои работы к публикации, для специалистов в области информатики и издательских систем, а также для математиков, интересующихся нестандартными приложениями.	Мир	2003	Computer Modern	\N	Библиотека издательских технологий	knuth_typo.jpg
52	Интерфейс: новые направления в проектировании компьютерных систем	70x90/16	272	\N	0	0	23	5-93286-030-8	Это уникальное руководство по разработке интерактивных систем, отражающее опыт и взгляды Джефа Раскина, создателя проекта Apple Macintosh, должен прочитать каждый, кто задумывается об интерфейсе.\nСейчас много говорят об эффективности современных подходов к разработке интерфейсов. Раскин же демонстрирует, что многие из них ведут в тупик, и для создания компьютеров, с которыми было бы проще работать, требуются совершенно новые принципы разработки. Он объясняет, как осуществить эти необходимые сегодня изменения, и высказывает нестандартные идеи, демонстрируя дальновидность и способность к практическому взгляду на вещи. Эта книга, рассказывающая о научном подходе к разработке интерфейсов, может быть полезна как для создателей программного обеспечения, так и для руководителей проектов.	Символ-Плюс	2003	\N	\N	\N	raskin_interface.jpg
28	Дзэн и искусство ухода за мотоциклом. Исследование ценностей	84x108/32	476	\N	0	0	18	978-5-17-073165-7	Одно из самых ярких и необычных произведений англоязычной литературы ХХ века, вошедшее в список 50-ти культовых книг всех времен и народов по версии "Daily Telegraph".\nОно принесло Роберту Пёрсигу статус знакового писателя своего поколения. О нем писали статьи, его обсуждали, о нем спорили. Оно попросту не имеет себе аналогов в современной литературе.\n.Речь идет о книге "Дзэн и искусство ухода за мотоциклом", возродившей во второй половине XX века жанр "философского романа-путешествия" века XVIII.\nВ романе Роберта Пёрсига необычно все - даже имя главного героя, философа-мотоциклиста, сразу отсылает читателя к теме "Диалогов" Платона и его идеи познания истины в спорах. Но еще более нестандартна сама тема романа: мы живем в рациональное время, и изменить этого нам не дано. Однако как совместить рационализм времени с идеализмом творческого начала? Возможно, помогут поиски новой философской теории, объединяющей в себе традиции Запада и Востока?..	АСТ	2014	\N	\N	\N	pirsig_zen.jpg
42	UNIX. Программное окружение	70x100/16	416	\N	0	0	45	5-93286-029-4	Книга представляет собой введение в программное окружение UNIX и адресована тем, кто хочет научиться программировать с помощью всех тех инструментов, которые поставляются с операционной системой. Рассматривается вход в систему, работа с файлами (cat, mv, cp, rm) и каталогами (cd, mkdir, ...), основы окружения (переменные, маски), фильтры (grep, sed, awk), программирование оболочки (циклы, сигналы, аргументы, стандартный ввод-вывод), введение в системные вызовы (read, write, open, creat, ...), введение в программирование с использованием lex, уасс и make, работа с документацией с помощью troff, tbl и eqn. Приводимые примеры не придуманы специально для этой книги, - некоторые из них впоследствии стали частью комплекта программ, используемых каждый день. Программы написаны на Си. Предполагается, что читатель знает или хотя бы изучает этот язык.\nПрочтение этой книги как новичками, так и опытными пользователями поможет понять, как сделать работу с системой эффективной и приносящей удовольствие.	Символ-Плюс	2003	\N	\N	High Tech	kp_unix.jpg
83	Рождение сложности. Эволюционная биология сегодня: неожиданные открытия и новые вопросы	60x90/16	527	\N	0	0	22	978-5-17-084031-1	Как зародилась и по каким законам развивалась жизнь на нашей планете? Что привело к формированию многоклеточных организмов? Как возникают и чем обусловлены мутации, приводящие к изменениям форм жизни? Социологические исследования показывают, что в поисках ответов на эти краеугольные вопросы люди сегодня все реже обращаются к данным науки, предпочитая довольствоваться поверхностными и зачастую неверными объяснениями, которые предлагают телевидение и желтая пресса. Книга доктора биологических наук, известного палеонтолога и популяризатора науки Александра Маркова - попытка преодолеть барьер взаимного непонимания между серьезными исследователями и широким читателем. "Рождение сложности" - это одновременно захватывающий рассказ о том, что происходит сегодня на переднем крае биологической науки, и в то же время - серьезная попытка обобщить и систематизировать знания, накопленные человечеством в этой области. Увлекательная и популярная книга Александра Маркова в то же время содержит сведения, которые могут заинтересовать не только широкого читателя, но и специалистов.	АСТ	2014	OriginalGaramondC	\N	Элементы	markov_complexity.jpg
78	(Не)совершенная случайность. Как случай управляет нашей жизнью	84x108/32	352	\N	0	0	14	978-5-904584-56-6	В книге "(Не)совершенная случайность. Как случай управляет нашей жизнью" Млодинов запросто знакомит всех желающих с теорией вероятностей, теорией случайных блужданий, научной и прикладной статистикой, историей развития этих всепроникающих теорий, а также с тем, какое значение случай, закономерность и неизбежная путаница между ними имеют в нашей повседневной жизни.\nЭта книга - отличный способ тряхнуть стариной и освежить в памяти кое-что из курса высшей математики, истории естественнонаучного знания, астрономии и статистики для тех, кто изучал эти дивные дисциплины в вузах; понятно и доступно изложенные основы теории вероятностей и ее применимости в житейских обстоятельствах (с многочисленными примерами) для тех, кому не посчастливилось изучать их специально; наконец, профессиональный и дружелюбный подсказчик грызущим гранит соответствующих наук в данный момент.	Livebook	2013	\N	3	\N	mlodinow_drunkard.jpg
55	Искусство программирования, том 3. Сортировка и поиск	70x100/16	832	\N	0	0	32	5-8459-0082-4	Во втором издании третьего тома содержится полный обзор классических алгоритмов сортировки и поиска. Представленная в нем информация дополняет приведенное в первом томе обсуждение структур данных. Автор рассматривает принципы построения больших и малых баз данных, а также внутренней и внешней памяти. В книге приведена подборка тщательно проверенных компьютерных алгоритмов и представлен анализ их эффективности. Кроме того, специальный раздел посвящен методам оптимальной сортировки и описанию новой теории перестановки и универсального хеширования.	Вильямс	2000	LH	2	\N	knuth_art3.jpg
69	Всеобщая история архитектуры	84x108/16	704	\N	0	0	13	978-5-699-55587-1	Успех "Всеобщей истории архитектуры" французского инженера путей сообщения, бывшего адъюнкт-профессора Политехнической школы Огюста Шуази (1841-1909) объяснялся несколькими причинами. Во-первых, широтой осуществленного автором замысла: в книгах представлены этапы развития архитектуры доисторической эпохи; государств Древнего Востока, античности, включая Индию, Китай, Японию; европейских стран в Средние века, новое и новейшее время. Во-вторых, научной добросовестностью исследователя, который скрупулезно описал постройки, их отдельные части, материалы и способы их применения, строительную технику и на основании непосредственного многолетнего личного опыта сделал смелые предположения, дав почву для размышления над своими архитектурными гипотезами другим ученым, идущим за ним. Наконец, труд Шуази - это взгляд профессионала на историю становления и развития человеческого общества сквозь призму взаимопроникновения различных архитектурных приемов и форм. В настоящее полное издание включены оба тома "Всеобщей истории архитектуры" О. Шуази. Ясный и легкий язык изложения, авторские рисунки и подрисуночные комментарии делают книгу понятной и интересной для современного читателя.	Эксмо	2012	\N	\N	\N	choisy_architecture.jpg
40	Изучаем редакторы vi и Vim	70x100/16	512	\N	0	0	46	978-5-93286-200-1	На протяжении 30 лет vi оставался стандартом для UNIX и Linux, а эта книга была главным пособием по vi. Однако сейчас UNIX уже не тот, что был 30 лет назад, и книга тоже не стоит на месте. Седьмое издание существенно расширено и включает подробную информацию о Vim - самом популярном клоне vi. Доступный стиль изложения сделал эту книгу классикой. Она незаменима, поскольку знание vi или Vim - обязательное условие, если вы работаете в Linux или UNIX.\nВы познакомитесь как с основами, так и с продвинутыми средствами, такими как интерактивные макросы и скрипты, расширяющие возможности редактора. Вы научитесь быстро перемещаться в vi, использовать буферы, применять глобальную функцию поиска и замены vi, настраивать vi и запускать команды UNIX, использовать расширенные текстовые объекты Vim и мощные регулярные выражения, редактировать в нескольких окнах и писать скрипты в Vim, использовать все возможности графической версии Vim (gvim), применять такие усовершенствования Vim, как подсветка синтаксиса и расширенные теги. Помимо Vim рассматриваются и другие клоны vi: nvi, elvis и vile.	Символ-Плюс	2013	\N	7	\N	robbins_vi.jpg
71	История русской архитектуры	70x100/16	512	\N	0	0	49	\N	В учебнике излагаются главнейшие проблемы истории русской архитектуры с древнейших времен до 1917 года. Рассматриваются наиболее значительные произведении национального зодчества.\nОсвещена народная деревянная архитектура, исстари оказывавшая существенное влияние на формирование монументального зодчества. Приводятся функционально-технические и социальные обоснования художественных особенностей русской архитектуры на разных этапах ее развития, в частности выявляются ее национальные черты и другие прогрессивные свойства. Именно они служат той основой архитектурного наследия, на которую опирается современная советская архитектура.\nВ книге выявлены предпосылки зарождения в зодчестве России XIX - начала XX в. некоторых черт советской архитектуры.	Стройиздат	1984	Таймс	\N	Специальность "Архитектура"	pilavsky_rusarchhist.jpg
4	SQL и реляционная теория: как грамотно писать код на SQL	70x100/16	480	\N	0	0	24	978-5-93286-173-8	Язык SQL распространен повсеместно. Но работать с ним непросто: он сложен, запутан, при написании SQL-команд легко допустить ошибку. Понимание теории, лежащей в основе SQL, - лучший способ гарантировать, что ваш код будет написан правильно, а сама база данных надежна и легко сопровождаема.\nВ предлагаемой книге К. Дж. Дейт - признанный эксперт, начавший заниматься этими вопросами еще в 1970 году - демонстрирует, как применить реляционную теорию к повседневной практике работы с SQL. Автор подробно объясняет различные аспекты этой модели, рассуждает и доказывает, приводит многочисленные примеры использования этого языка в соответствии с реляционной теорией.\nНе будучи привязанным ни к какому конкретному продукту, издание опирается на многолетний опыт исследований и представляет наиболее актуальное на сегодняшний день изложение материала. Всякий, имеющий хоть какой-то опыт использования SQL - от скромного до весьма обширного, - получит от прочтения этой книги немалую пользу и удовольствие.	Символ-Плюс	2010	\N	\N	\N	date_sql.jpg
53	Искусство программирования, том 1. Основные алгоритмы	70x100/16	720	\N	0	0	21	5-8459-0080-8	Первый том серии книг "Искусство программирования" начинается с описания основных понятий и методов программирования. Затем автор сосредоточивается на рассмотрении информационных структур - представлении информации внутри компьютера, структурных связях между элементами данных и способах эффективной работы с ними. Для методов имитации, символьных вычислений, числовых методов и методов разработки программного обеспечения даны примеры элементарных приложений. По сравнению с предыдущим изданием добавлены десятки простых, но в то же время очень важных алгоритмов. В соответствии с современными направлениями исследований был существенно переработан также раздел математического введения.	Вильямс	2000	LH	3	\N	knuth_art1.jpg
74	Глаз, мозг, зрение	70x100/16	239	\N	0	0	31	5-03-001254-0	В книге известного американского нейрофизиолога, лауреата Нобелевской премии, обобщены современные представления о том, как устроены нейронные структуры зрительной системы, включая кору головного мозга, и как они перерабатывают зрительную информацию. При высоком научном уровне изложения книга написана простым, ясным языком, прекрасно иллюстрирована. Она может служить учебным пособием по физиологии зрения и зрительного восприятия.\nДля студентов биологических и медицинских вузов, нейрофизиологов, офтальмологов, психологов, специалистов по вычислительной технике и искусственному интеллекту.	Мир	1990	\N	\N	\N	hubel_eye.jpg
63	Типографика: шрифт, верстка, дизайн	70x100/16	496	\N	0	0	26	5-94157-345-6	Книга посвящена типографике - искусству оформления произведений печати средствами набора и верстки, которое имеет и художественный, и технический аспекты. Рассматриваемые эстетические принципы выбора и применения шрифтов для печатной продукции и экранного представления поддерживаются множеством сведений, правил и тонкостей профессиональной компьютерной верстки, отвечающей современным стандартам. Благодаря обилию иллюстраций и примеров, а также художественному вкусу автора, книга полезна и доступна не только дизайнерам, печатникам и менеджерам полиграфического производства, но и всем, интересующимся вопросами верстки.	БХВ-Петербург	2004	\N	\N	\N	felici_typo.jpg
41	Операционная система UNIX: Курс лекций	60x90/16	288	\N	0	0	17	5-9556-0019-1	В книге приводятся теоретические и когнитивные основания UNIX-подобных операционных систем, а также практические данные, необходимые для дальнейшего самостоятельного освоения как системного, так и прикладного использования UNIX.	Интернет-Университет Информационных Технологий	2009	\N	\N	Основы информационных технологий	gosha_unix.jpg
1	Основы технологий баз данных	70x100/16	240	\N	0	0	23	978-5-94074-820-5	Представлены основы теории баз данных, методы и алгоритмы, применяемые при реализации систем управления базами данных, а также особенности этих методов и алгоритмов, реализованные в СУБД PostgreSQL.\nМатериал книги составляет основу для базового учебного курса и содержит краткий обзор требований и критериев оценки СУБД и баз данных, теоретическую реляционную модель данных, основные конструкции языка запросов SQL, организацию доступа к базе данных PostgreSQL, вопросы проектирования приложений и основные расширения, доступные в системе PostgreSQL.	ДМК Пресс	2019	ПТ Сериф	\N	\N	novikov_dbtech.jpg
37	Человеческий фактор в программировании	70x90/16	384	\N	0	0	28	5-93286-044-8	Хорошее программное обеспечение создается людьми. Так же как и плохое. Именно поэтому основная тема этой книги - не аппаратное и не программное обеспечение, а человеческий фактор в программировании (peopleware). Первое издание "Constantine on Peopleware" признано классическим трудом в области информационных технологий. Новая книга Ларри Константина включает все 52 легендарные статьи из предыдущей книги и 25 новых эссе.\nPeopleware охватывает все аспекты, связанные с ролью людей в разработке программного обеспечения. Это качество и продуктивность, модели и методы, динамика поведения коллектива, руководство проектами, разработка интерфейсов и взаимодействие между человеком и компьютером, психология и процессы мышления. В данное издание включены два новых раздела, посвященных организационной культуре и юзабилити программных продуктов.	Символ-Плюс	2004	\N	\N	Профессионально	constantine_peopleware.jpg
61	Набор и верстка в пакете LaTeX	60x88/16	374	\N	0	0	28	5-9000242-17-x	Книга посвящена популярной издательской системе LaTeX, предназначенной для набора и верстки сложных научно-технических текстов с большим количеством формул, таблиц, диаграмм и пр. Во втором издании обновлен практически весь материал книги и добавлены сведения о работе в новой версии - LaTeX 2e. Кроме того даны 5 новых приложений: это - импорт графики, программа makeindex, шрифты Американского математического общества, макет AMS-LaTeX, и информация о том, где все это можно получить.\n Полезна всем, кто имеет дело с изготовлением на компьютере оригинал-макетов изданий, а также авторам, самостоятельно набирающим на компьютере свои научные работы.	Космосинформ	1995	\N	2	\N	lvovsky_latex.jpg
70	Десять книг об архитектуре	60x90/16	320	\N	0	0	29	978-5-397-04086-0	Настоящая книга содержит трактат римского архитектора и инженера Витрувия, жившего во второй половине I в. до н. э. в годы правления Юлия Цезаря и императора Октавиана Августа. Трактат "Десять книг об архитектуре" представляет собой целую энциклопедию технических наук своего времени, сочетая в себе жанры практического руководства и обобщающего теоретического труда. Более двух тысяч лет этот знаменитый труд переписывался, переводился и комментировался, являясь фундаментом для разработки теории архитектуры во многих странах мира.\nВо второе издание книги были внесены исправления и уточнения, подготовленные выдающимся русским ученым, историком науки В. П. Зубовым (1900-1963) и любезно предоставленные его дочерью М. В. Зубовой.\nКнига адресована архитекторам, историкам науки, культуры и искусства, а также всем интересующимся классическим наследием.	Либроком	2013	\N	\N	Из истории архитектурной мысли	vitruvii.jpg
81	Эгоистичный ген	60x90/16	512	\N	0	0	31	978-5-17-077772-3	Мы созданы нашими генами. Мы, животные, существуем, чтобы сохранить их, и служим лишь машинами, обеспечивающими их выживание. Мир эгоистичного гена - это мир жестокой конкуренции, безжалостной эксплуатации и обмана. Ну а как же акты альтруизма, наблюдаемые в природе: пчелы, совершающие самоубийство, когда они жалят врага, чтобы защитить улей, или птицы, рискующие жизнью, чтобы предупредить стаю о приближении ястреба? Противоречит ли это фундаментальному закону об эгоистичности гена? Ни в коем случае! Докинз показывает, что эгоистичный ген - это еще и хитрый ген. И он лелеет надежду, что вид Homo sapiens - единственный на всем земном шаре - в силах взбунтоваться против намерений эгоистичного гена.\nПеревод сверен по юбилейному английскому изданию 2006 года.	АСТ	2014	OriginalGaramondC	\N	Элементы	dawkins_gene.jpg
20	Практика программирования	60x90/16	381	\N	0	0	33	5-7490-0068-9	Книга написана известнейшими американскими специалистами - авторами многих книг (в том числе переведенных на русский язык) и программистами (разработчиками таких систем, как ОС UNIX, язык программирования Си, язык скриптов AWK и др.). В систематической форме в ней излагаются основанные на многолетнем и разностороннем опыте рекомендации авторов: как надо программировать, как разрабатывать программу, как ее писать, как отлаживать, какие средства выбирать.\nКнига нужна каждому активно работающему программисту и студентам, специализирующимся в создании программного обеспечения. Она может (и должна бы) использоваться в качестве учебного пособия по соответствующим курсам.	Невский Диалект	2001	\N	\N	Библиотека программиста	kp_practice.jpg
93	Агрессия, или Так называемое зло	76x100/32	416	\N	0	0	45	978-5-17-105325-3	Конрад Лоренц - выдающийся зоолог и зоопсихолог, философ и психолог, лауреат Нобелевской премии по физиологии и медицине.\n"Агрессия, или Так называемое зло" - одна из самых известных и глубоких его работ, в которой он рассматривает агрессию на примере самых разных биологических видов - аквариумных рыбок, крыс, гусей, волков и, наконец, людей и приходит к парадоксальному выводу: глубокая личная привязанность возникает лишь в тех сообществах, где наблюдается высокий уровень агрессии. Где нет агрессии - нет крепкой дружбы и настоящей любви. Так можно ли считать агрессию злом, а подавление агрессии - благом? И сможет ли человечество развиваться в случае полного отказа от агрессии в отношении себе подобных?..	АСТ	2018	Newton	\N	Эксклюзивная классика	lorenz_agression.jpg
26	Читаемый код, или Программирование как искусство	70x100/16	208	\N	0	0	19	978-5-459-01188-3	Любому программисту доводилось видеть код, который настолько неаккуратен и так пестрит ошибками, что от его чтения начинает болеть голова. За пять лет авторы этой книги проанализировали сотни примеров "плохого" кода (в основном - собственного), пытаясь определить, чем плох тот или иной код и как его можно улучшить. К какому выводу они пришли? Необходимо писать такой код, который читатель сможет понять максимально быстро, причем, даже если этот читатель - сам создатель этого кода.\nВ данной книге рассматриваются базовые принципы и практические методы, которые можно применять всякий раз при написании кода. В каждой главе на примере несложных образцов кода, написанного на разных языках программирования, изучается отдельный аспект создания кода и демонстрируется, как сделать код простым для понимания.	Питер	2012	\N	\N	\N	boswell_readable.jpg
85	Эволюция человека. В 2 кн. Кн. 1. Обезьяны, кости и гены	60x90/16	464	\N	0	0	19	978-5-17-078088-4	Новая книга Александра Маркова - это увлекательный рассказ о происхождении и устройстве человека, основанный на последних исследованиях в антропологии, генетике и эволюционной психологии. Двухтомник "Эволюция человека" отвечает на многие вопросы, давно интересующие человека разумного. Что значит - быть человеком? Когда и почему мы стали людьми? В чем мы превосходим наших соседей по планете, а в чем - уступаем им? И как нам лучше использовать главное свое отличие и достоинство - огромный, сложно устроенный мозг? Один из способов - вдумчиво прочесть эту книгу.\nАлександр Марков - доктор биологических наук, ведущий научный сотрудник Палеонтологического института РАН. Его книга об эволюции живых существ "Рождение сложности" (2010) стала событием в научно-популярной литературе и получила широкое признание читателей.	АСТ	2017	OriginalGaramondC, MetaC	\N	\N	markov_human1.jpg
62	Основы стиля в типографике	60x100/16	432	\N	0	0	20	5-94056-014-8	Эта книга, впервые изданная в 1992 году, быстро стала профессиональным бестселлером и остается им в мире англоязычной типографики до сих пор. Ее авторитет был сразу признан в типографическом сообществе как приверженцами классики, так и сторонниками авангарда. Она переиздавалась с исправлениями и дополнениями много раз, была пере­ведена на итальянский и греческий языки. В 1996 году книга была переработана и существенно расширена.\nНастоящее издание - это перевод пятой версии второй редакции, доработанной и законченной автором в 2002 году. Русский перевод снабжен примечаниями редактора, делающими некоторые детали более понятными для российского читателя. 	Дмитрий Аронов	2006	ITC Charter, Humanist 531	\N	\N	bringhurst_style.jpg
95	Кратчайшая история времени	66x90/16	180	\N	0	0	42	978-5-367-02274-2	Природе пространства и времени, происхождению Вселенной посвящена эта научно-популярная книга знаменитого английского астрофизика Стивена Хокинга, написанная в соавторстве с популяризатором науки Леонардом Млодиновым. Это новая версия всемирно известной "Краткой истории времени", пополненная последними данными космологии, попытка еще проще и понятнее изложить самые сложные теории.	Амфора	2014	\N	\N	\N	hawking_brieferhistory.jpg
6	Рефакторинг SQL-приложений	70x100/16	336	\N	0	0	31	978-5-93286-145-5	Когда поднимается вопрос рефакторинга кода, специалист может быть уверен, что либо возникла серьезная проблема, либо предполагается, что она проявится в ближайшее время. Как правило, при этом известно, что следует улучшить в плане функциональности, но прежде необходимо понять природу проблемы.\nВ книге делается попытка дать реалистичный и честный обзор методов усовершенствования приложений SQL и определить рациональную концепцию для тактических маневров. Часто рефакторинг напоминает безумный поиск быстрых побед и эффектных усовершенствований, которые можно вписать в бюджет и сохранить голову на плечах. Но разумное и систематическое применение правильных принципов может привести к впечатляющим результатам. Эта книга поможет выработать правильную тактику и оценить перспективы различных решений.\nКнига предназначена для профессионалов в области информационных технологий, разработчиков, менеджеров проектов, служб поддержки, администраторов баз данных и специалистов по настройке, которым приходится принимать участие в операциях по спасению приложений со значительным объемом кода управления базами данных.	Символ-Плюс	2009	\N	\N	\N	faroult_refactor.jpg
10	Oracle для профессионалов. Книга 2. Расширение возможностей и защита	70x100/16	816	\N	0	0	49	5-93772-159-4	Выход в свет в конце прошлого года этой книги издательства Wrox стал эпохальным событием: впервые доходчиво и исчерпывающе раскрыты основные особенности архитектуры СУБД Oracle, принципиально отличающие ее от других популярных систем управления базами данных. Причем подробно описаны и проиллюстрированы множеством примеров именно те возможности, средства и особенности Oracle, которые обеспечивают разработку эффективных приложений для этой СУБД и ее успешную эксплуатацию.\nАвтор книги, Том Кайт, давно работает с СУБД Oracle, создает приложения и администрирует базы данных. Многие годы он профессионально занимается решением проблем, возникающих при использовании СУБД Oracle у администраторов и разработчиков по всему миру. На специализированном сайте корпорации Oracle (http://asktom.oracle.com) Том Кайт отвечает на десятки вопросов в день. Он не только делится знаниями, но и умело подталкивает читателя к самостоятельным экспериментам. Следуя по указанному им пути, становишься Профессионалом.\nЕсли вы приступаете к изучению СУБД Oracle, - начните с этой книги. Если вы опытный разработчик приложений или администратор баз данных Oracle, - прочтите ее и проверьте, достаточно ли глубоко вы знаете эту СУБД и умеете ли использовать ее возможности. Вы найдете в книге десятки советов, описаний приемов и методов решения задач, о которых никогда не подозревали.	ДиаСофтЮП	2005	Таймс	3	\N	kyte_oracle_2.jpg
45	Лекции лауреатов премии Тьюринга	60x88/16	560	\N	0	0	35	5-03-002130-2	Книга включает лекции лауреатов премии Тьюринга, которой отмечаются выдающиеся достижения в области программирования, вычислительной математики, математического обеспечения ЭВМ. Среди лауреатов - известные специалисты: Э. Дейкстра (Нидерланды), Д. Кнут (США), Ч. Хоар (Великобритания), Н. Вирт (Швейцария) и др., книги которых переводились на русский язык и известны советским читателям. Ряд лекции сопровождается послесловиями авторов, отражающими современное состояние и перспективы исследований.	Мир	1993	Литературная	\N	\N	turing20.jpg
43	Машина играет в шахматы	84x108/32	208	\N	0	0	12	\N	Книга посвящена одной из проблем искусственного интеллекта - созданию для ЭВМ программ, играющих в шахматы. Основной принцип таких программ - перебор позиций - является частным случаем общего метода перебора, широко применяемого при решении задач дискретной математики.\nАвторы книги - специалисты в области программирования, создатели шахматной программы "Каисса" - первого чемпиона мира среди машин.	Наука	1983	Обыкновенная	\N	Наука и технический прогресс	adelson_chess.jpg
30	Deadline. Роман об управлении проектами	60x90/16	288	\N	0	0	19	5-9626-0132-7	Возможно, встречаются еще менеджеры, которые полагают, что управление - это собрания, программы обучения и повышения качества продукции и разнообразные отчеты. Однако в наше время стало очевидным, что управление проектами - это прежде всего работа с людьми.\nКак выбрать из множества кандидатов нужного вам человека? Каково оптимальное число людей в команде на разных этапах проекта? Как можно оптимизировать работу, если перед вами поставлены жесткие сроки? Как определять и решать конфликты? Как уволить человека, не обидев его? Какими качествами должен обладать хороший руководитель? Обо всем этом вы узнаете из данной книги, которая к тому же представляет собой не сухой научный труд, а... увлекательный приключенческий роман!	Вершина	2006	\N	\N	\N	demarco_deadline.jpg
8	Oracle. Оптимизация производительности	70x100/16	464	\N	0	0	44	5-93286-078-2	Оптимизация производительности БД Oracle считается очень сложной задачей, подвластной лишь черной магии. Успехи настройки нередко случайны и достигаются скорее за счет интуиции, комбинируемой с методом проб и ошибок. Известные исследователи Oracle, Миллсап и Хольт, в практическом руководстве "Oracle. Оптимизация производительности" подробно описывают надежный, воспроизводимый и четкий метод выявления проблем производительности системы, позволяющий с уверенностью сказать, в чем причина любой из них.\nКлючом к методу Миллсапа и Хольта является тот факт, что программное обеспечение БД Oracle оснащено инструментами, способными предоставить информацию о том, на что тратится время при обработке запросов. Метод включает три этапа: выбор пользовательской операции, оптимизация которой наиболее важна с точки зрения бизнеса; сбор корректно выбранных данных расширенной трассировки SQL, относящихся к данной операции, и выявление по этим данным места и причин перерасхода времени; поиск наиболее эффективного способа повышения производительности (уменьшения времени отклика) данной операции.\nАвторы показывают, как применять метод, и объясняют, почему он эффективен. Метод способен помочь не только выявить проблемы производительности, но и оценить рост производительности при увеличении количества и/или мощности процессоров или добавлении оперативной памяти. Издание предназначено администраторам и разработчикам БД Oracle.	Символ-Плюс	2006	\N	\N	\N	millsap_tuning.jpg
77	Евклидово окно. История геометрии от параллельных прямых до гиперпространства	84x108/32	384	\N	0	0	48	978-5-904584-60-3	Мы привыкли воспринимать как должное два важнейших природных умений человека - воображение и абстрактное мышление, а зря: "Евклидово окно" рассказывает нам, как происходила эволюция нашей способности представлять то, чего мы не видим воочию.\nЭта книга - восхитительная смесь научного авторитетного труда и веселого балагурства, она превращает классические теории и понятия геометрии в доступные, поражающие воображение истории.\nСпасибо Млодинову: не нужно быть математиком или физиком, чтобы постичь загадки пространства и поразиться великолепию мироустройства.	Livebook	2013	\N	\N	\N	mlodinow_euclid.jpg
50	Психбольница в руках пациентов. Алан Купер о об интерфейсах: почему высокие технологии сводят нас с ума и как восстановить душевное равновесие	70x90/16	336	\N	0	0	19	978-5-93286-168-4	Как противостоять натиску компьютерных технологий, проникающих в нашу жизнь с ужасающей скоростью? Наши телефоны, фотокамеры, автомобили - все, что нас окружает, автоматизируется, программируется, создается людьми, которые, стремясь получить выгоду от применения микросхем, уклонились от своей прямой обязанности - делать эти продукты простыми в применении.\nИ это не преувеличение, это реальность. Наша жизнь все больше концентрируется вокруг превратностей, странностей, решений и катастроф индустрии высоких технологий. Разработчики программ, устройств и технологий думают не так, как мы. Облеченные полномочиями исполнительные лица ни на что не влияют в мире высоких технологий - здесь всем заправляют инженеры. Мы разрешили пациентам завладеть психбольницей. Алан Купер предлагает решение проблемы: программированию должно предшествовать проектирование взаимодействия с пользователем.	Символ-Плюс	2011	\N	2	Профессионально	cooper_asylum.jpg
87	Логика случая. О природе и происхождении биологической эволюции	60x90/16	527	\N	0	0	32	978-5-227-04982-7	В этой амбициозной книге Евгений Кунин освещает переплетение случайного и закономерного, лежащих в основе самой сути жизни. В попытке достичь более глубокого понимания взаимного влияния случайности и необходимости, двигающих вперед биологическую эволюцию, Кунин сводит воедино новые данные и концепции, намечая при этом дорогу, ведущую за пределы синтетической теории эволюции. Он интерпретирует эволюцию как стохастический процесс, основанный на заранее непредвиденных обстоятельствах, ограниченный необходимостью поддержки клеточной организации и направляемый процессом адаптации. Для поддержки своих выводов он объединяет между собой множество концептуальных идей: сравнительную геномику, проливающую свет на предковые формы; новое понимание шаблонов, способов и непредсказуемости процесса эволюции; достижения в изучении экспрессии генов, распространенности белков и других фенотипических молекулярных характеристик; применение методов статистической физики для изучения генов и геномов и новый взгляд на вероятность самопроизвольного появления жизни, порождаемый современной космологией.\nЛогика случая демонстрирует, что то понимание эволюции, которое было выработано наукой XX века, является устаревшим и неполным, и обрисовывает фундаментально новый подход - вызывающий, иногда противоречивый, но всегда основанный на твердых научных знаниях.	Центрполиграф	2014	Ньютон	\N	\N	kunin_chance.jpg
34	Джоэл о программировании и разнообразных и иногда родственных вопросах, которые должны быть интересны разработчикам программного обеспечения, проектировщикам и менеджерам, а также тем, кому посчастливилось или не повезло в каком-то качестве работать с ними	70x90/16	352	\N	0	0	42	5-93286-063-4	Книга представляет собой подборку эссе, опубликованных автором на его сайте http://www.joelonsoftware.com. Талант и глубокое проникновение в суть предмета сделали Джоэла мастером своего дела, а остроумие и едкий юмор принесли сайту скандальную известность среди программистов. Затронуты практически все вообразимые аспекты создания ПО от лучших способов устройства рабочего места программиста до лучших способов написания программного кода. Издание адресовано широкому кругу читателей - и тем, кто собирается руководить программистами, и самим программистам - как приверженцам Microsoft, так и сторонникам открытого кода.	Символ-Плюс	2006	\N	\N	Профессионально	joel_onsoftware.jpg
48	Не заставляйте меня думать	70x100/16	256	\N	0	0	27	5-93286-004-9	Книга посвящена юзабилити веб-сайтов и мобильных приложений. Автор популярно, с примерами и иллюстрациями, объясняет, как сделать сайт или мобильное приложение, которым будет удобно пользоваться всем.	Э	2017	\N	\N	Мировой компьютерный бестселлер	krug_dontmakemethink.jpg
2	Настройка приложений баз данных	70x100/16	240	\N	0	0	18	5-94157-840-7	Описываются методы настройки баз данных и приложений, применяемые при создании высокоэффективных систем. Показывается, как решения, принимаемые на различных этапах создания системы, начиная с определения требований и выбора архитектуры, влияют на итоговый продукт. Детально обсуждаются методы и приемы, обеспечивающие получение высокой эффективности приложения и базы данных, разработки запросов, а также действия по настройке базы данных во время эксплуатации системы.	БХВ-Петербург	2006	\N	\N	\N	novikov_tuning.jpg
11	Основы баз данных	60x90/16	484	\N	0	0	24	978-5-94774-736-2	На современном уровне определяется реляционная модель данных, включая реляционную алгебру и реляционное исчисление. Обсуждается классический подход к проектированию реляционных баз данных на основе принципов нормализации. Описываются основные черты подходов к семантическому моделированию баз данных. Рассматривается модель данных SQL.\nКнига рассчитана на студентов, специализирующихся в области технологий баз данных, специалистов, которые интересуются проблемами проектирования и моделирования баз данных, а также на широкий круг читателей, которые хотели бы с ними разобраться.	Бином	2011	Таймс	\N	Основы информационных технологий	kuznetsov_basics.jpg
49	Веб-дизайн: книга Дмитрия Кирсанова	70x90/16	376	\N	0	0	47	5-93286-003-0	Книга автора бестселлера "Факс-модем: от покупки и подключения до выхода в Интернет" - Дмитрия Кирсанова (www.kirsanov.com) - первый полный курс веб-дизайна на русском языке, написанный профессиональным дизайнером. От теоретических основ визуального дизайна до интернетовских технологий и приемов практической работы над сайтом - все это есть в книге, написанной понятно, подробно и увлекательно. Издание будет полезно не только начинающим создателям сайтов, но и дизайнерам, работающим в более традиционных областях, специалистам по рекламе и маркетингу, художникам, программистам, - и, конечно же, всем творческим и любознательным людям.	Символ-Плюс	1999	\N	\N	Библиотека дизайнера	kirsanov_webdesign.jpg
32	Сначала скажите "нет": секреты профессиональных переговорщиков	60x90/16	272	\N	0	0	18	5-98124-009-1	С непреложной истиной, что на переговорах не бывает партнеров, а есть противники, современный деловой мир, кажется, хорошо знаком. И тем не менее тактических ошибок в переговорном процессе избегать удается немногим. На удочку желанных сильной стороной компромиссов и уступок частенько попадаются неопытные в делах люди. Книга Джима Кэмпа научит вас с достоинством вести и выигрывать переговоры. Причем эта технология применима к любой сфере жизни - не только к бизнесу. Когда нужно противостоять мощному давлению, манипуляциям, отстаивать перед визави свои позиции, инструменты профессионального переговорщика придутся как нельзя кстати. Что бы ни происходило за столом переговоров, вы должны быть уверены в силе собственной позиции.	Добрая книга	2006	\N	\N	\N	camp_no.jpg
89	В поисках памяти: Возникновение новой науки о человеческой психике	60x88/16	736	\N	0	0	18	978-5-17-104268-4	Автор разъясняет революционные достижения современной биологии и проливает свет на то, как бихевиоризм, когнитивная психология и молекулярная биология породили новую науку. Книга начинается с воспоминаний о детстве в оккупированной нацистами Вене и описывает научную карьеру Канделя: от его раннего увлечения историей и психоанализом до новаторских работ в области изучения клеточных и молекулярных механизмов памяти, за которые он удостоился Нобелевской премии.	АСТ	2017	MetaNormalC	\N	Элементы	kandel_memory.jpg
15	Ремесло программиста. Практика написания хорошего кода	70x90/16	704	\N	0	0	14	978-5-93286-127-1	Ничто не сравнится по ценности с советами настоящего программиста-профессионала. Книга Питера Гудлифа "Ремесло программиста" написана ясно, практично и занимательно. Она поможет вам перейти на более высокий уровень мастерства программирования и покажет, как писать код, который больше чем "просто работает". Да, вы умеете писать работающий код, но как написать понятный код? Как добиться его надежности и отсутствия ошибок? Смогут ли другие программисты выяснить логику и цель вашего кода? Выдающиеся программисты не просто обладают техническими знаниями - у них есть правильный подход и отношение к программированию.\nПеред вами руководство по выживанию в условиях промышленного производства ПО. Эта книга посвящена тому, чему вас никто не учил: как правильно программировать в реальной жизни. Здесь вы найдете не связанные с конкретными языками рекомендации, полезные всем разработчикам и касающиеся таких проблем, как стиль представления, выбор имен переменных, обработка ошибок, безопасность, эффективность групповой работы, технологии разработки и составление документации.\nЧитатель должен обладать опытом программирования, ибо книга не учит программированию – она учит правильно программировать. Издание будет полезно и студентам старших курсов, знакомым с принципами программирования.	Символ-Плюс	2009	\N	\N	Профессионально	goodliffe_codecraft.jpg
35	Джоэл: о снова программировании. Новые мысли о разнообразных и иногда родственных вопросах, которые должны быть интересны разработчикам программного обеспечения, проектировщикам и менеджерам, а также тем, кому посчастливилось или не повезло в каком-то качестве работать с ними	70x90/16	320	\N	0	0	45	978-5-93286-144-8	Продолжение вышедшего в 2006 году бестселлера "Джоэл о программировании" представляет собой подборку самых популярных статей. Исключительный писательский талант, техническая эрудиция и язвительный ум Джоэла создали ему высочайшую профессиональную репутацию и принесли его сайту скандальную известность.\nВ книге затронуты разнообразные вопросы, касающиеся разработки и проектирования программного обеспечения, управления софтверным бизнесом, эффективного поиска и привлечения высококлассных сотрудников, организации рабочего места и общения с заказчиками. Автор предлагает практические советы как программистам, так и тем, кто руководит их работой.	Символ-Плюс	2009	\N	\N	Профессионально	joel_onsoftware2.jpg
\.
SELECT setval('books_book_id_seq', 96, true);
 
COPY public.authorships (author_id, book_id, seq_num) FROM stdin;
1	1	1
2	1	2
1	2	1
4	3	1
5	4	1
5	5	1
7	6	1
8	6	2
9	7	1
10	8	1
11	8	2
12	9	1
12	10	1
14	11	1
15	12	1
16	12	2
17	13	1
18	14	1
19	15	1
20	16	1
21	17	1
22	18	1
23	18	2
23	19	1
25	20	1
26	20	2
27	21	1
28	21	2
29	22	1
30	22	2
15	22	3
29	23	1
33	23	2
34	23	3
15	23	4
36	24	1
37	24	2
38	25	1
39	25	2
40	25	3
41	26	1
42	26	2
23	27	1
44	27	2
45	28	1
45	29	1
47	30	1
48	31	1
49	32	1
50	33	1
51	33	2
52	34	1
52	35	1
52	36	1
55	37	1
56	38	1
57	39	1
58	39	2
59	40	1
60	40	2
61	40	3
62	41	1
25	42	1
26	42	2
65	43	1
66	43	2
67	43	3
68	43	4
69	44	1
70	45	1
71	45	2
72	45	3
73	45	4
74	45	5
75	45	6
76	45	7
28	45	8
78	45	9
23	45	10
80	45	11
81	45	12
82	45	13
83	45	14
84	45	15
85	45	16
86	45	17
87	45	18
88	45	19
89	45	20
90	45	21
91	45	22
92	45	23
93	45	24
94	46	1
95	47	1
96	48	1
97	49	1
98	50	1
98	51	1
100	51	2
101	51	3
102	52	1
72	53	1
72	54	1
72	55	1
72	56	1
72	57	1
72	58	1
109	59	1
110	60	1
111	60	2
112	60	3
113	61	1
114	62	1
115	63	1
116	64	1
117	65	1
118	66	1
119	67	1
120	68	1
121	69	1
122	70	1
123	71	1
124	71	2
125	71	3
126	72	1
127	73	1
128	74	1
129	75	1
130	75	2
131	76	1
132	77	1
132	78	1
134	79	1
135	80	1
136	81	1
137	82	1
138	83	1
138	84	1
140	84	2
138	85	1
140	85	2
138	86	1
140	86	2
145	87	1
146	88	1
147	89	1
148	90	1
149	91	1
150	92	1
151	93	1
152	94	1
153	95	1
132	95	2
155	96	1
\.

COPY public.retail_prices (book_id, price) FROM stdin;
1	640
2	470
3	660
4	1420
5	1620
6	980
7	810
8	1920
9	2090
10	2080
11	830
12	1650
13	460
14	1350
15	2830
16	1380
17	1500
18	910
19	1220
20	830
21	960
22	1070
23	4390
95	480
24	950
25	1100
26	390
27	880
28	1860
29	1940
30	1140
31	1190
32	710
33	900
34	1550
35	670
36	630
37	1290
38	1100
39	910
40	1430
41	830
42	1790
43	380
44	500
45	1590
46	1270
47	1480
48	640
49	970
50	1140
51	1310
52	1090
53	3120
54	3470
55	3480
56	2460
57	1900
58	2830
59	1030
60	2700
61	1510
62	1220
63	1780
64	970
65	490
66	690
67	350
68	490
69	1100
70	760
71	1030
72	620
73	960
74	1010
75	830
76	1070
77	640
78	900
79	550
80	1120
81	1620
82	560
83	1230
88	1270
84	2700
85	730
86	910
87	2320
89	1420
90	1780
91	1620
92	630
93	1620
94	1230
96	1570
\.

COPY public.operations (operation_id, book_id, qty, price, at) FROM stdin;
1	6	31	538	2019-08-10 20:11:17.828541+03
2	44	22	275	2019-08-10 20:13:10.997786+03
3	57	27	1112	2019-08-10 20:25:46.485493+03
4	61	34	786	2019-08-10 20:36:05.835598+03
5	39	32	499	2019-08-10 20:41:19.553148+03
6	55	23	1721	2019-08-10 21:01:59.136072+03
7	52	28	499	2019-08-10 21:38:58.299907+03
8	57	-1	1900	2019-08-10 21:39:37.22308+03
9	31	28	687	2019-08-10 22:07:59.677907+03
10	67	25	164	2019-08-10 22:23:18.47434+03
11	87	37	1166	2019-08-10 22:24:52.404313+03
12	90	32	714	2019-08-10 22:29:31.653584+03
13	94	23	598	2019-08-10 22:37:52.434467+03
14	4	41	712	2019-08-10 22:42:27.216728+03
15	14	31	781	2019-08-10 22:55:36.219927+03
16	20	27	363	2019-08-10 23:27:33.875038+03
17	35	39	307	2019-08-10 23:31:33.783884+03
18	38	30	562	2019-08-10 23:42:05.966408+03
19	38	-1	1100	2019-08-11 00:02:36.819398+03
20	47	49	875	2019-08-11 00:06:51.503165+03
21	89	20	741	2019-08-11 00:41:45.529462+03
22	46	43	726	2019-08-11 01:02:25.355448+03
23	18	34	416	2019-08-11 01:23:55.064564+03
24	26	28	192	2019-08-11 01:34:09.056231+03
25	94	-1	1230	2019-08-11 02:04:48.119554+03
26	14	-1	1350	2019-08-11 02:14:20.216306+03
27	96	29	851	2019-08-11 02:20:52.033587+03
28	59	35	589	2019-08-11 02:23:23.961634+03
29	58	21	1543	2019-08-11 02:24:16.413265+03
30	25	17	514	2019-08-11 02:28:24.078781+03
31	20	-2	830	2019-08-11 02:51:04.607603+03
32	16	14	562	2019-08-11 03:09:09.305507+03
33	40	28	579	2019-08-11 03:32:22.130161+03
34	89	-1	1420	2019-08-11 03:47:15.020284+03
35	1	25	302	2019-08-11 03:49:57.251137+03
36	10	20	1069	2019-08-11 04:45:55.428573+03
37	86	34	388	2019-08-11 04:47:51.580603+03
38	82	16	295	2019-08-11 04:56:33.249466+03
39	10	-2	2080	2019-08-11 05:20:47.079181+03
40	18	-1	910	2019-08-11 05:21:30.836694+03
41	47	-1	1480	2019-08-11 05:33:27.905554+03
42	96	-1	1570	2019-08-11 05:43:44.029396+03
43	59	-1	1030	2019-08-11 05:44:48.437513+03
44	55	-2	3480	2019-08-11 06:05:16.038223+03
45	7	37	446	2019-08-11 06:25:14.051107+03
46	58	-1	2830	2019-08-11 07:06:26.244914+03
47	29	37	917	2019-08-11 07:15:49.746229+03
48	60	29	1174	2019-08-11 07:22:35.069122+03
49	38	-2	1100	2019-08-11 07:34:26.006141+03
50	90	-1	1780	2019-08-11 07:34:42.893458+03
51	67	-1	350	2019-08-11 07:53:34.271196+03
52	93	39	705	2019-08-11 08:02:04.958841+03
53	21	26	496	2019-08-11 08:27:55.337949+03
54	77	34	265	2019-08-11 08:43:21.324025+03
55	21	-1	960	2019-08-11 08:52:32.613883+03
56	3	28	278	2019-08-11 08:52:49.997963+03
57	85	26	404	2019-08-11 09:00:31.430369+03
58	8	37	839	2019-08-11 09:43:09.441731+03
59	61	-2	1510	2019-08-11 09:59:17.132499+03
60	55	-1	3480	2019-08-11 10:01:13.01647+03
61	53	26	1805	2019-08-11 10:13:05.220017+03
62	57	-1	1900	2019-08-11 10:18:53.054963+03
63	69	20	544	2019-08-11 10:24:21.630138+03
64	88	28	746	2019-08-11 11:17:19.723537+03
65	14	-1	1350	2019-08-11 11:18:44.770808+03
66	26	-2	390	2019-08-11 11:41:25.351987+03
67	34	34	787	2019-08-11 12:34:53.538084+03
68	25	-1	1100	2019-08-11 12:43:27.291315+03
69	45	25	677	2019-08-11 12:49:40.47362+03
70	44	-1	500	2019-08-11 13:35:57.926883+03
71	59	-1	1030	2019-08-11 13:40:57.691618+03
72	55	-1	3480	2019-08-11 13:52:21.49656+03
73	13	36	193	2019-08-11 13:54:29.878244+03
74	42	28	784	2019-08-11 13:58:48.596126+03
75	66	8	385	2019-08-11 14:13:05.578901+03
76	40	-1	1430	2019-08-11 14:27:55.73181+03
77	42	-2	1790	2019-08-11 15:05:38.388113+03
78	53	-1	3120	2019-08-11 15:07:14.944506+03
79	44	-1	500	2019-08-11 15:07:23.249163+03
80	65	22	197	2019-08-11 15:22:55.515692+03
81	34	-1	1550	2019-08-11 15:23:05.947644+03
82	24	20	528	2019-08-11 15:23:18.125788+03
83	70	32	367	2019-08-11 15:30:27.109856+03
84	64	32	582	2019-08-11 15:35:48.238684+03
85	91	22	925	2019-08-11 15:46:59.004198+03
86	22	39	513	2019-08-11 16:18:17.088585+03
87	67	-2	350	2019-08-11 16:32:21.967509+03
88	75	40	335	2019-08-11 16:47:07.501941+03
89	87	-1	2320	2019-08-11 16:47:27.509006+03
90	86	-1	910	2019-08-11 17:05:31.200779+03
91	95	30	272	2019-08-11 17:06:26.316596+03
92	94	-1	1230	2019-08-11 17:27:43.905899+03
93	31	-1	1190	2019-08-11 17:33:46.67717+03
94	49	43	481	2019-08-11 18:16:24.597651+03
95	23	18	2285	2019-08-11 18:17:06.653256+03
96	91	-1	1620	2019-08-11 18:32:42.905988+03
97	42	-1	1790	2019-08-11 19:00:22.116964+03
98	56	27	1402	2019-08-11 19:02:34.616134+03
99	1	-1	640	2019-08-11 19:06:48.354532+03
100	94	-1	1230	2019-08-11 19:52:27.241571+03
101	96	-1	1570	2019-08-11 20:01:36.804853+03
102	79	16	277	2019-08-11 20:16:11.344566+03
103	86	-2	910	2019-08-11 21:00:10.473896+03
104	20	-1	830	2019-08-11 21:17:28.447542+03
105	57	-1	1900	2019-08-11 21:31:02.173866+03
106	1	-1	640	2019-08-11 22:04:58.059176+03
107	95	-1	480	2019-08-11 22:24:00.185396+03
108	85	-1	730	2019-08-11 22:25:51.878376+03
109	77	-1	640	2019-08-11 22:36:00.487507+03
110	92	22	371	2019-08-11 22:49:45.328675+03
111	23	-1	4390	2019-08-11 23:18:19.18456+03
112	28	22	748	2019-08-11 23:38:06.901175+03
113	33	42	402	2019-08-11 23:59:35.4726+03
114	51	22	601	2019-08-12 00:00:16.449224+03
115	48	21	299	2019-08-12 00:00:45.003443+03
116	63	26	1006	2019-08-12 00:50:06.255021+03
117	20	-2	830	2019-08-12 01:40:52.986213+03
118	30	22	514	2019-08-12 02:01:21.227132+03
119	7	-1	810	2019-08-12 02:08:39.98528+03
120	30	-1	1140	2019-08-12 02:24:42.192641+03
121	51	-1	1310	2019-08-12 02:25:40.465045+03
122	38	-1	1100	2019-08-12 02:26:26.211437+03
123	37	36	629	2019-08-12 03:05:41.668953+03
124	2	14	202	2019-08-12 03:20:38.295565+03
125	34	-1	1550	2019-08-12 03:26:28.538195+03
126	36	24	256	2019-08-12 03:27:45.609922+03
127	93	-1	1620	2019-08-12 03:29:55.123521+03
128	31	-1	1190	2019-08-12 03:30:10.941505+03
129	6	-2	980	2019-08-12 03:47:33.854249+03
130	39	-1	910	2019-08-12 04:01:27.004725+03
131	22	-1	1070	2019-08-12 04:07:27.410055+03
132	15	18	1362	2019-08-12 04:12:44.304592+03
133	33	-1	900	2019-08-12 04:20:31.180261+03
134	84	30	1436	2019-08-12 04:22:39.80325+03
135	75	-1	830	2019-08-12 04:52:11.673489+03
136	85	-1	730	2019-08-12 04:52:54.173904+03
137	18	-1	910	2019-08-12 05:07:10.725736+03
138	68	24	280	2019-08-12 05:31:07.864633+03
139	41	25	335	2019-08-12 05:37:42.515819+03
140	90	-1	1780	2019-08-12 06:06:28.876537+03
141	6	-2	980	2019-08-12 06:07:41.907877+03
142	4	-1	1420	2019-08-12 06:39:16.477478+03
143	22	-1	1070	2019-08-12 06:42:36.54543+03
144	38	-1	1100	2019-08-12 07:21:17.340818+03
145	38	-1	1100	2019-08-12 07:26:34.611883+03
146	36	-1	630	2019-08-12 07:27:51.248195+03
147	7	-1	810	2019-08-12 08:23:01.175074+03
148	70	-2	760	2019-08-12 08:29:36.687121+03
149	10	38	908	2019-08-12 08:36:35.92201+03
150	81	27	847	2019-08-12 08:41:03.589984+03
151	78	21	519	2019-08-12 08:57:20.534737+03
152	42	-2	1790	2019-08-12 08:58:59.55544+03
153	46	-1	1270	2019-08-12 09:16:03.822164+03
154	64	-1	970	2019-08-12 09:20:05.442406+03
155	9	16	1126	2019-08-12 09:22:20.277678+03
156	93	-1	1620	2019-08-12 09:24:55.23311+03
157	31	-1	1190	2019-08-12 09:37:28.252115+03
158	25	-1	1100	2019-08-12 09:55:29.921106+03
159	51	-1	1310	2019-08-12 10:08:47.855394+03
160	63	-1	1780	2019-08-12 10:30:39.318671+03
161	28	-2	1860	2019-08-12 10:36:23.581967+03
162	13	-1	460	2019-08-12 10:36:48.371997+03
163	66	-1	690	2019-08-12 10:37:34.210071+03
164	75	-1	830	2019-08-12 10:48:33.060369+03
165	84	-1	2700	2019-08-12 10:53:24.381012+03
166	22	-1	1070	2019-08-12 11:24:32.691874+03
167	61	-1	1510	2019-08-12 11:32:19.803433+03
168	61	-1	1510	2019-08-12 11:45:38.759872+03
169	17	41	805	2019-08-12 11:56:00.227067+03
170	29	-1	1940	2019-08-12 12:12:06.784341+03
171	41	-1	830	2019-08-12 12:20:50.179323+03
172	7	-1	810	2019-08-12 12:24:39.130289+03
173	69	-1	1100	2019-08-12 13:05:52.590929+03
174	46	-1	1270	2019-08-12 13:08:28.290347+03
175	81	-1	1620	2019-08-12 13:09:52.605255+03
176	11	25	409	2019-08-12 13:23:04.131442+03
177	14	-2	1350	2019-08-12 13:23:07.039275+03
178	59	-1	1030	2019-08-12 13:23:38.390409+03
179	74	22	535	2019-08-12 13:38:51.954857+03
180	61	-1	1510	2019-08-12 13:53:20.912028+03
181	13	-1	460	2019-08-12 14:07:20.766482+03
182	22	-1	1070	2019-08-12 15:01:48.176707+03
183	71	35	607	2019-08-12 15:01:53.398384+03
184	89	-2	1420	2019-08-12 15:16:51.393259+03
185	91	-1	1620	2019-08-12 15:33:28.576379+03
186	89	-1	1420	2019-08-12 15:36:16.145896+03
187	22	-1	1070	2019-08-12 15:55:57.684475+03
188	59	-1	1030	2019-08-12 16:16:27.622157+03
189	3	-2	660	2019-08-12 17:48:06.02054+03
190	82	-1	560	2019-08-12 17:51:31.075123+03
191	89	40	841	2019-08-12 18:04:35.542658+03
192	29	-1	1940	2019-08-12 18:05:32.757261+03
193	4	-1	1420	2019-08-12 18:12:06.50967+03
194	33	-2	900	2019-08-12 18:30:57.622085+03
195	6	-1	980	2019-08-12 18:55:44.37722+03
196	14	-1	1350	2019-08-12 19:07:26.142824+03
197	51	-1	1310	2019-08-12 20:24:19.014641+03
198	3	-1	660	2019-08-12 20:50:30.176656+03
199	4	-1	1420	2019-08-12 20:51:09.578604+03
200	43	14	167	2019-08-12 20:52:32.707956+03
201	37	-1	1290	2019-08-12 21:13:15.469434+03
202	60	-1	2700	2019-08-12 21:22:52.875527+03
203	84	-1	2700	2019-08-12 21:26:00.336157+03
204	45	-1	1590	2019-08-12 21:45:36.184487+03
205	2	-1	470	2019-08-12 22:01:38.766117+03
206	7	-2	810	2019-08-12 22:09:54.830978+03
207	10	-1	2080	2019-08-12 22:11:36.223585+03
208	13	-1	460	2019-08-12 22:23:18.492271+03
209	79	-1	550	2019-08-12 22:24:58.96966+03
210	74	-1	1010	2019-08-12 22:29:18.984112+03
211	30	-1	1140	2019-08-12 22:30:28.86367+03
212	77	-1	640	2019-08-12 22:45:43.122976+03
213	31	-1	1190	2019-08-12 22:46:56.574222+03
214	2	-1	470	2019-08-12 22:48:08.700629+03
215	95	-1	480	2019-08-12 22:49:18.508396+03
216	39	-2	910	2019-08-12 22:53:34.31237+03
217	3	-2	660	2019-08-12 23:03:55.645624+03
218	87	-1	2320	2019-08-12 23:22:23.004676+03
219	60	-1	2700	2019-08-12 23:33:58.700784+03
220	39	-1	910	2019-08-12 23:40:15.675294+03
221	91	-1	1620	2019-08-12 23:43:27.531951+03
222	24	-2	950	2019-08-13 00:06:01.542792+03
223	9	-1	2090	2019-08-13 00:22:20.29313+03
224	81	-1	1620	2019-08-13 00:52:09.646151+03
225	44	-1	500	2019-08-13 01:00:20.662215+03
226	85	-1	730	2019-08-13 01:28:01.689417+03
227	29	-1	1940	2019-08-13 01:37:21.12663+03
228	10	-1	2080	2019-08-13 01:58:55.713752+03
229	84	-1	2700	2019-08-13 02:26:40.100336+03
230	95	-1	480	2019-08-13 02:26:49.373027+03
231	6	-1	980	2019-08-13 02:39:58.623331+03
232	20	-1	830	2019-08-13 02:42:42.218216+03
233	89	-1	1420	2019-08-13 03:02:11.573074+03
234	10	-1	2080	2019-08-13 03:05:03.722024+03
235	10	-1	2080	2019-08-13 03:30:40.389784+03
236	77	-1	640	2019-08-13 03:38:11.395555+03
237	19	45	607	2019-08-13 03:43:45.113276+03
238	56	-1	2460	2019-08-13 03:45:04.20929+03
239	87	-2	2320	2019-08-13 04:24:49.9051+03
240	36	-1	630	2019-08-13 04:37:42.117359+03
241	86	-1	910	2019-08-13 04:46:29.33561+03
242	40	-1	1430	2019-08-13 04:55:43.067779+03
243	93	-1	1620	2019-08-13 05:08:57.15266+03
244	21	-1	960	2019-08-13 05:09:23.398639+03
245	94	-1	1230	2019-08-13 05:43:15.58008+03
246	57	-1	1900	2019-08-13 05:44:38.172638+03
247	63	-1	1780	2019-08-13 06:17:29.325354+03
248	33	-1	900	2019-08-13 06:18:43.489121+03
249	35	-1	670	2019-08-13 06:31:34.986363+03
250	35	-1	670	2019-08-13 06:39:38.000496+03
251	12	40	766	2019-08-13 07:00:19.921932+03
252	81	-1	1620	2019-08-13 07:14:48.634245+03
253	92	-1	630	2019-08-13 07:18:59.44484+03
254	71	-1	1030	2019-08-13 07:37:00.729731+03
255	31	-2	1190	2019-08-13 07:48:52.784336+03
256	95	-1	480	2019-08-13 08:22:51.362863+03
257	56	-1	2460	2019-08-13 08:51:18.006314+03
258	55	-2	3480	2019-08-13 08:57:25.874377+03
259	15	-1	2830	2019-08-13 08:59:51.845182+03
260	1	-1	640	2019-08-13 09:13:45.565281+03
261	93	-1	1620	2019-08-13 09:30:24.714153+03
262	52	-1	1090	2019-08-13 10:40:58.623253+03
263	38	-1	1100	2019-08-13 11:02:00.575298+03
264	12	-2	1650	2019-08-13 11:08:57.208257+03
265	63	-1	1780	2019-08-13 11:13:14.537754+03
266	21	-2	960	2019-08-13 11:15:39.195569+03
267	14	-1	1350	2019-08-13 11:18:12.223106+03
268	83	32	661	2019-08-13 11:24:00.578791+03
269	80	26	625	2019-08-13 11:33:23.002073+03
270	25	-1	1100	2019-08-13 11:54:54.468665+03
271	54	24	1395	2019-08-13 12:40:41.460501+03
272	20	-1	830	2019-08-13 13:29:33.397131+03
273	43	-1	380	2019-08-13 13:38:18.230172+03
274	8	-1	1920	2019-08-13 13:42:26.03155+03
275	85	-2	730	2019-08-13 13:44:34.373547+03
276	63	-1	1780	2019-08-13 13:44:34.930047+03
277	75	-1	830	2019-08-13 14:07:44.984612+03
278	37	-1	1290	2019-08-13 14:16:08.502516+03
279	77	-1	640	2019-08-13 14:29:09.053619+03
280	27	17	355	2019-08-13 14:40:16.78611+03
281	12	-1	1650	2019-08-13 14:46:56.834236+03
282	8	-1	1920	2019-08-13 14:54:40.648047+03
283	95	-3	480	2019-08-13 15:13:10.040369+03
284	24	-1	950	2019-08-13 15:17:55.447871+03
285	70	-1	760	2019-08-13 15:34:28.421428+03
286	71	-1	1030	2019-08-13 15:42:13.473166+03
287	62	17	689	2019-08-13 15:58:16.782677+03
288	10	-1	2080	2019-08-13 16:10:51.636434+03
289	80	-1	1120	2019-08-13 16:29:06.288114+03
290	90	-1	1780	2019-08-13 16:56:30.914602+03
291	20	-2	830	2019-08-13 16:58:13.934531+03
292	67	-1	350	2019-08-13 17:10:42.568463+03
293	68	-1	490	2019-08-13 17:17:17.255789+03
294	77	-1	640	2019-08-13 17:20:21.347992+03
295	7	-2	810	2019-08-13 17:24:13.317878+03
296	42	-1	1790	2019-08-13 17:38:59.356853+03
297	21	-1	960	2019-08-13 18:03:30.405689+03
298	82	-1	560	2019-08-13 18:56:44.658357+03
299	57	-1	1900	2019-08-13 19:44:05.224772+03
300	46	-1	1270	2019-08-13 19:46:39.533567+03
301	8	-1	1920	2019-08-13 19:56:04.342066+03
302	5	29	923	2019-08-13 20:01:08.409507+03
303	57	-1	1900	2019-08-13 20:05:58.356132+03
304	31	-2	1190	2019-08-13 20:07:40.743683+03
305	32	33	422	2019-08-13 20:32:54.439321+03
306	92	-1	630	2019-08-13 20:41:04.298032+03
307	76	43	579	2019-08-13 20:41:52.117261+03
308	1	-1	640	2019-08-13 20:54:48.879068+03
309	10	-2	2080	2019-08-13 20:58:56.752819+03
310	59	-1	1030	2019-08-13 20:59:22.475338+03
311	36	-1	630	2019-08-13 21:04:54.702509+03
312	4	-1	1420	2019-08-13 21:15:28.619043+03
313	24	-1	950	2019-08-13 21:37:11.906049+03
314	87	-1	2320	2019-08-13 22:08:12.924363+03
315	73	18	410	2019-08-13 22:12:09.917199+03
316	85	-1	730	2019-08-13 22:23:04.557865+03
317	46	-1	1270	2019-08-13 22:39:17.976768+03
318	74	-1	1010	2019-08-13 22:46:18.76506+03
319	39	-1	910	2019-08-13 22:57:23.618239+03
320	90	-1	1780	2019-08-13 23:16:21.854714+03
321	54	-1	3470	2019-08-13 23:25:10.893325+03
322	48	-2	640	2019-08-13 23:29:36.77848+03
323	24	-2	950	2019-08-13 23:39:08.208021+03
324	44	-2	500	2019-08-13 23:56:04.411226+03
325	26	-1	390	2019-08-14 00:06:39.953712+03
326	71	-1	1030	2019-08-14 01:06:40.296535+03
327	3	-1	660	2019-08-14 01:14:42.370806+03
328	41	-1	830	2019-08-14 01:25:54.582694+03
329	18	-1	910	2019-08-14 01:48:24.899543+03
330	58	-2	2830	2019-08-14 02:07:43.10456+03
331	37	-1	1290	2019-08-14 02:10:25.393043+03
332	14	-1	1350	2019-08-14 02:10:28.594692+03
333	45	-1	1590	2019-08-14 02:11:04.225914+03
334	23	-2	4390	2019-08-14 02:13:18.143716+03
335	4	-1	1420	2019-08-14 02:14:18.400358+03
336	36	-1	630	2019-08-14 02:43:56.809925+03
337	18	-1	910	2019-08-14 03:45:23.54436+03
338	46	-2	1270	2019-08-14 04:13:56.772355+03
339	53	-1	3120	2019-08-14 04:21:48.64247+03
340	19	-1	1220	2019-08-14 04:22:45.723978+03
341	8	-2	1920	2019-08-14 04:24:52.103071+03
342	18	-1	910	2019-08-14 04:26:27.691844+03
343	94	-1	1230	2019-08-14 04:36:53.307876+03
344	93	-1	1620	2019-08-14 04:43:01.106796+03
345	25	-1	1100	2019-08-14 04:46:43.951269+03
346	96	-1	1570	2019-08-14 04:49:24.23359+03
347	22	-1	1070	2019-08-14 05:01:54.712348+03
348	13	-1	460	2019-08-14 05:48:37.95097+03
349	53	-1	3120	2019-08-14 05:52:25.463878+03
350	87	-1	2320	2019-08-14 06:08:14.738554+03
351	30	-1	1140	2019-08-14 06:18:43.906369+03
352	55	-1	3480	2019-08-14 06:42:46.989306+03
353	86	-1	910	2019-08-14 06:42:49.846614+03
354	95	-1	480	2019-08-14 06:46:52.27419+03
355	78	-1	900	2019-08-14 07:06:53.285332+03
356	25	-2	1100	2019-08-14 07:15:32.481575+03
357	68	-1	490	2019-08-14 07:47:05.883355+03
358	84	-1	2700	2019-08-14 08:41:10.193677+03
359	82	-1	560	2019-08-14 09:41:44.238016+03
360	84	-1	2700	2019-08-14 10:02:36.644026+03
361	26	-1	390	2019-08-14 10:04:03.637232+03
362	64	-1	970	2019-08-14 10:05:42.87734+03
363	32	-1	710	2019-08-14 10:13:54.029176+03
364	51	-2	1310	2019-08-14 10:30:23.289149+03
365	12	-1	1650	2019-08-14 10:41:00.327128+03
366	14	-1	1350	2019-08-14 10:43:40.151938+03
367	55	-1	3480	2019-08-14 11:06:34.033372+03
368	49	-1	970	2019-08-14 11:26:38.800997+03
369	22	-1	1070	2019-08-14 11:44:33.631404+03
370	45	-1	1590	2019-08-14 11:46:30.034552+03
371	7	-1	810	2019-08-14 12:18:55.509221+03
372	20	27	376	2019-08-14 12:24:35.17387+03
373	8	-1	1920	2019-08-14 12:39:19.413943+03
374	70	-1	760	2019-08-14 12:41:55.266993+03
375	47	-1	1480	2019-08-14 12:55:18.279559+03
376	19	-1	1220	2019-08-14 13:27:28.232368+03
377	46	-1	1270	2019-08-14 13:52:02.638087+03
378	18	-2	910	2019-08-14 14:05:54.194399+03
379	37	-1	1290	2019-08-14 15:27:21.049051+03
380	79	-2	550	2019-08-14 15:53:20.867974+03
381	24	-1	950	2019-08-14 16:02:40.911933+03
382	2	-1	470	2019-08-14 16:06:59.463551+03
383	96	-1	1570	2019-08-14 16:29:45.148402+03
384	14	-1	1350	2019-08-14 17:26:40.025314+03
385	67	-1	350	2019-08-14 18:13:09.44901+03
386	52	-1	1090	2019-08-14 18:39:33.64812+03
387	18	-1	910	2019-08-14 18:57:22.796718+03
388	87	-1	2320	2019-08-14 19:21:32.927696+03
389	48	-1	640	2019-08-14 19:23:34.77152+03
390	72	10	345	2019-08-14 19:40:15.998981+03
391	46	-2	1270	2019-08-14 19:48:55.27653+03
392	23	-1	4390	2019-08-14 19:54:50.363515+03
393	75	-1	830	2019-08-14 20:02:50.066419+03
394	9	-1	2090	2019-08-14 20:18:12.376124+03
395	14	-2	1350	2019-08-14 20:26:04.009969+03
396	34	-1	1550	2019-08-14 20:32:11.757702+03
397	18	-1	910	2019-08-14 20:46:23.526388+03
398	40	-1	1430	2019-08-14 20:56:25.543116+03
399	19	-1	1220	2019-08-14 21:19:58.202556+03
400	2	-1	470	2019-08-14 21:43:15.493149+03
401	10	-1	2080	2019-08-14 21:52:38.1389+03
402	90	-1	1780	2019-08-14 22:15:34.049304+03
403	95	-1	480	2019-08-14 22:21:36.89722+03
404	79	-1	550	2019-08-14 22:36:19.086303+03
405	91	-1	1620	2019-08-14 22:53:03.261413+03
406	71	-1	1030	2019-08-14 22:59:09.202125+03
407	37	-2	1290	2019-08-14 23:00:03.54541+03
408	55	27	1628	2019-08-14 23:16:10.715432+03
409	29	-1	1940	2019-08-14 23:42:50.059399+03
410	42	-2	1790	2019-08-14 23:54:53.62031+03
411	32	-1	710	2019-08-15 00:46:34.760995+03
412	80	-2	1120	2019-08-15 00:53:12.131568+03
413	39	-2	910	2019-08-15 01:37:08.826872+03
414	29	-2	1940	2019-08-15 01:46:45.251918+03
415	31	-1	1190	2019-08-15 02:09:07.423514+03
416	94	-1	1230	2019-08-15 02:25:18.301272+03
417	85	-1	730	2019-08-15 02:37:47.821925+03
418	7	-1	810	2019-08-15 02:46:49.298702+03
419	96	-1	1570	2019-08-15 03:02:44.313174+03
420	18	-1	910	2019-08-15 03:42:51.672928+03
421	75	-1	830	2019-08-15 03:49:00.272252+03
422	38	-1	1100	2019-08-15 03:50:22.390457+03
423	13	-1	460	2019-08-15 04:38:57.81937+03
424	87	-1	2320	2019-08-15 04:51:01.413131+03
425	8	-1	1920	2019-08-15 05:06:29.328067+03
426	6	-1	980	2019-08-15 05:12:59.237919+03
427	22	-1	1070	2019-08-15 05:19:25.907938+03
428	15	-1	2830	2019-08-15 05:36:45.462353+03
429	96	-2	1570	2019-08-15 05:55:31.640611+03
430	13	-2	460	2019-08-15 06:19:08.114511+03
431	27	-1	880	2019-08-15 06:33:54.541669+03
432	33	-1	900	2019-08-15 07:08:32.285931+03
433	95	-1	480	2019-08-15 07:09:26.311307+03
434	49	-1	970	2019-08-15 07:12:15.547776+03
435	56	-1	2460	2019-08-15 08:10:30.923458+03
436	67	-1	350	2019-08-15 08:12:50.729566+03
437	10	-1	2080	2019-08-15 08:14:48.949859+03
438	39	-1	910	2019-08-15 08:20:02.407866+03
439	33	-2	900	2019-08-15 08:27:02.684707+03
440	94	-1	1230	2019-08-15 09:38:11.554689+03
441	96	-1	1570	2019-08-15 09:40:38.70119+03
442	69	-1	1100	2019-08-15 10:24:57.490629+03
443	80	-2	1120	2019-08-15 10:28:20.149689+03
444	77	-1	640	2019-08-15 10:51:36.214579+03
445	37	-1	1290	2019-08-15 11:07:18.400906+03
446	36	-1	630	2019-08-15 11:15:26.643837+03
447	86	-1	910	2019-08-15 12:00:45.077433+03
448	65	-1	490	2019-08-15 12:22:48.241211+03
449	64	-1	970	2019-08-15 12:24:22.181035+03
450	46	-1	1270	2019-08-15 12:24:41.38112+03
451	49	-1	970	2019-08-15 12:32:45.842833+03
452	10	-1	2080	2019-08-15 13:11:52.163052+03
453	18	-1	910	2019-08-15 13:31:43.492765+03
454	8	-2	1920	2019-08-15 13:45:31.630553+03
455	24	-1	950	2019-08-15 13:48:33.330818+03
456	45	-2	1590	2019-08-15 14:01:32.831916+03
457	87	-1	2320	2019-08-15 14:02:14.271674+03
458	61	-3	1510	2019-08-15 14:30:54.205774+03
459	29	-1	1940	2019-08-15 14:35:21.122225+03
460	18	-1	910	2019-08-15 14:53:08.070843+03
461	22	-1	1070	2019-08-15 15:07:10.388173+03
462	38	-2	1100	2019-08-15 15:13:03.495182+03
463	84	-1	2700	2019-08-15 15:28:55.380667+03
464	93	-1	1620	2019-08-15 15:39:54.06653+03
465	57	-1	1900	2019-08-15 15:45:11.089071+03
466	78	-1	900	2019-08-15 16:13:11.730385+03
467	61	-1	1510	2019-08-15 16:29:45.044423+03
468	10	-2	2080	2019-08-15 16:31:03.257528+03
469	32	-2	710	2019-08-15 16:31:45.80965+03
470	73	-1	960	2019-08-15 16:40:47.522165+03
471	58	-1	2830	2019-08-15 16:49:33.633501+03
472	77	-1	640	2019-08-15 16:58:03.922495+03
473	39	-1	910	2019-08-15 17:29:16.250953+03
474	87	-2	2320	2019-08-15 17:29:17.841167+03
475	33	-1	900	2019-08-15 17:55:46.294981+03
476	86	-1	910	2019-08-15 18:00:33.408326+03
477	9	-1	2090	2019-08-15 18:18:01.830037+03
478	95	-1	480	2019-08-15 18:21:57.497351+03
479	88	-1	1270	2019-08-15 18:22:03.49796+03
480	38	-1	1100	2019-08-15 18:27:25.737945+03
481	70	-1	760	2019-08-15 18:28:45.441365+03
482	44	-1	500	2019-08-15 18:28:57.264463+03
483	3	-1	660	2019-08-15 18:42:56.939267+03
484	18	-2	910	2019-08-15 19:12:37.762535+03
485	38	-1	1100	2019-08-15 19:33:02.350041+03
486	46	-1	1270	2019-08-15 19:33:14.041807+03
487	12	-1	1650	2019-08-15 19:51:19.22196+03
488	36	-1	630	2019-08-15 20:02:18.060303+03
489	12	-1	1650	2019-08-15 20:05:46.21567+03
490	89	-1	1420	2019-08-15 20:10:51.645179+03
491	44	-2	500	2019-08-15 20:33:31.530841+03
492	85	-1	730	2019-08-15 20:54:52.704144+03
493	80	-1	1120	2019-08-15 20:59:39.105586+03
494	33	-2	900	2019-08-15 21:31:46.633936+03
495	8	-1	1920	2019-08-15 21:40:07.374784+03
496	84	-1	2700	2019-08-15 21:43:59.111169+03
497	20	-1	830	2019-08-15 21:47:35.639927+03
498	27	-1	880	2019-08-15 21:56:17.365176+03
499	43	-1	380	2019-08-15 21:56:22.654375+03
500	58	-1	2830	2019-08-15 22:12:13.392697+03
501	12	-1	1650	2019-08-15 22:14:28.955303+03
502	41	-1	830	2019-08-15 22:30:12.008311+03
503	5	-2	1620	2019-08-15 22:30:41.528371+03
504	55	-1	3480	2019-08-15 22:47:20.852129+03
505	49	-1	970	2019-08-15 22:49:50.057955+03
506	58	-1	2830	2019-08-15 23:01:04.323536+03
507	71	-1	1030	2019-08-15 23:18:55.343744+03
508	1	-1	640	2019-08-15 23:23:35.208013+03
509	38	-1	1100	2019-08-15 23:49:52.914263+03
510	40	-1	1430	2019-08-16 00:07:47.204236+03
511	44	-1	500	2019-08-16 00:36:15.994551+03
512	15	-1	2830	2019-08-16 00:42:37.714027+03
513	65	-2	490	2019-08-16 01:12:06.516196+03
514	59	-1	1030	2019-08-16 01:48:19.799238+03
515	18	-1	910	2019-08-16 02:03:25.131621+03
516	91	-1	1620	2019-08-16 02:04:25.354256+03
517	50	21	479	2019-08-16 02:05:17.570801+03
518	91	-1	1620	2019-08-16 02:05:25.114198+03
519	79	23	228	2019-08-16 02:10:12.378191+03
520	7	-1	810	2019-08-16 02:19:31.926962+03
521	18	-1	910	2019-08-16 02:26:08.61812+03
522	74	-1	1010	2019-08-16 03:07:57.939014+03
523	44	23	269	2019-08-16 03:18:53.658403+03
524	56	-1	2460	2019-08-16 04:01:53.544665+03
525	81	-1	1620	2019-08-16 04:19:26.542327+03
526	52	-1	1090	2019-08-16 04:23:48.358747+03
527	95	-1	480	2019-08-16 05:06:57.047331+03
528	39	-1	910	2019-08-16 05:08:14.959857+03
529	94	-2	1230	2019-08-16 05:10:28.023219+03
530	9	-1	2090	2019-08-16 05:19:36.131279+03
531	79	-2	550	2019-08-16 05:49:06.094469+03
532	69	-2	1100	2019-08-16 06:06:59.634653+03
533	56	-1	2460	2019-08-16 06:24:31.733303+03
534	32	-1	710	2019-08-16 07:54:25.555469+03
535	86	-1	910	2019-08-16 07:57:36.488224+03
536	55	-2	3480	2019-08-16 08:00:02.224313+03
537	52	-1	1090	2019-08-16 08:04:33.26286+03
538	13	-2	460	2019-08-16 08:18:33.663785+03
539	48	-1	640	2019-08-16 08:33:35.169394+03
540	83	-1	1230	2019-08-16 08:36:05.619232+03
541	14	-1	1350	2019-08-16 08:41:25.945357+03
542	49	-1	970	2019-08-16 08:44:35.708281+03
543	75	-1	830	2019-08-16 08:45:09.167533+03
544	7	-1	810	2019-08-16 09:07:27.751525+03
545	49	-1	970	2019-08-16 09:53:50.521423+03
546	18	-1	910	2019-08-16 11:17:09.443739+03
547	11	-2	830	2019-08-16 11:32:14.957407+03
548	36	-1	630	2019-08-16 11:55:32.514572+03
549	26	-1	390	2019-08-16 12:16:41.575368+03
550	49	-2	970	2019-08-16 12:52:42.572992+03
551	40	-2	1430	2019-08-16 13:01:29.831288+03
552	26	-1	390	2019-08-16 13:05:17.001343+03
553	4	-2	1420	2019-08-16 13:08:54.34789+03
554	46	-1	1270	2019-08-16 13:27:23.225666+03
555	40	-1	1430	2019-08-16 13:52:02.829161+03
556	53	-2	3120	2019-08-16 14:01:54.670386+03
557	47	-1	1480	2019-08-16 14:25:38.738446+03
558	61	-1	1510	2019-08-16 14:51:31.372529+03
559	55	-1	3480	2019-08-16 15:16:54.699245+03
560	29	-1	1940	2019-08-16 15:19:43.074623+03
561	20	-2	830	2019-08-16 15:34:36.723282+03
562	43	-1	380	2019-08-16 15:42:07.990677+03
563	6	-1	980	2019-08-16 16:02:35.175218+03
564	30	-1	1140	2019-08-16 16:20:20.387155+03
565	67	-1	350	2019-08-16 17:02:06.913998+03
566	47	-1	1480	2019-08-16 17:03:26.687844+03
567	79	-1	550	2019-08-16 17:07:47.319096+03
568	75	-1	830	2019-08-16 17:32:40.51317+03
569	38	-1	1100	2019-08-16 17:36:22.891929+03
570	68	-1	490	2019-08-16 17:47:00.636343+03
571	32	-1	710	2019-08-16 18:02:22.877765+03
572	12	-1	1650	2019-08-16 18:09:07.958603+03
573	33	-1	900	2019-08-16 18:17:46.662931+03
574	33	-1	900	2019-08-16 18:18:53.357943+03
575	4	-1	1420	2019-08-16 18:25:24.89734+03
576	47	-1	1480	2019-08-16 18:27:08.848293+03
577	14	39	810	2019-08-16 18:39:21.95062+03
578	30	-1	1140	2019-08-16 18:52:45.507787+03
579	84	-2	2700	2019-08-16 19:02:04.097502+03
580	29	-1	1940	2019-08-16 19:02:41.256237+03
581	49	-1	970	2019-08-16 19:07:39.998716+03
582	8	-1	1920	2019-08-16 19:19:56.378173+03
583	80	-1	1120	2019-08-16 19:33:53.038537+03
584	83	-1	1230	2019-08-16 19:53:45.414666+03
585	27	-3	880	2019-08-16 20:54:51.628529+03
586	1	-1	640	2019-08-16 20:58:59.908966+03
587	56	-1	2460	2019-08-16 21:30:52.89431+03
588	79	-1	550	2019-08-16 21:58:01.732959+03
589	10	-1	2080	2019-08-16 22:08:18.608172+03
590	60	-1	2700	2019-08-16 22:54:30.07598+03
591	94	-1	1230	2019-08-16 23:01:59.00266+03
592	15	-1	2830	2019-08-16 23:14:18.815143+03
593	39	-2	910	2019-08-16 23:44:10.549575+03
594	44	-1	500	2019-08-17 00:11:53.045432+03
595	55	-1	3480	2019-08-17 00:41:11.33049+03
596	71	-2	1030	2019-08-17 01:03:02.480388+03
597	52	-3	1090	2019-08-17 01:05:07.805116+03
598	20	-1	830	2019-08-17 01:13:16.494694+03
599	55	-1	3480	2019-08-17 01:42:45.262882+03
600	56	-2	2460	2019-08-17 01:50:53.229431+03
601	55	-2	3480	2019-08-17 02:08:09.849739+03
602	11	-1	830	2019-08-17 02:35:10.970962+03
603	23	26	1871	2019-08-17 02:36:05.161223+03
604	59	-1	1030	2019-08-17 02:43:05.90754+03
605	11	-1	830	2019-08-17 02:45:24.126699+03
606	48	-1	640	2019-08-17 03:02:49.622408+03
607	5	-1	1620	2019-08-17 04:35:46.760075+03
608	5	-2	1620	2019-08-17 04:41:20.736332+03
609	42	-1	1790	2019-08-17 04:42:16.742198+03
610	6	-1	980	2019-08-17 05:32:02.761868+03
611	89	-1	1420	2019-08-17 05:33:44.440292+03
612	55	-2	3480	2019-08-17 06:05:18.723967+03
613	28	-1	1860	2019-08-17 06:32:06.102139+03
614	40	-1	1430	2019-08-17 06:33:43.351719+03
615	93	-1	1620	2019-08-17 06:39:25.449892+03
616	16	-1	1380	2019-08-17 07:14:51.580782+03
617	55	-1	3480	2019-08-17 07:34:45.963966+03
618	32	-1	710	2019-08-17 07:36:40.714183+03
619	88	-1	1270	2019-08-17 07:44:53.470311+03
620	80	-1	1120	2019-08-17 07:49:13.58035+03
621	29	-2	1940	2019-08-17 07:59:39.133502+03
622	70	-1	760	2019-08-17 08:19:14.123603+03
623	94	25	587	2019-08-17 08:32:42.660596+03
624	38	25	649	2019-08-17 08:40:43.870847+03
625	12	-1	1650	2019-08-17 08:52:07.696534+03
626	10	-1	2080	2019-08-17 09:15:28.505059+03
627	42	-1	1790	2019-08-17 09:23:39.793324+03
628	56	-1	2460	2019-08-17 09:33:59.215737+03
629	87	-1	2320	2019-08-17 09:38:15.836844+03
630	13	-1	460	2019-08-17 09:56:49.729476+03
631	50	-1	1140	2019-08-17 09:57:57.561914+03
632	71	-1	1030	2019-08-17 09:58:29.002145+03
633	54	-1	3470	2019-08-17 10:07:03.555887+03
634	82	-1	560	2019-08-17 10:07:08.687665+03
635	74	-1	1010	2019-08-17 10:14:24.520278+03
636	64	-1	970	2019-08-17 10:14:49.895148+03
637	19	-1	1220	2019-08-17 10:29:23.331851+03
638	50	-1	1140	2019-08-17 10:30:00.842359+03
639	18	29	539	2019-08-17 10:30:52.378571+03
640	32	-2	710	2019-08-17 10:37:14.174284+03
641	10	-1	2080	2019-08-17 10:42:04.509992+03
642	68	-1	490	2019-08-17 10:45:46.993212+03
643	73	-2	960	2019-08-17 10:53:11.353083+03
644	49	-1	970	2019-08-17 10:59:38.413085+03
645	21	-1	960	2019-08-17 11:05:42.705602+03
646	15	-1	2830	2019-08-17 11:52:04.253248+03
647	90	-1	1780	2019-08-17 11:53:16.267496+03
648	13	-1	460	2019-08-17 11:59:24.535245+03
649	17	-1	1500	2019-08-17 12:28:43.663477+03
650	58	-1	2830	2019-08-17 12:38:07.269837+03
651	28	-1	1860	2019-08-17 12:42:06.662589+03
652	85	-1	730	2019-08-17 12:52:35.509719+03
653	95	-1	480	2019-08-17 13:21:07.393201+03
654	26	-1	390	2019-08-17 13:25:00.716051+03
655	30	21	558	2019-08-17 13:54:09.865308+03
656	61	-1	1510	2019-08-17 14:05:05.762086+03
657	8	-1	1920	2019-08-17 14:28:17.861643+03
658	65	-2	490	2019-08-17 14:39:03.899044+03
659	26	-2	390	2019-08-17 15:04:52.922729+03
660	14	-1	1350	2019-08-17 15:22:54.638505+03
661	70	-2	760	2019-08-17 15:30:17.976532+03
662	14	-1	1350	2019-08-17 16:07:25.697357+03
663	47	-1	1480	2019-08-17 16:38:23.632916+03
664	49	-1	970	2019-08-17 17:14:38.215959+03
665	6	-2	980	2019-08-17 17:17:38.729193+03
666	4	-1	1420	2019-08-17 17:35:33.963088+03
667	9	15	1242	2019-08-17 18:00:22.984657+03
668	18	-1	910	2019-08-17 18:33:08.08752+03
669	38	-1	1100	2019-08-17 18:35:50.787509+03
670	56	-1	2460	2019-08-17 18:37:03.961669+03
671	63	-1	1780	2019-08-17 19:22:01.93601+03
672	18	-1	910	2019-08-17 19:26:36.503123+03
673	80	-2	1120	2019-08-17 20:45:54.114117+03
674	59	-1	1030	2019-08-17 20:49:08.859362+03
675	15	-1	2830	2019-08-17 20:53:38.150562+03
676	5	-1	1620	2019-08-17 20:58:14.461194+03
677	55	-1	3480	2019-08-17 21:12:02.088682+03
678	70	-1	760	2019-08-17 21:16:21.426048+03
679	74	-2	1010	2019-08-17 21:40:13.069315+03
680	67	34	196	2019-08-17 21:56:12.134534+03
681	84	-1	2700	2019-08-17 22:00:43.743045+03
682	76	-1	1070	2019-08-17 22:09:39.114288+03
683	7	-1	810	2019-08-17 22:31:08.549646+03
684	14	-1	1350	2019-08-17 22:43:21.316813+03
685	79	-1	550	2019-08-17 22:51:15.509091+03
686	51	-2	1310	2019-08-17 22:57:06.949057+03
687	59	-1	1030	2019-08-17 22:57:13.979319+03
688	82	17	305	2019-08-17 23:14:17.824171+03
689	25	-1	1100	2019-08-18 00:28:29.963864+03
690	26	-1	390	2019-08-18 00:41:34.968633+03
691	30	-1	1140	2019-08-18 00:50:32.419345+03
692	54	-1	3470	2019-08-18 00:57:21.636876+03
693	79	-1	550	2019-08-18 01:05:11.402987+03
694	41	-1	830	2019-08-18 01:31:30.304645+03
695	49	-1	970	2019-08-18 01:33:35.172327+03
696	2	-1	470	2019-08-18 01:35:32.84754+03
697	35	-1	670	2019-08-18 02:10:36.542182+03
698	77	-1	640	2019-08-18 02:11:43.216893+03
699	45	-1	1590	2019-08-18 02:22:55.837241+03
700	91	-1	1620	2019-08-18 02:44:13.765214+03
701	50	-2	1140	2019-08-18 02:51:57.915729+03
702	66	11	320	2019-08-18 03:16:43.359852+03
703	30	-2	1140	2019-08-18 03:51:56.872032+03
704	34	-2	1550	2019-08-18 04:06:28.21649+03
705	47	-2	1480	2019-08-18 04:34:39.989163+03
706	89	-1	1420	2019-08-18 04:36:52.124066+03
707	16	-1	1380	2019-08-18 04:46:23.593505+03
708	49	-1	970	2019-08-18 04:54:53.089075+03
709	60	-1	2700	2019-08-18 05:05:57.47425+03
710	37	-1	1290	2019-08-18 05:11:44.049972+03
711	49	-1	970	2019-08-18 05:13:19.854797+03
712	62	-1	1220	2019-08-18 05:40:07.367883+03
713	8	-1	1920	2019-08-18 05:42:42.919872+03
714	25	-1	1100	2019-08-18 05:44:49.252479+03
715	61	-1	1510	2019-08-18 05:47:28.148973+03
716	33	-1	900	2019-08-18 06:00:01.078865+03
717	38	-2	1100	2019-08-18 06:03:44.89619+03
718	74	-1	1010	2019-08-18 06:10:55.617782+03
719	27	-1	880	2019-08-18 06:13:25.465965+03
720	96	-1	1570	2019-08-18 06:21:06.283819+03
721	17	-1	1500	2019-08-18 06:41:26.796482+03
722	22	-1	1070	2019-08-18 06:42:01.050136+03
723	9	-1	2090	2019-08-18 06:49:27.087393+03
724	55	-1	3480	2019-08-18 06:56:54.404253+03
725	20	-2	830	2019-08-18 07:09:18.114835+03
726	50	-2	1140	2019-08-18 07:09:30.588507+03
727	96	-2	1570	2019-08-18 07:19:19.967242+03
728	19	-1	1220	2019-08-18 07:26:49.742618+03
729	37	-1	1290	2019-08-18 07:36:13.537848+03
730	2	12	240	2019-08-18 07:48:04.589739+03
731	8	-1	1920	2019-08-18 07:48:55.222772+03
732	93	-2	1620	2019-08-18 07:51:08.31958+03
733	4	-1	1420	2019-08-18 07:56:15.64291+03
734	11	-2	830	2019-08-18 07:59:58.927617+03
735	14	-1	1350	2019-08-18 08:04:14.645992+03
736	87	-1	2320	2019-08-18 08:05:17.228848+03
737	4	-3	1420	2019-08-18 08:19:50.878658+03
738	78	-1	900	2019-08-18 09:22:19.826506+03
739	73	-1	960	2019-08-18 09:30:18.925107+03
740	30	-1	1140	2019-08-18 09:30:33.461822+03
741	79	-1	550	2019-08-18 09:36:00.465816+03
742	46	-1	1270	2019-08-18 09:37:48.588066+03
743	25	19	533	2019-08-18 09:45:50.148103+03
744	76	-1	1070	2019-08-18 09:53:03.874061+03
745	94	-1	1230	2019-08-18 10:05:10.924502+03
746	89	-1	1420	2019-08-18 11:21:36.843062+03
747	46	-1	1270	2019-08-18 11:57:42.552956+03
748	77	-1	640	2019-08-18 12:05:43.643785+03
749	83	-1	1230	2019-08-18 12:06:13.067281+03
750	81	-1	1620	2019-08-18 13:10:49.216524+03
751	33	-1	900	2019-08-18 13:16:51.546371+03
752	84	-1	2700	2019-08-18 13:43:57.939115+03
753	47	-1	1480	2019-08-18 14:05:15.223066+03
754	46	-1	1270	2019-08-18 14:21:08.197379+03
755	26	-1	390	2019-08-18 14:32:14.361135+03
756	5	-1	1620	2019-08-18 15:18:01.209914+03
757	9	-1	2090	2019-08-18 15:19:07.359922+03
758	3	-1	660	2019-08-18 15:24:33.430774+03
759	42	-1	1790	2019-08-18 15:36:17.398377+03
760	50	-1	1140	2019-08-18 15:47:06.992993+03
761	52	-1	1090	2019-08-18 15:52:57.773126+03
762	41	-1	830	2019-08-18 15:53:03.60481+03
763	84	-1	2700	2019-08-18 15:57:17.033289+03
764	40	-1	1430	2019-08-18 16:13:04.785766+03
765	94	-1	1230	2019-08-18 16:20:23.58458+03
766	70	-1	760	2019-08-18 17:04:50.096127+03
767	27	16	455	2019-08-18 17:15:08.563473+03
768	40	-1	1430	2019-08-18 17:15:58.581613+03
769	78	-1	900	2019-08-18 17:33:34.666311+03
770	86	-1	910	2019-08-18 17:35:52.925155+03
771	59	-1	1030	2019-08-18 17:55:14.035121+03
772	24	23	467	2019-08-18 18:08:55.171517+03
773	4	-1	1420	2019-08-18 18:16:29.350021+03
774	34	-1	1550	2019-08-18 18:29:32.141919+03
775	30	-1	1140	2019-08-18 18:44:52.226457+03
776	64	-1	970	2019-08-18 19:32:29.184121+03
777	70	-1	760	2019-08-18 19:39:42.871419+03
778	13	-1	460	2019-08-18 20:16:32.901973+03
779	76	-1	1070	2019-08-18 20:27:01.330185+03
780	61	-1	1510	2019-08-18 20:48:05.661332+03
781	40	-1	1430	2019-08-18 21:28:28.967219+03
782	68	-1	490	2019-08-18 22:24:14.315293+03
783	96	42	877	2019-08-18 22:29:46.210152+03
784	40	-1	1430	2019-08-18 23:01:56.323812+03
785	54	-2	3470	2019-08-18 23:18:13.260811+03
786	86	-1	910	2019-08-18 23:43:14.411853+03
787	71	-1	1030	2019-08-18 23:57:54.614152+03
788	34	-1	1550	2019-08-19 00:02:42.808198+03
789	58	-1	2830	2019-08-19 00:05:49.237948+03
790	20	-1	830	2019-08-19 00:29:52.544087+03
791	22	-2	1070	2019-08-19 00:30:58.709385+03
792	22	-2	1070	2019-08-19 00:56:37.388102+03
793	60	-1	2700	2019-08-19 00:57:25.422822+03
794	86	-2	910	2019-08-19 01:14:42.976099+03
795	35	-1	670	2019-08-19 01:31:22.968459+03
796	20	-1	830	2019-08-19 01:59:02.65483+03
797	42	29	888	2019-08-19 02:00:12.360591+03
798	1	-1	640	2019-08-19 02:06:58.818634+03
799	85	-1	730	2019-08-19 02:31:40.455672+03
800	40	40	762	2019-08-19 02:39:45.235726+03
801	20	-1	830	2019-08-19 03:04:47.105815+03
802	6	-1	980	2019-08-19 03:11:45.141609+03
803	38	-1	1100	2019-08-19 03:18:49.544443+03
804	31	-1	1190	2019-08-19 03:28:50.998206+03
805	83	-1	1230	2019-08-19 03:39:09.780072+03
806	40	-1	1430	2019-08-19 03:50:15.792873+03
807	90	-2	1780	2019-08-19 03:51:36.917296+03
808	77	-1	640	2019-08-19 04:15:58.921946+03
809	6	43	566	2019-08-19 04:18:25.722914+03
810	77	-1	640	2019-08-19 04:47:44.102366+03
811	78	-2	900	2019-08-19 04:54:37.545971+03
812	95	-1	480	2019-08-19 04:56:36.924959+03
813	57	-2	1900	2019-08-19 05:54:29.936335+03
814	77	-1	640	2019-08-19 06:02:09.125327+03
815	9	-1	2090	2019-08-19 06:40:35.974547+03
816	96	-1	1570	2019-08-19 06:55:50.615074+03
817	63	-1	1780	2019-08-19 07:01:18.936789+03
818	4	-1	1420	2019-08-19 07:09:37.205143+03
819	79	-1	550	2019-08-19 07:12:35.58498+03
820	42	-1	1790	2019-08-19 07:34:13.445226+03
821	65	-1	490	2019-08-19 08:43:36.154184+03
822	59	-1	1030	2019-08-19 08:49:32.213453+03
823	18	-1	910	2019-08-19 08:58:45.915866+03
824	33	-1	900	2019-08-19 09:08:45.477054+03
825	96	-1	1570	2019-08-19 09:14:26.81781+03
826	58	24	1469	2019-08-19 10:59:39.460204+03
827	76	-1	1070	2019-08-19 11:43:39.655273+03
828	34	-2	1550	2019-08-19 12:03:34.133163+03
829	15	-1	2830	2019-08-19 12:05:30.923922+03
830	93	-2	1620	2019-08-19 12:05:47.12565+03
831	47	-2	1480	2019-08-19 12:53:59.566411+03
832	74	-1	1010	2019-08-19 12:59:35.678179+03
833	1	-1	640	2019-08-19 13:06:30.214241+03
834	30	-2	1140	2019-08-19 13:12:57.737307+03
835	10	-1	2080	2019-08-19 13:25:48.768645+03
836	37	-2	1290	2019-08-19 13:32:32.092413+03
837	95	29	213	2019-08-19 13:45:01.516365+03
838	86	-1	910	2019-08-19 13:46:52.324437+03
839	86	-1	910	2019-08-19 14:53:04.933494+03
840	44	-2	500	2019-08-19 14:57:54.035658+03
841	41	-1	830	2019-08-19 15:10:35.163197+03
842	85	-1	730	2019-08-19 15:28:36.172376+03
843	42	-1	1790	2019-08-19 15:40:30.716172+03
844	77	-1	640	2019-08-19 15:52:17.982382+03
845	76	-1	1070	2019-08-19 15:54:15.971461+03
846	75	-2	830	2019-08-19 15:55:15.592598+03
847	69	-2	1100	2019-08-19 15:58:57.104719+03
848	27	-1	880	2019-08-19 16:49:44.989704+03
849	63	-1	1780	2019-08-19 17:04:38.963067+03
850	90	-2	1780	2019-08-19 17:08:35.960005+03
851	77	-1	640	2019-08-19 17:13:02.818849+03
852	96	-1	1570	2019-08-19 17:16:56.051275+03
853	79	-1	550	2019-08-19 17:51:02.647048+03
854	25	-1	1100	2019-08-19 17:52:11.39859+03
855	82	-1	560	2019-08-19 18:13:11.170092+03
856	1	-1	640	2019-08-19 18:15:41.477827+03
857	82	-1	560	2019-08-19 18:19:27.540943+03
858	42	-1	1790	2019-08-19 18:33:39.89137+03
859	8	-1	1920	2019-08-19 18:40:47.501689+03
860	48	-1	640	2019-08-19 18:55:30.254433+03
861	46	-1	1270	2019-08-19 18:59:35.902165+03
862	14	-1	1350	2019-08-19 19:00:59.596479+03
863	35	-1	670	2019-08-19 19:09:12.287061+03
864	77	-1	640	2019-08-19 19:53:15.630952+03
865	65	-1	490	2019-08-19 20:01:29.684275+03
866	9	-1	2090	2019-08-19 20:02:06.53942+03
867	21	-1	960	2019-08-19 20:26:44.904007+03
868	62	-2	1220	2019-08-19 20:37:34.856058+03
869	47	-1	1480	2019-08-19 20:47:15.502424+03
870	45	-1	1590	2019-08-19 20:56:51.048509+03
871	83	-1	1230	2019-08-19 21:07:46.993697+03
872	47	-2	1480	2019-08-19 21:32:41.294786+03
873	79	-1	550	2019-08-19 21:44:56.610138+03
874	7	-2	810	2019-08-19 22:32:55.492249+03
875	77	37	374	2019-08-19 22:40:28.113338+03
876	17	-2	1500	2019-08-19 22:46:05.136117+03
877	17	-1	1500	2019-08-19 23:36:36.579522+03
878	88	-1	1270	2019-08-19 23:38:30.39983+03
879	82	-1	560	2019-08-19 23:46:28.44169+03
880	18	-1	910	2019-08-20 00:06:30.783644+03
881	87	-2	2320	2019-08-20 00:08:12.454887+03
882	94	-1	1230	2019-08-20 00:12:45.771146+03
883	47	-1	1480	2019-08-20 00:59:01.83571+03
884	56	31	1315	2019-08-20 01:19:06.628804+03
885	76	-2	1070	2019-08-20 01:51:50.564445+03
886	21	-1	960	2019-08-20 02:00:55.649039+03
887	84	-2	2700	2019-08-20 02:27:00.806106+03
888	64	-2	970	2019-08-20 03:23:48.694534+03
889	53	-1	3120	2019-08-20 04:02:39.693706+03
890	81	-1	1620	2019-08-20 04:05:39.954774+03
891	39	-1	910	2019-08-20 04:33:43.779575+03
892	47	-1	1480	2019-08-20 04:55:36.463819+03
893	48	-1	640	2019-08-20 05:00:22.866442+03
894	56	-2	2460	2019-08-20 05:10:03.681059+03
895	45	-1	1590	2019-08-20 05:13:39.500925+03
896	75	-2	830	2019-08-20 05:28:13.498489+03
897	30	-1	1140	2019-08-20 05:39:01.375806+03
898	37	-1	1290	2019-08-20 05:42:19.094717+03
899	30	-1	1140	2019-08-20 05:48:19.347275+03
900	4	-1	1420	2019-08-20 05:55:30.191119+03
901	5	-1	1620	2019-08-20 06:13:41.704965+03
902	56	-1	2460	2019-08-20 06:39:18.696229+03
903	96	-1	1570	2019-08-20 06:58:51.033045+03
904	87	-1	2320	2019-08-20 07:17:32.895952+03
905	74	-1	1010	2019-08-20 07:23:41.685431+03
906	95	-1	480	2019-08-20 07:39:59.596198+03
907	69	-1	1100	2019-08-20 07:50:28.977273+03
908	66	-1	690	2019-08-20 07:50:29.193473+03
909	79	-1	550	2019-08-20 09:14:15.911276+03
910	42	-1	1790	2019-08-20 09:20:19.264345+03
911	57	44	1045	2019-08-20 09:50:14.45187+03
912	56	-2	2460	2019-08-20 10:13:44.185201+03
913	72	-1	620	2019-08-20 10:58:22.927279+03
914	4	-1	1420	2019-08-20 12:02:39.833888+03
915	33	-1	900	2019-08-20 12:17:21.248345+03
916	31	-1	1190	2019-08-20 13:31:13.971466+03
917	40	-1	1430	2019-08-20 13:40:50.159781+03
918	6	-1	980	2019-08-20 13:54:06.123479+03
919	4	-1	1420	2019-08-20 14:44:19.03363+03
920	58	-1	2830	2019-08-20 15:30:37.716803+03
921	88	-1	1270	2019-08-20 15:35:20.339564+03
922	64	-1	970	2019-08-20 15:42:46.872145+03
923	7	-1	810	2019-08-20 16:24:16.265961+03
924	86	-1	910	2019-08-20 16:25:00.511965+03
925	87	-1	2320	2019-08-20 16:30:51.743119+03
926	73	18	407	2019-08-20 17:14:23.842052+03
927	60	-1	2700	2019-08-20 17:33:51.888582+03
928	20	-1	830	2019-08-20 17:43:02.894456+03
929	59	-1	1030	2019-08-20 18:00:17.267084+03
930	1	32	336	2019-08-20 19:18:24.676266+03
931	22	-1	1070	2019-08-20 19:20:07.106014+03
932	31	-1	1190	2019-08-20 20:19:41.630699+03
933	76	-1	1070	2019-08-20 20:29:02.005043+03
934	1	-1	640	2019-08-20 20:33:19.967641+03
935	9	-1	2090	2019-08-20 21:19:34.006878+03
936	52	-2	1090	2019-08-20 21:38:07.763374+03
937	95	-1	480	2019-08-20 21:53:06.416184+03
938	28	-1	1860	2019-08-20 22:00:43.61159+03
939	47	-1	1480	2019-08-20 22:13:28.183909+03
940	68	-2	490	2019-08-20 22:27:53.469015+03
941	29	-2	1940	2019-08-20 22:41:33.210646+03
942	44	-1	500	2019-08-20 22:47:09.717215+03
943	60	-1	2700	2019-08-20 22:56:05.505627+03
944	12	-1	1650	2019-08-20 23:15:49.41368+03
945	80	-1	1120	2019-08-20 23:18:46.774806+03
946	32	-1	710	2019-08-20 23:22:50.631263+03
947	2	-1	470	2019-08-21 00:07:14.383317+03
948	13	-1	460	2019-08-21 00:30:41.322226+03
949	35	-1	670	2019-08-21 00:46:33.956804+03
950	13	-1	460	2019-08-21 00:48:30.372262+03
951	85	-1	730	2019-08-21 00:48:31.487981+03
952	31	-1	1190	2019-08-21 01:50:21.358349+03
953	29	-1	1940	2019-08-21 02:26:58.886209+03
954	77	-1	640	2019-08-21 02:47:03.534084+03
955	16	-1	1380	2019-08-21 03:18:51.656561+03
956	94	-1	1230	2019-08-21 03:35:24.09601+03
957	49	-2	970	2019-08-21 03:35:55.074718+03
958	32	-1	710	2019-08-21 03:47:02.842134+03
959	5	-1	1620	2019-08-21 03:48:47.946501+03
960	36	-1	630	2019-08-21 03:54:23.496171+03
961	32	-1	710	2019-08-21 03:56:42.791066+03
962	79	-1	550	2019-08-21 04:06:09.832796+03
963	15	-1	2830	2019-08-21 04:35:31.756763+03
964	67	-1	350	2019-08-21 04:51:52.960653+03
965	59	-1	1030	2019-08-21 05:02:36.356143+03
966	14	-1	1350	2019-08-21 05:11:50.438305+03
967	14	-1	1350	2019-08-21 06:06:19.034765+03
968	58	-1	2830	2019-08-21 06:20:02.601325+03
969	63	-1	1780	2019-08-21 06:20:32.597109+03
970	29	-1	1940	2019-08-21 07:26:05.483889+03
971	21	-1	960	2019-08-21 07:27:49.200738+03
972	30	-1	1140	2019-08-21 07:35:00.5277+03
973	19	-1	1220	2019-08-21 07:35:05.03206+03
974	92	-1	630	2019-08-21 07:54:00.431006+03
975	81	-1	1620	2019-08-21 08:03:43.210086+03
976	63	-1	1780	2019-08-21 08:09:21.219749+03
977	61	-1	1510	2019-08-21 08:13:33.732365+03
978	71	-2	1030	2019-08-21 08:14:44.827471+03
979	87	-2	2320	2019-08-21 08:45:02.439202+03
980	16	-1	1380	2019-08-21 09:06:53.379773+03
981	52	-1	1090	2019-08-21 09:48:20.905897+03
982	68	-1	490	2019-08-21 09:56:24.409653+03
983	29	-1	1940	2019-08-21 10:28:01.873378+03
984	33	-1	900	2019-08-21 10:28:51.014659+03
985	40	-1	1430	2019-08-21 10:29:23.574393+03
986	24	-1	950	2019-08-21 10:33:01.438681+03
987	42	-1	1790	2019-08-21 10:38:06.930301+03
988	66	-2	690	2019-08-21 10:41:24.942787+03
989	87	40	1086	2019-08-21 10:49:16.867475+03
990	86	-1	910	2019-08-21 11:03:37.733228+03
991	58	-1	2830	2019-08-21 11:11:10.72642+03
992	48	-1	640	2019-08-21 11:17:04.759106+03
993	44	-1	500	2019-08-21 11:21:31.109645+03
994	21	-1	960	2019-08-21 11:42:01.798458+03
995	55	-1	3480	2019-08-21 12:02:19.751949+03
996	67	-1	350	2019-08-21 12:07:02.740855+03
997	57	-1	1900	2019-08-21 12:29:15.899599+03
998	54	-2	3470	2019-08-21 12:30:02.320602+03
999	56	-1	2460	2019-08-21 12:50:44.296426+03
1000	49	-1	970	2019-08-21 13:04:05.992056+03
1001	81	-1	1620	2019-08-21 13:39:39.079682+03
1002	46	-1	1270	2019-08-21 13:45:57.487474+03
1003	89	-1	1420	2019-08-21 13:51:36.080003+03
1004	8	-2	1920	2019-08-21 14:00:13.967709+03
1005	91	-1	1620	2019-08-21 14:34:36.944203+03
1006	78	-1	900	2019-08-21 15:03:40.402538+03
1007	85	-1	730	2019-08-21 15:09:34.894101+03
1008	89	-1	1420	2019-08-21 15:13:09.033607+03
1009	59	-1	1030	2019-08-21 15:15:24.704684+03
1010	77	-1	640	2019-08-21 15:15:38.527082+03
1011	38	-1	1100	2019-08-21 15:23:23.698308+03
1012	93	-1	1620	2019-08-21 15:25:53.637378+03
1013	56	-1	2460	2019-08-21 15:28:40.944587+03
1014	13	-1	460	2019-08-21 15:42:28.612496+03
1015	76	-1	1070	2019-08-21 16:03:14.123473+03
1016	13	-1	460	2019-08-21 16:56:28.299162+03
1017	33	-1	900	2019-08-21 17:01:20.743562+03
1018	95	-1	480	2019-08-21 17:03:47.124959+03
1019	58	-1	2830	2019-08-21 17:04:07.757129+03
1020	55	-1	3480	2019-08-21 17:06:22.591651+03
1021	51	-1	1310	2019-08-21 17:16:42.765501+03
1022	57	-1	1900	2019-08-21 17:20:31.780221+03
1023	60	-1	2700	2019-08-21 17:48:12.988137+03
1024	92	-1	630	2019-08-21 17:48:39.31616+03
1025	10	-2	2080	2019-08-21 17:48:49.624416+03
1026	51	28	759	2019-08-21 18:25:12.362459+03
1027	73	-1	960	2019-08-21 18:27:19.323827+03
1028	74	22	457	2019-08-21 19:04:11.199491+03
1029	8	-1	1920	2019-08-21 19:05:12.114212+03
1030	56	-1	2460	2019-08-21 19:28:52.87394+03
1031	74	-1	1010	2019-08-21 19:34:43.058855+03
1032	21	-1	960	2019-08-21 19:40:31.097651+03
1033	2	-1	470	2019-08-21 19:43:27.048987+03
1034	5	-3	1620	2019-08-21 20:15:04.340795+03
1035	20	-1	830	2019-08-21 20:45:28.331741+03
1036	49	-1	970	2019-08-21 21:11:02.872861+03
1037	92	-1	630	2019-08-21 21:12:07.384705+03
1038	80	25	468	2019-08-21 22:05:22.93852+03
1039	49	-1	970	2019-08-21 22:17:20.331113+03
1040	67	-1	350	2019-08-21 22:26:12.561283+03
1041	5	-1	1620	2019-08-21 23:01:25.17408+03
1042	34	-2	1550	2019-08-21 23:22:36.48895+03
1043	2	-1	470	2019-08-22 00:13:14.716182+03
1044	20	-1	830	2019-08-22 00:16:30.019156+03
1045	23	-1	4390	2019-08-22 00:37:47.668973+03
1046	10	-1	2080	2019-08-22 00:45:36.425366+03
1047	35	-1	670	2019-08-22 01:18:40.445546+03
1048	77	-1	640	2019-08-22 01:23:07.330118+03
1049	49	-1	970	2019-08-22 02:02:36.971185+03
1050	76	-2	1070	2019-08-22 02:32:31.737347+03
1051	12	-3	1650	2019-08-22 03:29:31.129893+03
1052	92	-1	630	2019-08-22 03:42:22.437687+03
1053	67	-1	350	2019-08-22 03:47:06.550292+03
1054	49	-2	970	2019-08-22 03:59:22.148795+03
1055	4	-1	1420	2019-08-22 04:04:10.120793+03
1056	86	32	460	2019-08-22 04:23:33.951122+03
1057	5	28	852	2019-08-22 04:30:15.635109+03
1058	95	-1	480	2019-08-22 04:58:01.093717+03
1059	18	-1	910	2019-08-22 05:10:08.845433+03
1060	37	-1	1290	2019-08-22 05:11:25.455059+03
1061	79	-1	550	2019-08-22 05:43:21.628167+03
1062	48	24	349	2019-08-22 05:46:54.611795+03
1063	37	-2	1290	2019-08-22 06:37:18.599979+03
1064	56	-1	2460	2019-08-22 06:43:04.390742+03
1065	57	-2	1900	2019-08-22 06:46:43.042385+03
1066	61	-1	1510	2019-08-22 07:20:51.844657+03
1067	46	-2	1270	2019-08-22 07:21:14.850241+03
1068	16	-1	1380	2019-08-22 07:33:53.717674+03
1069	42	-2	1790	2019-08-22 07:35:17.176299+03
1070	23	-1	4390	2019-08-22 07:42:10.825434+03
1071	29	-1	1940	2019-08-22 07:46:18.092261+03
1072	14	-2	1350	2019-08-22 07:57:57.292701+03
1073	8	-1	1920	2019-08-22 08:05:27.542072+03
1074	22	-2	1070	2019-08-22 08:35:28.326444+03
1075	24	-2	950	2019-08-22 09:26:03.370987+03
1076	4	-1	1420	2019-08-22 09:57:21.785899+03
1077	14	-1	1350	2019-08-22 09:57:47.900809+03
1078	20	-1	830	2019-08-22 10:04:44.758189+03
1079	63	-1	1780	2019-08-22 10:30:48.136613+03
1080	10	-1	2080	2019-08-22 10:55:55.546347+03
1081	33	-1	900	2019-08-22 11:05:38.493262+03
1082	61	-1	1510	2019-08-22 11:10:01.29077+03
1083	78	-1	900	2019-08-22 11:34:33.385676+03
1084	29	42	1161	2019-08-22 11:44:10.445866+03
1085	49	-2	970	2019-08-22 11:45:17.953953+03
1086	5	-1	1620	2019-08-22 11:51:06.366227+03
1087	4	24	788	2019-08-22 11:53:06.123621+03
1088	86	-1	910	2019-08-22 11:59:36.856884+03
1089	46	-1	1270	2019-08-22 12:05:54.655339+03
1090	60	-1	2700	2019-08-22 12:10:44.033633+03
1091	15	22	1280	2019-08-22 12:40:04.078817+03
1092	51	-1	1310	2019-08-22 13:11:55.94471+03
1093	70	-1	760	2019-08-22 13:17:06.273294+03
1094	12	-1	1650	2019-08-22 13:46:30.47942+03
1095	5	-2	1620	2019-08-22 13:46:39.416025+03
1096	34	-1	1550	2019-08-22 13:50:22.868786+03
1097	88	-1	1270	2019-08-22 14:18:19.47936+03
1098	31	23	502	2019-08-22 14:20:19.116869+03
1099	96	-1	1570	2019-08-22 15:03:40.78901+03
1100	36	29	261	2019-08-22 15:19:54.349535+03
1101	81	-1	1620	2019-08-22 15:30:20.374449+03
1102	27	-1	880	2019-08-22 15:56:28.078647+03
1103	13	-1	460	2019-08-22 15:57:18.088541+03
1104	17	-1	1500	2019-08-22 15:57:50.79979+03
1105	65	-1	490	2019-08-22 16:03:08.893931+03
1106	32	-1	710	2019-08-22 16:16:20.124973+03
1107	47	-1	1480	2019-08-22 16:46:58.605886+03
1108	86	-1	910	2019-08-22 16:47:03.012804+03
1109	86	-1	910	2019-08-22 16:48:38.93964+03
1110	62	-1	1220	2019-08-22 17:19:31.764492+03
1111	8	-1	1920	2019-08-22 17:35:38.096878+03
1112	47	-2	1480	2019-08-22 17:44:57.781831+03
1113	47	-1	1480	2019-08-22 17:59:21.746569+03
1114	42	-1	1790	2019-08-22 18:06:37.13823+03
1115	10	-2	2080	2019-08-22 18:10:25.809508+03
1116	68	-1	490	2019-08-22 18:12:54.1023+03
1117	30	-1	1140	2019-08-22 18:19:46.678572+03
1118	36	-2	630	2019-08-22 18:25:17.759536+03
1119	87	-1	2320	2019-08-22 18:37:35.603162+03
1120	26	-2	390	2019-08-22 19:05:05.27811+03
1121	14	-1	1350	2019-08-22 19:29:14.09081+03
1122	17	-1	1500	2019-08-22 19:41:07.081882+03
1123	75	-1	830	2019-08-22 20:00:53.006283+03
1124	63	-2	1780	2019-08-22 20:12:46.697453+03
1125	39	-1	910	2019-08-22 20:14:06.31577+03
1126	76	-2	1070	2019-08-22 20:28:19.454469+03
1127	19	-1	1220	2019-08-22 20:31:00.993939+03
1128	4	-1	1420	2019-08-22 20:34:02.596223+03
1129	20	-2	830	2019-08-22 20:38:46.914933+03
1130	81	-1	1620	2019-08-22 20:41:55.460226+03
1131	1	-1	640	2019-08-22 21:04:01.076778+03
1132	56	-1	2460	2019-08-22 21:33:47.939286+03
1133	93	-1	1620	2019-08-22 21:46:47.226314+03
1134	5	-2	1620	2019-08-22 21:59:34.925047+03
1135	32	-1	710	2019-08-22 23:10:41.643962+03
1136	92	-1	630	2019-08-22 23:20:08.397584+03
1137	65	-2	490	2019-08-22 23:22:44.457384+03
1138	25	-1	1100	2019-08-22 23:23:36.465884+03
1139	13	-1	460	2019-08-23 00:02:43.863478+03
1140	33	-1	900	2019-08-23 00:20:42.349264+03
1141	33	-1	900	2019-08-23 00:33:13.150693+03
1142	74	-1	1010	2019-08-23 00:39:53.412898+03
1143	53	-1	3120	2019-08-23 00:46:13.36695+03
1144	58	-1	2830	2019-08-23 00:50:31.873341+03
1145	69	20	579	2019-08-23 01:08:45.44439+03
1146	12	-1	1650	2019-08-23 01:14:12.328897+03
1147	29	-1	1940	2019-08-23 02:32:18.314335+03
1148	47	-1	1480	2019-08-23 02:38:36.547459+03
1149	61	-1	1510	2019-08-23 03:22:21.454924+03
1150	90	-1	1780	2019-08-23 03:43:58.398148+03
1151	60	-1	2700	2019-08-23 03:45:06.261818+03
1152	80	-1	1120	2019-08-23 03:45:07.051139+03
1153	78	-1	900	2019-08-23 03:47:53.660343+03
1154	84	31	1549	2019-08-23 04:13:32.505416+03
1155	96	-1	1570	2019-08-23 04:13:43.474847+03
1156	33	-1	900	2019-08-23 04:20:32.310134+03
1157	53	-1	3120	2019-08-23 04:35:49.920356+03
1158	24	-1	950	2019-08-23 05:04:14.716324+03
1159	81	-1	1620	2019-08-23 05:04:22.364692+03
1160	87	-1	2320	2019-08-23 05:04:55.136505+03
1161	64	-1	970	2019-08-23 05:14:25.419842+03
1162	86	-1	910	2019-08-23 05:57:43.187227+03
1163	68	-1	490	2019-08-23 05:58:08.20457+03
1164	48	-1	640	2019-08-23 06:15:59.525026+03
1165	35	-1	670	2019-08-23 06:20:58.606962+03
1166	84	-1	2700	2019-08-23 06:43:17.582525+03
1167	90	-1	1780	2019-08-23 06:55:26.142933+03
1168	31	-2	1190	2019-08-23 06:58:40.708672+03
1169	96	-1	1570	2019-08-23 07:15:50.39169+03
1170	49	33	508	2019-08-23 07:24:22.582082+03
1171	12	-1	1650	2019-08-23 07:36:04.590858+03
1172	88	-1	1270	2019-08-23 07:41:55.041443+03
1173	46	-1	1270	2019-08-23 07:46:37.311432+03
1174	6	-1	980	2019-08-23 07:54:08.132901+03
1175	38	-2	1100	2019-08-23 08:03:30.762476+03
1176	9	-1	2090	2019-08-23 08:09:23.21411+03
1177	54	-1	3470	2019-08-23 08:48:42.82138+03
1178	49	-2	970	2019-08-23 09:02:48.398005+03
1179	58	-1	2830	2019-08-23 09:09:40.695643+03
1180	35	-1	670	2019-08-23 09:49:43.006608+03
1181	19	-1	1220	2019-08-23 10:12:36.664943+03
1182	44	-1	500	2019-08-23 10:15:16.421555+03
1183	65	-1	490	2019-08-23 11:16:13.503547+03
1184	44	-1	500	2019-08-23 11:30:26.952955+03
1185	43	17	190	2019-08-23 12:01:25.806507+03
1186	67	-1	350	2019-08-23 12:07:36.010066+03
1187	94	-2	1230	2019-08-23 12:25:20.524029+03
1188	42	-1	1790	2019-08-23 12:26:29.966837+03
1189	7	-1	810	2019-08-23 12:30:55.859768+03
1190	62	-2	1220	2019-08-23 12:51:49.134692+03
1191	19	-1	1220	2019-08-23 12:53:23.33855+03
1192	33	-1	900	2019-08-23 13:10:43.51739+03
1193	90	-1	1780	2019-08-23 13:20:20.634531+03
1194	13	36	188	2019-08-23 13:25:13.620274+03
1195	91	-1	1620	2019-08-23 14:06:04.397297+03
1196	35	-2	670	2019-08-23 14:06:27.763931+03
1197	18	-1	910	2019-08-23 14:07:03.266892+03
1198	1	-1	640	2019-08-23 14:19:29.304061+03
1199	85	-1	730	2019-08-23 14:42:17.25342+03
1200	47	-3	1480	2019-08-23 14:43:58.92803+03
1201	28	-1	1860	2019-08-23 14:45:43.998164+03
1202	77	-1	640	2019-08-23 14:57:49.878381+03
1203	42	-1	1790	2019-08-23 15:47:05.111926+03
1204	96	-1	1570	2019-08-23 15:49:26.185405+03
1205	12	-1	1650	2019-08-23 15:52:53.074141+03
1206	30	-1	1140	2019-08-23 16:02:18.906614+03
1207	75	-1	830	2019-08-23 16:49:03.039468+03
1208	71	-1	1030	2019-08-23 16:59:46.597535+03
1209	53	-1	3120	2019-08-23 17:23:12.874379+03
1210	8	-1	1920	2019-08-23 17:39:25.869129+03
1211	54	34	1694	2019-08-23 18:04:01.805574+03
1212	94	-1	1230	2019-08-23 19:02:57.217309+03
1213	28	-1	1860	2019-08-23 19:12:41.766574+03
1214	5	-1	1620	2019-08-23 19:17:56.577063+03
1215	49	-1	970	2019-08-23 19:19:41.432429+03
1216	49	-2	970	2019-08-23 19:24:37.20026+03
1217	14	-1	1350	2019-08-23 19:38:54.107043+03
1218	85	17	428	2019-08-23 19:48:51.316408+03
1219	80	-1	1120	2019-08-23 20:24:29.153519+03
1220	90	-1	1780	2019-08-23 20:40:29.769124+03
1221	83	-1	1230	2019-08-23 20:41:46.416676+03
1222	80	-1	1120	2019-08-23 21:38:30.575567+03
1223	87	-1	2320	2019-08-23 21:39:03.593922+03
1224	94	-2	1230	2019-08-23 21:39:55.479308+03
1225	92	-1	630	2019-08-23 21:41:39.931302+03
1226	74	-1	1010	2019-08-23 21:42:17.284329+03
1227	29	-1	1940	2019-08-23 21:44:11.775711+03
1228	33	-1	900	2019-08-23 22:03:09.430083+03
1229	80	-1	1120	2019-08-23 22:06:02.538043+03
1230	87	-1	2320	2019-08-23 22:07:25.847461+03
1231	60	-2	2700	2019-08-23 22:13:43.602621+03
1232	87	-1	2320	2019-08-23 22:15:08.694308+03
1233	55	-2	3480	2019-08-23 22:17:14.788012+03
1234	78	20	409	2019-08-23 22:24:55.786011+03
1235	93	-1	1620	2019-08-23 23:02:55.229486+03
1236	14	-1	1350	2019-08-23 23:32:13.241121+03
1237	83	-1	1230	2019-08-23 23:40:49.447611+03
1238	6	-3	980	2019-08-23 23:41:14.140803+03
1239	80	-1	1120	2019-08-23 23:56:06.915603+03
1240	64	-1	970	2019-08-24 00:35:16.456714+03
1241	14	-2	1350	2019-08-24 00:43:12.648268+03
1242	9	-1	2090	2019-08-24 00:43:45.86075+03
1243	71	-1	1030	2019-08-24 01:11:43.930878+03
1244	54	-1	3470	2019-08-24 01:12:11.893296+03
1245	39	-1	910	2019-08-24 01:55:21.830777+03
1246	6	-1	980	2019-08-24 01:58:45.175314+03
1247	49	-2	970	2019-08-24 02:35:45.12998+03
1248	59	-1	1030	2019-08-24 02:38:21.31658+03
1249	35	-1	670	2019-08-24 03:20:48.658542+03
1250	69	-1	1100	2019-08-24 03:21:15.385274+03
1251	47	-1	1480	2019-08-24 03:21:31.832079+03
1252	23	-2	4390	2019-08-24 03:33:52.688904+03
1253	70	-2	760	2019-08-24 03:44:14.486327+03
1254	12	-1	1650	2019-08-24 03:49:22.168386+03
1255	9	-1	2090	2019-08-24 04:11:05.707712+03
1256	5	-1	1620	2019-08-24 04:21:15.222146+03
1257	37	-1	1290	2019-08-24 04:28:12.568133+03
1258	40	-1	1430	2019-08-24 04:40:22.532447+03
1259	22	-1	1070	2019-08-24 04:40:36.754179+03
1260	1	-1	640	2019-08-24 05:00:43.022125+03
1261	87	-1	2320	2019-08-24 05:19:46.503671+03
1262	69	-2	1100	2019-08-24 05:20:35.285975+03
1263	35	-1	670	2019-08-24 05:22:54.144012+03
1264	17	-1	1500	2019-08-24 05:47:15.695192+03
1265	87	-1	2320	2019-08-24 06:01:18.40003+03
1266	36	-1	630	2019-08-24 06:03:20.966647+03
1267	61	-2	1510	2019-08-24 06:03:41.913404+03
1268	1	-1	640	2019-08-24 06:04:07.112394+03
1269	74	-1	1010	2019-08-24 06:05:16.704969+03
1270	25	-1	1100	2019-08-24 06:08:38.551307+03
1271	5	-1	1620	2019-08-24 06:23:51.05612+03
1272	35	-1	670	2019-08-24 06:36:27.733789+03
1273	59	-1	1030	2019-08-24 07:25:39.573588+03
1274	39	30	490	2019-08-24 07:31:47.673911+03
1275	79	-1	550	2019-08-24 07:34:26.494389+03
1276	54	-2	3470	2019-08-24 07:49:42.810293+03
1277	55	-1	3480	2019-08-24 08:11:13.427494+03
1278	22	-1	1070	2019-08-24 08:28:11.082995+03
1279	57	-1	1900	2019-08-24 08:38:01.483048+03
1280	14	-1	1350	2019-08-24 08:50:47.521833+03
1281	26	-1	390	2019-08-24 08:51:32.064767+03
1282	52	-1	1090	2019-08-24 08:59:25.504144+03
1283	54	-1	3470	2019-08-24 09:05:56.707354+03
1284	29	-1	1940	2019-08-24 09:19:23.594055+03
1285	55	-2	3480	2019-08-24 09:56:11.76465+03
1286	87	-1	2320	2019-08-24 10:12:13.787988+03
1287	29	-1	1940	2019-08-24 10:57:50.947542+03
1288	49	-2	970	2019-08-24 11:14:05.009181+03
1289	30	-2	1140	2019-08-24 11:45:22.86822+03
1290	25	-1	1100	2019-08-24 11:54:33.707909+03
1291	94	-1	1230	2019-08-24 12:01:30.735219+03
1292	51	-2	1310	2019-08-24 12:14:19.785608+03
1293	76	-1	1070	2019-08-24 12:27:03.789741+03
1294	86	-1	910	2019-08-24 12:27:37.381674+03
1295	29	-1	1940	2019-08-24 12:39:31.963648+03
1296	54	-3	3470	2019-08-24 12:48:21.110589+03
1297	20	-1	830	2019-08-24 12:51:04.582093+03
1298	92	-1	630	2019-08-24 12:51:07.725856+03
1299	17	-1	1500	2019-08-24 13:36:20.01086+03
1300	76	-1	1070	2019-08-24 14:27:52.134303+03
1301	14	-1	1350	2019-08-24 14:30:03.597191+03
1302	93	-1	1620	2019-08-24 14:36:18.229919+03
1303	69	-1	1100	2019-08-24 15:44:49.394543+03
1304	86	-1	910	2019-08-24 16:00:49.901363+03
1305	42	-2	1790	2019-08-24 16:16:54.078953+03
1306	39	-2	910	2019-08-24 16:41:19.61916+03
1307	47	-1	1480	2019-08-24 16:46:15.748563+03
1308	14	-2	1350	2019-08-24 16:50:57.131325+03
1309	10	-2	2080	2019-08-24 16:55:17.968154+03
1310	27	-2	880	2019-08-24 16:56:26.34998+03
1311	32	-1	710	2019-08-24 17:15:33.074011+03
1312	30	-1	1140	2019-08-24 17:16:13.41915+03
1313	17	-1	1500	2019-08-24 17:43:28.536516+03
1314	10	-1	2080	2019-08-24 17:58:48.812581+03
1315	20	-1	830	2019-08-24 17:59:22.294993+03
1316	8	25	772	2019-08-24 18:01:24.72767+03
1317	76	-1	1070	2019-08-24 18:10:30.900063+03
1318	55	-1	3480	2019-08-24 18:18:39.437385+03
1319	86	-1	910	2019-08-24 19:02:01.428313+03
1320	80	-1	1120	2019-08-24 19:14:34.5038+03
1321	56	-1	2460	2019-08-24 19:42:58.124935+03
1322	27	-2	880	2019-08-24 20:09:24.722447+03
1323	92	27	293	2019-08-24 20:13:46.053567+03
1324	4	-1	1420	2019-08-24 20:17:20.821047+03
1325	80	-1	1120	2019-08-24 20:35:52.473499+03
1326	35	-1	670	2019-08-24 20:36:38.812436+03
1327	19	-1	1220	2019-08-24 20:48:58.827933+03
1328	84	-1	2700	2019-08-24 20:59:26.540509+03
1329	46	-1	1270	2019-08-24 21:05:13.100099+03
1330	30	-1	1140	2019-08-24 21:36:47.711992+03
1331	52	-1	1090	2019-08-24 21:37:38.58961+03
1332	14	-1	1350	2019-08-24 21:40:43.467637+03
1333	29	-1	1940	2019-08-24 22:27:42.183785+03
1334	12	-1	1650	2019-08-24 22:49:19.194583+03
1335	47	41	711	2019-08-24 22:49:25.695278+03
1336	14	-1	1350	2019-08-24 22:51:59.503288+03
1337	30	-2	1140	2019-08-24 23:40:49.454764+03
1338	14	-1	1350	2019-08-24 23:51:30.921856+03
1339	76	-1	1070	2019-08-24 23:51:45.533369+03
1340	52	-1	1090	2019-08-24 23:57:20.161889+03
1341	31	-1	1190	2019-08-25 00:14:14.556298+03
1342	35	-2	670	2019-08-25 00:20:50.038544+03
1343	33	30	381	2019-08-25 00:21:40.043049+03
1344	40	-1	1430	2019-08-25 00:29:29.395974+03
1345	15	-1	2830	2019-08-25 00:32:37.102226+03
1346	51	-3	1310	2019-08-25 00:55:46.802788+03
1347	71	-2	1030	2019-08-25 01:00:21.933478+03
1348	57	-1	1900	2019-08-25 01:00:50.499142+03
1349	71	-2	1030	2019-08-25 01:02:25.548834+03
1350	79	-1	550	2019-08-25 01:06:35.659771+03
1351	95	-1	480	2019-08-25 01:21:46.491459+03
1352	22	34	517	2019-08-25 01:28:36.03061+03
1353	61	-1	1510	2019-08-25 01:34:28.674944+03
1354	87	-2	2320	2019-08-25 01:36:27.789804+03
1355	84	-1	2700	2019-08-25 01:37:36.965444+03
1356	1	-1	640	2019-08-25 01:38:38.693601+03
1357	14	-1	1350	2019-08-25 02:05:35.27322+03
1358	55	-1	3480	2019-08-25 02:13:08.88853+03
1359	64	-2	970	2019-08-25 02:25:34.874824+03
1360	77	-1	640	2019-08-25 02:29:21.140253+03
1361	46	-1	1270	2019-08-25 02:54:51.118066+03
1362	94	-2	1230	2019-08-25 03:07:37.370406+03
1363	47	-1	1480	2019-08-25 03:14:28.253863+03
1364	57	-2	1900	2019-08-25 03:22:59.126843+03
1365	34	-2	1550	2019-08-25 03:34:50.144642+03
1366	14	-1	1350	2019-08-25 03:45:21.639488+03
1367	93	-2	1620	2019-08-25 03:56:04.124895+03
1368	4	-1	1420	2019-08-25 04:11:08.653551+03
1369	40	-1	1430	2019-08-25 04:48:36.826806+03
1370	53	-1	3120	2019-08-25 05:01:22.752022+03
1371	57	-1	1900	2019-08-25 05:16:13.660037+03
1372	83	-1	1230	2019-08-25 05:59:15.652113+03
1373	87	-1	2320	2019-08-25 06:04:02.443334+03
1374	28	-1	1860	2019-08-25 06:04:13.312099+03
1375	17	-1	1500	2019-08-25 06:13:58.88981+03
1376	10	-2	2080	2019-08-25 06:48:39.339649+03
1377	40	-1	1430	2019-08-25 06:49:16.779503+03
1378	15	-1	2830	2019-08-25 06:56:07.345771+03
1379	46	33	655	2019-08-25 07:41:30.550151+03
1380	49	-1	970	2019-08-25 07:46:10.658343+03
1381	30	-2	1140	2019-08-25 08:15:18.503271+03
1382	12	36	940	2019-08-25 08:43:44.528658+03
1383	21	-1	960	2019-08-25 08:53:33.737072+03
1384	94	-1	1230	2019-08-25 09:09:00.102703+03
1385	3	-1	660	2019-08-25 09:17:57.851399+03
1386	41	-1	830	2019-08-25 09:25:18.310677+03
1387	51	-1	1310	2019-08-25 10:09:35.492315+03
1388	68	-1	490	2019-08-25 10:22:06.967012+03
1389	80	-1	1120	2019-08-25 11:08:09.306239+03
1390	53	-1	3120	2019-08-25 11:17:52.533928+03
1391	93	-2	1620	2019-08-25 12:00:15.095868+03
1392	5	-3	1620	2019-08-25 12:21:02.610051+03
1393	47	-2	1480	2019-08-25 12:27:18.114928+03
1394	21	-1	960	2019-08-25 12:29:12.395489+03
1395	14	-1	1350	2019-08-25 12:54:33.543137+03
1396	67	-1	350	2019-08-25 13:58:50.905621+03
1397	85	-1	730	2019-08-25 14:12:06.883032+03
1398	11	-1	830	2019-08-25 14:51:43.210073+03
1399	46	-1	1270	2019-08-25 14:53:08.779566+03
1400	11	-1	830	2019-08-25 15:05:44.475841+03
1401	92	-3	630	2019-08-25 15:09:55.727763+03
1402	34	-1	1550	2019-08-25 15:49:25.577378+03
1403	59	-2	1030	2019-08-25 15:54:02.416032+03
1404	10	-1	2080	2019-08-25 15:54:36.85407+03
1405	71	40	535	2019-08-25 16:04:07.2228+03
1406	54	-1	3470	2019-08-25 16:06:28.117129+03
1407	61	-1	1510	2019-08-25 16:30:23.50295+03
1408	56	-1	2460	2019-08-25 16:37:36.677221+03
1409	4	-2	1420	2019-08-25 17:35:10.408316+03
1410	67	-1	350	2019-08-25 17:41:07.306324+03
1411	29	-2	1940	2019-08-25 17:53:58.024258+03
1412	88	-1	1270	2019-08-25 18:00:16.801468+03
1413	52	24	441	2019-08-25 18:00:35.219896+03
1414	20	-1	830	2019-08-25 18:44:40.662937+03
1415	93	-1	1620	2019-08-25 18:58:06.864823+03
1416	34	-1	1550	2019-08-25 19:27:02.334471+03
1417	68	-1	490	2019-08-25 19:29:09.092371+03
1418	21	22	432	2019-08-25 19:40:40.842988+03
1419	70	-1	760	2019-08-25 19:43:14.972901+03
1420	77	-2	640	2019-08-25 20:06:16.720138+03
1421	80	-1	1120	2019-08-25 20:12:31.382706+03
1422	9	-1	2090	2019-08-25 20:23:52.87104+03
1423	17	-1	1500	2019-08-25 20:32:47.194785+03
1424	71	-2	1030	2019-08-25 20:42:42.645098+03
1425	29	-1	1940	2019-08-25 20:53:55.644537+03
1426	77	-1	640	2019-08-25 21:16:17.484782+03
1427	62	-1	1220	2019-08-25 21:27:20.201885+03
1428	4	-1	1420	2019-08-25 21:29:41.084646+03
1429	17	-1	1500	2019-08-25 21:46:27.85043+03
1430	36	-1	630	2019-08-25 21:49:42.691683+03
1431	22	-2	1070	2019-08-25 22:02:05.32206+03
1432	60	-1	2700	2019-08-25 22:05:31.726193+03
1433	60	-1	2700	2019-08-25 22:11:42.95108+03
1434	47	-1	1480	2019-08-25 22:36:20.338708+03
1435	31	-1	1190	2019-08-25 22:45:10.53148+03
1436	13	-1	460	2019-08-25 22:45:10.919777+03
1437	10	-1	2080	2019-08-25 23:39:52.819164+03
1438	30	33	536	2019-08-25 23:41:17.42577+03
1439	16	-2	1380	2019-08-25 23:42:09.023358+03
1440	23	-1	4390	2019-08-26 00:00:25.539666+03
1441	8	-1	1920	2019-08-26 00:17:09.257724+03
1442	82	-1	560	2019-08-26 00:29:13.769138+03
1443	96	-1	1570	2019-08-26 00:45:36.520662+03
1444	73	-1	960	2019-08-26 01:01:29.773875+03
1445	1	-1	640	2019-08-26 01:06:06.625474+03
1446	54	-1	3470	2019-08-26 01:07:38.329698+03
1447	33	-1	900	2019-08-26 01:18:21.602578+03
1448	50	-1	1140	2019-08-26 01:23:38.609412+03
1449	83	-1	1230	2019-08-26 01:27:11.654889+03
1450	18	-1	910	2019-08-26 01:59:47.738626+03
1451	95	-1	480	2019-08-26 02:22:20.720509+03
1452	58	-1	2830	2019-08-26 02:33:01.526914+03
1453	73	-2	960	2019-08-26 02:48:02.256799+03
1454	6	-1	980	2019-08-26 02:55:04.457433+03
1455	48	-1	640	2019-08-26 03:03:42.352906+03
1456	22	-1	1070	2019-08-26 03:12:17.691758+03
1457	80	-1	1120	2019-08-26 03:23:53.996584+03
1458	47	-1	1480	2019-08-26 03:29:08.693659+03
1459	32	-1	710	2019-08-26 03:55:48.091477+03
1460	32	26	415	2019-08-26 04:02:58.527383+03
1461	40	-1	1430	2019-08-26 04:23:28.713404+03
1462	25	-1	1100	2019-08-26 04:52:49.931446+03
1463	67	-1	350	2019-08-26 05:03:29.064003+03
1464	62	-1	1220	2019-08-26 05:04:05.739093+03
1465	86	-1	910	2019-08-26 05:45:03.294095+03
1466	48	-1	640	2019-08-26 05:51:02.63123+03
1467	4	-1	1420	2019-08-26 05:54:45.581372+03
1468	28	-1	1860	2019-08-26 06:16:29.013731+03
1469	11	-1	830	2019-08-26 06:21:38.427612+03
1470	17	-1	1500	2019-08-26 06:38:54.933359+03
1471	4	-1	1420	2019-08-26 07:22:27.220139+03
1472	89	-2	1420	2019-08-26 07:46:49.427091+03
1473	93	-1	1620	2019-08-26 08:35:31.627346+03
1474	73	-1	960	2019-08-26 09:10:39.759288+03
1475	22	-1	1070	2019-08-26 09:28:31.793829+03
1476	18	-1	910	2019-08-26 09:33:43.05502+03
1477	69	-1	1100	2019-08-26 10:06:05.145476+03
1478	95	-1	480	2019-08-26 10:24:46.453609+03
1479	26	-1	390	2019-08-26 10:26:16.450291+03
1480	37	-2	1290	2019-08-26 10:37:05.288972+03
1481	3	-1	660	2019-08-26 11:29:31.298279+03
1482	47	-2	1480	2019-08-26 11:30:38.995696+03
1483	39	-1	910	2019-08-26 12:11:58.483499+03
1484	21	-2	960	2019-08-26 12:15:49.48469+03
1485	38	-1	1100	2019-08-26 12:15:57.826492+03
1486	51	-1	1310	2019-08-26 12:19:59.745541+03
1487	53	32	1788	2019-08-26 14:20:52.774874+03
1488	81	-2	1620	2019-08-26 14:59:37.8079+03
1489	72	-1	620	2019-08-26 15:11:24.830921+03
1490	79	-1	550	2019-08-26 15:17:41.909775+03
1491	44	-1	500	2019-08-26 15:21:29.39704+03
1492	13	-1	460	2019-08-26 15:42:49.784959+03
1493	29	-1	1940	2019-08-26 16:18:13.640262+03
1494	45	-1	1590	2019-08-26 16:35:46.311461+03
1495	41	-1	830	2019-08-26 16:40:19.250601+03
1496	58	-1	2830	2019-08-26 16:48:02.967756+03
1497	58	-2	2830	2019-08-26 17:17:05.921551+03
1498	74	-1	1010	2019-08-26 18:05:48.386578+03
1499	1	-1	640	2019-08-26 18:53:38.779004+03
1500	59	-1	1030	2019-08-26 18:56:54.29437+03
1501	90	-1	1780	2019-08-26 19:02:26.085255+03
1502	82	-2	560	2019-08-26 19:08:37.317139+03
1503	18	-1	910	2019-08-26 19:11:25.252969+03
1504	81	26	855	2019-08-26 19:11:58.580145+03
1505	82	-1	560	2019-08-26 19:24:15.635711+03
1506	68	22	225	2019-08-26 19:46:30.479827+03
1507	65	-1	490	2019-08-26 19:46:41.315303+03
1508	1	-1	640	2019-08-26 20:28:36.667045+03
1509	81	-1	1620	2019-08-26 20:34:57.163732+03
1510	42	-1	1790	2019-08-26 21:02:36.325716+03
1511	90	-1	1780	2019-08-26 21:35:07.795316+03
1512	23	-1	4390	2019-08-26 22:48:39.934441+03
1513	19	-1	1220	2019-08-26 23:38:21.907448+03
1514	54	-1	3470	2019-08-27 00:06:53.038216+03
1515	20	-1	830	2019-08-27 00:20:14.109592+03
1516	31	-1	1190	2019-08-27 00:29:20.919174+03
1517	73	-2	960	2019-08-27 00:42:25.147068+03
1518	45	-1	1590	2019-08-27 01:01:58.17089+03
1519	8	-1	1920	2019-08-27 01:14:49.939991+03
1520	47	-1	1480	2019-08-27 01:19:03.025449+03
1521	38	-1	1100	2019-08-27 01:21:15.67155+03
1522	65	14	222	2019-08-27 01:25:43.900333+03
1523	81	-1	1620	2019-08-27 01:28:11.091713+03
1524	13	-1	460	2019-08-27 01:50:13.555214+03
1525	82	-1	560	2019-08-27 01:53:49.097715+03
1526	76	-2	1070	2019-08-27 01:54:29.035494+03
1527	61	26	855	2019-08-27 02:13:00.502168+03
1528	56	-2	2460	2019-08-27 02:27:02.278117+03
1529	19	-1	1220	2019-08-27 02:39:20.66294+03
1530	76	-2	1070	2019-08-27 02:40:23.245067+03
1531	46	-2	1270	2019-08-27 02:55:36.310245+03
1532	38	-1	1100	2019-08-27 03:43:20.932286+03
1533	94	-1	1230	2019-08-27 04:11:02.901103+03
1534	89	-1	1420	2019-08-27 04:13:33.143964+03
1535	45	-1	1590	2019-08-27 04:21:22.493315+03
1536	88	-1	1270	2019-08-27 05:17:40.072512+03
1537	22	-2	1070	2019-08-27 05:39:43.500383+03
1538	61	-1	1510	2019-08-27 06:25:49.54505+03
1539	5	-2	1620	2019-08-27 06:32:01.803207+03
1540	3	-1	660	2019-08-27 06:33:37.808118+03
1541	47	-1	1480	2019-08-27 06:45:46.385583+03
1542	87	-1	2320	2019-08-27 07:03:14.41223+03
1543	5	-1	1620	2019-08-27 07:20:35.283386+03
1544	48	-1	640	2019-08-27 08:15:39.179063+03
1545	51	-2	1310	2019-08-27 08:23:54.526311+03
1546	19	-1	1220	2019-08-27 08:33:36.028179+03
1547	58	-1	2830	2019-08-27 08:41:16.18291+03
1548	7	-1	810	2019-08-27 08:55:19.932326+03
1549	74	-1	1010	2019-08-27 09:04:35.151228+03
1550	93	-1	1620	2019-08-27 09:13:01.634541+03
1551	32	-1	710	2019-08-27 09:29:46.194723+03
1552	19	-2	1220	2019-08-27 09:50:06.466272+03
1553	30	-1	1140	2019-08-27 10:18:13.602629+03
1554	23	-2	4390	2019-08-27 10:29:30.626975+03
1555	78	-2	900	2019-08-27 10:43:40.999047+03
1556	8	-1	1920	2019-08-27 10:49:21.1208+03
1557	77	-1	640	2019-08-27 11:03:55.417633+03
1558	2	-1	470	2019-08-27 11:04:29.935843+03
1559	71	-1	1030	2019-08-27 11:34:23.748218+03
1560	27	-1	880	2019-08-27 11:37:30.203551+03
1561	40	-2	1430	2019-08-27 11:45:16.84178+03
1562	35	-1	670	2019-08-27 11:46:12.119635+03
1563	37	-1	1290	2019-08-27 11:54:47.949009+03
1564	59	30	574	2019-08-27 12:12:47.925064+03
1565	39	-1	910	2019-08-27 12:39:07.031547+03
1566	54	-1	3470	2019-08-27 12:40:33.582376+03
1567	1	-1	640	2019-08-27 12:53:00.813612+03
1568	83	-1	1230	2019-08-27 12:53:38.731439+03
1569	86	-1	910	2019-08-27 12:54:05.643625+03
1570	86	-1	910	2019-08-27 13:07:01.343933+03
1571	59	-1	1030	2019-08-27 13:09:48.803228+03
1572	30	-1	1140	2019-08-27 13:13:03.417039+03
1573	95	-1	480	2019-08-27 13:34:30.863047+03
1574	9	-1	2090	2019-08-27 13:44:25.311973+03
1575	6	-1	980	2019-08-27 14:20:29.738267+03
1576	71	-2	1030	2019-08-27 14:58:20.811947+03
1577	13	-1	460	2019-08-27 15:14:55.093413+03
1578	30	-1	1140	2019-08-27 15:43:10.793878+03
1579	13	-2	460	2019-08-27 15:54:37.259066+03
1580	87	-1	2320	2019-08-27 15:55:15.303052+03
1581	84	-1	2700	2019-08-27 16:07:23.395845+03
1582	7	-1	810	2019-08-27 16:10:03.814719+03
1583	54	-1	3470	2019-08-27 16:11:50.74008+03
1584	71	-1	1030	2019-08-27 16:18:44.487771+03
1585	63	26	740	2019-08-27 16:46:00.443594+03
1586	22	-1	1070	2019-08-27 16:47:48.636916+03
1587	39	-1	910	2019-08-27 16:58:34.787087+03
1588	86	-1	910	2019-08-27 17:02:42.545255+03
1589	61	-1	1510	2019-08-27 17:05:57.196406+03
1590	93	-1	1620	2019-08-27 17:09:57.75534+03
1591	80	-1	1120	2019-08-27 17:15:48.401877+03
1592	4	-1	1420	2019-08-27 18:00:08.978705+03
1593	22	-2	1070	2019-08-27 18:06:28.788908+03
1594	47	-1	1480	2019-08-27 18:11:58.335587+03
1595	14	-1	1350	2019-08-27 18:15:58.100054+03
1596	9	-1	2090	2019-08-27 18:16:22.812985+03
1597	26	22	197	2019-08-27 18:57:13.476225+03
1598	48	-1	640	2019-08-27 19:37:00.12256+03
1599	73	-1	960	2019-08-27 19:37:04.151959+03
1600	21	-1	960	2019-08-27 19:46:13.843641+03
1601	54	-1	3470	2019-08-27 19:50:18.575704+03
1602	71	-1	1030	2019-08-27 20:01:57.168674+03
1603	67	-1	350	2019-08-27 20:08:24.833346+03
1604	30	-1	1140	2019-08-27 20:17:56.331413+03
1605	62	13	674	2019-08-27 20:18:21.822456+03
1606	33	-1	900	2019-08-27 20:21:54.864935+03
1607	13	-1	460	2019-08-27 20:44:09.299492+03
1608	94	-1	1230	2019-08-27 20:47:21.179439+03
1609	18	-2	910	2019-08-27 21:26:35.981504+03
1610	60	-1	2700	2019-08-27 21:26:53.367505+03
1611	76	-1	1070	2019-08-27 21:30:47.00021+03
1612	80	-1	1120	2019-08-27 21:50:02.169113+03
1613	81	-1	1620	2019-08-27 21:51:30.35404+03
1614	54	-1	3470	2019-08-27 22:10:52.364284+03
1615	46	-1	1270	2019-08-27 22:27:16.971429+03
1616	95	-1	480	2019-08-27 22:32:44.440039+03
1617	20	-2	830	2019-08-27 22:44:09.060706+03
1618	92	-2	630	2019-08-27 22:55:23.59823+03
1619	27	-1	880	2019-08-27 23:06:37.604577+03
1620	60	32	1087	2019-08-27 23:29:19.170504+03
1621	62	-1	1220	2019-08-28 00:12:23.468052+03
1622	58	-1	2830	2019-08-28 01:05:34.190705+03
1623	88	-2	1270	2019-08-28 01:08:20.685579+03
1624	40	-2	1430	2019-08-28 01:27:13.962094+03
1625	2	-2	470	2019-08-28 01:43:13.757514+03
1626	96	-1	1570	2019-08-28 01:56:20.984708+03
1627	64	-1	970	2019-08-28 02:22:33.747651+03
1628	24	-2	950	2019-08-28 02:27:16.756684+03
1629	8	-1	1920	2019-08-28 02:39:00.038324+03
1630	50	-1	1140	2019-08-28 02:46:59.912595+03
1631	46	-1	1270	2019-08-28 03:02:53.894594+03
1632	31	-1	1190	2019-08-28 03:15:39.256661+03
1633	49	-1	970	2019-08-28 03:24:48.051575+03
1634	17	-2	1500	2019-08-28 04:12:30.312626+03
1635	51	-1	1310	2019-08-28 04:14:54.759914+03
1636	69	-1	1100	2019-08-28 04:17:09.656937+03
1637	47	-2	1480	2019-08-28 04:17:56.42858+03
1638	83	-1	1230	2019-08-28 04:19:22.953016+03
1639	30	-1	1140	2019-08-28 04:56:10.734972+03
1640	30	-2	1140	2019-08-28 05:06:59.675635+03
1641	79	-1	550	2019-08-28 06:23:29.342597+03
1642	2	-2	470	2019-08-28 06:50:16.879991+03
1643	11	-1	830	2019-08-28 07:01:28.182901+03
1644	8	-1	1920	2019-08-28 07:32:46.25526+03
1645	35	-2	670	2019-08-28 07:57:04.343476+03
1646	7	-1	810	2019-08-28 08:13:55.83472+03
1647	27	-1	880	2019-08-28 09:07:28.175434+03
1648	92	-1	630	2019-08-28 09:19:16.891449+03
1649	38	-1	1100	2019-08-28 09:26:13.229966+03
1650	84	-1	2700	2019-08-28 09:28:05.79025+03
1651	75	-1	830	2019-08-28 09:52:05.900941+03
1652	32	-1	710	2019-08-28 10:30:13.872693+03
1653	77	-1	640	2019-08-28 11:26:16.630991+03
1654	72	-1	620	2019-08-28 11:26:54.696413+03
1655	41	-1	830	2019-08-28 12:03:20.78383+03
1656	74	-2	1010	2019-08-28 12:22:25.511918+03
1657	7	-1	810	2019-08-28 12:25:51.568799+03
1658	89	-1	1420	2019-08-28 12:39:37.394789+03
1659	47	-1	1480	2019-08-28 12:46:41.198601+03
1660	80	-1	1120	2019-08-28 12:50:24.377781+03
1661	30	-1	1140	2019-08-28 13:08:03.354095+03
1662	92	-2	630	2019-08-28 13:18:32.742335+03
1663	46	-1	1270	2019-08-28 13:28:10.199698+03
1664	51	-1	1310	2019-08-28 13:33:41.89509+03
1665	55	-1	3480	2019-08-28 13:34:04.008217+03
1666	39	-1	910	2019-08-28 13:42:14.084635+03
1667	13	-1	460	2019-08-28 14:16:12.112702+03
1668	49	-2	970	2019-08-28 14:53:40.713734+03
1669	60	-1	2700	2019-08-28 14:55:09.039769+03
1670	1	-1	640	2019-08-28 15:23:51.241413+03
1671	42	-1	1790	2019-08-28 15:45:27.634728+03
1672	47	-1	1480	2019-08-28 15:55:49.344232+03
1673	38	-1	1100	2019-08-28 16:16:55.181632+03
1674	25	-1	1100	2019-08-28 16:29:11.5512+03
1675	81	-1	1620	2019-08-28 16:34:11.260781+03
1676	34	-1	1550	2019-08-28 16:36:36.123101+03
1677	65	-1	490	2019-08-28 16:40:06.836613+03
1678	30	-1	1140	2019-08-28 16:45:57.777702+03
1679	14	-2	1350	2019-08-28 18:15:09.624363+03
1680	43	-1	380	2019-08-28 18:16:38.963341+03
1681	8	-2	1920	2019-08-28 18:27:25.142364+03
1682	67	-1	350	2019-08-28 18:33:32.68317+03
1683	85	-1	730	2019-08-28 18:47:29.616958+03
1684	36	-1	630	2019-08-28 18:53:28.937635+03
1685	56	-1	2460	2019-08-28 19:06:20.997579+03
1686	87	-1	2320	2019-08-28 19:15:30.496242+03
1687	91	24	935	2019-08-28 19:17:02.745004+03
1688	13	-1	460	2019-08-28 19:41:56.253638+03
1689	88	-1	1270	2019-08-28 19:42:11.792525+03
1690	83	-2	1230	2019-08-28 20:17:59.303453+03
1691	76	-1	1070	2019-08-28 20:22:43.9389+03
1692	92	-1	630	2019-08-28 20:23:52.155623+03
1693	71	-1	1030	2019-08-28 20:31:40.29893+03
1694	77	-1	640	2019-08-28 20:34:16.055719+03
1695	39	-1	910	2019-08-28 20:45:14.163661+03
1696	54	-1	3470	2019-08-28 21:01:05.83844+03
1697	83	-1	1230	2019-08-28 21:25:52.769095+03
1698	71	-1	1030	2019-08-28 21:50:56.687177+03
1699	80	-1	1120	2019-08-28 21:58:48.468868+03
1700	66	-1	690	2019-08-28 22:06:18.043792+03
1701	41	-1	830	2019-08-28 22:06:23.834572+03
1702	9	-1	2090	2019-08-28 22:13:57.614821+03
1703	5	-2	1620	2019-08-28 22:25:53.271995+03
1704	39	-1	910	2019-08-28 22:28:51.823471+03
1705	36	-2	630	2019-08-28 22:54:44.53046+03
1706	46	-1	1270	2019-08-28 23:00:34.506944+03
1707	59	-1	1030	2019-08-28 23:09:39.464434+03
1708	86	-1	910	2019-08-28 23:42:18.843211+03
1709	32	-2	710	2019-08-28 23:46:46.98951+03
1710	52	-1	1090	2019-08-29 00:08:03.300891+03
1711	69	-1	1100	2019-08-29 00:47:49.891925+03
1712	1	-1	640	2019-08-29 00:59:36.129619+03
1713	67	-1	350	2019-08-29 01:22:07.634573+03
1714	50	20	614	2019-08-29 01:41:59.327297+03
1715	82	-1	560	2019-08-29 02:20:39.724154+03
1716	54	-1	3470	2019-08-29 02:37:38.984791+03
1717	13	-2	460	2019-08-29 02:45:43.74201+03
1718	94	-2	1230	2019-08-29 02:45:57.917035+03
1719	26	-1	390	2019-08-29 02:53:25.903501+03
1720	10	-2	2080	2019-08-29 03:20:23.372283+03
1721	4	-1	1420	2019-08-29 03:35:41.179568+03
1722	81	-1	1620	2019-08-29 03:39:06.237119+03
1723	13	-2	460	2019-08-29 03:52:37.236525+03
1724	37	36	652	2019-08-29 04:09:02.179425+03
1725	80	-1	1120	2019-08-29 04:14:23.839659+03
1726	20	-2	830	2019-08-29 04:20:40.080097+03
1727	7	-1	810	2019-08-29 04:27:01.799915+03
1728	77	-1	640	2019-08-29 04:40:38.300855+03
1729	18	-1	910	2019-08-29 04:53:21.935165+03
1730	59	-1	1030	2019-08-29 05:18:40.967877+03
1731	6	-1	980	2019-08-29 05:27:04.596177+03
1732	17	-1	1500	2019-08-29 05:29:33.150427+03
1733	39	-2	910	2019-08-29 05:37:39.099466+03
1734	48	-1	640	2019-08-29 06:15:40.255179+03
1735	21	-1	960	2019-08-29 06:19:15.83377+03
1736	18	-1	910	2019-08-29 06:29:23.464539+03
1737	69	-1	1100	2019-08-29 06:37:21.275895+03
1738	69	-2	1100	2019-08-29 07:25:52.590453+03
1739	77	-1	640	2019-08-29 07:53:52.598465+03
1740	92	-1	630	2019-08-29 08:00:39.005771+03
1741	92	-1	630	2019-08-29 08:29:09.48158+03
1742	60	-1	2700	2019-08-29 08:38:27.183319+03
1743	55	-2	3480	2019-08-29 09:04:28.108967+03
1744	57	-1	1900	2019-08-29 09:16:09.620222+03
1745	92	-1	630	2019-08-29 09:18:48.779652+03
1746	10	-2	2080	2019-08-29 09:22:04.057484+03
1747	55	-1	3480	2019-08-29 09:50:34.144095+03
1748	92	-1	630	2019-08-29 09:57:01.134196+03
1749	91	-2	1620	2019-08-29 09:57:18.538643+03
1750	46	-2	1270	2019-08-29 10:10:46.605866+03
1751	52	-2	1090	2019-08-29 10:14:57.470918+03
1752	89	-1	1420	2019-08-29 11:00:17.500791+03
1753	54	-1	3470	2019-08-29 11:00:43.473658+03
1754	63	-1	1780	2019-08-29 11:03:04.147592+03
1755	76	-1	1070	2019-08-29 11:07:14.492706+03
1756	96	-1	1570	2019-08-29 11:13:56.583728+03
1757	11	-1	830	2019-08-29 11:17:57.440875+03
1758	68	-1	490	2019-08-29 11:20:32.758548+03
1759	24	-1	950	2019-08-29 11:39:23.964344+03
1760	44	-1	500	2019-08-29 11:49:56.032515+03
1761	54	-1	3470	2019-08-29 12:04:24.75622+03
1762	5	-1	1620	2019-08-29 12:14:43.861735+03
1763	29	-2	1940	2019-08-29 12:30:53.063132+03
1764	87	-1	2320	2019-08-29 12:32:43.228936+03
1765	13	-1	460	2019-08-29 12:54:12.178054+03
1766	36	-1	630	2019-08-29 13:12:19.454505+03
1767	38	-1	1100	2019-08-29 13:22:14.437786+03
1768	14	-1	1350	2019-08-29 13:41:16.38264+03
1769	14	-3	1350	2019-08-29 13:50:48.257858+03
1770	40	-2	1430	2019-08-29 13:51:20.469227+03
1771	84	-1	2700	2019-08-29 13:59:04.91643+03
1772	14	-2	1350	2019-08-29 14:08:54.378642+03
1773	26	-1	390	2019-08-29 14:26:27.194441+03
1774	74	-1	1010	2019-08-29 14:29:55.874371+03
1775	57	-1	1900	2019-08-29 14:31:46.176883+03
1776	12	-1	1650	2019-08-29 15:16:54.498899+03
1777	42	-1	1790	2019-08-29 16:03:14.784822+03
1778	83	-1	1230	2019-08-29 16:05:02.705914+03
1779	89	-1	1420	2019-08-29 16:11:03.635603+03
1780	51	-1	1310	2019-08-29 16:12:07.504665+03
1781	41	-1	830	2019-08-29 16:23:59.839458+03
1782	38	-1	1100	2019-08-29 16:29:01.400224+03
1783	66	-2	690	2019-08-29 16:30:43.82654+03
1784	30	-1	1140	2019-08-29 16:44:45.548139+03
1785	89	-1	1420	2019-08-29 16:46:27.480467+03
1786	26	-1	390	2019-08-29 16:57:17.739142+03
1787	6	-1	980	2019-08-29 17:04:22.380284+03
1788	25	-1	1100	2019-08-29 17:07:50.201519+03
1789	51	-1	1310	2019-08-29 17:26:29.301454+03
1790	34	-1	1550	2019-08-29 17:39:25.015304+03
1791	95	-1	480	2019-08-29 17:42:32.860785+03
1792	26	-1	390	2019-08-29 17:52:15.238761+03
1793	19	-1	1220	2019-08-29 18:11:01.017312+03
1794	60	-1	2700	2019-08-29 18:13:21.556491+03
1795	1	-1	640	2019-08-29 18:19:03.021375+03
1796	42	-1	1790	2019-08-29 18:27:06.682107+03
1797	31	-2	1190	2019-08-29 18:43:42.177018+03
1798	89	-1	1420	2019-08-29 19:13:05.93751+03
1799	8	-1	1920	2019-08-29 19:17:28.293896+03
1800	31	-1	1190	2019-08-29 19:33:03.799541+03
1801	29	-1	1940	2019-08-29 19:48:31.827601+03
1802	58	-1	2830	2019-08-29 19:54:15.204306+03
1803	31	-2	1190	2019-08-29 19:59:17.282085+03
1804	38	-1	1100	2019-08-29 20:16:05.130763+03
1805	40	-1	1430	2019-08-29 20:20:01.933591+03
1806	23	-1	4390	2019-08-29 20:24:55.880369+03
1807	64	-1	970	2019-08-29 21:30:18.233922+03
1808	75	-1	830	2019-08-29 21:31:17.833705+03
1809	74	-1	1010	2019-08-29 21:36:24.934532+03
1810	74	-1	1010	2019-08-29 21:40:48.975197+03
1811	70	-1	760	2019-08-29 21:45:07.429213+03
1812	49	-1	970	2019-08-29 21:46:42.465354+03
1813	44	-1	500	2019-08-29 21:53:16.391739+03
1814	3	-1	660	2019-08-29 22:02:19.050348+03
1815	19	-1	1220	2019-08-29 22:06:44.761381+03
1816	24	-1	950	2019-08-29 22:14:07.860724+03
1817	75	-1	830	2019-08-29 22:27:38.152664+03
1818	28	-2	1860	2019-08-29 22:48:53.502016+03
1819	8	-1	1920	2019-08-29 23:24:38.817495+03
1820	23	-1	4390	2019-08-29 23:28:10.26266+03
1821	1	-1	640	2019-08-29 23:53:05.325201+03
1822	49	-2	970	2019-08-30 00:27:06.195257+03
1823	7	-1	810	2019-08-30 01:19:29.335019+03
1824	20	-1	830	2019-08-30 01:41:37.230996+03
1825	47	-1	1480	2019-08-30 01:57:38.719045+03
1826	4	-2	1420	2019-08-30 02:56:25.296569+03
1827	84	-1	2700	2019-08-30 02:59:03.725535+03
1828	76	-1	1070	2019-08-30 03:05:05.366183+03
1829	49	-1	970	2019-08-30 03:09:19.884026+03
1830	96	-1	1570	2019-08-30 03:25:50.631526+03
1831	6	-2	980	2019-08-30 03:30:47.092899+03
1832	78	-1	900	2019-08-30 03:41:50.759467+03
1833	38	-1	1100	2019-08-30 03:53:16.009475+03
1834	45	-2	1590	2019-08-30 04:12:19.776782+03
1835	56	-1	2460	2019-08-30 04:19:32.085298+03
1836	19	-1	1220	2019-08-30 04:24:48.133673+03
1837	82	-1	560	2019-08-30 04:27:30.958819+03
1838	4	-1	1420	2019-08-30 04:29:33.042837+03
1839	57	-1	1900	2019-08-30 04:30:20.173241+03
1840	65	-1	490	2019-08-30 05:02:17.024284+03
1841	81	-1	1620	2019-08-30 05:21:58.730127+03
1842	54	-1	3470	2019-08-30 05:43:46.857407+03
1843	56	-1	2460	2019-08-30 05:46:34.521109+03
1844	18	-1	910	2019-08-30 06:31:08.908787+03
1845	69	-1	1100	2019-08-30 07:03:34.42447+03
1846	16	13	647	2019-08-30 07:11:16.215976+03
1847	18	-1	910	2019-08-30 08:05:09.429132+03
1848	58	-2	2830	2019-08-30 08:09:12.483945+03
1849	54	-1	3470	2019-08-30 08:27:50.043542+03
1850	10	-1	2080	2019-08-30 09:00:22.950061+03
1851	50	-1	1140	2019-08-30 09:02:10.17848+03
1852	52	-1	1090	2019-08-30 09:07:52.809191+03
1853	47	-1	1480	2019-08-30 10:01:24.630262+03
1854	53	-2	3120	2019-08-30 10:02:28.874859+03
1855	53	-2	3120	2019-08-30 10:17:19.428168+03
1856	31	-1	1190	2019-08-30 10:22:21.56519+03
1857	57	-1	1900	2019-08-30 11:25:10.009469+03
1858	63	-1	1780	2019-08-30 13:35:59.981622+03
1859	24	-1	950	2019-08-30 13:42:01.383689+03
1860	22	-1	1070	2019-08-30 14:05:09.248173+03
1861	17	-1	1500	2019-08-30 14:22:34.003833+03
1862	87	-1	2320	2019-08-30 14:42:02.905052+03
1863	44	-1	500	2019-08-30 14:47:06.349012+03
1864	86	-1	910	2019-08-30 15:38:38.609465+03
1865	88	-1	1270	2019-08-30 15:47:27.501076+03
1866	84	-1	2700	2019-08-30 15:53:35.539705+03
1867	48	-1	640	2019-08-30 16:17:54.335127+03
1868	55	-1	3480	2019-08-30 16:27:25.537669+03
1869	67	-2	350	2019-08-30 17:01:50.197779+03
1870	8	-1	1920	2019-08-30 17:08:40.631357+03
1871	2	-1	470	2019-08-30 17:44:50.712969+03
1872	17	-2	1500	2019-08-30 18:00:00.106265+03
1873	51	-1	1310	2019-08-30 18:00:03.08699+03
1874	36	-1	630	2019-08-30 18:01:14.922066+03
1875	59	-1	1030	2019-08-30 18:10:17.363718+03
1876	64	-1	970	2019-08-30 18:24:44.348006+03
1877	22	-1	1070	2019-08-30 18:32:36.217426+03
1878	22	-2	1070	2019-08-30 18:33:36.454576+03
1879	46	-1	1270	2019-08-30 18:49:13.705985+03
1880	23	-2	4390	2019-08-30 18:53:35.586843+03
1881	89	-1	1420	2019-08-30 19:16:15.356865+03
1882	34	35	791	2019-08-30 19:16:43.523144+03
1883	92	-1	630	2019-08-30 19:17:35.939189+03
1884	90	-1	1780	2019-08-30 19:47:06.781268+03
1885	83	27	540	2019-08-30 19:51:35.552421+03
1886	87	-1	2320	2019-08-30 19:56:45.21951+03
1887	88	-1	1270	2019-08-30 19:59:55.319997+03
1888	92	-2	630	2019-08-30 20:05:23.364111+03
1889	36	-2	630	2019-08-30 20:09:04.014795+03
1890	32	-1	710	2019-08-30 20:10:25.807679+03
1891	53	-1	3120	2019-08-30 20:14:01.240934+03
1892	74	-1	1010	2019-08-30 20:15:56.244076+03
1893	76	37	457	2019-08-30 20:50:09.202939+03
1894	30	-1	1140	2019-08-30 21:13:20.049602+03
1895	70	30	321	2019-08-30 21:44:24.058027+03
1896	64	-1	970	2019-08-30 21:45:01.474347+03
1897	13	-1	460	2019-08-30 22:08:51.951569+03
1898	64	36	551	2019-08-30 23:18:51.763835+03
1899	76	-1	1070	2019-08-30 23:39:33.438712+03
1900	18	-1	910	2019-08-30 23:54:33.291641+03
1901	32	-1	710	2019-08-31 00:17:25.467049+03
1902	52	-1	1090	2019-08-31 01:03:40.561998+03
1903	72	-1	620	2019-08-31 01:18:33.243063+03
1904	26	-1	390	2019-08-31 01:23:08.720012+03
1905	33	-2	900	2019-08-31 01:43:09.17425+03
1906	65	-1	490	2019-08-31 01:56:29.718953+03
1907	28	26	924	2019-08-31 02:33:29.072058+03
1908	70	-1	760	2019-08-31 02:49:37.899582+03
1909	77	-1	640	2019-08-31 02:53:28.644098+03
1910	90	28	805	2019-08-31 03:06:08.981268+03
1911	49	-1	970	2019-08-31 03:07:02.936133+03
1912	92	-2	630	2019-08-31 03:37:21.291552+03
1913	12	-1	1650	2019-08-31 04:11:59.749114+03
1914	8	-1	1920	2019-08-31 04:13:49.850458+03
1915	11	-1	830	2019-08-31 04:15:00.93057+03
1916	86	-1	910	2019-08-31 04:34:13.480762+03
1917	18	-2	910	2019-08-31 04:34:50.078823+03
1918	56	-1	2460	2019-08-31 04:41:18.823431+03
1919	91	-2	1620	2019-08-31 04:57:20.339251+03
1920	43	-1	380	2019-08-31 05:30:37.579973+03
1921	14	-1	1350	2019-08-31 05:40:03.821124+03
1922	32	-1	710	2019-08-31 05:45:28.690827+03
1923	10	-1	2080	2019-08-31 05:55:11.790648+03
1924	75	-1	830	2019-08-31 05:55:50.895687+03
1925	41	-1	830	2019-08-31 06:00:29.037247+03
1926	71	-1	1030	2019-08-31 06:06:52.478447+03
1927	39	-1	910	2019-08-31 06:10:29.204368+03
1928	77	-1	640	2019-08-31 06:19:30.158159+03
1929	81	-2	1620	2019-08-31 06:44:45.436509+03
1930	29	-1	1940	2019-08-31 06:54:38.716497+03
1931	63	-1	1780	2019-08-31 07:03:02.84426+03
1932	24	-1	950	2019-08-31 07:25:27.435799+03
1933	6	-1	980	2019-08-31 07:32:38.265635+03
1934	69	-1	1100	2019-08-31 07:35:53.991353+03
1935	67	-1	350	2019-08-31 07:47:41.194445+03
1936	10	-1	2080	2019-08-31 08:19:40.166583+03
1937	88	32	722	2019-08-31 08:21:48.554406+03
1938	15	-1	2830	2019-08-31 08:32:25.185909+03
1939	6	-1	980	2019-08-31 08:35:46.109121+03
1940	81	-2	1620	2019-08-31 08:36:05.581654+03
1941	88	-1	1270	2019-08-31 08:38:41.697899+03
1942	66	-1	690	2019-08-31 08:39:37.065171+03
1943	94	-1	1230	2019-08-31 08:44:18.969688+03
1944	92	-1	630	2019-08-31 09:06:40.367034+03
1945	18	-2	910	2019-08-31 09:14:49.336945+03
1946	35	-1	670	2019-08-31 09:21:53.623169+03
1947	31	-1	1190	2019-08-31 09:27:53.619599+03
1948	22	-2	1070	2019-08-31 09:54:58.745907+03
1949	85	-1	730	2019-08-31 10:04:06.584171+03
1950	55	23	1781	2019-08-31 10:13:19.11169+03
1951	10	-1	2080	2019-08-31 10:14:56.641081+03
1952	3	-1	660	2019-08-31 10:20:39.527846+03
1953	63	-1	1780	2019-08-31 10:27:24.053157+03
1954	64	-1	970	2019-08-31 10:32:48.547741+03
1955	17	-1	1500	2019-08-31 10:43:18.308771+03
1956	55	-1	3480	2019-08-31 10:46:50.221179+03
1957	41	31	363	2019-08-31 10:50:08.915199+03
1958	88	-1	1270	2019-08-31 11:49:10.238146+03
1959	46	-1	1270	2019-08-31 11:50:48.166983+03
1960	70	-1	760	2019-08-31 11:53:58.994904+03
1961	27	-1	880	2019-08-31 11:56:38.763766+03
1962	6	-1	980	2019-08-31 12:10:52.662671+03
1963	52	-1	1090	2019-08-31 12:19:42.017917+03
1964	13	-1	460	2019-08-31 12:24:15.667273+03
1965	15	-2	2830	2019-08-31 13:18:18.408506+03
1966	71	-1	1030	2019-08-31 13:18:56.110725+03
1967	46	-1	1270	2019-08-31 13:22:28.792338+03
1968	81	-1	1620	2019-08-31 13:37:48.29063+03
1969	20	-2	830	2019-08-31 14:03:45.442517+03
1970	39	-1	910	2019-08-31 14:17:17.426797+03
1971	84	-1	2700	2019-08-31 14:24:31.575556+03
1972	22	-2	1070	2019-08-31 14:41:08.26951+03
1973	41	-1	830	2019-08-31 15:06:28.192246+03
1974	7	33	451	2019-08-31 16:16:31.32953+03
1975	91	-2	1620	2019-08-31 16:26:58.663549+03
1976	23	-1	4390	2019-08-31 17:50:56.950817+03
1977	10	-1	2080	2019-08-31 18:00:01.217357+03
1978	40	-1	1430	2019-08-31 18:27:26.470139+03
1979	57	-1	1900	2019-08-31 18:58:26.416943+03
1980	55	-1	3480	2019-08-31 19:04:10.910002+03
1981	52	-1	1090	2019-08-31 19:06:30.296524+03
1982	25	-1	1100	2019-08-31 19:15:23.62951+03
1983	41	-1	830	2019-08-31 19:35:35.442387+03
1984	19	-1	1220	2019-08-31 19:47:14.586121+03
1985	67	-1	350	2019-08-31 19:53:28.814721+03
1986	46	-1	1270	2019-08-31 20:05:59.921195+03
1987	12	-1	1650	2019-08-31 20:10:24.353318+03
1988	11	-1	830	2019-08-31 20:11:27.601918+03
1989	95	-1	480	2019-08-31 20:21:23.211417+03
1990	35	-1	670	2019-08-31 20:49:25.919904+03
1991	13	-1	460	2019-08-31 21:08:52.871454+03
1992	67	-1	350	2019-08-31 21:11:55.6534+03
1993	74	-2	1010	2019-08-31 21:28:04.199298+03
1994	7	-1	810	2019-08-31 21:31:38.841009+03
1995	74	-1	1010	2019-08-31 21:48:17.011645+03
1996	48	-1	640	2019-08-31 21:54:16.321092+03
1997	64	-2	970	2019-08-31 21:54:42.443927+03
1998	71	-2	1030	2019-08-31 22:16:12.909825+03
1999	22	-1	1070	2019-08-31 22:18:49.284993+03
2000	3	-1	660	2019-08-31 22:54:50.689367+03
2001	31	-1	1190	2019-08-31 22:59:07.335056+03
2002	90	-2	1780	2019-08-31 23:12:57.430753+03
2003	19	-2	1220	2019-08-31 23:24:29.442553+03
2004	61	-1	1510	2019-08-31 23:27:56.110664+03
2005	7	-1	810	2019-08-31 23:28:32.931979+03
2006	96	-1	1570	2019-09-01 01:42:49.683737+03
2007	19	-1	1220	2019-09-01 02:28:16.957658+03
2008	74	-1	1010	2019-09-01 02:49:57.680176+03
2009	90	-2	1780	2019-09-01 03:17:57.2474+03
2010	22	-1	1070	2019-09-01 03:30:58.749392+03
2011	35	-1	670	2019-09-01 03:33:21.176792+03
2012	46	-1	1270	2019-09-01 03:45:11.851362+03
2013	87	-1	2320	2019-09-01 04:55:33.289975+03
2014	95	-1	480	2019-09-01 05:01:27.992002+03
2015	76	-1	1070	2019-09-01 05:20:09.229053+03
2016	39	-2	910	2019-09-01 05:52:00.614075+03
2017	93	30	697	2019-09-01 06:12:12.434469+03
2018	40	-2	1430	2019-09-01 06:59:54.987002+03
2019	74	-1	1010	2019-09-01 07:20:03.763692+03
2020	55	-2	3480	2019-09-01 07:43:35.525895+03
2021	12	-1	1650	2019-09-01 07:58:02.707094+03
2022	88	-1	1270	2019-09-01 08:02:33.830827+03
2023	29	-2	1940	2019-09-01 08:32:51.346546+03
2024	13	-1	460	2019-09-01 08:35:40.434594+03
2025	7	-1	810	2019-09-01 08:44:44.455098+03
2026	92	-1	630	2019-09-01 09:01:49.152093+03
2027	86	-2	910	2019-09-01 09:29:25.684056+03
2028	30	-2	1140	2019-09-01 09:33:28.182408+03
2029	89	-1	1420	2019-09-01 09:35:24.725311+03
2030	14	-1	1350	2019-09-01 09:40:10.375672+03
2031	84	-1	2700	2019-09-01 09:48:11.542684+03
2032	96	-1	1570	2019-09-01 09:55:07.43282+03
2033	81	-1	1620	2019-09-01 10:16:08.141923+03
2034	46	-1	1270	2019-09-01 10:20:18.289666+03
2035	15	-1	2830	2019-09-01 11:10:29.311327+03
2036	78	-1	900	2019-09-01 11:21:52.540673+03
2037	38	-2	1100	2019-09-01 11:22:40.534143+03
2038	47	-2	1480	2019-09-01 11:23:39.718448+03
2039	22	-1	1070	2019-09-01 11:26:25.575851+03
2040	85	-1	730	2019-09-01 11:40:19.272326+03
2041	22	-2	1070	2019-09-01 12:20:31.935278+03
2042	33	-1	900	2019-09-01 12:23:30.051126+03
2043	16	-1	1380	2019-09-01 12:28:06.863294+03
2044	32	-1	710	2019-09-01 13:06:30.910964+03
2045	3	-1	660	2019-09-01 13:14:43.844265+03
2046	78	-1	900	2019-09-01 13:16:27.165282+03
2047	94	-1	1230	2019-09-01 13:18:16.050261+03
2048	78	-2	900	2019-09-01 14:14:54.08602+03
2049	41	-1	830	2019-09-01 14:34:31.224779+03
2050	8	-1	1920	2019-09-01 14:49:09.901995+03
2051	21	-2	960	2019-09-01 15:58:25.645814+03
2052	37	-2	1290	2019-09-01 16:06:40.583309+03
2053	56	-1	2460	2019-09-01 16:12:47.756443+03
2054	68	-1	490	2019-09-01 17:18:30.468249+03
2055	82	-1	560	2019-09-01 17:38:36.791931+03
2056	70	-1	760	2019-09-01 17:52:57.024287+03
2057	80	-1	1120	2019-09-01 18:33:07.90969+03
2058	43	-2	380	2019-09-01 18:39:39.777465+03
2059	45	24	708	2019-09-01 19:27:04.80702+03
2060	3	24	344	2019-09-01 19:47:47.314088+03
2061	2	-2	470	2019-09-01 20:06:29.154207+03
2062	86	-1	910	2019-09-01 20:10:20.629215+03
2063	34	-1	1550	2019-09-01 20:40:14.747628+03
2064	44	-1	500	2019-09-01 21:01:30.173431+03
2065	96	-1	1570	2019-09-01 21:05:56.094496+03
2066	77	-1	640	2019-09-01 21:27:04.539617+03
2067	54	-1	3470	2019-09-01 21:29:59.609843+03
2068	58	-1	2830	2019-09-01 21:33:57.613365+03
2069	86	-2	910	2019-09-01 23:28:28.986337+03
2070	45	-1	1590	2019-09-01 23:30:28.243417+03
2071	57	-1	1900	2019-09-02 00:02:35.141599+03
2072	69	-1	1100	2019-09-02 00:04:01.084597+03
2073	78	-1	900	2019-09-02 00:30:19.677787+03
2074	53	-1	3120	2019-09-02 00:40:13.800664+03
2075	15	-3	2830	2019-09-02 00:40:47.116959+03
2076	21	-1	960	2019-09-02 00:44:31.08309+03
2077	48	-1	640	2019-09-02 01:07:33.797513+03
2078	76	-1	1070	2019-09-02 01:16:14.266836+03
2079	39	-1	910	2019-09-02 01:58:27.601401+03
2080	15	-1	2830	2019-09-02 02:11:52.60337+03
2081	24	-1	950	2019-09-02 02:13:19.90549+03
2082	40	-1	1430	2019-09-02 02:19:42.2941+03
2083	34	-1	1550	2019-09-02 02:39:41.982517+03
2084	89	-1	1420	2019-09-02 02:45:53.744393+03
2085	4	-1	1420	2019-09-02 02:47:06.593414+03
2086	96	-1	1570	2019-09-02 03:07:02.86488+03
2087	64	-1	970	2019-09-02 03:41:23.842059+03
2088	54	-1	3470	2019-09-02 03:41:48.740395+03
2089	45	-1	1590	2019-09-02 04:02:30.8487+03
2090	71	-2	1030	2019-09-02 04:04:29.630298+03
2091	11	22	434	2019-09-02 04:27:12.078567+03
2092	9	-1	2090	2019-09-02 04:29:55.816026+03
2093	34	-1	1550	2019-09-02 04:30:38.192862+03
2094	76	-1	1070	2019-09-02 04:34:24.274239+03
2095	77	-1	640	2019-09-02 05:12:04.432042+03
2096	6	-2	980	2019-09-02 05:27:39.497875+03
2097	87	-1	2320	2019-09-02 05:54:27.050193+03
2098	40	-1	1430	2019-09-02 05:57:01.625058+03
2099	38	-1	1100	2019-09-02 06:29:25.100535+03
2100	92	-2	630	2019-09-02 06:42:41.588053+03
2101	70	-1	760	2019-09-02 07:00:37.017918+03
2102	81	-1	1620	2019-09-02 07:01:28.343437+03
2103	47	-1	1480	2019-09-02 07:19:09.274176+03
2104	58	-2	2830	2019-09-02 07:55:05.387786+03
2105	24	-1	950	2019-09-02 07:56:21.908119+03
2106	21	-1	960	2019-09-02 08:06:35.468681+03
2107	78	-1	900	2019-09-02 08:07:40.074791+03
2108	68	-1	490	2019-09-02 08:18:50.275115+03
2109	64	-1	970	2019-09-02 09:02:53.952274+03
2110	85	-2	730	2019-09-02 09:07:21.691402+03
2111	37	-1	1290	2019-09-02 09:09:11.778751+03
2112	17	-1	1500	2019-09-02 09:17:49.336276+03
2113	71	-1	1030	2019-09-02 09:39:28.975932+03
2114	11	-1	830	2019-09-02 09:56:12.150199+03
2115	18	-1	910	2019-09-02 10:07:09.581049+03
2116	38	-1	1100	2019-09-02 10:10:23.052276+03
2117	73	-1	960	2019-09-02 10:17:47.606941+03
2118	2	-1	470	2019-09-02 10:18:34.574906+03
2119	86	-1	910	2019-09-02 10:29:49.805732+03
2120	39	-1	910	2019-09-02 10:40:38.676289+03
2121	4	-1	1420	2019-09-02 10:48:36.221994+03
2122	64	-2	970	2019-09-02 10:56:52.802274+03
2123	27	-1	880	2019-09-02 11:07:31.644838+03
2124	47	-1	1480	2019-09-02 11:21:07.111918+03
2125	90	-1	1780	2019-09-02 11:25:50.846171+03
2126	19	-1	1220	2019-09-02 11:30:14.904692+03
2127	40	-1	1430	2019-09-02 11:40:58.539276+03
2128	44	-1	500	2019-09-02 11:43:48.849797+03
2129	84	-1	2700	2019-09-02 11:46:44.610577+03
2130	47	-1	1480	2019-09-02 11:59:07.49971+03
2131	49	-2	970	2019-09-02 12:15:44.491143+03
2132	67	-1	350	2019-09-02 12:25:26.542163+03
2133	25	-1	1100	2019-09-02 13:03:09.553807+03
2134	29	-1	1940	2019-09-02 13:13:23.324444+03
2135	36	-1	630	2019-09-02 13:47:55.450197+03
2136	37	-1	1290	2019-09-02 13:57:57.297731+03
2137	91	-1	1620	2019-09-02 14:39:14.223566+03
2138	36	-1	630	2019-09-02 14:50:53.738874+03
2139	11	-1	830	2019-09-02 14:51:27.305251+03
2140	21	-1	960	2019-09-02 14:59:19.932297+03
2141	71	-2	1030	2019-09-02 15:18:14.702158+03
2142	29	-1	1940	2019-09-02 15:22:26.373815+03
2143	64	-1	970	2019-09-02 15:44:20.350479+03
2144	8	-1	1920	2019-09-02 16:06:21.852239+03
2145	44	-1	500	2019-09-02 16:11:36.217978+03
2146	86	-1	910	2019-09-02 17:20:08.685113+03
2147	5	-2	1620	2019-09-02 17:30:29.28141+03
2148	67	-1	350	2019-09-02 17:43:21.176986+03
2149	29	-2	1940	2019-09-02 18:05:36.757693+03
2150	95	-1	480	2019-09-02 18:39:26.31495+03
2151	75	-1	830	2019-09-02 19:04:18.896108+03
2152	49	-1	970	2019-09-02 19:08:56.547533+03
2153	30	-2	1140	2019-09-02 19:13:15.659552+03
2154	34	-1	1550	2019-09-02 19:17:30.672973+03
2155	31	-1	1190	2019-09-02 19:23:28.045467+03
2156	53	-1	3120	2019-09-02 19:35:34.266251+03
2157	80	-1	1120	2019-09-02 19:37:19.131181+03
2158	5	-1	1620	2019-09-02 19:43:02.680382+03
2159	21	-1	960	2019-09-02 19:56:30.314159+03
2160	89	-1	1420	2019-09-02 20:04:18.009974+03
2161	27	-1	880	2019-09-02 20:28:40.550297+03
2162	49	-1	970	2019-09-02 21:08:43.196015+03
2163	55	-1	3480	2019-09-02 21:48:55.665288+03
2164	10	35	998	2019-09-02 21:55:54.808039+03
2165	61	-1	1510	2019-09-02 21:57:00.931252+03
2166	95	-1	480	2019-09-02 22:02:54.251489+03
2167	39	-1	910	2019-09-02 22:18:26.269554+03
2168	79	-1	550	2019-09-02 22:38:13.581034+03
2169	27	-2	880	2019-09-02 22:59:51.583782+03
2170	53	-1	3120	2019-09-02 23:14:01.511584+03
2171	64	-2	970	2019-09-02 23:26:45.696255+03
2172	21	-1	960	2019-09-02 23:36:03.670696+03
2173	87	-1	2320	2019-09-02 23:47:53.177793+03
2174	83	-1	1230	2019-09-02 23:49:42.31516+03
2175	54	-1	3470	2019-09-02 23:56:36.214875+03
2176	33	-1	900	2019-09-03 01:01:51.56748+03
2177	91	-1	1620	2019-09-03 01:24:52.519144+03
2178	30	-1	1140	2019-09-03 02:14:47.4138+03
2179	33	-1	900	2019-09-03 02:17:53.613577+03
2180	81	-1	1620	2019-09-03 02:20:07.393747+03
2181	38	-1	1100	2019-09-03 02:29:57.899703+03
2182	5	-2	1620	2019-09-03 02:31:43.185434+03
2183	88	-1	1270	2019-09-03 02:32:57.636007+03
2184	32	-1	710	2019-09-03 02:37:44.861866+03
2185	65	-1	490	2019-09-03 03:05:06.701307+03
2186	81	-1	1620	2019-09-03 03:19:24.021745+03
2187	63	-2	1780	2019-09-03 03:44:31.324809+03
2188	6	-2	980	2019-09-03 04:00:56.073049+03
2189	39	-1	910	2019-09-03 04:15:31.153837+03
2190	63	-1	1780	2019-09-03 04:20:05.065942+03
2191	55	-1	3480	2019-09-03 04:25:48.476362+03
2192	22	-1	1070	2019-09-03 04:37:42.122131+03
2193	73	-2	960	2019-09-03 04:45:39.534872+03
2194	31	-1	1190	2019-09-03 05:25:03.376118+03
2195	41	-2	830	2019-09-03 05:25:32.751159+03
2196	58	-2	2830	2019-09-03 06:25:03.608923+03
2197	63	-1	1780	2019-09-03 06:44:17.854401+03
2198	6	-1	980	2019-09-03 07:31:46.567984+03
2199	27	-1	880	2019-09-03 08:17:38.065312+03
2200	81	-1	1620	2019-09-03 08:19:54.152178+03
2201	67	-1	350	2019-09-03 08:52:44.959049+03
2202	5	-1	1620	2019-09-03 09:12:00.32107+03
2203	23	-2	4390	2019-09-03 10:27:58.660913+03
2204	64	-1	970	2019-09-03 11:23:35.885395+03
2205	35	32	369	2019-09-03 11:23:46.546736+03
2206	94	-1	1230	2019-09-03 11:36:00.760751+03
2207	12	-2	1650	2019-09-03 11:43:45.433587+03
2208	46	-1	1270	2019-09-03 11:43:45.839635+03
2209	40	-1	1430	2019-09-03 11:52:49.021507+03
2210	95	-1	480	2019-09-03 11:58:03.136267+03
2211	52	-1	1090	2019-09-03 12:04:52.124322+03
2212	46	-1	1270	2019-09-03 12:22:38.187762+03
2213	39	-1	910	2019-09-03 12:39:21.94144+03
2214	75	-2	830	2019-09-03 12:45:00.062229+03
2215	73	-1	960	2019-09-03 12:45:51.276097+03
2216	47	-1	1480	2019-09-03 13:08:38.13982+03
2217	76	-1	1070	2019-09-03 13:20:13.744802+03
2218	32	-1	710	2019-09-03 13:21:19.724545+03
2219	5	-1	1620	2019-09-03 13:29:49.500056+03
2220	57	-1	1900	2019-09-03 13:43:44.359607+03
2221	9	-1	2090	2019-09-03 13:49:51.777964+03
2222	67	-2	350	2019-09-03 13:55:47.089832+03
2223	32	-1	710	2019-09-03 14:16:44.94044+03
2224	52	-1	1090	2019-09-03 14:21:32.566598+03
2225	94	-1	1230	2019-09-03 14:42:39.93132+03
2226	71	-1	1030	2019-09-03 15:25:43.230177+03
2227	12	-2	1650	2019-09-03 15:37:12.875315+03
2228	69	-2	1100	2019-09-03 15:53:48.217187+03
2229	61	-1	1510	2019-09-03 16:03:29.685416+03
2230	73	-1	960	2019-09-03 16:07:23.137167+03
2231	6	-2	980	2019-09-03 16:15:49.982505+03
2232	95	-1	480	2019-09-03 17:04:18.322873+03
2233	46	-1	1270	2019-09-03 17:18:43.159721+03
2234	29	-1	1940	2019-09-03 17:27:48.396472+03
2235	14	-1	1350	2019-09-03 17:33:19.330913+03
2236	22	-2	1070	2019-09-03 17:58:44.882728+03
2237	52	-1	1090	2019-09-03 17:59:32.896851+03
2238	82	-2	560	2019-09-03 18:37:08.895487+03
2239	46	-1	1270	2019-09-03 18:37:59.737039+03
2240	34	-1	1550	2019-09-03 18:51:58.110616+03
2241	95	-2	480	2019-09-03 18:55:46.294736+03
2242	90	-1	1780	2019-09-03 19:11:37.946695+03
2243	39	-2	910	2019-09-03 20:08:59.362608+03
2244	46	-1	1270	2019-09-03 20:19:03.303385+03
2245	17	-1	1500	2019-09-03 20:26:52.496904+03
2246	50	-2	1140	2019-09-03 20:42:01.070658+03
2247	47	-2	1480	2019-09-03 20:53:20.402829+03
2248	76	-1	1070	2019-09-03 20:54:08.268091+03
2249	24	-1	950	2019-09-03 21:10:25.532274+03
2250	21	-1	960	2019-09-03 21:15:45.262131+03
2251	50	-1	1140	2019-09-03 21:53:45.079259+03
2252	31	-1	1190	2019-09-03 22:03:55.251404+03
2253	53	-2	3120	2019-09-03 23:03:55.975733+03
2254	46	-1	1270	2019-09-03 23:57:17.51481+03
2255	1	-1	640	2019-09-04 00:03:15.70467+03
2256	8	-1	1920	2019-09-04 00:20:56.823247+03
2257	49	-1	970	2019-09-04 00:48:15.391331+03
2258	69	-2	1100	2019-09-04 00:53:09.577189+03
2259	10	-1	2080	2019-09-04 00:57:58.834017+03
2260	26	-2	390	2019-09-04 01:02:10.284437+03
2261	52	-1	1090	2019-09-04 01:10:11.99526+03
2262	8	-1	1920	2019-09-04 01:30:15.680507+03
2263	73	-1	960	2019-09-04 03:05:35.285104+03
2264	53	-1	3120	2019-09-04 03:11:46.000124+03
2265	25	-1	1100	2019-09-04 03:17:22.418497+03
2266	39	-1	910	2019-09-04 03:29:23.419111+03
2267	56	-1	2460	2019-09-04 03:36:46.06304+03
2268	92	-1	630	2019-09-04 04:02:56.208351+03
2269	30	-2	1140	2019-09-04 04:16:26.296836+03
2270	6	-1	980	2019-09-04 04:29:07.145016+03
2271	64	-1	970	2019-09-04 04:58:42.000074+03
2272	84	-1	2700	2019-09-04 05:52:03.182551+03
2273	70	-1	760	2019-09-04 05:59:40.643821+03
2274	86	-1	910	2019-09-04 06:18:35.924525+03
2275	37	-1	1290	2019-09-04 06:30:33.746179+03
2276	33	-1	900	2019-09-04 07:14:50.66495+03
2277	41	-1	830	2019-09-04 07:22:28.402316+03
2278	81	-1	1620	2019-09-04 07:26:20.669731+03
2279	85	-1	730	2019-09-04 07:26:24.330188+03
2280	90	-1	1780	2019-09-04 08:54:54.372796+03
2281	85	-1	730	2019-09-04 08:55:09.847072+03
2282	92	-1	630	2019-09-04 09:53:53.547568+03
2283	5	-2	1620	2019-09-04 09:57:46.745413+03
2284	23	-1	4390	2019-09-04 10:06:54.655226+03
2285	9	-1	2090	2019-09-04 10:11:56.215408+03
2286	31	-1	1190	2019-09-04 10:18:12.805233+03
2287	30	-1	1140	2019-09-04 10:27:54.154943+03
2288	93	-2	1620	2019-09-04 11:07:32.166339+03
2289	28	-2	1860	2019-09-04 11:24:47.285766+03
2290	59	-1	1030	2019-09-04 11:38:10.83562+03
2291	64	-1	970	2019-09-04 11:56:48.210692+03
2292	25	-1	1100	2019-09-04 12:06:17.808158+03
2293	80	-1	1120	2019-09-04 12:08:06.399957+03
2294	94	-2	1230	2019-09-04 12:13:08.307466+03
2295	55	-1	3480	2019-09-04 12:21:28.031333+03
2296	18	-1	910	2019-09-04 13:07:06.078672+03
2297	53	-1	3120	2019-09-04 13:19:28.604668+03
2298	26	-1	390	2019-09-04 13:45:16.622297+03
2299	45	-1	1590	2019-09-04 14:04:03.0502+03
2300	75	-1	830	2019-09-04 14:19:55.175728+03
2301	51	-2	1310	2019-09-04 14:57:50.1034+03
2302	75	-1	830	2019-09-04 15:35:05.543434+03
2303	81	-1	1620	2019-09-04 15:49:02.826272+03
2304	90	-1	1780	2019-09-04 16:49:56.49931+03
2305	94	-1	1230	2019-09-04 16:52:44.114011+03
2306	38	-1	1100	2019-09-04 17:03:09.280742+03
2307	26	-1	390	2019-09-04 17:03:31.235658+03
2308	10	-1	2080	2019-09-04 17:32:39.334938+03
2309	4	-1	1420	2019-09-04 17:59:26.207763+03
2310	40	-1	1430	2019-09-04 18:23:31.815728+03
2311	93	-1	1620	2019-09-04 18:55:48.427075+03
2312	8	-1	1920	2019-09-04 19:03:11.240936+03
2313	10	-2	2080	2019-09-04 19:30:49.458028+03
2314	47	-2	1480	2019-09-04 19:42:25.457575+03
2315	41	-1	830	2019-09-04 19:59:32.327893+03
2316	83	-1	1230	2019-09-04 20:11:19.321416+03
2317	87	-2	2320	2019-09-04 20:26:02.365684+03
2318	25	-1	1100	2019-09-04 21:03:01.956516+03
2319	87	-1	2320	2019-09-04 21:03:54.061607+03
2320	74	-1	1010	2019-09-04 21:10:58.220335+03
2321	47	-2	1480	2019-09-04 21:13:37.082122+03
2322	37	-2	1290	2019-09-04 21:13:41.655644+03
2323	48	-1	640	2019-09-04 21:46:15.894043+03
2324	62	-1	1220	2019-09-04 21:50:17.877123+03
2325	12	-1	1650	2019-09-04 21:50:26.12569+03
2326	38	-1	1100	2019-09-04 22:12:00.030017+03
2327	49	-1	970	2019-09-04 23:11:02.279812+03
2328	6	-1	980	2019-09-04 23:23:12.673643+03
2329	6	-2	980	2019-09-04 23:25:30.880304+03
2330	3	-1	660	2019-09-04 23:44:50.572508+03
2331	17	-1	1500	2019-09-04 23:54:58.614106+03
2332	26	-1	390	2019-09-05 01:01:06.977786+03
2333	15	-2	2830	2019-09-05 01:08:21.6514+03
2334	50	-1	1140	2019-09-05 01:20:46.083616+03
2335	31	-1	1190	2019-09-05 01:28:06.033745+03
2336	63	-1	1780	2019-09-05 01:40:25.785142+03
2337	49	-1	970	2019-09-05 01:45:01.048466+03
2338	69	-1	1100	2019-09-05 03:00:26.23+03
2339	78	-1	900	2019-09-05 03:11:46.280712+03
2340	94	-1	1230	2019-09-05 03:16:30.650747+03
2341	53	-2	3120	2019-09-05 03:19:59.173155+03
2342	31	-1	1190	2019-09-05 03:44:12.471923+03
2343	38	-1	1100	2019-09-05 04:07:06.096205+03
2344	71	-1	1030	2019-09-05 04:11:31.342933+03
2345	15	-1	2830	2019-09-05 04:16:49.480161+03
2346	37	-1	1290	2019-09-05 04:20:35.662261+03
2347	30	-1	1140	2019-09-05 04:28:57.365252+03
2348	46	-1	1270	2019-09-05 04:32:34.737239+03
2349	70	-1	760	2019-09-05 04:52:13.791967+03
2350	89	-1	1420	2019-09-05 05:14:23.545762+03
2351	39	-1	910	2019-09-05 05:39:59.301891+03
2352	2	14	252	2019-09-05 05:47:53.895679+03
2353	91	-1	1620	2019-09-05 06:52:57.893935+03
2354	12	-1	1650	2019-09-05 07:20:59.540786+03
2355	76	-3	1070	2019-09-05 07:26:00.576234+03
2356	70	-1	760	2019-09-05 08:07:32.903011+03
2357	93	-2	1620	2019-09-05 08:26:12.698214+03
2358	11	-1	830	2019-09-05 09:00:06.142767+03
2359	37	-1	1290	2019-09-05 09:08:48.887071+03
2360	78	-1	900	2019-09-05 09:36:31.404568+03
2361	11	-3	830	2019-09-05 09:53:39.082518+03
2362	92	-1	630	2019-09-05 10:04:32.480245+03
2363	49	-1	970	2019-09-05 10:13:23.901342+03
2364	11	-1	830	2019-09-05 11:08:46.404794+03
2365	18	-1	910	2019-09-05 11:20:03.620227+03
2366	59	-2	1030	2019-09-05 11:48:01.693548+03
2367	75	-1	830	2019-09-05 12:02:20.733807+03
2368	79	-1	550	2019-09-05 12:24:08.254915+03
2369	88	-1	1270	2019-09-05 12:49:23.351578+03
2370	77	-2	640	2019-09-05 12:59:32.553722+03
2371	83	-2	1230	2019-09-05 13:02:00.142017+03
2372	67	-1	350	2019-09-05 13:43:12.371747+03
2373	85	-1	730	2019-09-05 14:27:25.926432+03
2374	86	-1	910	2019-09-05 14:27:45.154101+03
2375	64	-1	970	2019-09-05 14:41:27.625068+03
2376	76	-1	1070	2019-09-05 14:47:36.038849+03
2377	87	-1	2320	2019-09-05 14:58:52.607269+03
2378	29	-2	1940	2019-09-05 15:03:11.663634+03
2379	37	-1	1290	2019-09-05 15:55:21.623406+03
2380	47	-2	1480	2019-09-05 15:55:21.923403+03
2381	54	-1	3470	2019-09-05 16:12:18.713131+03
2382	76	-1	1070	2019-09-05 16:35:25.724061+03
2383	25	-1	1100	2019-09-05 16:35:44.146043+03
2384	78	-1	900	2019-09-05 16:40:45.684116+03
2385	6	-1	980	2019-09-05 16:41:31.099135+03
2386	44	-1	500	2019-09-05 16:52:08.572158+03
2387	4	-1	1420	2019-09-05 16:57:00.503962+03
2388	54	-1	3470	2019-09-05 17:04:52.868639+03
2389	52	-1	1090	2019-09-05 17:10:30.036312+03
2390	67	-1	350	2019-09-05 17:20:11.075329+03
2391	83	-1	1230	2019-09-05 17:36:09.683308+03
2392	63	-1	1780	2019-09-05 17:43:00.417769+03
2393	38	-1	1100	2019-09-05 17:50:52.796449+03
2394	79	-1	550	2019-09-05 17:56:04.132738+03
2395	87	-1	2320	2019-09-05 18:09:47.856559+03
2396	95	-1	480	2019-09-05 18:35:55.338636+03
2397	33	-1	900	2019-09-05 18:55:46.154386+03
2398	32	-1	710	2019-09-05 19:45:44.053952+03
2399	71	-1	1030	2019-09-05 19:52:38.114663+03
2400	83	-2	1230	2019-09-05 20:13:30.839459+03
2401	20	-2	830	2019-09-05 20:36:13.566556+03
2402	24	-1	950	2019-09-05 20:56:36.721592+03
2403	21	-1	960	2019-09-05 20:56:53.857102+03
2404	33	-1	900	2019-09-05 21:05:01.857186+03
2405	55	-1	3480	2019-09-05 21:06:19.23852+03
2406	72	11	343	2019-09-05 21:13:01.404439+03
2407	36	-2	630	2019-09-05 21:38:45.802608+03
2408	21	-1	960	2019-09-05 21:42:24.202487+03
2409	29	-1	1940	2019-09-05 21:56:06.005038+03
2410	38	32	445	2019-09-05 22:13:35.216281+03
2411	88	-2	1270	2019-09-05 22:19:13.004076+03
2412	58	-1	2830	2019-09-05 22:27:12.938851+03
2413	47	-2	1480	2019-09-05 22:27:21.770786+03
2414	85	-1	730	2019-09-05 22:28:29.640877+03
2415	7	-1	810	2019-09-05 22:40:14.182724+03
2416	28	-1	1860	2019-09-05 23:27:10.950413+03
2417	72	-1	620	2019-09-05 23:41:04.411857+03
2418	94	21	541	2019-09-06 00:20:17.26823+03
2419	5	-1	1620	2019-09-06 01:22:36.731158+03
2420	85	-1	730	2019-09-06 01:26:03.906233+03
2421	34	-1	1550	2019-09-06 01:56:16.911016+03
2422	63	-1	1780	2019-09-06 02:02:17.572029+03
2423	80	-2	1120	2019-09-06 02:17:49.043413+03
2424	68	-1	490	2019-09-06 03:08:13.462926+03
2425	6	-2	980	2019-09-06 03:18:32.612989+03
2426	56	-1	2460	2019-09-06 03:30:03.154992+03
2427	89	-3	1420	2019-09-06 03:54:48.059946+03
2428	65	-1	490	2019-09-06 04:37:12.830096+03
2429	10	-1	2080	2019-09-06 04:50:54.316806+03
2430	3	-1	660	2019-09-06 05:14:34.898732+03
2431	73	-1	960	2019-09-06 05:29:36.78278+03
2432	34	-1	1550	2019-09-06 05:30:05.753258+03
2433	71	-1	1030	2019-09-06 05:31:39.209909+03
2434	24	-1	950	2019-09-06 05:47:28.115398+03
2435	72	-1	620	2019-09-06 06:10:41.99104+03
2436	43	-1	380	2019-09-06 06:10:52.919033+03
2437	83	-2	1230	2019-09-06 06:24:09.671744+03
2438	46	-1	1270	2019-09-06 06:30:57.444574+03
2439	86	-1	910	2019-09-06 06:40:06.127617+03
2440	11	-1	830	2019-09-06 06:46:20.484919+03
2441	43	-1	380	2019-09-06 06:57:05.156446+03
2442	22	-1	1070	2019-09-06 07:00:56.429662+03
2443	64	-1	970	2019-09-06 07:06:21.065999+03
2444	27	-1	880	2019-09-06 07:09:28.559005+03
2445	65	-1	490	2019-09-06 07:44:14.487587+03
2446	93	-2	1620	2019-09-06 08:01:07.064153+03
2447	39	-1	910	2019-09-06 08:01:24.503473+03
2448	34	-1	1550	2019-09-06 08:01:36.278654+03
2449	22	-2	1070	2019-09-06 08:48:06.659451+03
2450	24	-1	950	2019-09-06 08:52:48.837919+03
2451	29	-1	1940	2019-09-06 09:06:53.687402+03
2452	76	-1	1070	2019-09-06 09:25:26.937609+03
2453	29	-1	1940	2019-09-06 09:59:41.625452+03
2454	51	-1	1310	2019-09-06 10:11:44.655013+03
2455	31	-1	1190	2019-09-06 10:42:39.106812+03
2456	20	32	363	2019-09-06 11:43:50.590874+03
2457	84	-2	2700	2019-09-06 11:45:34.401367+03
2458	28	-1	1860	2019-09-06 11:53:53.442147+03
2459	15	-1	2830	2019-09-06 12:01:44.943395+03
2460	46	-1	1270	2019-09-06 12:05:26.220689+03
2461	88	-1	1270	2019-09-06 12:13:56.848911+03
2462	84	-1	2700	2019-09-06 12:22:36.313199+03
2463	57	-2	1900	2019-09-06 12:57:20.775628+03
2464	87	-1	2320	2019-09-06 13:31:58.197128+03
2465	64	-1	970	2019-09-06 15:02:46.589051+03
2466	14	-1	1350	2019-09-06 15:03:24.735278+03
2467	56	-2	2460	2019-09-06 15:08:32.025473+03
2468	70	-1	760	2019-09-06 15:12:41.088735+03
2469	13	-1	460	2019-09-06 15:21:51.856469+03
2470	87	-1	2320	2019-09-06 15:34:35.976201+03
2471	55	-1	3480	2019-09-06 15:50:17.33647+03
2472	81	-1	1620	2019-09-06 16:00:24.2543+03
2473	4	-1	1420	2019-09-06 16:02:39.255773+03
2474	63	-1	1780	2019-09-06 16:11:12.457606+03
2475	19	-1	1220	2019-09-06 16:32:24.124822+03
2476	46	-1	1270	2019-09-06 17:11:36.734744+03
2477	69	-1	1100	2019-09-06 17:28:29.890794+03
2478	38	-1	1100	2019-09-06 17:32:01.665846+03
2479	7	-1	810	2019-09-06 17:34:15.147432+03
2480	3	-1	660	2019-09-06 17:45:40.216897+03
2481	47	-1	1480	2019-09-06 17:52:05.146937+03
2482	88	-1	1270	2019-09-06 18:06:18.211188+03
2483	64	-2	970	2019-09-06 18:13:43.516027+03
2484	57	-1	1900	2019-09-06 18:46:38.971864+03
2485	87	-1	2320	2019-09-06 19:09:47.347059+03
2486	80	-1	1120	2019-09-06 20:02:07.275227+03
2487	87	-1	2320	2019-09-06 20:07:52.852365+03
2488	14	-1	1350	2019-09-06 20:27:05.345805+03
2489	32	-1	710	2019-09-06 20:31:29.624642+03
2490	84	-1	2700	2019-09-06 21:25:18.715803+03
2491	11	-1	830	2019-09-06 21:26:57.824467+03
2492	22	-1	1070	2019-09-06 21:47:31.539911+03
2493	56	-1	2460	2019-09-06 21:52:00.191103+03
2494	44	-1	500	2019-09-06 22:08:46.449522+03
2495	9	24	1229	2019-09-06 22:29:40.426305+03
2496	73	-2	960	2019-09-06 22:57:05.946653+03
2497	68	-1	490	2019-09-06 23:22:38.218938+03
2498	73	-2	960	2019-09-07 00:17:33.647048+03
2499	18	-2	910	2019-09-07 00:20:58.382703+03
2500	10	-1	2080	2019-09-07 00:49:33.889317+03
2501	57	-1	1900	2019-09-07 00:58:59.096378+03
2502	76	-2	1070	2019-09-07 01:03:29.705431+03
2503	28	-2	1860	2019-09-07 01:16:53.359411+03
2504	61	-1	1510	2019-09-07 01:22:10.409696+03
2505	50	-1	1140	2019-09-07 01:51:22.080967+03
2506	34	-1	1550	2019-09-07 02:10:15.044602+03
2507	49	-1	970	2019-09-07 02:11:59.578771+03
2508	54	-1	3470	2019-09-07 02:21:07.783302+03
2509	62	-1	1220	2019-09-07 02:34:44.236054+03
2510	83	-1	1230	2019-09-07 03:08:44.670869+03
2511	10	-1	2080	2019-09-07 03:10:37.82323+03
2512	12	-1	1650	2019-09-07 03:29:46.665535+03
2513	91	-1	1620	2019-09-07 04:08:42.535963+03
2514	78	-2	900	2019-09-07 04:23:10.13819+03
2515	37	-1	1290	2019-09-07 04:29:14.351945+03
2516	38	-2	1100	2019-09-07 04:31:08.694981+03
2517	49	-2	970	2019-09-07 04:50:39.257985+03
2518	43	-1	380	2019-09-07 05:05:31.376961+03
2519	68	-1	490	2019-09-07 05:33:18.97918+03
2520	18	-1	910	2019-09-07 06:10:34.583277+03
2521	53	-1	3120	2019-09-07 06:17:00.175497+03
2522	92	-1	630	2019-09-07 06:34:49.862798+03
2523	12	-2	1650	2019-09-07 06:45:54.827331+03
2524	33	-1	900	2019-09-07 06:54:31.687938+03
2525	83	-3	1230	2019-09-07 06:58:32.947266+03
2526	81	-1	1620	2019-09-07 07:51:14.364376+03
2527	28	-2	1860	2019-09-07 08:03:29.88279+03
2528	71	-1	1030	2019-09-07 08:19:04.337661+03
2529	3	-1	660	2019-09-07 08:31:04.506531+03
2530	74	-1	1010	2019-09-07 08:35:54.534033+03
2531	26	-2	390	2019-09-07 09:09:35.706025+03
2532	61	-1	1510	2019-09-07 09:42:06.109189+03
2533	77	-1	640	2019-09-07 10:06:31.507705+03
2534	63	-1	1780	2019-09-07 10:40:36.609019+03
2535	14	33	784	2019-09-07 10:49:18.888863+03
2536	58	-2	2830	2019-09-07 11:01:19.390688+03
2537	91	-2	1620	2019-09-07 11:17:43.271701+03
2538	88	-1	1270	2019-09-07 11:25:18.03038+03
2539	4	-3	1420	2019-09-07 11:40:48.82064+03
2540	35	-2	670	2019-09-07 12:17:34.226369+03
2541	23	-1	4390	2019-09-07 12:23:53.213447+03
2542	3	-2	660	2019-09-07 12:30:53.510538+03
2543	12	-3	1650	2019-09-07 12:54:47.083596+03
2544	88	-1	1270	2019-09-07 12:54:53.92983+03
2545	88	-1	1270	2019-09-07 12:55:05.53072+03
2546	59	-1	1030	2019-09-07 12:57:31.546808+03
2547	2	-1	470	2019-09-07 13:15:05.138909+03
2548	22	-1	1070	2019-09-07 13:26:28.227234+03
2549	10	-1	2080	2019-09-07 13:44:33.939887+03
2550	82	-1	560	2019-09-07 13:46:43.142187+03
2551	5	34	763	2019-09-07 13:53:19.223745+03
2552	55	-2	3480	2019-09-07 14:03:33.167785+03
2553	71	-1	1030	2019-09-07 14:31:09.50144+03
2554	30	-1	1140	2019-09-07 14:41:14.407255+03
2555	29	-1	1940	2019-09-07 14:44:18.637599+03
2556	14	-2	1350	2019-09-07 14:46:03.893497+03
2557	56	-1	2460	2019-09-07 14:59:31.170934+03
2558	22	-2	1070	2019-09-07 15:04:46.481618+03
2559	66	-1	690	2019-09-07 15:37:55.378522+03
2560	48	-1	640	2019-09-07 16:28:03.991747+03
2561	27	17	488	2019-09-07 16:30:47.682096+03
2562	33	-1	900	2019-09-07 16:33:18.360048+03
2563	85	-1	730	2019-09-07 17:26:50.539281+03
2564	89	-1	1420	2019-09-07 17:36:16.797775+03
2565	67	-1	350	2019-09-07 17:44:57.970133+03
2566	31	-2	1190	2019-09-07 17:48:53.015019+03
2567	52	-1	1090	2019-09-07 17:56:01.951213+03
2568	39	-1	910	2019-09-07 18:15:46.079884+03
2569	6	-1	980	2019-09-07 18:19:28.033999+03
2570	76	-1	1070	2019-09-07 18:35:46.471512+03
2571	54	-1	3470	2019-09-07 18:53:53.034167+03
2572	12	-1	1650	2019-09-07 19:00:56.762332+03
2573	12	-2	1650	2019-09-07 19:12:23.321367+03
2574	78	-1	900	2019-09-07 19:29:03.215936+03
2575	39	-1	910	2019-09-07 19:35:41.652434+03
2576	44	-1	500	2019-09-07 20:00:44.916999+03
2577	61	-1	1510	2019-09-07 20:34:01.933293+03
2578	81	-1	1620	2019-09-07 20:54:00.194696+03
2579	12	-2	1650	2019-09-07 21:23:36.250305+03
2580	49	-1	970	2019-09-07 21:47:25.15725+03
2581	89	-1	1420	2019-09-07 21:48:06.206448+03
2582	57	-1	1900	2019-09-07 22:02:30.70269+03
2583	70	-1	760	2019-09-07 22:29:12.642781+03
2584	20	-2	830	2019-09-07 22:55:08.690478+03
2585	22	-1	1070	2019-09-08 00:25:19.339293+03
2586	67	-1	350	2019-09-08 00:31:35.590909+03
2587	12	-1	1650	2019-09-08 00:40:13.547541+03
2588	49	-1	970	2019-09-08 00:56:03.448728+03
2589	76	-2	1070	2019-09-08 01:10:32.33193+03
2590	60	-1	2700	2019-09-08 01:21:40.376768+03
2591	55	-2	3480	2019-09-08 01:23:21.511498+03
2592	78	-2	900	2019-09-08 01:25:12.133266+03
2593	39	-1	910	2019-09-08 01:45:33.646388+03
2594	57	-1	1900	2019-09-08 02:01:34.156594+03
2595	77	-1	640	2019-09-08 02:01:43.415922+03
2596	82	-1	560	2019-09-08 02:09:58.939534+03
2597	56	-1	2460	2019-09-08 02:15:25.090587+03
2598	40	-1	1430	2019-09-08 02:25:38.605236+03
2599	40	-1	1430	2019-09-08 02:41:28.870792+03
2600	37	-2	1290	2019-09-08 02:51:44.150678+03
2601	3	-1	660	2019-09-08 03:04:39.15296+03
2602	49	-1	970	2019-09-08 03:09:35.393127+03
2603	45	-1	1590	2019-09-08 03:18:36.04876+03
2604	40	-1	1430	2019-09-08 03:19:42.662525+03
2605	85	-1	730	2019-09-08 03:20:18.208439+03
2606	13	-2	460	2019-09-08 03:22:03.185615+03
2607	59	-2	1030	2019-09-08 03:24:43.830676+03
2608	5	-1	1620	2019-09-08 03:38:07.85067+03
2609	95	-1	480	2019-09-08 03:39:58.900552+03
2610	22	-1	1070	2019-09-08 04:32:57.427588+03
2611	33	-2	900	2019-09-08 04:34:10.153227+03
2612	96	-1	1570	2019-09-08 04:37:01.600377+03
2613	79	-2	550	2019-09-08 04:40:01.356296+03
2614	52	-2	1090	2019-09-08 04:49:05.769434+03
2615	12	-1	1650	2019-09-08 04:50:50.819941+03
2616	1	-1	640	2019-09-08 04:58:24.894157+03
2617	14	-2	1350	2019-09-08 05:23:30.359439+03
2618	47	-1	1480	2019-09-08 05:42:48.545948+03
2619	45	-1	1590	2019-09-08 06:08:43.291786+03
2620	66	-1	690	2019-09-08 06:28:40.926627+03
2621	21	-1	960	2019-09-08 06:45:26.219108+03
2622	68	-1	490	2019-09-08 07:01:43.027283+03
2623	48	-1	640	2019-09-08 07:21:55.312698+03
2624	42	-1	1790	2019-09-08 07:44:08.965597+03
2625	77	-2	640	2019-09-08 07:57:48.925342+03
2626	84	-1	2700	2019-09-08 08:07:36.361617+03
2627	5	-1	1620	2019-09-08 08:36:42.937402+03
2628	37	-1	1290	2019-09-08 08:53:59.19955+03
2629	67	-2	350	2019-09-08 08:57:34.347174+03
2630	54	-1	3470	2019-09-08 09:01:32.345776+03
2631	86	-1	910	2019-09-08 09:38:20.140846+03
2632	80	-1	1120	2019-09-08 09:39:08.351659+03
2633	86	-1	910	2019-09-08 10:08:38.345547+03
2634	15	-1	2830	2019-09-08 10:15:47.120285+03
2635	4	-1	1420	2019-09-08 10:32:01.635447+03
2636	41	-1	830	2019-09-08 10:58:37.605357+03
2637	12	-1	1650	2019-09-08 11:03:12.373084+03
2638	17	-1	1500	2019-09-08 11:04:53.115316+03
2639	85	-2	730	2019-09-08 11:23:07.405812+03
2640	87	-1	2320	2019-09-08 11:54:51.972131+03
2641	94	-1	1230	2019-09-08 12:23:26.579158+03
2642	45	-1	1590	2019-09-08 12:35:22.440243+03
2643	3	-1	660	2019-09-08 12:36:06.709172+03
2644	29	-1	1940	2019-09-08 12:48:58.513712+03
2645	51	-1	1310	2019-09-08 12:55:13.728542+03
2646	4	-2	1420	2019-09-08 13:24:31.516501+03
2647	74	-1	1010	2019-09-08 13:52:25.318394+03
2648	81	-2	1620	2019-09-08 14:33:39.661234+03
2649	22	46	562	2019-09-08 14:39:23.925304+03
2650	90	-1	1780	2019-09-08 15:04:11.635755+03
2651	9	-1	2090	2019-09-08 15:09:21.956069+03
2652	20	-1	830	2019-09-08 15:35:18.111947+03
2653	33	-1	900	2019-09-08 15:43:44.699128+03
2654	78	-1	900	2019-09-08 15:55:37.500177+03
2655	4	44	606	2019-09-08 16:02:25.457711+03
2656	49	-1	970	2019-09-08 16:15:39.707187+03
2657	9	-2	2090	2019-09-08 16:45:09.92846+03
2658	14	-1	1350	2019-09-08 17:25:01.883715+03
2659	59	-1	1030	2019-09-08 17:54:04.557443+03
2660	37	-1	1290	2019-09-08 18:07:33.266294+03
2661	89	-1	1420	2019-09-08 18:09:26.243397+03
2662	12	-1	1650	2019-09-08 18:36:06.922131+03
2663	18	-1	910	2019-09-08 18:55:22.112255+03
2664	2	-1	470	2019-09-08 19:18:02.604969+03
2665	83	-1	1230	2019-09-08 19:30:18.910971+03
2666	77	-1	640	2019-09-08 19:33:02.802984+03
2667	84	-1	2700	2019-09-08 19:38:16.104483+03
2668	95	-1	480	2019-09-08 19:46:23.721542+03
2669	30	-1	1140	2019-09-08 20:02:26.212229+03
2670	2	-1	470	2019-09-08 20:31:20.335798+03
2671	32	-1	710	2019-09-08 20:59:34.111119+03
2672	70	-1	760	2019-09-08 21:41:59.405066+03
2673	51	-1	1310	2019-09-08 22:38:10.429858+03
2674	95	-1	480	2019-09-08 22:47:04.98628+03
2675	55	-1	3480	2019-09-08 23:09:26.374681+03
2676	35	-1	670	2019-09-08 23:28:19.47404+03
2677	38	-2	1100	2019-09-08 23:41:11.940539+03
2678	24	-1	950	2019-09-09 00:51:45.971373+03
2679	47	-1	1480	2019-09-09 01:07:40.198666+03
2680	85	-1	730	2019-09-09 01:56:17.620696+03
2681	40	-1	1430	2019-09-09 02:08:29.864007+03
2682	35	-1	670	2019-09-09 02:28:15.856359+03
2683	46	-1	1270	2019-09-09 02:44:48.558896+03
2684	55	-1	3480	2019-09-09 03:46:03.57788+03
2685	15	-1	2830	2019-09-09 04:11:14.988175+03
2686	17	23	611	2019-09-09 05:12:22.225478+03
2687	37	-2	1290	2019-09-09 05:21:23.897392+03
2688	55	-2	3480	2019-09-09 05:29:03.147+03
2689	81	-1	1620	2019-09-09 05:38:55.855524+03
2690	19	-1	1220	2019-09-09 05:50:07.751394+03
2691	76	-1	1070	2019-09-09 05:58:32.991404+03
2692	48	-1	640	2019-09-09 05:58:53.700322+03
2693	89	-1	1420	2019-09-09 05:59:43.562482+03
2694	14	-2	1350	2019-09-09 06:08:22.017716+03
2695	51	-2	1310	2019-09-09 06:11:58.309626+03
2696	68	-1	490	2019-09-09 06:19:21.469719+03
2697	88	-1	1270	2019-09-09 06:59:25.381395+03
2698	45	-1	1590	2019-09-09 07:13:32.553801+03
2699	75	-1	830	2019-09-09 07:29:16.797481+03
2700	63	-1	1780	2019-09-09 07:51:18.874817+03
2701	46	-1	1270	2019-09-09 08:01:01.457535+03
2702	37	-1	1290	2019-09-09 08:16:42.581775+03
2703	63	-1	1780	2019-09-09 09:14:45.309358+03
2704	14	-1	1350	2019-09-09 09:27:12.941826+03
2705	74	-1	1010	2019-09-09 09:39:51.504818+03
2706	67	-1	350	2019-09-09 09:42:13.39549+03
2707	13	-1	460	2019-09-09 09:45:01.386578+03
2708	14	-1	1350	2019-09-09 09:45:51.629548+03
2709	53	-1	3120	2019-09-09 09:46:15.091373+03
2710	66	-1	690	2019-09-09 10:00:04.585535+03
2711	96	-1	1570	2019-09-09 10:00:47.931841+03
2712	10	-1	2080	2019-09-09 10:04:29.392793+03
2713	90	-1	1780	2019-09-09 10:28:47.752999+03
2714	28	-1	1860	2019-09-09 10:31:25.135038+03
2715	83	-1	1230	2019-09-09 10:32:06.382636+03
2716	85	19	393	2019-09-09 10:53:55.158696+03
2717	79	-1	550	2019-09-09 11:08:55.430679+03
2718	55	-1	3480	2019-09-09 11:18:21.038394+03
2719	95	-1	480	2019-09-09 11:18:24.300577+03
2720	29	-2	1940	2019-09-09 12:03:26.008792+03
2721	53	-1	3120	2019-09-09 12:40:44.06821+03
2722	70	-1	760	2019-09-09 13:07:47.150937+03
2723	16	-2	1380	2019-09-09 13:20:33.678171+03
2724	34	-1	1550	2019-09-09 13:45:47.473058+03
2725	38	-1	1100	2019-09-09 13:51:11.522372+03
2726	26	-1	390	2019-09-09 14:05:28.140316+03
2727	77	-1	640	2019-09-09 14:23:04.108981+03
2728	29	-1	1940	2019-09-09 14:45:14.385392+03
2729	26	-1	390	2019-09-09 15:02:45.816163+03
2730	50	-1	1140	2019-09-09 15:17:21.439364+03
2731	40	-1	1430	2019-09-09 15:22:53.82955+03
2732	93	-1	1620	2019-09-09 15:50:52.785002+03
2733	61	-1	1510	2019-09-09 15:52:16.849091+03
2734	35	-2	670	2019-09-09 16:03:53.332891+03
2735	76	-2	1070	2019-09-09 16:16:00.828708+03
2736	47	-1	1480	2019-09-09 16:44:33.035137+03
2737	38	-1	1100	2019-09-09 17:10:14.109319+03
2738	8	-2	1920	2019-09-09 17:41:01.432619+03
2739	83	-1	1230	2019-09-09 17:42:33.549449+03
2740	90	-1	1780	2019-09-09 17:43:08.149503+03
2741	20	-1	830	2019-09-09 17:58:17.145076+03
2742	60	-1	2700	2019-09-09 18:29:49.182489+03
2743	19	-1	1220	2019-09-09 18:35:04.09968+03
2744	49	36	557	2019-09-09 18:47:25.982593+03
2745	67	-1	350	2019-09-09 18:47:41.81732+03
2746	64	-1	970	2019-09-09 18:59:12.43824+03
2747	21	-1	960	2019-09-09 19:01:37.0216+03
2748	65	-1	490	2019-09-09 19:06:16.162219+03
2749	90	-1	1780	2019-09-09 19:22:02.698601+03
2750	39	-1	910	2019-09-09 19:50:24.780436+03
2751	40	-1	1430	2019-09-09 19:53:14.683041+03
2752	67	-1	350	2019-09-09 20:03:33.849984+03
2753	47	-1	1480	2019-09-09 20:21:29.16633+03
2754	17	-1	1500	2019-09-09 20:30:09.102631+03
2755	37	-1	1290	2019-09-09 20:39:00.607562+03
2756	32	-2	710	2019-09-09 20:59:54.220823+03
2757	29	-1	1940	2019-09-09 21:04:55.867808+03
2758	56	-1	2460	2019-09-09 21:14:02.287121+03
2759	31	-1	1190	2019-09-09 21:19:17.817817+03
2760	71	-2	1030	2019-09-09 21:20:26.942419+03
2761	17	-2	1500	2019-09-09 22:04:17.825569+03
2762	24	-1	950	2019-09-09 22:04:44.628687+03
2763	22	-1	1070	2019-09-09 22:18:34.150098+03
2764	59	-2	1030	2019-09-09 22:23:16.856709+03
2765	67	-1	350	2019-09-09 22:39:21.208904+03
2766	41	-1	830	2019-09-09 22:59:07.178825+03
2767	88	-1	1270	2019-09-09 23:02:56.17933+03
2768	19	-1	1220	2019-09-09 23:07:36.144551+03
2769	85	-2	730	2019-09-09 23:09:54.036022+03
2770	14	-2	1350	2019-09-09 23:12:20.652662+03
2771	69	-1	1100	2019-09-09 23:21:14.227718+03
2772	59	-2	1030	2019-09-09 23:24:35.122373+03
2773	42	-1	1790	2019-09-09 23:29:46.634291+03
2774	78	-1	900	2019-09-09 23:32:36.677839+03
2775	44	-1	500	2019-09-09 23:43:31.904626+03
2776	78	-1	900	2019-09-10 00:57:29.147701+03
2777	47	-1	1480	2019-09-10 00:57:43.969971+03
2778	83	-1	1230	2019-09-10 01:06:54.468102+03
2779	90	-1	1780	2019-09-10 01:44:19.592901+03
2780	18	-1	910	2019-09-10 01:46:43.182415+03
2781	36	-1	630	2019-09-10 02:00:24.677663+03
2782	18	-1	910	2019-09-10 02:06:13.033548+03
2783	46	-1	1270	2019-09-10 02:13:27.639695+03
2784	89	-1	1420	2019-09-10 02:27:43.363899+03
2785	37	-1	1290	2019-09-10 02:46:52.920321+03
2786	19	-2	1220	2019-09-10 02:51:19.346103+03
2787	48	-2	640	2019-09-10 03:00:30.27777+03
2788	28	-1	1860	2019-09-10 03:03:46.514549+03
2789	58	-1	2830	2019-09-10 03:10:26.278126+03
2790	94	-2	1230	2019-09-10 03:13:41.675633+03
2791	57	-1	1900	2019-09-10 03:42:35.598783+03
2792	65	-1	490	2019-09-10 03:48:18.139781+03
2793	59	-1	1030	2019-09-10 04:04:01.095232+03
2794	20	-2	830	2019-09-10 04:27:29.265199+03
2795	30	-1	1140	2019-09-10 04:43:46.636345+03
2796	84	-1	2700	2019-09-10 05:16:46.289023+03
2797	63	-1	1780	2019-09-10 05:36:07.357493+03
2798	10	-1	2080	2019-09-10 05:50:57.199644+03
2799	1	-1	640	2019-09-10 05:57:24.607605+03
2800	22	-2	1070	2019-09-10 06:00:34.306294+03
2801	90	-1	1780	2019-09-10 06:07:52.496077+03
2802	28	-1	1860	2019-09-10 07:10:22.240014+03
2803	73	26	411	2019-09-10 08:27:30.552834+03
2804	40	-1	1430	2019-09-10 08:50:51.267109+03
2805	90	-1	1780	2019-09-10 08:53:38.308164+03
2806	88	-1	1270	2019-09-10 08:54:15.05653+03
2807	22	-1	1070	2019-09-10 09:06:52.199098+03
2808	63	-1	1780	2019-09-10 09:25:42.786905+03
2809	65	-1	490	2019-09-10 09:25:45.077403+03
2810	87	-1	2320	2019-09-10 09:37:08.605919+03
2811	77	-1	640	2019-09-10 09:38:55.665302+03
2812	58	24	1290	2019-09-10 09:46:29.44588+03
2813	64	-1	970	2019-09-10 09:50:34.721306+03
2814	31	25	491	2019-09-10 10:06:01.314139+03
2815	9	-1	2090	2019-09-10 10:13:18.997706+03
2816	58	-1	2830	2019-09-10 10:14:04.727942+03
2817	80	-1	1120	2019-09-10 10:58:57.375944+03
2818	8	-2	1920	2019-09-10 11:03:15.886007+03
2819	83	-1	1230	2019-09-10 11:08:35.332258+03
2820	41	-1	830	2019-09-10 11:20:59.512018+03
2821	1	-1	640	2019-09-10 11:40:17.625781+03
2822	14	-2	1350	2019-09-10 12:24:00.000685+03
2823	83	-2	1230	2019-09-10 12:40:02.477638+03
2824	39	-2	910	2019-09-10 13:11:49.621357+03
2825	42	-1	1790	2019-09-10 13:23:49.345298+03
2826	42	-1	1790	2019-09-10 13:49:55.266122+03
2827	36	-1	630	2019-09-10 14:03:20.934456+03
2828	96	-1	1570	2019-09-10 14:15:54.94429+03
2829	1	-1	640	2019-09-10 14:25:59.123384+03
2830	38	-2	1100	2019-09-10 14:56:31.225098+03
2831	37	-1	1290	2019-09-10 15:09:01.278617+03
2832	57	-2	1900	2019-09-10 15:12:48.102825+03
2833	55	-1	3480	2019-09-10 15:36:29.129696+03
2834	27	-1	880	2019-09-10 16:36:07.353807+03
2835	65	-1	490	2019-09-10 16:43:20.516819+03
2836	56	-1	2460	2019-09-10 16:43:34.294897+03
2837	29	-1	1940	2019-09-10 17:11:46.759868+03
2838	56	-2	2460	2019-09-10 17:56:06.597203+03
2839	41	-1	830	2019-09-10 18:15:22.957708+03
2840	84	-1	2700	2019-09-10 18:32:36.968816+03
2841	79	25	325	2019-09-10 19:08:20.688777+03
2842	85	-1	730	2019-09-10 19:23:01.443901+03
2843	57	-1	1900	2019-09-10 19:47:03.619183+03
2844	86	-2	910	2019-09-10 19:54:17.152233+03
2845	13	-1	460	2019-09-10 20:16:47.650748+03
2846	55	-1	3480	2019-09-10 20:37:48.365474+03
2847	28	-1	1860	2019-09-10 20:37:57.084829+03
2848	16	-1	1380	2019-09-10 20:39:28.049952+03
2849	7	-1	810	2019-09-10 20:43:52.70188+03
2850	55	-1	3480	2019-09-10 20:44:18.341526+03
2851	29	-1	1940	2019-09-10 21:08:28.563475+03
2852	2	-1	470	2019-09-10 21:18:47.662028+03
2853	78	24	379	2019-09-10 21:30:14.383268+03
2854	19	-1	1220	2019-09-10 21:54:05.52039+03
2855	21	-2	960	2019-09-10 22:38:06.905884+03
2856	90	-1	1780	2019-09-10 22:44:47.280683+03
2857	11	-2	830	2019-09-10 22:52:46.468144+03
2858	75	-1	830	2019-09-10 23:02:43.463038+03
2859	19	19	567	2019-09-10 23:06:58.912753+03
2860	41	-1	830	2019-09-10 23:20:59.716907+03
2861	16	-1	1380	2019-09-10 23:31:09.443066+03
2862	4	-1	1420	2019-09-10 23:40:20.95197+03
2863	38	-1	1100	2019-09-10 23:51:24.509515+03
2864	47	-1	1480	2019-09-11 00:29:34.417467+03
2865	29	-1	1940	2019-09-11 00:39:11.445705+03
2866	8	-2	1920	2019-09-11 00:45:18.528508+03
2867	42	-1	1790	2019-09-11 00:54:47.621617+03
2868	71	-1	1030	2019-09-11 01:33:05.033031+03
2869	84	-1	2700	2019-09-11 01:35:55.297353+03
2870	6	-1	980	2019-09-11 02:16:25.869722+03
2871	55	-1	3480	2019-09-11 02:47:41.699332+03
2872	70	-1	760	2019-09-11 02:48:25.844262+03
2873	46	-1	1270	2019-09-11 02:57:34.431963+03
2874	71	-2	1030	2019-09-11 03:57:27.899877+03
2875	93	-2	1620	2019-09-11 04:27:58.40171+03
2876	66	-1	690	2019-09-11 04:29:47.321752+03
2877	6	-2	980	2019-09-11 04:51:20.588967+03
2878	87	-1	2320	2019-09-11 05:28:09.552813+03
2879	83	-1	1230	2019-09-11 05:46:26.349377+03
2880	23	-1	4390	2019-09-11 06:32:03.703504+03
2881	29	-1	1940	2019-09-11 06:40:00.418641+03
2882	19	-2	1220	2019-09-11 06:42:27.461815+03
2883	1	-1	640	2019-09-11 07:03:53.635201+03
2884	56	-1	2460	2019-09-11 07:06:58.502059+03
2885	75	25	399	2019-09-11 07:11:00.206144+03
2886	14	-1	1350	2019-09-11 07:16:52.120424+03
2887	28	-1	1860	2019-09-11 07:19:49.127321+03
2888	19	-1	1220	2019-09-11 07:36:53.973973+03
2889	16	-2	1380	2019-09-11 07:44:49.147217+03
2890	42	-1	1790	2019-09-11 07:52:29.619594+03
2891	41	-1	830	2019-09-11 07:57:46.349125+03
2892	86	-1	910	2019-09-11 08:00:50.3191+03
2893	28	-1	1860	2019-09-11 08:07:12.251141+03
2894	53	-2	3120	2019-09-11 08:18:47.770742+03
2895	1	-1	640	2019-09-11 09:12:33.225101+03
2896	13	-3	460	2019-09-11 09:20:35.282024+03
2897	39	31	444	2019-09-11 09:23:27.419227+03
2898	48	-1	640	2019-09-11 09:59:56.884485+03
2899	6	-2	980	2019-09-11 10:14:39.247451+03
2900	46	-1	1270	2019-09-11 11:18:24.382113+03
2901	90	-1	1780	2019-09-11 11:20:40.226345+03
2902	19	-1	1220	2019-09-11 11:33:13.647719+03
2903	26	-1	390	2019-09-11 11:53:14.388135+03
2904	26	-1	390	2019-09-11 12:00:35.329781+03
2905	93	-1	1620	2019-09-11 12:20:47.483604+03
2906	55	-1	3480	2019-09-11 12:21:10.720435+03
2907	68	-1	490	2019-09-11 12:33:57.836947+03
2908	31	-2	1190	2019-09-11 12:36:50.495215+03
2909	24	-1	950	2019-09-11 12:42:51.095196+03
2910	4	-1	1420	2019-09-11 12:47:23.548512+03
2911	64	-1	970	2019-09-11 12:53:49.485297+03
2912	24	-2	950	2019-09-11 13:16:09.817787+03
2913	22	-2	1070	2019-09-11 14:01:00.932771+03
2914	92	-1	630	2019-09-11 14:49:31.15906+03
2915	51	-1	1310	2019-09-11 14:50:23.961166+03
2916	60	-1	2700	2019-09-11 14:52:58.762499+03
2917	31	-1	1190	2019-09-11 15:32:16.180362+03
2918	67	-1	350	2019-09-11 16:14:35.805476+03
2919	69	25	528	2019-09-11 16:31:36.971999+03
2920	36	-1	630	2019-09-11 16:37:39.84536+03
2921	55	26	1487	2019-09-11 16:50:41.336036+03
2922	14	-1	1350	2019-09-11 17:08:10.407644+03
2923	22	-1	1070	2019-09-11 17:13:58.011085+03
2924	85	-1	730	2019-09-11 17:28:31.217292+03
2925	12	-1	1650	2019-09-11 17:43:00.203666+03
2926	84	-1	2700	2019-09-11 17:43:07.667157+03
2927	83	-1	1230	2019-09-11 17:48:20.7248+03
2928	30	-1	1140	2019-09-11 18:00:53.144857+03
2929	30	-1	1140	2019-09-11 18:05:59.204854+03
2930	71	-1	1030	2019-09-11 18:20:39.694261+03
2931	65	-1	490	2019-09-11 18:23:15.818725+03
2932	77	-2	640	2019-09-11 18:26:47.386764+03
2933	94	-2	1230	2019-09-11 19:12:24.765716+03
2934	83	-1	1230	2019-09-11 19:21:44.715275+03
2935	90	-1	1780	2019-09-11 19:23:29.097993+03
2936	81	-2	1620	2019-09-11 19:41:26.616464+03
2937	79	-1	550	2019-09-11 19:57:20.514721+03
2938	89	-1	1420	2019-09-11 21:16:52.049387+03
2939	46	-1	1270	2019-09-11 21:22:38.910173+03
2940	63	-1	1780	2019-09-11 21:30:35.694867+03
2941	93	-1	1620	2019-09-11 21:34:41.259726+03
2942	86	-1	910	2019-09-11 21:46:54.869826+03
2943	86	-1	910	2019-09-11 22:23:26.731462+03
2944	58	-2	2830	2019-09-11 22:25:39.927166+03
2945	75	-2	830	2019-09-11 22:44:47.62466+03
2946	25	-1	1100	2019-09-11 22:46:01.620046+03
2947	48	-1	640	2019-09-11 22:50:09.822335+03
2948	55	-2	3480	2019-09-11 23:34:02.351117+03
2949	54	-1	3470	2019-09-12 00:02:59.821574+03
2950	14	-1	1350	2019-09-12 00:18:04.87254+03
2951	14	-1	1350	2019-09-12 00:27:37.697439+03
2952	43	-1	380	2019-09-12 00:43:36.72188+03
2953	88	-2	1270	2019-09-12 00:57:23.983946+03
2954	80	-1	1120	2019-09-12 01:37:05.915506+03
2955	80	-1	1120	2019-09-12 01:47:58.188401+03
2956	83	-2	1230	2019-09-12 01:58:44.208322+03
2957	79	-1	550	2019-09-12 02:03:51.968994+03
2958	80	23	583	2019-09-12 02:18:13.618592+03
2959	35	-1	670	2019-09-12 02:45:22.850639+03
2960	67	-1	350	2019-09-12 03:12:46.333462+03
2961	42	-1	1790	2019-09-12 03:35:01.785923+03
2962	90	-2	1780	2019-09-12 04:10:34.45827+03
2963	85	-1	730	2019-09-12 04:41:12.967139+03
2964	22	-1	1070	2019-09-12 04:42:33.999153+03
2965	47	-1	1480	2019-09-12 05:01:17.894439+03
2966	11	-1	830	2019-09-12 05:52:15.82234+03
2967	44	-1	500	2019-09-12 06:22:24.474928+03
2968	32	-1	710	2019-09-12 06:23:05.576204+03
2969	7	-1	810	2019-09-12 06:27:37.856121+03
2970	19	-2	1220	2019-09-12 06:44:16.243482+03
2971	53	-1	3120	2019-09-12 08:17:30.63015+03
2972	13	-1	460	2019-09-12 08:24:56.867164+03
2973	13	-1	460	2019-09-12 08:34:17.940723+03
2974	38	-2	1100	2019-09-12 09:08:02.497224+03
2975	84	-1	2700	2019-09-12 09:13:11.233879+03
2976	45	-1	1590	2019-09-12 09:16:33.149626+03
2977	93	-1	1620	2019-09-12 09:29:51.39206+03
2978	22	-1	1070	2019-09-12 09:36:54.367692+03
2979	23	-1	4390	2019-09-12 10:14:07.002207+03
2980	62	-1	1220	2019-09-12 10:19:36.535476+03
2981	43	-1	380	2019-09-12 11:30:55.893181+03
2982	36	-1	630	2019-09-12 11:43:28.63666+03
2983	64	-1	970	2019-09-12 11:49:32.84605+03
2984	42	-1	1790	2019-09-12 12:11:26.56358+03
2985	64	-1	970	2019-09-12 12:15:37.294096+03
2986	9	-2	2090	2019-09-12 12:18:26.314318+03
2987	33	-2	900	2019-09-12 12:27:09.562645+03
2988	64	-1	970	2019-09-12 12:30:35.714785+03
2989	9	-1	2090	2019-09-12 12:49:53.537574+03
2990	61	-1	1510	2019-09-12 12:53:46.014683+03
2991	68	-2	490	2019-09-12 13:12:30.809422+03
2992	11	-1	830	2019-09-12 13:12:53.974768+03
2993	77	-2	640	2019-09-12 13:16:47.552415+03
2994	50	-1	1140	2019-09-12 13:45:22.665517+03
2995	35	-1	670	2019-09-12 13:50:08.386907+03
2996	50	-1	1140	2019-09-12 13:51:30.481911+03
2997	84	-1	2700	2019-09-12 13:54:37.44777+03
2998	82	-1	560	2019-09-12 15:20:18.181984+03
2999	31	-2	1190	2019-09-12 15:35:10.124574+03
3000	30	-1	1140	2019-09-12 15:50:01.324832+03
3001	93	-2	1620	2019-09-12 16:13:50.144924+03
3002	63	-1	1780	2019-09-12 16:14:23.163931+03
3003	28	-1	1860	2019-09-12 16:29:22.138196+03
3004	58	-2	2830	2019-09-12 16:30:02.37404+03
3005	71	-1	1030	2019-09-12 16:45:18.786627+03
3006	12	-1	1650	2019-09-12 16:52:23.545276+03
3007	67	-1	350	2019-09-12 16:55:54.745417+03
3008	11	-1	830	2019-09-12 17:05:03.273775+03
3009	51	-1	1310	2019-09-12 17:12:00.084668+03
3010	38	-1	1100	2019-09-12 17:13:18.490728+03
3011	32	-1	710	2019-09-12 17:14:12.633825+03
3012	73	-2	960	2019-09-12 17:18:43.614927+03
3013	81	29	675	2019-09-12 17:32:42.74077+03
3014	25	-1	1100	2019-09-12 17:59:18.450169+03
3015	32	-1	710	2019-09-12 18:03:54.750797+03
3016	54	-1	3470	2019-09-12 18:17:20.76189+03
3017	77	-1	640	2019-09-12 18:32:32.269972+03
3018	76	-1	1070	2019-09-12 18:33:06.106049+03
3019	23	-1	4390	2019-09-12 18:50:59.718246+03
3020	40	-1	1430	2019-09-12 18:56:25.063781+03
3021	79	-1	550	2019-09-12 18:57:17.047448+03
3022	2	-1	470	2019-09-12 19:06:41.910741+03
3023	83	-1	1230	2019-09-12 19:28:50.248039+03
3024	75	-1	830	2019-09-12 19:44:14.525429+03
3025	90	-2	1780	2019-09-12 19:49:46.156986+03
3026	87	-1	2320	2019-09-12 21:15:52.443733+03
3027	11	-1	830	2019-09-12 21:43:03.660674+03
3028	49	-1	970	2019-09-12 21:50:09.833178+03
3029	88	-1	1270	2019-09-12 22:24:51.646269+03
3030	89	-1	1420	2019-09-12 23:07:05.148993+03
3031	5	-1	1620	2019-09-12 23:19:10.587484+03
3032	31	-1	1190	2019-09-12 23:30:45.639428+03
3033	94	-1	1230	2019-09-12 23:51:40.580021+03
3034	47	39	656	2019-09-12 23:52:39.337913+03
3035	59	-2	1030	2019-09-13 00:04:51.426677+03
3036	18	41	421	2019-09-13 00:06:48.732465+03
3037	47	-1	1480	2019-09-13 00:17:16.341415+03
3038	40	-1	1430	2019-09-13 00:23:03.81244+03
3039	75	-1	830	2019-09-13 00:39:51.066677+03
3040	23	-1	4390	2019-09-13 01:16:09.750107+03
3041	53	-2	3120	2019-09-13 01:32:57.301513+03
3042	12	-1	1650	2019-09-13 01:54:48.115462+03
3043	10	-2	2080	2019-09-13 02:14:23.377782+03
3044	38	-1	1100	2019-09-13 03:26:13.111329+03
3045	15	-1	2830	2019-09-13 03:31:56.317407+03
3046	19	-1	1220	2019-09-13 03:32:54.320057+03
3047	37	-1	1290	2019-09-13 03:55:18.329271+03
3048	38	-1	1100	2019-09-13 04:22:18.135119+03
3049	55	-2	3480	2019-09-13 04:24:24.967419+03
3050	5	-1	1620	2019-09-13 05:07:41.053184+03
3051	42	-1	1790	2019-09-13 05:21:48.091913+03
3052	41	-1	830	2019-09-13 05:25:58.865095+03
3053	87	-1	2320	2019-09-13 05:45:55.003861+03
3054	71	-1	1030	2019-09-13 06:00:56.002214+03
3055	63	-1	1780	2019-09-13 06:33:00.894423+03
3056	65	-1	490	2019-09-13 06:41:24.724971+03
3057	50	-1	1140	2019-09-13 06:56:39.753904+03
3058	61	-1	1510	2019-09-13 07:11:36.574317+03
3059	11	-1	830	2019-09-13 07:21:51.652137+03
3060	15	-1	2830	2019-09-13 07:30:14.111052+03
3061	93	-1	1620	2019-09-13 07:36:19.1798+03
3062	61	-1	1510	2019-09-13 07:41:21.742577+03
3063	95	-1	480	2019-09-13 07:50:46.596601+03
3064	71	-1	1030	2019-09-13 07:52:30.34797+03
3065	4	-1	1420	2019-09-13 08:34:14.711623+03
3066	61	-1	1510	2019-09-13 08:38:12.97258+03
3067	79	-1	550	2019-09-13 08:40:00.513421+03
3068	25	-1	1100	2019-09-13 08:56:58.761089+03
3069	1	-1	640	2019-09-13 09:08:21.867417+03
3070	81	-2	1620	2019-09-13 09:24:30.970104+03
3071	4	-1	1420	2019-09-13 09:54:58.093789+03
3072	22	-1	1070	2019-09-13 10:21:23.873202+03
3073	40	-2	1430	2019-09-13 10:23:07.180098+03
3074	36	-1	630	2019-09-13 10:40:09.618642+03
3075	87	-1	2320	2019-09-13 10:42:30.648614+03
3076	87	-1	2320	2019-09-13 11:04:09.803516+03
3077	43	-1	380	2019-09-13 11:29:52.010128+03
3078	46	-1	1270	2019-09-13 11:43:51.547194+03
3079	94	-1	1230	2019-09-13 11:44:55.93687+03
3080	9	-1	2090	2019-09-13 11:52:32.216191+03
3081	60	-1	2700	2019-09-13 12:00:42.61068+03
3082	28	-2	1860	2019-09-13 12:03:55.215704+03
3083	71	-1	1030	2019-09-13 12:28:43.500634+03
3084	47	-1	1480	2019-09-13 12:35:31.725756+03
3085	46	-1	1270	2019-09-13 12:44:14.159924+03
3086	26	-1	390	2019-09-13 13:02:35.282067+03
3087	72	-1	620	2019-09-13 13:52:41.935646+03
3088	36	-1	630	2019-09-13 14:11:53.059585+03
3089	92	21	274	2019-09-13 14:27:40.716928+03
3090	83	-1	1230	2019-09-13 14:31:11.133359+03
3091	63	-1	1780	2019-09-13 14:35:27.881478+03
3092	6	-1	980	2019-09-13 14:42:35.290146+03
3093	49	-2	970	2019-09-13 14:54:06.394631+03
3094	95	-2	480	2019-09-13 15:33:31.914526+03
3095	20	-1	830	2019-09-13 15:49:27.391292+03
3096	91	-1	1620	2019-09-13 16:06:30.37604+03
3097	55	-1	3480	2019-09-13 16:51:45.335094+03
3098	13	-1	460	2019-09-13 17:03:53.702177+03
3099	95	-1	480	2019-09-13 17:05:05.422914+03
3100	42	-2	1790	2019-09-13 17:09:06.701477+03
3101	40	-1	1430	2019-09-13 17:57:11.957495+03
3102	13	-1	460	2019-09-13 18:20:13.207614+03
3103	26	-1	390	2019-09-13 18:33:03.635688+03
3104	29	-1	1940	2019-09-13 18:38:37.348794+03
3105	72	-1	620	2019-09-13 18:49:46.874042+03
3106	6	-1	980	2019-09-13 18:53:43.252283+03
3107	85	-1	730	2019-09-13 18:57:30.099419+03
3108	81	-2	1620	2019-09-13 18:59:46.314078+03
3109	4	-1	1420	2019-09-13 19:11:00.770027+03
3110	10	-1	2080	2019-09-13 19:11:22.048072+03
3111	5	-1	1620	2019-09-13 19:32:50.773075+03
3112	17	-2	1500	2019-09-13 19:33:18.833971+03
3113	58	-1	2830	2019-09-13 20:02:58.203135+03
3114	38	-2	1100	2019-09-13 20:09:20.46818+03
3115	70	-1	760	2019-09-13 20:17:52.662095+03
3116	44	-1	500	2019-09-13 20:18:42.810006+03
3117	8	-1	1920	2019-09-13 20:19:59.579344+03
3118	36	-1	630	2019-09-13 20:22:58.79348+03
3119	51	-1	1310	2019-09-13 21:15:56.904936+03
3120	69	-1	1100	2019-09-13 21:17:11.994096+03
3121	29	-1	1940	2019-09-13 21:21:11.714195+03
3122	61	-1	1510	2019-09-13 21:32:59.656697+03
3123	55	-1	3480	2019-09-13 21:34:30.598128+03
3124	85	-1	730	2019-09-13 21:40:36.596248+03
3125	76	-1	1070	2019-09-13 21:50:56.215612+03
3126	59	-1	1030	2019-09-13 22:19:17.879949+03
3127	23	-1	4390	2019-09-13 22:37:48.456093+03
3128	43	-1	380	2019-09-13 22:44:12.721341+03
3129	74	-1	1010	2019-09-13 22:49:51.588101+03
3130	88	-2	1270	2019-09-13 22:59:24.98843+03
3131	61	-1	1510	2019-09-13 23:29:56.12306+03
3132	52	-2	1090	2019-09-13 23:51:10.006184+03
3133	71	-1	1030	2019-09-13 23:52:08.308219+03
3134	50	-2	1140	2019-09-14 00:01:52.132073+03
3135	14	-1	1350	2019-09-14 00:26:58.035347+03
3136	84	-1	2700	2019-09-14 00:28:58.837318+03
3137	88	-2	1270	2019-09-14 00:58:50.321865+03
3138	59	-2	1030	2019-09-14 01:10:20.84732+03
3139	16	-1	1380	2019-09-14 01:15:31.123309+03
3140	38	-1	1100	2019-09-14 01:50:22.576389+03
3141	36	-1	630	2019-09-14 01:52:09.889338+03
3142	58	-1	2830	2019-09-14 01:59:57.917998+03
3143	34	-1	1550	2019-09-14 02:14:28.092403+03
3144	14	-1	1350	2019-09-14 03:04:17.129821+03
3145	40	-1	1430	2019-09-14 03:24:09.865873+03
3146	5	-2	1620	2019-09-14 03:39:45.784635+03
3147	39	-1	910	2019-09-14 03:47:49.887637+03
3148	3	-1	660	2019-09-14 04:13:13.675669+03
3149	7	-1	810	2019-09-14 04:38:11.097088+03
3150	22	-1	1070	2019-09-14 04:55:32.007666+03
3151	49	-1	970	2019-09-14 04:58:10.717279+03
3152	4	-1	1420	2019-09-14 05:17:05.477802+03
3153	40	-1	1430	2019-09-14 05:37:55.006414+03
3154	30	-1	1140	2019-09-14 06:10:05.451261+03
3155	17	-1	1500	2019-09-14 06:26:01.103323+03
3156	53	-2	3120	2019-09-14 06:33:40.416186+03
3157	51	-1	1310	2019-09-14 06:50:56.597769+03
3158	23	-1	4390	2019-09-14 07:04:07.347295+03
3159	16	-1	1380	2019-09-14 07:11:52.501107+03
3160	59	-2	1030	2019-09-14 07:21:11.548256+03
3161	6	-1	980	2019-09-14 07:23:10.716394+03
3162	13	-1	460	2019-09-14 07:37:06.830102+03
3163	51	-1	1310	2019-09-14 07:45:33.554428+03
3164	48	-1	640	2019-09-14 07:53:57.940747+03
3165	49	-1	970	2019-09-14 08:34:59.825966+03
3166	67	29	207	2019-09-14 08:40:50.163034+03
3167	80	-1	1120	2019-09-14 08:44:36.142981+03
3168	19	-1	1220	2019-09-14 08:58:27.976972+03
3169	56	40	1204	2019-09-14 09:14:56.902174+03
3170	89	-1	1420	2019-09-14 09:28:58.177273+03
3171	64	-1	970	2019-09-14 09:37:36.690514+03
3172	63	-1	1780	2019-09-14 10:20:56.284547+03
3173	86	-1	910	2019-09-14 10:25:39.085853+03
3174	76	-1	1070	2019-09-14 11:02:27.65744+03
3175	84	-1	2700	2019-09-14 11:22:46.619913+03
3176	55	-1	3480	2019-09-14 11:23:27.049035+03
3177	53	-1	3120	2019-09-14 12:08:34.39767+03
3178	59	-1	1030	2019-09-14 12:27:06.28908+03
3179	22	-1	1070	2019-09-14 12:32:00.92347+03
3180	93	-1	1620	2019-09-14 12:39:22.305149+03
3181	54	-1	3470	2019-09-14 13:09:53.198565+03
3182	79	-1	550	2019-09-14 13:10:51.121863+03
3183	50	-1	1140	2019-09-14 13:31:39.289227+03
3184	62	-1	1220	2019-09-14 13:40:53.283905+03
3185	35	-1	670	2019-09-14 13:42:11.246947+03
3186	41	-1	830	2019-09-14 13:59:51.341481+03
3187	66	16	315	2019-09-14 14:04:26.326106+03
3188	70	-1	760	2019-09-14 14:05:14.036551+03
3189	49	-1	970	2019-09-14 14:24:35.30897+03
3190	83	26	528	2019-09-14 14:31:14.903156+03
3191	49	-1	970	2019-09-14 14:35:01.712903+03
3192	6	-1	980	2019-09-14 14:49:34.238529+03
3193	30	-1	1140	2019-09-14 14:51:17.761074+03
3194	5	-1	1620	2019-09-14 15:04:25.067149+03
3195	73	-2	960	2019-09-14 16:00:40.339303+03
3196	65	-1	490	2019-09-14 16:08:09.942668+03
3197	59	-1	1030	2019-09-14 16:32:09.323051+03
3198	86	-1	910	2019-09-14 16:54:18.987789+03
3199	74	31	523	2019-09-14 16:56:15.072209+03
3200	52	-1	1090	2019-09-14 16:56:44.271697+03
3201	87	-1	2320	2019-09-14 16:59:22.111453+03
3202	25	-2	1100	2019-09-14 17:34:33.42733+03
3203	87	-1	2320	2019-09-14 18:07:08.136921+03
3204	28	-2	1860	2019-09-14 18:33:33.734553+03
3205	39	-2	910	2019-09-14 18:35:37.774985+03
3206	28	-1	1860	2019-09-14 18:49:46.733362+03
3207	33	-1	900	2019-09-14 18:58:10.678138+03
3208	30	-1	1140	2019-09-14 19:02:47.856951+03
3209	74	-1	1010	2019-09-14 19:03:05.738405+03
3210	30	-2	1140	2019-09-14 19:10:33.03664+03
3211	49	-1	970	2019-09-14 19:28:24.934743+03
3212	42	-1	1790	2019-09-14 20:37:03.956218+03
3213	22	-2	1070	2019-09-14 21:11:02.85113+03
3214	12	-1	1650	2019-09-14 21:24:04.656866+03
3215	7	-1	810	2019-09-14 21:31:38.669631+03
3216	8	-1	1920	2019-09-14 21:45:00.870901+03
3217	28	-1	1860	2019-09-14 22:24:44.902865+03
3218	46	40	709	2019-09-14 22:26:05.558667+03
3219	46	-1	1270	2019-09-14 22:33:06.232831+03
3220	37	-2	1290	2019-09-14 22:34:57.759313+03
3221	17	-2	1500	2019-09-14 22:38:02.069913+03
3222	37	-1	1290	2019-09-15 00:05:12.080714+03
3223	51	-1	1310	2019-09-15 00:26:29.699667+03
3224	7	-1	810	2019-09-15 00:51:17.338604+03
3225	41	-1	830	2019-09-15 00:54:35.786047+03
3226	32	-1	710	2019-09-15 01:06:14.831124+03
3227	91	-1	1620	2019-09-15 01:24:29.349869+03
3228	77	-1	640	2019-09-15 01:52:22.069536+03
3229	90	-1	1780	2019-09-15 02:23:29.266657+03
3230	45	-1	1590	2019-09-15 02:24:13.791248+03
3231	41	-1	830	2019-09-15 02:26:24.765836+03
3232	91	-1	1620	2019-09-15 03:17:37.790855+03
3233	54	-1	3470	2019-09-15 03:26:58.139771+03
3234	26	-2	390	2019-09-15 03:29:17.675713+03
3235	55	-1	3480	2019-09-15 04:07:58.195552+03
3236	74	-1	1010	2019-09-15 04:49:48.271068+03
3237	89	-2	1420	2019-09-15 04:53:42.8922+03
3238	43	-1	380	2019-09-15 04:57:29.801246+03
3239	56	-2	2460	2019-09-15 05:01:16.377661+03
3240	42	-1	1790	2019-09-15 05:19:47.946296+03
3241	73	-3	960	2019-09-15 05:32:00.551256+03
3242	53	-1	3120	2019-09-15 06:03:46.952698+03
3243	87	-1	2320	2019-09-15 06:37:10.38855+03
3244	85	-1	730	2019-09-15 07:02:32.131778+03
3245	34	-1	1550	2019-09-15 07:32:01.944394+03
3246	88	-1	1270	2019-09-15 07:32:40.76584+03
3247	84	-1	2700	2019-09-15 07:48:43.071744+03
3248	69	-1	1100	2019-09-15 08:25:44.998974+03
3249	49	-1	970	2019-09-15 08:34:59.412402+03
3250	59	-1	1030	2019-09-15 08:50:31.218342+03
3251	1	-1	640	2019-09-15 09:26:02.854158+03
3252	17	-1	1500	2019-09-15 09:44:01.909791+03
3253	94	-1	1230	2019-09-15 09:52:21.402186+03
3254	13	-1	460	2019-09-15 10:01:25.605181+03
3255	6	-1	980	2019-09-15 10:11:19.021953+03
3256	79	-1	550	2019-09-15 11:07:00.866908+03
3257	4	-1	1420	2019-09-15 11:44:19.184494+03
3258	72	-1	620	2019-09-15 11:56:06.107434+03
3259	96	-2	1570	2019-09-15 12:29:42.528339+03
3260	39	-2	910	2019-09-15 13:19:11.662587+03
3261	22	-1	1070	2019-09-15 13:44:32.181897+03
3262	76	-2	1070	2019-09-15 14:14:12.325002+03
3263	27	-2	880	2019-09-15 14:17:15.997272+03
3264	21	-2	960	2019-09-15 14:36:57.010062+03
3265	30	-1	1140	2019-09-15 14:53:10.071365+03
3266	84	-1	2700	2019-09-15 14:54:11.643117+03
3267	84	-2	2700	2019-09-15 15:56:52.003552+03
3268	6	-2	980	2019-09-15 16:36:01.789668+03
3269	30	-1	1140	2019-09-15 16:44:45.818917+03
3270	92	-1	630	2019-09-15 16:59:18.731505+03
3271	31	-1	1190	2019-09-15 17:14:48.548336+03
3272	17	-1	1500	2019-09-15 17:14:55.968383+03
3273	80	-1	1120	2019-09-15 17:21:21.872431+03
3274	38	-1	1100	2019-09-15 17:22:00.132265+03
3275	34	-1	1550	2019-09-15 17:25:01.615737+03
3276	45	-1	1590	2019-09-15 17:43:22.925593+03
3277	67	-1	350	2019-09-15 18:01:22.042664+03
3278	40	-1	1430	2019-09-15 19:25:18.023319+03
3279	60	-1	2700	2019-09-15 19:39:05.893598+03
3280	2	-1	470	2019-09-15 19:56:41.923176+03
3281	81	-1	1620	2019-09-15 20:11:27.895202+03
3282	18	-1	910	2019-09-15 20:24:42.503376+03
3283	57	-1	1900	2019-09-15 20:25:50.192192+03
3284	33	-1	900	2019-09-15 20:28:02.228373+03
3285	56	-1	2460	2019-09-15 20:29:00.871743+03
3286	86	34	450	2019-09-15 20:29:15.92597+03
3287	40	-2	1430	2019-09-15 20:35:42.118341+03
3288	64	-1	970	2019-09-15 20:48:36.26667+03
3289	43	-1	380	2019-09-15 20:55:16.02326+03
3290	91	-1	1620	2019-09-15 21:32:34.916388+03
3291	45	-1	1590	2019-09-15 22:00:05.323141+03
3292	7	-1	810	2019-09-15 22:03:55.319789+03
3293	43	-1	380	2019-09-15 22:09:26.48928+03
3294	48	-1	640	2019-09-15 22:37:32.409108+03
3295	8	-1	1920	2019-09-15 22:55:14.824932+03
3296	36	-1	630	2019-09-15 23:04:44.125069+03
3297	53	-1	3120	2019-09-15 23:08:39.972521+03
3298	13	-1	460	2019-09-15 23:14:14.304068+03
3299	46	-2	1270	2019-09-15 23:23:19.636194+03
3300	79	-1	550	2019-09-15 23:27:13.875928+03
3301	56	-2	2460	2019-09-15 23:58:46.447387+03
3302	2	-1	470	2019-09-16 00:08:35.845256+03
3303	96	-1	1570	2019-09-16 00:09:32.731904+03
3304	63	-1	1780	2019-09-16 00:10:54.997724+03
3305	12	-1	1650	2019-09-16 00:23:48.342076+03
3306	10	-1	2080	2019-09-16 00:33:15.880484+03
3307	45	-1	1590	2019-09-16 01:25:18.58937+03
3308	14	-1	1350	2019-09-16 01:42:52.877457+03
3309	35	-1	670	2019-09-16 02:14:35.162676+03
3310	52	-1	1090	2019-09-16 02:33:18.72107+03
3311	21	-1	960	2019-09-16 02:45:03.253494+03
3312	74	-2	1010	2019-09-16 02:47:48.742812+03
3313	89	-1	1420	2019-09-16 02:51:44.853588+03
3314	71	-1	1030	2019-09-16 02:56:41.144684+03
3315	47	-1	1480	2019-09-16 03:02:56.484388+03
3316	4	-1	1420	2019-09-16 03:44:52.674663+03
3317	21	-1	960	2019-09-16 03:54:27.198213+03
3318	47	-1	1480	2019-09-16 04:29:44.515184+03
3319	84	30	1204	2019-09-16 04:46:31.537535+03
3320	42	34	907	2019-09-16 04:51:21.453672+03
3321	70	-1	760	2019-09-16 04:56:42.360875+03
3322	56	-1	2460	2019-09-16 05:05:22.27789+03
3323	30	-1	1140	2019-09-16 05:08:29.147685+03
3324	17	-1	1500	2019-09-16 05:27:25.288472+03
3325	35	-2	670	2019-09-16 05:27:29.052536+03
3326	32	-2	710	2019-09-16 06:36:10.577614+03
3327	4	-1	1420	2019-09-16 06:37:50.390671+03
3328	62	-1	1220	2019-09-16 07:21:44.083764+03
3329	17	-2	1500	2019-09-16 07:40:01.989206+03
3330	95	-1	480	2019-09-16 07:49:19.161038+03
3331	56	-1	2460	2019-09-16 08:11:40.271607+03
3332	31	-2	1190	2019-09-16 08:14:32.808036+03
3333	5	-1	1620	2019-09-16 09:01:31.700858+03
3334	78	-1	900	2019-09-16 09:23:58.916907+03
3335	76	-1	1070	2019-09-16 09:47:45.70556+03
3336	81	-1	1620	2019-09-16 10:00:41.440027+03
3337	28	-1	1860	2019-09-16 10:12:20.583001+03
3338	15	-1	2830	2019-09-16 10:13:25.27535+03
3339	22	-1	1070	2019-09-16 10:17:36.410959+03
3340	65	-1	490	2019-09-16 10:18:48.871742+03
3341	12	-1	1650	2019-09-16 10:44:00.394038+03
3342	64	-1	970	2019-09-16 10:45:41.297476+03
3343	13	-1	460	2019-09-16 10:47:46.684322+03
3344	59	-1	1030	2019-09-16 10:47:53.738532+03
3345	30	38	644	2019-09-16 10:48:54.369843+03
3346	21	26	415	2019-09-16 11:08:47.747518+03
3347	39	-2	910	2019-09-16 11:59:53.672633+03
3348	33	-1	900	2019-09-16 12:31:53.057322+03
3349	33	-1	900	2019-09-16 12:41:19.680442+03
3350	74	-1	1010	2019-09-16 13:00:11.167028+03
3351	10	-2	2080	2019-09-16 13:09:14.460908+03
3352	52	-1	1090	2019-09-16 14:08:26.137441+03
3353	31	-2	1190	2019-09-16 14:13:24.765551+03
3354	17	-1	1500	2019-09-16 14:14:50.790965+03
3355	96	-1	1570	2019-09-16 14:20:44.272224+03
3356	88	-1	1270	2019-09-16 14:22:55.062472+03
3357	95	-1	480	2019-09-16 14:23:36.188761+03
3358	57	-2	1900	2019-09-16 14:31:32.287908+03
3359	51	28	572	2019-09-16 14:46:02.987011+03
3360	47	-1	1480	2019-09-16 14:56:47.19055+03
3361	95	31	256	2019-09-16 15:54:03.024659+03
3362	9	-1	2090	2019-09-16 16:04:47.178203+03
3363	38	-1	1100	2019-09-16 16:05:53.339577+03
3364	52	-1	1090	2019-09-16 16:11:10.24387+03
3365	74	-1	1010	2019-09-16 16:12:02.320807+03
3366	54	-1	3470	2019-09-16 16:20:37.038601+03
3367	14	-1	1350	2019-09-16 16:23:41.312181+03
3368	20	-3	830	2019-09-16 16:57:01.93308+03
3369	60	-2	2700	2019-09-16 16:57:20.415296+03
3370	41	-1	830	2019-09-16 17:01:15.293306+03
3371	71	-1	1030	2019-09-16 17:10:44.330363+03
3372	13	-2	460	2019-09-16 17:28:27.910896+03
3373	23	-2	4390	2019-09-16 17:44:37.621012+03
3374	31	-1	1190	2019-09-16 18:24:21.252656+03
3375	81	-1	1620	2019-09-16 18:27:30.965428+03
3376	60	-2	2700	2019-09-16 19:50:28.30378+03
3377	38	-1	1100	2019-09-16 19:53:35.011859+03
3378	96	-2	1570	2019-09-16 19:58:32.626641+03
3379	96	-2	1570	2019-09-16 20:23:12.376959+03
3380	40	27	589	2019-09-16 20:24:07.72769+03
3381	62	-1	1220	2019-09-16 20:32:44.282139+03
3382	77	-1	640	2019-09-16 20:34:15.251354+03
3383	7	-1	810	2019-09-16 20:58:51.374543+03
3384	10	-1	2080	2019-09-16 21:08:43.717353+03
3385	95	-1	480	2019-09-16 21:13:52.605878+03
3386	3	-1	660	2019-09-16 21:53:52.092553+03
3387	87	-1	2320	2019-09-16 22:58:27.239835+03
3388	12	-2	1650	2019-09-16 23:30:26.727106+03
3389	35	-1	670	2019-09-16 23:46:05.31873+03
3390	62	-1	1220	2019-09-16 23:50:02.963414+03
3391	92	-1	630	2019-09-17 00:03:10.906172+03
3392	48	-1	640	2019-09-17 00:05:33.956554+03
3393	70	-1	760	2019-09-17 00:36:45.623118+03
3394	86	-2	910	2019-09-17 00:48:20.134573+03
3395	2	-2	470	2019-09-17 00:51:03.130318+03
3396	67	-1	350	2019-09-17 01:03:36.764189+03
3397	1	-1	640	2019-09-17 01:04:25.257591+03
3398	13	36	215	2019-09-17 01:13:46.316213+03
3399	13	-1	460	2019-09-17 01:19:49.871771+03
3400	20	-1	830	2019-09-17 01:29:46.455152+03
3401	87	34	1302	2019-09-17 01:47:39.749372+03
3402	21	-1	960	2019-09-17 01:48:07.35067+03
3403	66	-1	690	2019-09-17 01:59:58.19525+03
3404	63	-2	1780	2019-09-17 02:11:03.780755+03
3405	77	-2	640	2019-09-17 02:26:57.400843+03
3406	66	-2	690	2019-09-17 02:31:25.3713+03
3407	94	-1	1230	2019-09-17 02:45:12.364607+03
3408	2	-1	470	2019-09-17 02:53:35.110393+03
3409	52	-2	1090	2019-09-17 03:25:54.671941+03
3410	5	-1	1620	2019-09-17 03:27:07.605293+03
3411	24	-2	950	2019-09-17 03:28:40.450706+03
3412	14	-1	1350	2019-09-17 03:32:43.851438+03
3413	41	-1	830	2019-09-17 03:35:39.540515+03
3414	31	-1	1190	2019-09-17 03:52:27.636627+03
3415	18	-1	910	2019-09-17 03:53:21.213347+03
3416	4	-1	1420	2019-09-17 03:59:22.726655+03
3417	22	-1	1070	2019-09-17 03:59:47.000085+03
3418	78	-2	900	2019-09-17 04:11:06.587038+03
3419	79	-1	550	2019-09-17 04:30:11.877324+03
3420	95	-2	480	2019-09-17 04:30:52.213671+03
3421	51	-1	1310	2019-09-17 04:35:49.126787+03
3422	21	-1	960	2019-09-17 04:37:57.772863+03
3423	69	-1	1100	2019-09-17 04:38:03.867904+03
3424	67	-1	350	2019-09-17 04:41:45.496837+03
3425	53	-1	3120	2019-09-17 04:58:16.444658+03
3426	22	-1	1070	2019-09-17 05:24:26.926851+03
3427	33	-1	900	2019-09-17 05:26:27.817249+03
3428	9	-2	2090	2019-09-17 05:37:39.897622+03
3429	52	-1	1090	2019-09-17 05:53:42.34339+03
3430	9	-1	2090	2019-09-17 05:54:17.440252+03
3431	35	-1	670	2019-09-17 06:06:15.499518+03
3432	42	-1	1790	2019-09-17 06:09:23.956034+03
3433	76	-1	1070	2019-09-17 06:11:03.536549+03
3434	65	16	266	2019-09-17 06:11:39.983647+03
3435	17	-1	1500	2019-09-17 06:12:42.417148+03
3436	32	-2	710	2019-09-17 06:52:02.366758+03
3437	17	-1	1500	2019-09-17 07:14:44.202657+03
3438	39	-1	910	2019-09-17 07:50:12.679526+03
3439	77	-1	640	2019-09-17 07:54:06.924536+03
3440	43	-2	380	2019-09-17 08:26:38.739213+03
3441	52	19	496	2019-09-17 08:32:01.679493+03
3442	47	-2	1480	2019-09-17 08:48:17.436084+03
3443	87	-1	2320	2019-09-17 08:56:46.244596+03
3444	42	-1	1790	2019-09-17 08:59:57.227106+03
3445	19	-1	1220	2019-09-17 09:18:08.46058+03
3446	51	-1	1310	2019-09-17 09:33:06.102621+03
3447	9	-2	2090	2019-09-17 09:41:28.049516+03
3448	40	-1	1430	2019-09-17 09:53:47.917352+03
3449	70	-1	760	2019-09-17 10:18:13.215815+03
3450	76	-1	1070	2019-09-17 10:18:17.497351+03
3451	3	-1	660	2019-09-17 10:19:59.005472+03
3452	93	-2	1620	2019-09-17 10:20:49.797434+03
3453	87	-2	2320	2019-09-17 10:40:39.527198+03
3454	70	-2	760	2019-09-17 10:47:13.879767+03
3455	36	-1	630	2019-09-17 10:59:03.630622+03
3456	22	-1	1070	2019-09-17 11:08:09.231412+03
3457	93	-1	1620	2019-09-17 11:18:27.907287+03
3458	75	-1	830	2019-09-17 11:34:10.943766+03
3459	6	-1	980	2019-09-17 11:44:41.98835+03
3460	48	-1	640	2019-09-17 11:45:37.861415+03
3461	76	-1	1070	2019-09-17 12:03:41.382669+03
3462	90	-1	1780	2019-09-17 12:12:05.914667+03
3463	47	-1	1480	2019-09-17 12:26:42.110371+03
3464	67	-1	350	2019-09-17 12:31:08.588912+03
3465	6	37	590	2019-09-17 12:53:41.178836+03
3466	55	-1	3480	2019-09-17 12:54:17.885767+03
3467	43	-1	380	2019-09-17 13:00:34.906487+03
3468	49	-2	970	2019-09-17 13:06:50.84681+03
3469	52	-1	1090	2019-09-17 13:41:30.381624+03
3470	90	-1	1780	2019-09-17 13:45:49.79926+03
3471	94	-1	1230	2019-09-17 14:17:58.640846+03
3472	43	-1	380	2019-09-17 14:38:34.748458+03
3473	11	-1	830	2019-09-17 14:45:17.291269+03
3474	43	21	219	2019-09-17 15:09:46.70709+03
3475	79	-1	550	2019-09-17 15:16:27.234438+03
3476	76	-2	1070	2019-09-17 15:27:54.300578+03
3477	17	-2	1500	2019-09-17 15:46:04.182237+03
3478	39	-2	910	2019-09-17 15:47:59.564437+03
3479	50	-1	1140	2019-09-17 15:52:43.952813+03
3480	76	-1	1070	2019-09-17 15:55:37.960713+03
3481	18	-1	910	2019-09-17 15:58:38.173617+03
3482	42	-1	1790	2019-09-17 16:27:48.880007+03
3483	51	-2	1310	2019-09-17 16:32:25.604289+03
3484	82	-1	560	2019-09-17 16:59:55.932982+03
3485	29	-1	1940	2019-09-17 17:06:15.946419+03
3486	4	-1	1420	2019-09-17 17:29:17.329881+03
3487	70	-1	760	2019-09-17 17:43:04.471854+03
3488	67	-1	350	2019-09-17 17:51:18.403225+03
3489	87	-1	2320	2019-09-17 19:21:49.267341+03
3490	17	-2	1500	2019-09-17 20:02:30.264476+03
3491	31	-1	1190	2019-09-17 20:05:33.881696+03
3492	93	-2	1620	2019-09-17 20:05:38.979243+03
3493	16	-1	1380	2019-09-17 20:27:28.382273+03
3494	23	-1	4390	2019-09-17 20:28:35.898931+03
3495	41	-2	830	2019-09-17 20:31:46.654331+03
3496	55	-1	3480	2019-09-17 20:50:09.659836+03
3497	9	-1	2090	2019-09-17 20:57:31.1708+03
3498	67	-1	350	2019-09-17 21:06:47.621543+03
3499	83	-1	1230	2019-09-17 21:20:59.41516+03
3500	76	-2	1070	2019-09-17 22:02:55.479653+03
3501	8	40	882	2019-09-17 22:12:18.992239+03
3502	6	-1	980	2019-09-17 22:51:20.625881+03
3503	95	-1	480	2019-09-17 23:17:32.495327+03
3504	36	-3	630	2019-09-17 23:18:16.951861+03
3505	51	-1	1310	2019-09-18 00:14:25.908969+03
3506	42	-1	1790	2019-09-18 00:29:28.579584+03
3507	96	-1	1570	2019-09-18 00:42:32.920417+03
3508	76	-1	1070	2019-09-18 00:49:21.567956+03
3509	33	-1	900	2019-09-18 00:55:48.413833+03
3510	88	-1	1270	2019-09-18 01:20:42.180023+03
3511	8	-2	1920	2019-09-18 01:26:26.969697+03
3512	13	-2	460	2019-09-18 01:26:35.84089+03
3513	38	-1	1100	2019-09-18 01:26:47.207963+03
3514	60	-2	2700	2019-09-18 01:27:44.471916+03
3515	93	-1	1620	2019-09-18 01:28:42.210883+03
3516	61	-1	1510	2019-09-18 01:34:41.671925+03
3517	5	-1	1620	2019-09-18 01:43:48.929147+03
3518	4	-1	1420	2019-09-18 02:02:13.812691+03
3519	96	-2	1570	2019-09-18 02:22:04.890971+03
3520	19	-1	1220	2019-09-18 02:24:27.617239+03
3521	62	-1	1220	2019-09-18 02:58:13.835968+03
3522	56	-1	2460	2019-09-18 03:09:34.793786+03
3523	20	-1	830	2019-09-18 03:10:14.326865+03
3524	77	-1	640	2019-09-18 03:30:25.93542+03
3525	22	-1	1070	2019-09-18 03:42:15.931617+03
3526	22	-1	1070	2019-09-18 03:42:54.115703+03
3527	94	-1	1230	2019-09-18 03:44:58.864589+03
3528	58	-1	2830	2019-09-18 04:05:47.530123+03
3529	16	-1	1380	2019-09-18 04:13:03.652186+03
3530	66	-1	690	2019-09-18 04:15:22.050541+03
3531	67	-1	350	2019-09-18 04:19:06.72917+03
3532	85	-1	730	2019-09-18 04:32:41.128592+03
3533	45	-1	1590	2019-09-18 04:49:49.209615+03
3534	44	-2	500	2019-09-18 05:01:26.037658+03
3535	33	-1	900	2019-09-18 05:10:03.379561+03
3536	6	-1	980	2019-09-18 05:35:29.123794+03
3537	76	-1	1070	2019-09-18 05:41:30.562191+03
3538	76	-1	1070	2019-09-18 05:44:01.886327+03
3539	63	30	1007	2019-09-18 05:48:57.41233+03
3540	68	-1	490	2019-09-18 06:01:33.856972+03
3541	75	-1	830	2019-09-18 06:02:34.032334+03
3542	5	-1	1620	2019-09-18 06:16:19.569708+03
3543	12	-1	1650	2019-09-18 06:32:20.069313+03
3544	90	-1	1780	2019-09-18 07:00:01.041402+03
3545	35	-1	670	2019-09-18 07:00:23.730324+03
3546	26	-2	390	2019-09-18 07:28:19.103538+03
3547	36	-1	630	2019-09-18 07:29:53.854049+03
3548	14	-1	1350	2019-09-18 07:51:18.009383+03
3549	29	-1	1940	2019-09-18 07:55:49.348089+03
3550	37	-1	1290	2019-09-18 08:05:26.14142+03
3551	30	-1	1140	2019-09-18 08:13:26.769822+03
3552	43	-2	380	2019-09-18 09:05:11.299125+03
3553	95	-1	480	2019-09-18 09:21:25.997783+03
3554	12	-1	1650	2019-09-18 09:24:55.656266+03
3555	88	-2	1270	2019-09-18 09:25:40.562009+03
3556	87	-1	2320	2019-09-18 09:30:01.313942+03
3557	56	-1	2460	2019-09-18 09:34:23.898122+03
3558	73	-1	960	2019-09-18 09:52:15.272294+03
3559	6	-1	980	2019-09-18 09:59:48.514702+03
3560	77	23	334	2019-09-18 10:09:12.929943+03
3561	13	-1	460	2019-09-18 10:10:33.218167+03
3562	18	-2	910	2019-09-18 10:24:11.063039+03
3563	61	-1	1510	2019-09-18 10:34:24.265273+03
3564	31	-1	1190	2019-09-18 10:41:16.111231+03
3565	31	-1	1190	2019-09-18 10:54:54.050722+03
3566	52	-1	1090	2019-09-18 11:03:33.710333+03
3567	95	-1	480	2019-09-18 11:14:28.536198+03
3568	80	-1	1120	2019-09-18 11:24:07.750459+03
3569	2	-1	470	2019-09-18 11:28:00.637875+03
3570	35	-1	670	2019-09-18 12:24:01.095338+03
3571	70	-1	760	2019-09-18 12:25:49.319899+03
3572	13	-2	460	2019-09-18 13:04:47.770468+03
3573	3	-1	660	2019-09-18 13:29:38.755176+03
3574	64	-1	970	2019-09-18 13:44:07.570024+03
3575	92	-1	630	2019-09-18 14:06:07.643838+03
3576	20	-1	830	2019-09-18 14:10:14.188703+03
3577	64	-1	970	2019-09-18 14:31:47.146125+03
3578	11	-1	830	2019-09-18 14:59:52.959564+03
3579	65	-2	490	2019-09-18 15:13:12.521415+03
3580	84	-1	2700	2019-09-18 15:23:45.814372+03
3581	58	-1	2830	2019-09-18 15:26:21.504077+03
3582	31	-1	1190	2019-09-18 15:37:38.595841+03
3583	13	-1	460	2019-09-18 16:04:59.744127+03
3584	64	-1	970	2019-09-18 16:19:01.298183+03
3585	87	-1	2320	2019-09-18 16:21:54.654503+03
3586	24	24	387	2019-09-18 16:25:02.84209+03
3587	37	-1	1290	2019-09-18 17:05:39.025973+03
3588	13	-1	460	2019-09-18 17:14:40.558659+03
3589	49	-1	970	2019-09-18 17:24:22.264098+03
3590	61	-1	1510	2019-09-18 17:39:00.676687+03
3591	57	-1	1900	2019-09-18 18:08:02.706107+03
3592	14	-1	1350	2019-09-18 18:36:51.747452+03
3593	6	-1	980	2019-09-18 18:44:57.007455+03
3594	95	-1	480	2019-09-18 19:39:45.341565+03
3595	26	23	208	2019-09-18 19:45:39.337725+03
3596	57	-1	1900	2019-09-18 20:00:14.813369+03
3597	35	-2	670	2019-09-18 20:05:01.957752+03
3598	81	-1	1620	2019-09-18 20:33:54.675418+03
3599	35	-1	670	2019-09-18 20:46:22.830862+03
3600	3	-1	660	2019-09-18 20:47:07.438824+03
3601	59	-1	1030	2019-09-18 20:49:14.629005+03
3602	77	-1	640	2019-09-18 21:07:03.587032+03
3603	43	-1	380	2019-09-18 21:28:54.375461+03
3604	37	-1	1290	2019-09-18 21:32:13.248105+03
3605	4	-1	1420	2019-09-18 21:33:03.424415+03
3606	64	-1	970	2019-09-18 22:00:43.212368+03
3607	49	-1	970	2019-09-18 22:02:06.674013+03
3608	76	31	558	2019-09-18 22:33:44.838654+03
3609	44	-1	500	2019-09-18 23:00:27.112853+03
3610	38	-2	1100	2019-09-18 23:00:31.861607+03
3611	58	-1	2830	2019-09-18 23:30:02.245176+03
3612	39	-1	910	2019-09-18 23:32:43.700014+03
3613	50	-1	1140	2019-09-18 23:41:14.447638+03
3614	80	-2	1120	2019-09-18 23:44:05.119412+03
3615	55	-1	3480	2019-09-19 00:12:05.758914+03
3616	1	-2	640	2019-09-19 00:43:07.188647+03
3617	77	-1	640	2019-09-19 00:50:09.643428+03
3618	26	-1	390	2019-09-19 01:12:54.825567+03
3619	64	-1	970	2019-09-19 01:39:51.866+03
3620	46	-1	1270	2019-09-19 02:00:06.590551+03
3621	92	-1	630	2019-09-19 02:09:42.218663+03
3622	26	-1	390	2019-09-19 02:27:10.76937+03
3623	30	-1	1140	2019-09-19 03:16:43.912997+03
3624	75	-1	830	2019-09-19 03:52:31.112495+03
3625	69	-1	1100	2019-09-19 03:59:42.432179+03
3626	71	-2	1030	2019-09-19 04:10:51.7863+03
3627	59	-1	1030	2019-09-19 04:27:07.206982+03
3628	54	-1	3470	2019-09-19 04:48:30.592521+03
3629	5	-1	1620	2019-09-19 05:29:01.959261+03
3630	57	-1	1900	2019-09-19 05:35:03.714605+03
3631	77	-1	640	2019-09-19 05:36:50.659512+03
3632	80	-1	1120	2019-09-19 05:38:17.278297+03
3633	83	-1	1230	2019-09-19 06:18:47.169766+03
3634	73	-2	960	2019-09-19 07:02:56.078862+03
3635	66	-2	690	2019-09-19 07:05:32.04347+03
3636	57	-1	1900	2019-09-19 07:12:23.874459+03
3637	49	-2	970	2019-09-19 07:12:26.070339+03
3638	16	-1	1380	2019-09-19 07:16:40.302555+03
3639	35	-1	670	2019-09-19 07:26:30.661861+03
3640	22	-2	1070	2019-09-19 07:49:38.162767+03
3641	12	-1	1650	2019-09-19 08:02:49.007089+03
3642	68	-2	490	2019-09-19 08:07:03.074694+03
3643	79	-1	550	2019-09-19 08:10:07.379919+03
3644	36	24	375	2019-09-19 08:22:37.093179+03
3645	1	-1	640	2019-09-19 08:36:02.745705+03
3646	42	-1	1790	2019-09-19 08:43:31.754987+03
3647	12	44	965	2019-09-19 09:10:36.313718+03
3648	87	-1	2320	2019-09-19 09:12:14.939876+03
3649	21	-2	960	2019-09-19 09:41:43.22797+03
3650	39	-2	910	2019-09-19 10:09:07.540824+03
3651	65	-2	490	2019-09-19 10:30:01.43291+03
3652	23	22	2387	2019-09-19 10:35:05.818311+03
3653	22	-1	1070	2019-09-19 11:12:23.870841+03
3654	46	-2	1270	2019-09-19 11:21:03.144935+03
3655	45	-1	1590	2019-09-19 11:24:07.705397+03
3656	21	-1	960	2019-09-19 11:54:34.50299+03
3657	12	-1	1650	2019-09-19 11:59:22.868975+03
3658	5	-1	1620	2019-09-19 12:05:51.613073+03
3659	12	-1	1650	2019-09-19 12:14:11.433689+03
3660	6	-1	980	2019-09-19 13:25:06.309205+03
3661	13	-1	460	2019-09-19 13:28:03.429043+03
3662	53	-1	3120	2019-09-19 13:58:47.408666+03
3663	62	-2	1220	2019-09-19 14:22:46.201917+03
3664	77	-1	640	2019-09-19 14:35:37.755539+03
3665	90	-1	1780	2019-09-19 14:41:43.04465+03
3666	30	-1	1140	2019-09-19 14:48:29.048882+03
3667	57	-1	1900	2019-09-19 14:56:17.96529+03
3668	9	-1	2090	2019-09-19 14:56:31.618146+03
3669	48	-1	640	2019-09-19 15:11:00.61816+03
3670	21	-1	960	2019-09-19 15:48:00.036139+03
3671	1	-1	640	2019-09-19 16:04:55.507667+03
3672	24	-1	950	2019-09-19 16:14:04.018416+03
3673	61	-2	1510	2019-09-19 16:14:12.821124+03
3674	39	-1	910	2019-09-19 16:47:27.064655+03
3675	75	-1	830	2019-09-19 16:51:14.547876+03
3676	20	-1	830	2019-09-19 17:13:47.164663+03
3677	57	-2	1900	2019-09-19 18:35:58.584847+03
3678	22	-1	1070	2019-09-19 19:19:46.296504+03
3679	21	-1	960	2019-09-19 19:22:01.196182+03
3680	23	-1	4390	2019-09-19 19:39:59.988435+03
3681	53	-1	3120	2019-09-19 19:52:27.850399+03
3682	16	-1	1380	2019-09-19 20:12:27.331225+03
3683	84	-2	2700	2019-09-19 20:44:50.746097+03
3684	71	-1	1030	2019-09-19 21:07:43.016751+03
3685	92	-1	630	2019-09-19 21:25:20.861717+03
3686	48	-1	640	2019-09-19 22:01:46.011079+03
3687	94	-1	1230	2019-09-19 23:04:16.35821+03
3688	17	-1	1500	2019-09-19 23:08:25.009747+03
3689	40	-1	1430	2019-09-19 23:30:15.630911+03
3690	80	-1	1120	2019-09-19 23:50:21.776029+03
3691	26	-1	390	2019-09-20 00:49:40.048099+03
3692	14	-3	1350	2019-09-20 01:27:13.246565+03
3693	55	-1	3480	2019-09-20 02:00:39.336361+03
3694	26	-1	390	2019-09-20 02:08:06.826791+03
3695	60	-2	2700	2019-09-20 02:09:41.218492+03
3696	31	-1	1190	2019-09-20 02:14:54.666881+03
3697	39	-2	910	2019-09-20 02:27:53.97448+03
3698	6	-1	980	2019-09-20 02:36:42.604133+03
3699	81	-1	1620	2019-09-20 02:43:36.005292+03
3700	20	-1	830	2019-09-20 02:55:27.894991+03
3701	32	-1	710	2019-09-20 03:09:33.977717+03
3702	13	-1	460	2019-09-20 03:15:29.500487+03
3703	38	-1	1100	2019-09-20 03:27:11.031221+03
3704	90	-1	1780	2019-09-20 03:53:01.75808+03
3705	7	-1	810	2019-09-20 04:05:30.802327+03
3706	43	-1	380	2019-09-20 04:14:56.151001+03
3707	13	-1	460	2019-09-20 04:34:28.089887+03
3708	83	-3	1230	2019-09-20 05:23:46.310321+03
3709	67	-2	350	2019-09-20 05:36:30.7781+03
3710	49	-1	970	2019-09-20 05:37:08.230902+03
3711	36	-1	630	2019-09-20 05:44:42.2834+03
3712	30	-2	1140	2019-09-20 05:54:51.363684+03
3713	79	-1	550	2019-09-20 07:09:28.418401+03
3714	76	-1	1070	2019-09-20 07:58:42.198745+03
3715	79	-1	550	2019-09-20 08:17:18.411731+03
3716	78	-1	900	2019-09-20 08:19:11.720612+03
3717	1	-1	640	2019-09-20 08:48:13.471627+03
3718	41	-1	830	2019-09-20 10:00:31.510755+03
3719	53	-1	3120	2019-09-20 10:05:06.15802+03
3720	78	-1	900	2019-09-20 10:30:43.588431+03
3721	27	-1	880	2019-09-20 11:16:20.399569+03
3722	14	-1	1350	2019-09-20 12:24:57.376703+03
3723	85	-1	730	2019-09-20 12:45:37.998565+03
3724	56	-1	2460	2019-09-20 13:02:37.386667+03
3725	90	31	762	2019-09-20 13:02:56.369759+03
3726	84	-1	2700	2019-09-20 13:27:48.982503+03
3727	83	-1	1230	2019-09-20 13:40:39.606626+03
3728	64	-1	970	2019-09-20 14:15:51.023715+03
3729	4	-2	1420	2019-09-20 14:35:33.398915+03
3730	58	-1	2830	2019-09-20 14:43:04.690749+03
3731	23	-1	4390	2019-09-20 14:43:50.373807+03
3732	68	-1	490	2019-09-20 15:27:00.372503+03
3733	18	-2	910	2019-09-20 15:37:23.677904+03
3734	48	-1	640	2019-09-20 15:45:26.400733+03
3735	5	-2	1620	2019-09-20 15:58:40.138988+03
3736	23	-1	4390	2019-09-20 16:06:22.290854+03
3737	2	-1	470	2019-09-20 16:33:52.508931+03
3738	37	-1	1290	2019-09-20 17:00:19.451663+03
3739	19	-1	1220	2019-09-20 17:04:15.228046+03
3740	27	-1	880	2019-09-20 17:31:31.281196+03
3741	35	-1	670	2019-09-20 17:33:25.817333+03
3742	10	-2	2080	2019-09-20 17:40:57.601337+03
3743	15	-2	2830	2019-09-20 17:42:05.101663+03
3744	30	-1	1140	2019-09-20 17:50:27.377688+03
3745	10	-1	2080	2019-09-20 18:11:18.411817+03
3746	78	-1	900	2019-09-20 18:54:32.220903+03
3747	59	-1	1030	2019-09-20 19:39:15.292336+03
3748	11	-1	830	2019-09-20 19:56:19.344197+03
3749	81	-1	1620	2019-09-20 20:18:10.029444+03
3750	4	-1	1420	2019-09-20 20:23:45.394372+03
3751	24	-1	950	2019-09-20 21:02:21.416972+03
3752	96	-1	1570	2019-09-20 21:09:54.58304+03
3753	49	-1	970	2019-09-20 21:10:09.916922+03
3754	58	-3	2830	2019-09-20 21:30:39.097622+03
3755	86	-1	910	2019-09-20 21:51:04.904162+03
3756	91	-1	1620	2019-09-20 23:13:04.14491+03
3757	61	-1	1510	2019-09-20 23:33:04.222628+03
3758	3	-1	660	2019-09-20 23:58:17.732321+03
3759	12	-2	1650	2019-09-21 00:02:56.779348+03
3760	12	-1	1650	2019-09-21 00:04:01.687101+03
3761	63	-1	1780	2019-09-21 00:25:03.945634+03
3762	69	-1	1100	2019-09-21 00:34:17.075975+03
3763	57	-2	1900	2019-09-21 00:41:39.11687+03
3764	39	-1	910	2019-09-21 00:52:27.012852+03
3765	59	-1	1030	2019-09-21 01:12:07.141796+03
3766	47	-1	1480	2019-09-21 01:46:29.943517+03
3767	47	-1	1480	2019-09-21 01:56:46.480392+03
3768	87	-1	2320	2019-09-21 02:11:24.981341+03
3769	4	-3	1420	2019-09-21 02:17:05.965332+03
3770	58	-2	2830	2019-09-21 02:28:31.582866+03
3771	28	-1	1860	2019-09-21 02:37:50.649352+03
3772	57	-1	1900	2019-09-21 02:38:38.892362+03
3773	62	-1	1220	2019-09-21 02:53:00.716594+03
3774	76	-1	1070	2019-09-21 03:00:51.81863+03
3775	26	-2	390	2019-09-21 03:16:32.175485+03
3776	73	-1	960	2019-09-21 03:24:40.535901+03
3777	58	-2	2830	2019-09-21 03:41:16.668791+03
3778	49	-1	970	2019-09-21 04:02:20.674132+03
3779	50	-1	1140	2019-09-21 04:16:49.397289+03
3780	72	-1	620	2019-09-21 04:24:16.99382+03
3781	46	-1	1270	2019-09-21 04:55:41.244431+03
3782	13	-1	460	2019-09-21 05:06:01.217315+03
3783	4	-1	1420	2019-09-21 05:08:56.740061+03
3784	31	-1	1190	2019-09-21 06:03:05.92297+03
3785	36	-1	630	2019-09-21 06:15:48.149586+03
3786	42	-1	1790	2019-09-21 06:21:04.8105+03
3787	70	-1	760	2019-09-21 07:02:47.792722+03
3788	15	-1	2830	2019-09-21 07:13:13.924505+03
3789	48	20	374	2019-09-21 07:18:57.91401+03
3790	84	-1	2700	2019-09-21 07:19:23.042084+03
3791	39	-1	910	2019-09-21 07:20:33.384981+03
3792	80	-1	1120	2019-09-21 07:55:16.91268+03
3793	52	-1	1090	2019-09-21 08:17:34.611848+03
3794	9	-1	2090	2019-09-21 08:33:23.072315+03
3795	52	-1	1090	2019-09-21 08:50:02.423163+03
3796	80	-1	1120	2019-09-21 10:19:38.490547+03
3797	4	-1	1420	2019-09-21 10:58:25.793163+03
3798	23	-2	4390	2019-09-21 11:03:56.078901+03
3799	3	-1	660	2019-09-21 11:11:47.773585+03
3800	60	-1	2700	2019-09-21 11:19:33.522051+03
3801	10	-1	2080	2019-09-21 11:35:08.791723+03
3802	34	-2	1550	2019-09-21 11:52:46.240456+03
3803	46	-2	1270	2019-09-21 12:18:55.718692+03
3804	30	-1	1140	2019-09-21 12:24:24.413402+03
3805	83	-1	1230	2019-09-21 12:24:30.87361+03
3806	7	-1	810	2019-09-21 13:06:51.445847+03
3807	71	36	528	2019-09-21 13:18:40.343616+03
3808	29	-2	1940	2019-09-21 13:25:32.56566+03
3809	21	-1	960	2019-09-21 13:36:24.979364+03
3810	22	-1	1070	2019-09-21 13:55:46.381741+03
3811	10	-1	2080	2019-09-21 14:05:37.601194+03
3812	52	-1	1090	2019-09-21 14:34:31.306446+03
3813	4	-2	1420	2019-09-21 15:16:10.750748+03
3814	18	-1	910	2019-09-21 15:26:27.319253+03
3815	39	-1	910	2019-09-21 15:31:44.234514+03
3816	7	-1	810	2019-09-21 15:46:01.038654+03
3817	8	-1	1920	2019-09-21 15:54:08.40175+03
3818	79	-1	550	2019-09-21 16:11:30.288226+03
3819	56	-2	2460	2019-09-21 16:30:54.887682+03
3820	48	-1	640	2019-09-21 16:51:26.284493+03
3821	4	-2	1420	2019-09-21 16:54:34.956975+03
3822	59	37	418	2019-09-21 16:59:13.868274+03
3823	12	-2	1650	2019-09-21 17:00:43.352385+03
3824	32	-1	710	2019-09-21 17:07:25.824371+03
3825	7	-1	810	2019-09-21 17:15:03.900777+03
3826	56	-1	2460	2019-09-21 17:17:01.266687+03
3827	84	-1	2700	2019-09-21 17:17:26.496846+03
3828	86	-1	910	2019-09-21 17:18:14.232222+03
3829	82	-1	560	2019-09-21 17:27:13.01395+03
3830	41	-1	830	2019-09-21 17:57:46.597525+03
3831	9	-1	2090	2019-09-21 18:39:33.105146+03
3832	80	-1	1120	2019-09-21 18:56:35.733485+03
3833	14	-1	1350	2019-09-21 19:19:49.581463+03
3834	29	48	988	2019-09-21 19:21:24.365211+03
3835	94	-1	1230	2019-09-21 19:27:32.583176+03
3836	23	-1	4390	2019-09-21 19:52:02.046012+03
3837	91	-1	1620	2019-09-21 20:08:36.012132+03
3838	57	-1	1900	2019-09-21 20:17:40.256417+03
3839	19	-2	1220	2019-09-21 20:27:07.670944+03
3840	49	-1	970	2019-09-21 20:52:21.615207+03
3841	62	-1	1220	2019-09-21 20:52:32.132493+03
3842	90	-2	1780	2019-09-21 21:06:42.185829+03
3843	93	-1	1620	2019-09-21 21:21:58.317749+03
3844	90	-1	1780	2019-09-21 21:50:28.804411+03
3845	13	-1	460	2019-09-21 21:51:26.436131+03
3846	57	-1	1900	2019-09-21 22:44:00.473974+03
3847	31	-1	1190	2019-09-21 22:50:41.919432+03
3848	85	-2	730	2019-09-21 23:06:28.631774+03
3849	94	-1	1230	2019-09-21 23:26:09.572987+03
3850	39	-1	910	2019-09-21 23:27:20.312348+03
3851	33	-1	900	2019-09-21 23:40:57.975102+03
3852	30	-1	1140	2019-09-21 23:43:08.854682+03
3853	54	17	1985	2019-09-21 23:45:02.891834+03
3854	73	-1	960	2019-09-21 23:52:01.998429+03
3855	87	-1	2320	2019-09-22 00:21:52.253355+03
3856	75	-1	830	2019-09-22 00:28:03.24588+03
3857	12	-1	1650	2019-09-22 00:41:54.960043+03
3858	37	-1	1290	2019-09-22 01:08:55.468991+03
3859	24	-1	950	2019-09-22 01:13:59.346891+03
3860	7	-1	810	2019-09-22 01:37:32.882617+03
3861	57	-2	1900	2019-09-22 01:46:03.129452+03
3862	77	-1	640	2019-09-22 02:11:23.690737+03
3863	70	-1	760	2019-09-22 02:21:17.773076+03
3864	84	-3	2700	2019-09-22 02:32:06.622075+03
3865	92	-1	630	2019-09-22 02:34:49.713797+03
3866	37	-1	1290	2019-09-22 02:43:09.404793+03
3867	92	-2	630	2019-09-22 02:47:49.011334+03
3868	56	-1	2460	2019-09-22 03:24:14.627624+03
3869	37	-2	1290	2019-09-22 03:32:30.322228+03
3870	39	-1	910	2019-09-22 04:32:43.593401+03
3871	80	-1	1120	2019-09-22 04:40:29.807994+03
3872	83	-1	1230	2019-09-22 04:49:43.638979+03
3873	94	-1	1230	2019-09-22 05:42:13.346513+03
3874	93	-3	1620	2019-09-22 05:52:51.722208+03
3875	26	-1	390	2019-09-22 06:10:32.992075+03
3876	64	-2	970	2019-09-22 06:36:14.350055+03
3877	68	-1	490	2019-09-22 06:47:19.878075+03
3878	75	-1	830	2019-09-22 06:51:53.391914+03
3879	64	-1	970	2019-09-22 06:55:44.341763+03
3880	81	-1	1620	2019-09-22 07:17:14.419115+03
3881	8	-1	1920	2019-09-22 07:22:05.646273+03
3882	87	-2	2320	2019-09-22 07:22:23.304631+03
3883	74	-1	1010	2019-09-22 07:50:23.864905+03
3884	64	40	544	2019-09-22 07:53:43.482869+03
3885	7	-1	810	2019-09-22 08:20:00.786296+03
3886	39	-1	910	2019-09-22 08:36:16.611062+03
3887	73	-1	960	2019-09-22 09:28:05.28153+03
3888	38	-1	1100	2019-09-22 09:36:04.4034+03
3889	31	-2	1190	2019-09-22 09:42:17.269949+03
3890	69	-1	1100	2019-09-22 11:11:08.500871+03
3891	53	-1	3120	2019-09-22 11:30:19.171038+03
3892	83	-1	1230	2019-09-22 11:34:54.162864+03
3893	53	-1	3120	2019-09-22 11:44:28.809622+03
3894	6	-1	980	2019-09-22 11:45:48.909408+03
3895	62	11	663	2019-09-22 11:59:10.183714+03
3896	3	-3	660	2019-09-22 12:12:39.228617+03
3897	55	-1	3480	2019-09-22 12:22:59.927845+03
3898	7	-1	810	2019-09-22 12:23:52.005462+03
3899	46	-1	1270	2019-09-22 12:48:25.38435+03
3900	46	-1	1270	2019-09-22 12:51:09.740796+03
3901	15	16	1647	2019-09-22 12:51:38.773442+03
3902	91	-1	1620	2019-09-22 12:52:45.057417+03
3903	47	-1	1480	2019-09-22 13:15:51.36777+03
3904	94	-1	1230	2019-09-22 13:43:54.555267+03
3905	22	-1	1070	2019-09-22 13:48:19.097505+03
3906	22	-3	1070	2019-09-22 14:08:40.568024+03
3907	96	-2	1570	2019-09-22 14:30:54.543879+03
3908	61	-1	1510	2019-09-22 14:46:42.161149+03
3909	52	-1	1090	2019-09-22 15:22:03.647288+03
3910	47	-1	1480	2019-09-22 15:24:33.096764+03
3911	22	-1	1070	2019-09-22 15:28:17.567957+03
3912	52	-1	1090	2019-09-22 15:40:57.082646+03
3913	13	-1	460	2019-09-22 15:52:03.384626+03
3914	30	-1	1140	2019-09-22 15:57:10.844722+03
3915	22	-1	1070	2019-09-22 15:58:47.02046+03
3916	67	-1	350	2019-09-22 16:13:50.572801+03
3917	58	-2	2830	2019-09-22 16:15:40.15247+03
3918	61	-1	1510	2019-09-22 16:20:30.875454+03
3919	43	-1	380	2019-09-22 16:31:41.850968+03
3920	7	-1	810	2019-09-22 16:32:59.882564+03
3921	15	-1	2830	2019-09-22 16:34:29.746842+03
3922	25	-1	1100	2019-09-22 16:46:14.865639+03
3923	71	-1	1030	2019-09-22 16:52:25.494939+03
3924	95	-1	480	2019-09-22 17:05:31.397169+03
3925	52	-1	1090	2019-09-22 17:49:40.953097+03
3926	10	-1	2080	2019-09-22 18:04:48.214048+03
3927	47	-1	1480	2019-09-22 18:09:02.77613+03
3928	8	-1	1920	2019-09-22 18:16:23.807299+03
3929	67	-1	350	2019-09-22 18:29:27.758346+03
3930	33	-1	900	2019-09-22 18:35:29.725975+03
3931	66	-1	690	2019-09-22 18:36:45.900185+03
3932	46	-1	1270	2019-09-22 19:12:21.41233+03
3933	11	-1	830	2019-09-22 20:02:04.151886+03
3934	57	-1	1900	2019-09-22 20:05:15.164208+03
3935	48	-1	640	2019-09-22 20:15:42.219643+03
3936	94	-1	1230	2019-09-22 20:35:26.61282+03
3937	94	-1	1230	2019-09-22 20:38:23.937377+03
3938	34	-1	1550	2019-09-22 20:38:51.847815+03
3939	2	-1	470	2019-09-22 20:50:56.962648+03
3940	47	-1	1480	2019-09-22 20:52:16.520515+03
3941	4	-2	1420	2019-09-22 20:52:20.537116+03
3942	30	-1	1140	2019-09-22 21:03:39.902412+03
3943	89	-2	1420	2019-09-22 21:27:46.913741+03
3944	51	-1	1310	2019-09-22 21:33:52.688063+03
3945	64	-2	970	2019-09-22 22:24:31.072315+03
3946	22	-2	1070	2019-09-22 22:37:33.648224+03
3947	64	-1	970	2019-09-22 22:39:21.731406+03
3948	80	-1	1120	2019-09-22 22:45:47.958312+03
3949	96	-1	1570	2019-09-22 22:45:52.362043+03
3950	82	17	286	2019-09-22 22:57:36.069618+03
3951	87	-2	2320	2019-09-22 23:19:46.818736+03
3952	11	-1	830	2019-09-22 23:23:51.666913+03
3953	70	-1	760	2019-09-22 23:33:08.754496+03
3954	81	-2	1620	2019-09-23 00:01:55.820053+03
3955	72	-1	620	2019-09-23 00:40:13.861382+03
3956	26	-2	390	2019-09-23 00:41:38.066273+03
3957	86	-1	910	2019-09-23 01:02:17.886036+03
3958	69	-1	1100	2019-09-23 01:29:53.807609+03
3959	93	-1	1620	2019-09-23 02:02:51.676717+03
3960	95	-1	480	2019-09-23 03:02:00.924779+03
3961	27	-1	880	2019-09-23 03:14:27.408269+03
3962	56	-1	2460	2019-09-23 03:18:05.903852+03
3963	22	-1	1070	2019-09-23 03:26:59.14529+03
3964	19	-1	1220	2019-09-23 03:36:33.078744+03
3965	91	-1	1620	2019-09-23 03:59:40.280023+03
3966	65	-2	490	2019-09-23 04:15:18.864217+03
3967	33	-2	900	2019-09-23 04:24:27.717504+03
3968	27	-1	880	2019-09-23 04:37:03.168132+03
3969	10	-1	2080	2019-09-23 04:40:42.091853+03
3970	77	-1	640	2019-09-23 04:45:58.760636+03
3971	29	-1	1940	2019-09-23 04:51:47.777354+03
3972	33	-1	900	2019-09-23 04:53:10.189708+03
3973	96	-1	1570	2019-09-23 05:23:25.045333+03
3974	78	-1	900	2019-09-23 05:38:52.131335+03
3975	38	-2	1100	2019-09-23 05:55:13.208512+03
3976	77	-1	640	2019-09-23 06:34:57.154185+03
3977	17	-1	1500	2019-09-23 07:13:24.886566+03
3978	65	-1	490	2019-09-23 07:39:30.682354+03
3979	17	32	722	2019-09-23 07:45:28.7086+03
3980	69	-1	1100	2019-09-23 07:58:33.144697+03
3981	60	-1	2700	2019-09-23 08:06:31.720642+03
3982	87	-1	2320	2019-09-23 08:17:28.000991+03
3983	58	-1	2830	2019-09-23 08:24:50.949355+03
3984	89	-1	1420	2019-09-23 08:45:18.119416+03
3985	20	-1	830	2019-09-23 09:47:09.340757+03
3986	13	-1	460	2019-09-23 10:14:08.227776+03
3987	88	-1	1270	2019-09-23 10:19:40.3979+03
3988	42	-1	1790	2019-09-23 10:57:56.222328+03
3989	95	-1	480	2019-09-23 11:15:06.667978+03
3990	88	-1	1270	2019-09-23 11:20:46.695138+03
3991	13	-1	460	2019-09-23 11:42:43.832929+03
3992	41	-1	830	2019-09-23 11:52:39.791727+03
3993	34	-1	1550	2019-09-23 12:08:12.321201+03
3994	65	-1	490	2019-09-23 12:39:06.448378+03
3995	80	-1	1120	2019-09-23 12:44:19.81635+03
3996	14	-1	1350	2019-09-23 12:48:25.354138+03
3997	77	-1	640	2019-09-23 12:56:12.872724+03
3998	44	19	201	2019-09-23 12:57:08.680538+03
3999	52	-1	1090	2019-09-23 13:00:58.546289+03
4000	12	-2	1650	2019-09-23 13:24:08.854094+03
4001	46	-2	1270	2019-09-23 13:29:54.254779+03
4002	64	-2	970	2019-09-23 13:35:16.969491+03
4003	19	-2	1220	2019-09-23 13:45:59.37775+03
4004	49	-1	970	2019-09-23 15:07:31.278782+03
4005	47	-1	1480	2019-09-23 15:14:19.110802+03
4006	15	-1	2830	2019-09-23 15:15:49.698592+03
4007	76	-1	1070	2019-09-23 15:48:30.688709+03
4008	82	-1	560	2019-09-23 16:00:31.402895+03
4009	67	-2	350	2019-09-23 16:27:02.760772+03
4010	55	-2	3480	2019-09-23 16:34:55.711514+03
4011	92	-1	630	2019-09-23 17:10:44.741052+03
4012	95	-1	480	2019-09-23 17:32:16.286851+03
4013	41	-1	830	2019-09-23 17:39:14.177715+03
4014	21	-1	960	2019-09-23 18:13:43.559259+03
4015	8	-1	1920	2019-09-23 18:26:09.268151+03
4016	57	39	916	2019-09-23 18:42:07.066899+03
4017	72	-1	620	2019-09-23 20:00:39.385796+03
4018	24	-1	950	2019-09-23 20:31:44.599558+03
4019	40	-1	1430	2019-09-23 21:06:06.389471+03
4020	34	-1	1550	2019-09-23 21:12:56.544258+03
4021	96	-1	1570	2019-09-23 21:13:35.783335+03
4022	65	-1	490	2019-09-23 21:21:44.723052+03
4023	78	-1	900	2019-09-23 21:56:17.241513+03
4024	42	-1	1790	2019-09-23 21:59:41.04165+03
4025	71	-1	1030	2019-09-23 22:16:13.413939+03
4026	14	-1	1350	2019-09-23 22:19:26.044238+03
4027	76	-1	1070	2019-09-23 22:22:32.621244+03
4028	56	-1	2460	2019-09-23 22:39:45.483341+03
4029	46	-1	1270	2019-09-23 22:51:47.744496+03
4030	76	-1	1070	2019-09-23 23:05:49.012715+03
4031	11	-1	830	2019-09-23 23:22:23.191963+03
4032	3	-1	660	2019-09-23 23:49:45.079674+03
4033	93	-1	1620	2019-09-23 23:50:17.708443+03
4034	31	-1	1190	2019-09-23 23:56:43.837565+03
4035	39	-1	910	2019-09-23 23:59:00.146042+03
4036	17	-2	1500	2019-09-24 00:02:31.352779+03
4037	93	-1	1620	2019-09-24 00:55:02.17956+03
4038	79	-1	550	2019-09-24 00:58:57.529098+03
4039	87	-1	2320	2019-09-24 00:59:13.471629+03
4040	64	-1	970	2019-09-24 01:07:31.915891+03
4041	68	-1	490	2019-09-24 01:29:16.641567+03
4042	54	-1	3470	2019-09-24 01:37:18.897873+03
4043	13	-1	460	2019-09-24 02:10:15.330361+03
4044	26	-1	390	2019-09-24 02:15:19.416073+03
4045	7	-2	810	2019-09-24 02:26:09.98641+03
4046	51	-1	1310	2019-09-24 02:41:24.163434+03
4047	32	-1	710	2019-09-24 03:03:16.944004+03
4048	48	-2	640	2019-09-24 03:06:25.881191+03
4049	89	-1	1420	2019-09-24 03:38:08.667921+03
4050	48	-1	640	2019-09-24 03:42:07.940792+03
4051	10	-2	2080	2019-09-24 03:42:38.271535+03
4052	89	-1	1420	2019-09-24 03:57:16.5255+03
4053	12	-1	1650	2019-09-24 04:17:22.830632+03
4054	11	-1	830	2019-09-24 04:25:58.992915+03
4055	46	-1	1270	2019-09-24 04:58:20.766784+03
4056	70	-1	760	2019-09-24 05:03:32.59265+03
4057	87	-1	2320	2019-09-24 05:07:28.823316+03
4058	7	-1	810	2019-09-24 05:56:41.251263+03
4059	44	-1	500	2019-09-24 05:57:11.301387+03
4060	21	-1	960	2019-09-24 06:02:50.177416+03
4061	63	-2	1780	2019-09-24 06:07:16.562309+03
4062	83	-1	1230	2019-09-24 06:11:10.16153+03
4063	53	28	1732	2019-09-24 06:34:02.979317+03
4064	16	14	737	2019-09-24 06:41:58.564375+03
4065	74	-1	1010	2019-09-24 07:04:09.091262+03
4066	21	-1	960	2019-09-24 07:29:11.784878+03
4067	91	-2	1620	2019-09-24 07:37:45.148011+03
4068	49	-1	970	2019-09-24 07:51:01.608641+03
4069	52	-1	1090	2019-09-24 07:54:04.06447+03
4070	93	28	899	2019-09-24 08:33:01.273514+03
4071	81	-2	1620	2019-09-24 08:36:18.962574+03
4072	38	-1	1100	2019-09-24 08:52:13.459085+03
4073	21	-1	960	2019-09-24 08:55:24.522378+03
4074	82	-2	560	2019-09-24 09:22:19.229338+03
4075	53	-1	3120	2019-09-24 09:35:48.733224+03
4076	47	-1	1480	2019-09-24 10:00:06.73412+03
4077	91	-1	1620	2019-09-24 10:16:50.19364+03
4078	21	-2	960	2019-09-24 10:37:52.117382+03
4079	32	25	366	2019-09-24 10:55:49.432344+03
4080	35	-1	670	2019-09-24 10:58:39.714048+03
4081	71	-1	1030	2019-09-24 11:11:25.63019+03
4082	22	-1	1070	2019-09-24 11:26:57.627841+03
4083	10	-1	2080	2019-09-24 11:47:47.974395+03
4084	55	-1	3480	2019-09-24 11:51:44.571579+03
4085	90	-2	1780	2019-09-24 12:03:11.549519+03
4086	84	-1	2700	2019-09-24 12:09:28.489703+03
4087	10	-1	2080	2019-09-24 12:33:33.611383+03
4088	89	-1	1420	2019-09-24 12:37:02.641751+03
4089	48	-1	640	2019-09-24 12:54:42.248217+03
4090	31	-1	1190	2019-09-24 12:59:08.431698+03
4091	20	-1	830	2019-09-24 13:06:50.87636+03
4092	5	-1	1620	2019-09-24 13:35:14.049102+03
4093	62	-2	1220	2019-09-24 13:39:56.075372+03
4094	50	-1	1140	2019-09-24 13:44:45.731618+03
4095	89	25	727	2019-09-24 14:11:10.898553+03
4096	70	-1	760	2019-09-24 14:13:05.452036+03
4097	40	-1	1430	2019-09-24 14:16:47.064236+03
4098	10	-1	2080	2019-09-24 14:21:43.982849+03
4099	38	-1	1100	2019-09-24 14:37:20.855697+03
4100	17	-1	1500	2019-09-24 14:55:25.752745+03
4101	75	-1	830	2019-09-24 15:21:08.005659+03
4102	33	-1	900	2019-09-24 15:22:19.513683+03
4103	32	-1	710	2019-09-24 15:32:28.126455+03
4104	46	-1	1270	2019-09-24 15:50:37.844447+03
4105	94	-1	1230	2019-09-24 16:03:30.219203+03
4106	95	-1	480	2019-09-24 16:25:30.402761+03
4107	41	-2	830	2019-09-24 16:26:44.853526+03
4108	73	-2	960	2019-09-24 16:26:52.043389+03
4109	60	-1	2700	2019-09-24 17:28:19.896923+03
4110	23	-1	4390	2019-09-24 17:32:22.886226+03
4111	42	-1	1790	2019-09-24 17:39:59.323958+03
4112	75	-3	830	2019-09-24 18:10:59.863923+03
4113	28	-2	1860	2019-09-24 18:29:03.604485+03
4114	58	-1	2830	2019-09-24 18:48:38.363815+03
4115	80	-1	1120	2019-09-24 18:50:29.965773+03
4116	46	-1	1270	2019-09-24 19:02:56.763637+03
4117	89	-1	1420	2019-09-24 19:32:51.951706+03
4118	51	-2	1310	2019-09-24 19:35:47.617203+03
4119	4	-1	1420	2019-09-24 19:55:57.832622+03
4120	44	-2	500	2019-09-24 20:08:41.298832+03
4121	38	-1	1100	2019-09-24 20:11:02.521934+03
4122	46	-1	1270	2019-09-24 20:15:02.309434+03
4123	4	-1	1420	2019-09-24 20:16:53.287737+03
4124	16	-1	1380	2019-09-24 21:04:58.664858+03
4125	33	40	455	2019-09-24 21:09:50.878232+03
4126	86	-1	910	2019-09-24 21:10:23.04891+03
4127	87	-1	2320	2019-09-24 21:13:06.688489+03
4128	89	-1	1420	2019-09-24 21:20:07.564288+03
4129	50	-1	1140	2019-09-24 21:29:00.340682+03
4130	73	-2	960	2019-09-24 21:45:25.516412+03
4131	42	-2	1790	2019-09-24 21:46:37.987886+03
4132	30	-1	1140	2019-09-24 21:47:28.669024+03
4133	8	-1	1920	2019-09-24 21:56:54.29053+03
4134	30	-1	1140	2019-09-24 22:13:05.449564+03
4135	47	-1	1480	2019-09-24 22:20:13.586562+03
4136	33	-1	900	2019-09-24 23:21:27.244298+03
4137	87	-1	2320	2019-09-24 23:22:32.135371+03
4138	71	-1	1030	2019-09-24 23:23:34.885979+03
4139	4	-1	1420	2019-09-24 23:26:58.292379+03
4140	75	-1	830	2019-09-25 00:15:34.530903+03
4141	75	-1	830	2019-09-25 00:51:44.860494+03
4142	12	-1	1650	2019-09-25 01:04:10.49263+03
4143	77	-1	640	2019-09-25 01:18:19.863417+03
4144	45	-1	1590	2019-09-25 01:21:50.721953+03
4145	2	16	230	2019-09-25 01:23:00.344886+03
4146	43	-2	380	2019-09-25 01:23:38.265479+03
4147	9	-1	2090	2019-09-25 01:40:40.584831+03
4148	10	-1	2080	2019-09-25 01:42:58.012715+03
4149	33	-1	900	2019-09-25 01:43:03.875966+03
4150	5	-1	1620	2019-09-25 02:24:42.090358+03
4151	57	-1	1900	2019-09-25 02:25:28.77365+03
4152	33	-1	900	2019-09-25 02:29:36.768153+03
4153	22	-1	1070	2019-09-25 02:30:26.393872+03
4154	68	-1	490	2019-09-25 02:33:37.230751+03
4155	93	-1	1620	2019-09-25 02:38:01.415782+03
4156	69	-1	1100	2019-09-25 02:44:32.777944+03
4157	6	-1	980	2019-09-25 03:08:50.467221+03
4158	70	-1	760	2019-09-25 03:29:40.961531+03
4159	68	-1	490	2019-09-25 03:32:08.983779+03
4160	96	-1	1570	2019-09-25 03:46:59.360623+03
4161	2	-1	470	2019-09-25 03:50:23.419663+03
4162	85	-1	730	2019-09-25 03:57:41.607241+03
4163	57	-1	1900	2019-09-25 04:18:36.052364+03
4164	62	-1	1220	2019-09-25 05:04:01.581782+03
4165	31	-1	1190	2019-09-25 05:06:35.01888+03
4166	24	-1	950	2019-09-25 05:11:06.142764+03
4167	80	-2	1120	2019-09-25 05:12:48.417958+03
4168	28	-1	1860	2019-09-25 05:28:50.042958+03
4169	79	-2	550	2019-09-25 05:42:06.638688+03
4170	95	-1	480	2019-09-25 06:13:12.359865+03
4171	39	-1	910	2019-09-25 06:18:24.697003+03
4172	46	-1	1270	2019-09-25 06:23:44.59877+03
4173	88	-1	1270	2019-09-25 06:45:53.510908+03
4174	12	-1	1650	2019-09-25 06:57:12.833344+03
4175	83	-1	1230	2019-09-25 06:59:24.256786+03
4176	62	-1	1220	2019-09-25 07:04:41.665852+03
4177	88	-1	1270	2019-09-25 08:39:56.868371+03
4178	2	-1	470	2019-09-25 08:43:55.178592+03
4179	67	-1	350	2019-09-25 09:14:33.528009+03
4180	46	-1	1270	2019-09-25 10:15:07.233678+03
4181	75	-3	830	2019-09-25 10:19:54.464337+03
4182	10	-1	2080	2019-09-25 10:28:20.246264+03
4183	88	-1	1270	2019-09-25 10:41:26.538174+03
4184	56	-1	2460	2019-09-25 10:47:28.838587+03
4185	65	-1	490	2019-09-25 11:06:47.896957+03
4186	3	-1	660	2019-09-25 11:15:58.005425+03
4187	12	-1	1650	2019-09-25 11:28:17.146727+03
4188	14	-1	1350	2019-09-25 11:40:42.895977+03
4189	84	-1	2700	2019-09-25 11:51:34.685059+03
4190	75	-2	830	2019-09-25 12:05:02.474297+03
4191	33	-1	900	2019-09-25 12:27:47.09856+03
4192	21	-1	960	2019-09-25 12:33:08.571396+03
4193	4	-1	1420	2019-09-25 12:34:35.350197+03
4194	4	-1	1420	2019-09-25 12:37:01.474188+03
4195	12	-1	1650	2019-09-25 12:40:07.804577+03
4196	21	-1	960	2019-09-25 13:32:13.230788+03
4197	89	-1	1420	2019-09-25 13:37:39.598093+03
4198	78	-1	900	2019-09-25 13:53:49.787838+03
4199	23	-1	4390	2019-09-25 14:07:16.401293+03
4200	29	-1	1940	2019-09-25 14:13:14.584075+03
4201	88	25	611	2019-09-25 14:32:39.348814+03
4202	68	-1	490	2019-09-25 15:02:52.728889+03
4203	57	-1	1900	2019-09-25 15:07:24.11493+03
4204	82	-2	560	2019-09-25 15:09:48.682793+03
4205	86	-1	910	2019-09-25 15:14:48.619616+03
4206	67	-1	350	2019-09-25 15:28:00.790964+03
4207	73	-2	960	2019-09-25 15:33:01.803523+03
4208	81	-1	1620	2019-09-25 15:48:05.24329+03
4209	85	-1	730	2019-09-25 16:10:55.328081+03
4210	70	-1	760	2019-09-25 16:17:35.660048+03
4211	42	-1	1790	2019-09-25 16:43:06.026483+03
4212	12	-1	1650	2019-09-25 16:43:09.746761+03
4213	66	-1	690	2019-09-25 16:54:29.822005+03
4214	31	31	601	2019-09-25 17:01:30.531407+03
4215	88	-1	1270	2019-09-25 17:07:13.506658+03
4216	42	-1	1790	2019-09-25 17:19:49.023669+03
4217	23	-1	4390	2019-09-25 17:24:09.100318+03
4218	17	-1	1500	2019-09-25 17:26:47.77978+03
4219	54	-2	3470	2019-09-25 17:28:17.208241+03
4220	10	-1	2080	2019-09-25 18:06:52.542903+03
4221	51	-1	1310	2019-09-25 19:12:57.982499+03
4222	81	-1	1620	2019-09-25 19:17:22.167593+03
4223	40	-1	1430	2019-09-25 19:19:42.556559+03
4224	63	-2	1780	2019-09-25 19:19:43.747753+03
4225	14	-1	1350	2019-09-25 19:20:03.6045+03
4226	40	-1	1430	2019-09-25 19:20:52.210352+03
4227	27	-1	880	2019-09-25 19:56:19.457542+03
4228	25	18	659	2019-09-25 20:04:35.019581+03
4229	89	-2	1420	2019-09-25 20:10:29.410356+03
4230	4	-1	1420	2019-09-25 20:10:32.265107+03
4231	75	-1	830	2019-09-25 20:21:46.553232+03
4232	96	-3	1570	2019-09-25 20:23:13.379507+03
4233	92	-1	630	2019-09-25 20:26:18.026929+03
4234	75	-1	830	2019-09-25 20:43:40.724319+03
4235	71	-1	1030	2019-09-25 20:55:17.734909+03
4236	89	-2	1420	2019-09-25 21:08:58.49274+03
4237	18	-1	910	2019-09-25 21:12:50.542401+03
4238	41	-2	830	2019-09-25 21:18:39.914806+03
4239	69	-1	1100	2019-09-25 22:12:33.526661+03
4240	57	-2	1900	2019-09-25 22:14:08.508797+03
4241	14	30	685	2019-09-25 22:15:02.931318+03
4242	50	-1	1140	2019-09-25 22:23:23.280256+03
4243	10	-1	2080	2019-09-25 22:30:36.544429+03
4244	5	-1	1620	2019-09-25 22:56:11.750568+03
4245	76	-1	1070	2019-09-25 23:15:46.80865+03
4246	52	-1	1090	2019-09-25 23:27:55.714769+03
4247	47	-1	1480	2019-09-25 23:33:41.681067+03
4248	70	-2	760	2019-09-25 23:35:31.982756+03
4249	83	-1	1230	2019-09-25 23:48:49.993976+03
4250	86	-1	910	2019-09-26 00:01:45.381495+03
4251	59	-1	1030	2019-09-26 00:26:28.660979+03
4252	75	-1	830	2019-09-26 00:37:01.69275+03
4253	11	21	374	2019-09-26 00:48:16.823269+03
4254	12	-1	1650	2019-09-26 00:55:09.655526+03
4255	34	-1	1550	2019-09-26 01:01:21.913316+03
4256	4	-1	1420	2019-09-26 01:04:15.191951+03
4257	80	-1	1120	2019-09-26 01:17:00.045685+03
4258	61	-1	1510	2019-09-26 01:38:31.444702+03
4259	5	-1	1620	2019-09-26 01:40:13.466505+03
4260	5	-1	1620	2019-09-26 01:40:15.587749+03
4261	92	-2	630	2019-09-26 02:04:03.979797+03
4262	33	-1	900	2019-09-26 02:04:35.176445+03
4263	38	36	446	2019-09-26 02:17:02.779581+03
4264	3	-1	660	2019-09-26 02:30:35.261906+03
4265	71	-1	1030	2019-09-26 03:17:10.34722+03
4266	59	-1	1030	2019-09-26 03:22:59.317944+03
4267	35	-3	670	2019-09-26 03:25:33.603898+03
4268	11	-1	830	2019-09-26 03:31:00.628262+03
4269	80	-1	1120	2019-09-26 03:34:32.296156+03
4270	82	-1	560	2019-09-26 03:47:43.221364+03
4271	49	-1	970	2019-09-26 03:57:35.266678+03
4272	66	-1	690	2019-09-26 04:08:29.223159+03
4273	77	-1	640	2019-09-26 04:28:19.090042+03
4274	10	-1	2080	2019-09-26 04:39:00.129728+03
4275	39	-1	910	2019-09-26 04:40:28.247265+03
4276	42	-2	1790	2019-09-26 05:49:23.805867+03
4277	35	-1	670	2019-09-26 06:10:34.049179+03
4278	34	-1	1550	2019-09-26 06:12:36.635323+03
4279	12	-1	1650	2019-09-26 06:13:32.571602+03
4280	68	-1	490	2019-09-26 06:14:29.104076+03
4281	8	-2	1920	2019-09-26 06:29:45.991672+03
4282	57	-1	1900	2019-09-26 06:46:53.078246+03
4283	12	-1	1650	2019-09-26 07:30:02.750918+03
4284	52	-1	1090	2019-09-26 07:57:02.256979+03
4285	56	-1	2460	2019-09-26 08:12:29.404292+03
4286	42	-2	1790	2019-09-26 08:21:05.86298+03
4287	55	-1	3480	2019-09-26 08:26:18.975251+03
4288	74	-1	1010	2019-09-26 08:27:10.227682+03
4289	8	-2	1920	2019-09-26 09:00:01.241643+03
4290	88	-3	1270	2019-09-26 09:15:51.210135+03
4291	12	-1	1650	2019-09-26 09:19:27.518587+03
4292	16	-1	1380	2019-09-26 09:26:41.11074+03
4293	29	-1	1940	2019-09-26 10:06:40.250575+03
4294	81	-1	1620	2019-09-26 10:22:34.397115+03
4295	47	-2	1480	2019-09-26 10:25:58.392853+03
4296	4	-1	1420	2019-09-26 10:34:15.282346+03
4297	70	-1	760	2019-09-26 10:51:38.551812+03
4298	20	-2	830	2019-09-26 11:51:24.075995+03
4299	21	-1	960	2019-09-26 11:54:09.181533+03
4300	13	-1	460	2019-09-26 12:31:57.47391+03
4301	31	-2	1190	2019-09-26 12:39:48.566217+03
4302	30	-2	1140	2019-09-26 12:45:59.013176+03
4303	94	-2	1230	2019-09-26 13:27:09.167813+03
4304	12	-1	1650	2019-09-26 13:27:40.363438+03
4305	31	-1	1190	2019-09-26 13:57:14.356505+03
4306	96	-1	1570	2019-09-26 14:21:00.600016+03
4307	20	-1	830	2019-09-26 14:33:46.167268+03
4308	6	-1	980	2019-09-26 14:45:10.773141+03
4309	41	-1	830	2019-09-26 15:07:28.015408+03
4310	2	-1	470	2019-09-26 15:38:25.769514+03
4311	27	-2	880	2019-09-26 15:52:48.212843+03
4312	5	-1	1620	2019-09-26 16:02:14.91562+03
4313	1	-1	640	2019-09-26 16:33:08.12611+03
4314	53	-1	3120	2019-09-26 17:16:21.947699+03
4315	81	-1	1620	2019-09-26 17:56:26.364049+03
4316	86	-1	910	2019-09-26 18:08:32.3787+03
4317	17	-1	1500	2019-09-26 18:22:06.266397+03
4318	54	-1	3470	2019-09-26 18:24:49.366568+03
4319	62	-1	1220	2019-09-26 18:41:29.295606+03
4320	54	-1	3470	2019-09-26 18:48:33.459661+03
4321	14	-1	1350	2019-09-26 19:21:14.642936+03
4322	79	-1	550	2019-09-26 19:25:22.692746+03
4323	7	-1	810	2019-09-26 19:58:39.853794+03
4324	17	-1	1500	2019-09-26 20:01:38.380671+03
4325	9	-1	2090	2019-09-26 20:02:17.649484+03
4326	29	-1	1940	2019-09-26 20:05:50.498964+03
4327	32	-1	710	2019-09-26 20:06:52.214289+03
4328	38	-1	1100	2019-09-26 20:10:34.753516+03
4329	70	20	448	2019-09-26 20:12:46.030511+03
4330	49	-2	970	2019-09-26 20:25:07.732716+03
4331	73	-1	960	2019-09-26 20:38:07.780991+03
4332	70	-1	760	2019-09-26 21:12:12.060801+03
4333	6	-1	980	2019-09-26 21:45:03.614994+03
4334	88	-1	1270	2019-09-26 22:08:30.605854+03
4335	8	-1	1920	2019-09-26 22:15:02.960031+03
4336	14	-1	1350	2019-09-26 22:19:06.366424+03
4337	12	-1	1650	2019-09-26 22:19:39.63606+03
4338	73	-1	960	2019-09-26 22:21:11.109808+03
4339	26	-2	390	2019-09-26 22:23:08.925388+03
4340	5	-1	1620	2019-09-26 22:31:21.628025+03
4341	40	-1	1430	2019-09-26 22:31:58.936475+03
4342	90	-1	1780	2019-09-26 22:43:00.205746+03
4343	56	-1	2460	2019-09-26 22:50:57.561185+03
4344	94	26	554	2019-09-26 23:18:49.182208+03
4345	63	-1	1780	2019-09-26 23:25:38.103732+03
4346	12	-2	1650	2019-09-26 23:25:44.701037+03
4347	69	-1	1100	2019-09-26 23:33:20.353723+03
4348	83	-1	1230	2019-09-26 23:56:06.678203+03
4349	3	-2	660	2019-09-26 23:56:29.463627+03
4350	10	-1	2080	2019-09-27 00:03:10.71007+03
4351	50	-1	1140	2019-09-27 00:29:00.615372+03
4352	30	-1	1140	2019-09-27 00:43:54.595969+03
4353	78	-1	900	2019-09-27 00:48:59.601721+03
4354	73	-2	960	2019-09-27 00:49:37.34334+03
4355	94	-1	1230	2019-09-27 00:56:49.987058+03
4356	20	-1	830	2019-09-27 01:14:55.405445+03
4357	71	-2	1030	2019-09-27 01:15:10.531157+03
4358	71	-1	1030	2019-09-27 01:27:40.625282+03
4359	23	-1	4390	2019-09-27 02:06:57.90429+03
4360	5	-2	1620	2019-09-27 02:07:05.636737+03
4361	51	-1	1310	2019-09-27 02:15:01.541746+03
4362	57	-1	1900	2019-09-27 02:18:26.300451+03
4363	59	-2	1030	2019-09-27 02:23:51.632175+03
4364	55	-1	3480	2019-09-27 02:44:35.240513+03
4365	78	-1	900	2019-09-27 03:04:25.255879+03
4366	60	-1	2700	2019-09-27 03:08:58.224289+03
4367	39	-1	910	2019-09-27 03:17:22.707897+03
4368	24	-1	950	2019-09-27 03:23:03.889537+03
4369	15	-1	2830	2019-09-27 03:23:35.675494+03
4370	92	-1	630	2019-09-27 03:29:32.98678+03
4371	87	-1	2320	2019-09-27 03:29:34.048593+03
4372	8	-1	1920	2019-09-27 04:19:04.794138+03
4373	32	-1	710	2019-09-27 04:20:08.04991+03
4374	30	-1	1140	2019-09-27 04:23:40.208262+03
4375	39	-1	910	2019-09-27 04:38:33.409671+03
4376	58	-1	2830	2019-09-27 04:54:17.756062+03
4377	40	-1	1430	2019-09-27 05:09:09.21295+03
4378	43	-1	380	2019-09-27 05:36:55.889027+03
4379	10	36	897	2019-09-27 05:48:33.05807+03
4380	32	-1	710	2019-09-27 05:52:43.603976+03
4381	64	-1	970	2019-09-27 06:15:00.59067+03
4382	82	-1	560	2019-09-27 06:18:41.568262+03
4383	24	-2	950	2019-09-27 06:32:18.419123+03
4384	68	-1	490	2019-09-27 06:48:13.708971+03
4385	25	-1	1100	2019-09-27 06:53:10.027802+03
4386	92	-1	630	2019-09-27 07:02:29.71625+03
4387	13	-1	460	2019-09-27 07:05:20.425073+03
4388	53	-2	3120	2019-09-27 07:14:12.562859+03
4389	81	-1	1620	2019-09-27 07:16:17.394159+03
4390	71	-1	1030	2019-09-27 08:27:56.542027+03
4391	22	-1	1070	2019-09-27 08:31:14.475488+03
4392	73	-1	960	2019-09-27 08:47:21.509504+03
4393	76	-1	1070	2019-09-27 09:08:50.641003+03
4394	82	-1	560	2019-09-27 09:20:25.753687+03
4395	67	-1	350	2019-09-27 09:22:18.783372+03
4396	14	-2	1350	2019-09-27 09:39:26.964463+03
4397	84	-1	2700	2019-09-27 09:54:01.796876+03
4398	46	-2	1270	2019-09-27 09:56:06.136246+03
4399	50	-1	1140	2019-09-27 09:58:47.439869+03
4400	81	-1	1620	2019-09-27 10:01:27.207405+03
4401	6	-2	980	2019-09-27 10:19:20.604512+03
4402	12	-1	1650	2019-09-27 10:23:40.09615+03
4403	37	-1	1290	2019-09-27 10:42:24.978803+03
4404	56	-2	2460	2019-09-27 10:52:30.734089+03
4405	84	-2	2700	2019-09-27 10:54:06.442948+03
4406	12	-1	1650	2019-09-27 10:55:05.297023+03
4407	20	-2	830	2019-09-27 10:56:02.531493+03
4408	53	-1	3120	2019-09-27 11:05:43.322709+03
4409	57	-1	1900	2019-09-27 11:09:57.635683+03
4410	32	-1	710	2019-09-27 11:24:27.849323+03
4411	89	-1	1420	2019-09-27 11:31:56.747903+03
4412	44	-1	500	2019-09-27 11:43:05.717712+03
4413	42	-1	1790	2019-09-27 12:08:37.483518+03
4414	28	22	1049	2019-09-27 12:12:59.403658+03
4415	18	-1	910	2019-09-27 12:14:50.930963+03
4416	80	-1	1120	2019-09-27 12:33:55.903867+03
4417	30	-2	1140	2019-09-27 13:17:40.989072+03
4418	71	-1	1030	2019-09-27 13:25:05.890759+03
4419	56	-1	2460	2019-09-27 13:25:45.265445+03
4420	78	-1	900	2019-09-27 13:38:15.852509+03
4421	17	-1	1500	2019-09-27 14:12:57.358648+03
4422	14	-1	1350	2019-09-27 14:42:37.702514+03
4423	19	-1	1220	2019-09-27 14:45:34.200086+03
4424	32	-1	710	2019-09-27 14:47:45.718225+03
4425	67	-2	350	2019-09-27 15:05:00.97277+03
4426	23	-2	4390	2019-09-27 15:12:34.141311+03
4427	10	-1	2080	2019-09-27 15:13:21.519924+03
4428	69	-2	1100	2019-09-27 15:21:52.062907+03
4429	83	-1	1230	2019-09-27 15:24:10.308985+03
4430	92	-1	630	2019-09-27 15:52:53.450829+03
4431	32	-1	710	2019-09-27 16:30:11.534481+03
4432	18	-1	910	2019-09-27 16:33:52.722591+03
4433	35	-1	670	2019-09-27 16:36:42.398102+03
4434	18	-2	910	2019-09-27 16:49:05.913066+03
4435	80	-1	1120	2019-09-27 17:12:01.713307+03
4436	58	-1	2830	2019-09-27 17:15:51.578739+03
4437	23	-1	4390	2019-09-27 17:34:49.120479+03
4438	9	-2	2090	2019-09-27 18:04:41.892241+03
4439	22	-1	1070	2019-09-27 18:29:06.092569+03
4440	96	-1	1570	2019-09-27 18:40:12.41951+03
4441	22	-1	1070	2019-09-27 18:50:58.818887+03
4442	49	-1	970	2019-09-27 19:05:09.04347+03
4443	19	-1	1220	2019-09-27 19:06:31.888415+03
4444	92	-1	630	2019-09-27 19:10:21.107369+03
4445	37	-1	1290	2019-09-27 19:36:04.476914+03
4446	84	-1	2700	2019-09-27 19:36:51.679048+03
4447	86	-1	910	2019-09-27 19:38:07.608499+03
4448	46	-1	1270	2019-09-27 19:58:58.331022+03
4449	23	-1	4390	2019-09-27 20:02:46.86287+03
4450	87	-1	2320	2019-09-27 20:03:20.530929+03
4451	92	-1	630	2019-09-27 20:18:10.943799+03
4452	74	-2	1010	2019-09-27 20:18:22.604154+03
4453	90	-1	1780	2019-09-27 20:23:06.047498+03
4454	34	-1	1550	2019-09-27 20:25:51.478677+03
4455	31	-2	1190	2019-09-27 20:27:41.042071+03
4456	49	-2	970	2019-09-27 20:32:30.682071+03
4457	89	-1	1420	2019-09-27 20:54:50.175767+03
4458	1	-2	640	2019-09-27 21:21:23.057691+03
4459	2	-1	470	2019-09-27 21:30:22.648692+03
4460	22	-1	1070	2019-09-27 21:37:11.413221+03
4461	77	-1	640	2019-09-27 21:49:03.497268+03
4462	41	-1	830	2019-09-27 21:54:31.958773+03
4463	38	-2	1100	2019-09-27 21:57:30.236975+03
4464	18	-1	910	2019-09-27 22:07:29.188716+03
4465	63	-1	1780	2019-09-27 22:10:03.616845+03
4466	76	-1	1070	2019-09-27 22:10:43.584383+03
4467	14	-1	1350	2019-09-27 22:26:17.745491+03
4468	80	-1	1120	2019-09-27 22:40:48.880591+03
4469	18	-1	910	2019-09-27 23:10:18.124334+03
4470	42	-1	1790	2019-09-27 23:23:15.728625+03
4471	18	-1	910	2019-09-27 23:32:03.069442+03
4472	32	-1	710	2019-09-27 23:55:20.524768+03
4473	34	-1	1550	2019-09-28 00:03:58.71822+03
4474	46	-1	1270	2019-09-28 00:13:19.060645+03
4475	3	-1	660	2019-09-28 00:58:59.915778+03
4476	38	-2	1100	2019-09-28 01:19:47.946645+03
4477	29	-1	1940	2019-09-28 01:30:02.229928+03
4478	86	-1	910	2019-09-28 01:43:38.19768+03
4479	57	-1	1900	2019-09-28 01:45:54.131443+03
4480	84	-1	2700	2019-09-28 02:04:28.708473+03
4481	13	-2	460	2019-09-28 02:06:15.636904+03
4482	60	-1	2700	2019-09-28 02:40:14.467269+03
4483	25	-1	1100	2019-09-28 02:51:34.568951+03
4484	88	-1	1270	2019-09-28 03:15:16.337258+03
4485	7	-2	810	2019-09-28 03:55:46.590045+03
4486	29	-1	1940	2019-09-28 04:17:09.387886+03
4487	88	-1	1270	2019-09-28 05:14:53.682448+03
4488	74	-1	1010	2019-09-28 05:25:39.656937+03
4489	35	-1	670	2019-09-28 05:33:59.088577+03
4490	75	-1	830	2019-09-28 06:19:01.989919+03
4491	74	-2	1010	2019-09-28 06:19:38.265885+03
4492	64	-2	970	2019-09-28 06:24:04.233844+03
4493	33	-1	900	2019-09-28 06:36:13.758979+03
4494	65	-1	490	2019-09-28 06:53:14.000913+03
4495	76	-1	1070	2019-09-28 07:10:51.955257+03
4496	57	-1	1900	2019-09-28 07:20:02.223013+03
4497	41	24	419	2019-09-28 07:24:58.402136+03
4498	42	-2	1790	2019-09-28 08:05:51.884145+03
4499	60	-1	2700	2019-09-28 09:37:54.506988+03
4500	31	-1	1190	2019-09-28 10:11:56.586688+03
4501	63	-2	1780	2019-09-28 10:20:23.635565+03
4502	52	-1	1090	2019-09-28 10:36:33.814258+03
4503	71	-2	1030	2019-09-28 10:36:53.670413+03
4504	17	-1	1500	2019-09-28 10:40:58.337459+03
4505	28	-1	1860	2019-09-28 10:46:25.745137+03
4506	52	-1	1090	2019-09-28 10:57:21.211463+03
4507	33	-1	900	2019-09-28 11:07:43.204432+03
4508	80	-1	1120	2019-09-28 11:19:24.545799+03
4509	42	-2	1790	2019-09-28 11:28:07.967853+03
4510	94	-2	1230	2019-09-28 11:42:53.007524+03
4511	9	-1	2090	2019-09-28 12:05:46.17801+03
4512	34	-2	1550	2019-09-28 12:06:24.457+03
4513	78	-2	900	2019-09-28 12:10:02.522928+03
4514	9	-1	2090	2019-09-28 12:12:47.853416+03
4515	73	-1	960	2019-09-28 12:23:11.643659+03
4516	6	-1	980	2019-09-28 12:34:38.566228+03
4517	75	29	438	2019-09-28 12:51:32.679297+03
4518	74	-2	1010	2019-09-28 13:03:30.248168+03
4519	46	-1	1270	2019-09-28 13:06:43.553863+03
4520	79	-1	550	2019-09-28 13:12:57.195354+03
4521	95	-1	480	2019-09-28 13:23:36.087917+03
4522	57	-1	1900	2019-09-28 13:36:10.980443+03
4523	6	-1	980	2019-09-28 13:53:55.587184+03
4524	31	-1	1190	2019-09-28 14:04:01.815116+03
4525	24	-1	950	2019-09-28 14:09:29.394344+03
4526	30	-2	1140	2019-09-28 14:18:28.749391+03
4527	44	-2	500	2019-09-28 14:40:58.608423+03
4528	40	-1	1430	2019-09-28 14:46:28.122827+03
4529	28	-1	1860	2019-09-28 15:22:48.225169+03
4530	30	-1	1140	2019-09-28 15:29:28.182974+03
4531	32	-1	710	2019-09-28 15:40:34.717312+03
4532	26	-1	390	2019-09-28 16:01:32.78374+03
4533	30	-1	1140	2019-09-28 16:03:28.39106+03
4534	84	-2	2700	2019-09-28 16:36:43.930829+03
4535	4	-1	1420	2019-09-28 17:14:50.020735+03
4536	37	-1	1290	2019-09-28 17:43:30.863414+03
4537	88	-1	1270	2019-09-28 18:03:40.793942+03
4538	75	-1	830	2019-09-28 18:19:18.363659+03
4539	17	-1	1500	2019-09-28 18:24:50.087621+03
4540	5	-2	1620	2019-09-28 18:41:17.138567+03
4541	28	-1	1860	2019-09-28 18:42:55.089063+03
4542	50	22	613	2019-09-28 18:48:38.967314+03
4543	22	-1	1070	2019-09-28 18:57:49.481372+03
4544	13	-1	460	2019-09-28 19:00:20.434177+03
4545	32	-1	710	2019-09-28 19:44:47.654348+03
4546	86	-1	910	2019-09-28 20:15:16.495196+03
4547	4	-1	1420	2019-09-28 20:18:43.754655+03
4548	49	-1	970	2019-09-28 20:41:28.300724+03
4549	5	-1	1620	2019-09-28 21:15:58.907507+03
4550	39	-1	910	2019-09-28 21:57:50.879459+03
4551	44	-1	500	2019-09-28 22:10:53.04954+03
4552	71	-1	1030	2019-09-28 22:15:49.446197+03
4553	6	-1	980	2019-09-28 22:30:18.242997+03
4554	31	-1	1190	2019-09-28 22:33:46.667511+03
4555	84	-1	2700	2019-09-28 22:33:54.543749+03
4556	4	-2	1420	2019-09-28 22:43:15.331468+03
4557	67	-1	350	2019-09-28 23:15:46.390387+03
4558	4	-2	1420	2019-09-28 23:54:30.932464+03
4559	91	-1	1620	2019-09-29 00:07:17.480929+03
4560	92	-1	630	2019-09-29 00:11:53.541607+03
4561	77	-1	640	2019-09-29 00:41:37.279959+03
4562	74	-1	1010	2019-09-29 00:43:24.014113+03
4563	67	-1	350	2019-09-29 01:57:33.863047+03
4564	93	-1	1620	2019-09-29 02:02:48.687802+03
4565	4	-1	1420	2019-09-29 02:09:12.044513+03
4566	4	-1	1420	2019-09-29 03:07:50.090978+03
4567	96	31	780	2019-09-29 03:14:51.32651+03
4568	37	33	555	2019-09-29 04:01:44.003414+03
4569	30	-1	1140	2019-09-29 04:18:00.320972+03
4570	91	27	659	2019-09-29 04:22:19.839543+03
4571	26	-1	390	2019-09-29 04:29:33.538214+03
4572	71	-1	1030	2019-09-29 04:37:06.297656+03
4573	74	-1	1010	2019-09-29 04:39:14.513305+03
4574	94	-1	1230	2019-09-29 04:53:13.07461+03
4575	3	-1	660	2019-09-29 05:09:19.311136+03
4576	39	-1	910	2019-09-29 05:12:34.178741+03
4577	89	-1	1420	2019-09-29 05:58:40.540832+03
4578	11	-1	830	2019-09-29 06:15:13.546468+03
4579	73	-1	960	2019-09-29 06:20:41.11505+03
4580	20	-2	830	2019-09-29 06:24:57.737912+03
4581	42	-1	1790	2019-09-29 06:34:29.010179+03
4582	39	-1	910	2019-09-29 07:19:37.862453+03
4583	70	-1	760	2019-09-29 07:40:36.049318+03
4584	80	-1	1120	2019-09-29 07:47:04.484277+03
4585	60	-1	2700	2019-09-29 07:55:30.006571+03
4586	86	-1	910	2019-09-29 08:12:52.422865+03
4587	41	-1	830	2019-09-29 08:20:34.185238+03
4588	42	-1	1790	2019-09-29 08:26:25.283192+03
4589	63	-1	1780	2019-09-29 08:53:57.80396+03
4590	72	-1	620	2019-09-29 09:31:21.843771+03
4591	71	-1	1030	2019-09-29 09:33:22.992803+03
4592	45	-1	1590	2019-09-29 09:55:16.625232+03
4593	42	-1	1790	2019-09-29 09:57:10.551136+03
4594	14	-1	1350	2019-09-29 09:57:14.092585+03
4595	64	-1	970	2019-09-29 10:07:51.698953+03
4596	85	-1	730	2019-09-29 10:17:37.334475+03
4597	59	-1	1030	2019-09-29 10:39:39.040389+03
4598	35	-1	670	2019-09-29 11:21:02.081074+03
4599	94	-2	1230	2019-09-29 11:42:56.743117+03
4600	70	-1	760	2019-09-29 12:17:22.614899+03
4601	1	-1	640	2019-09-29 12:21:26.413681+03
4602	12	-1	1650	2019-09-29 12:26:17.973541+03
4603	66	-1	690	2019-09-29 12:38:54.754295+03
4604	31	-1	1190	2019-09-29 12:44:50.95668+03
4605	6	-2	980	2019-09-29 12:49:52.690322+03
4606	28	-1	1860	2019-09-29 12:52:46.71089+03
4607	34	-1	1550	2019-09-29 12:59:12.567518+03
4608	93	-1	1620	2019-09-29 14:05:40.639736+03
4609	82	-1	560	2019-09-29 14:06:36.511157+03
4610	6	-1	980	2019-09-29 14:17:04.350132+03
4611	78	-1	900	2019-09-29 14:19:06.903516+03
4612	59	-1	1030	2019-09-29 15:23:34.09163+03
4613	5	-1	1620	2019-09-29 16:05:09.172778+03
4614	18	-1	910	2019-09-29 16:24:16.447646+03
4615	83	-1	1230	2019-09-29 16:48:27.632214+03
4616	22	-1	1070	2019-09-29 16:49:34.832483+03
4617	86	-1	910	2019-09-29 17:01:27.954514+03
4618	7	-1	810	2019-09-29 17:02:40.652941+03
4619	10	-1	2080	2019-09-29 17:04:50.198894+03
4620	92	-1	630	2019-09-29 17:08:25.445636+03
4621	25	-1	1100	2019-09-29 17:17:55.260275+03
4622	38	-1	1100	2019-09-29 17:34:56.97368+03
4623	33	-1	900	2019-09-29 17:47:55.978904+03
4624	83	-1	1230	2019-09-29 18:03:44.803779+03
4625	68	20	267	2019-09-29 18:11:22.511403+03
4626	56	-1	2460	2019-09-29 18:15:08.931808+03
4627	40	-1	1430	2019-09-29 18:22:28.34788+03
4628	87	-1	2320	2019-09-29 18:29:18.490717+03
4629	70	-2	760	2019-09-29 18:48:09.225738+03
4630	12	-2	1650	2019-09-29 19:11:55.984325+03
4631	42	-1	1790	2019-09-29 19:58:09.60741+03
4632	60	-1	2700	2019-09-29 20:19:32.583982+03
4633	6	-1	980	2019-09-29 20:23:52.580265+03
4634	96	-1	1570	2019-09-29 20:27:21.955268+03
4635	53	-1	3120	2019-09-29 20:40:22.118533+03
4636	61	-1	1510	2019-09-29 21:08:11.645735+03
4637	36	-1	630	2019-09-29 21:09:34.827131+03
4638	93	-1	1620	2019-09-29 21:35:28.966582+03
4639	34	-2	1550	2019-09-29 22:26:54.526029+03
4640	71	-1	1030	2019-09-29 22:35:00.421713+03
4641	65	-1	490	2019-09-29 22:51:05.997901+03
4642	70	-1	760	2019-09-29 23:23:05.281289+03
4643	57	-1	1900	2019-09-29 23:33:28.680454+03
4644	87	-1	2320	2019-09-30 01:01:01.861537+03
4645	87	-1	2320	2019-09-30 01:15:38.930894+03
4646	65	-1	490	2019-09-30 01:26:01.096645+03
4647	9	20	1094	2019-09-30 01:29:58.385209+03
4648	86	-1	910	2019-09-30 01:29:59.078091+03
4649	95	-1	480	2019-09-30 02:12:58.247684+03
4650	42	-1	1790	2019-09-30 02:15:03.060103+03
4651	93	-1	1620	2019-09-30 02:24:23.654798+03
4652	29	-1	1940	2019-09-30 02:42:14.441197+03
4653	44	-1	500	2019-09-30 03:00:40.31244+03
4654	94	-1	1230	2019-09-30 03:03:46.133822+03
4655	64	-1	970	2019-09-30 03:08:34.287037+03
4656	86	-1	910	2019-09-30 03:28:59.273175+03
4657	12	-1	1650	2019-09-30 03:57:37.879201+03
4658	87	-1	2320	2019-09-30 04:08:24.994922+03
4659	17	-1	1500	2019-09-30 04:17:04.028367+03
4660	82	-1	560	2019-09-30 04:27:32.773977+03
4661	32	-1	710	2019-09-30 04:44:29.223538+03
4662	52	-2	1090	2019-09-30 04:53:24.134255+03
4663	58	27	1677	2019-09-30 05:10:02.219959+03
4664	58	-1	2830	2019-09-30 05:27:21.624228+03
4665	1	28	290	2019-09-30 05:37:43.932445+03
4666	90	-1	1780	2019-09-30 06:04:32.482898+03
4667	19	-1	1220	2019-09-30 06:04:42.958296+03
4668	78	-1	900	2019-09-30 06:09:12.73548+03
4669	89	-1	1420	2019-09-30 06:32:33.899985+03
4670	2	-2	470	2019-09-30 06:33:31.491302+03
4671	46	-1	1270	2019-09-30 06:34:48.224446+03
4672	56	-1	2460	2019-09-30 06:56:16.427012+03
4673	45	-1	1590	2019-09-30 07:07:36.497873+03
4674	33	-2	900	2019-09-30 07:14:22.365078+03
4675	1	-1	640	2019-09-30 07:24:27.883427+03
4676	54	-1	3470	2019-09-30 08:04:20.667191+03
4677	68	-2	490	2019-09-30 08:18:45.665383+03
4678	6	-1	980	2019-09-30 08:19:33.176569+03
4679	19	28	673	2019-09-30 08:31:23.980539+03
4680	87	-1	2320	2019-09-30 08:50:30.349316+03
4681	12	-1	1650	2019-09-30 09:10:16.742787+03
4682	25	-1	1100	2019-09-30 09:52:01.695418+03
4683	8	-1	1920	2019-09-30 10:05:55.993175+03
4684	35	-1	670	2019-09-30 10:10:44.118737+03
4685	69	-1	1100	2019-09-30 10:36:29.765009+03
4686	18	-1	910	2019-09-30 10:41:29.020282+03
4687	54	-1	3470	2019-09-30 10:59:50.476066+03
4688	46	-1	1270	2019-09-30 11:21:06.461064+03
4689	80	29	579	2019-09-30 11:23:20.465621+03
4690	54	-2	3470	2019-09-30 11:26:31.534336+03
4691	4	-1	1420	2019-09-30 12:04:09.674821+03
4692	68	-1	490	2019-09-30 12:04:30.746952+03
4693	35	-1	670	2019-09-30 12:10:26.116454+03
4694	51	-1	1310	2019-09-30 12:15:45.971371+03
4695	67	-1	350	2019-09-30 13:16:03.384202+03
4696	77	-1	640	2019-09-30 13:29:22.584041+03
4697	17	-1	1500	2019-09-30 13:36:54.374002+03
4698	96	-2	1570	2019-09-30 13:38:13.560735+03
4699	13	-1	460	2019-09-30 14:31:17.061997+03
4700	7	-1	810	2019-09-30 14:44:18.501193+03
4701	13	-1	460	2019-09-30 15:02:28.663189+03
4702	55	-1	3480	2019-09-30 15:03:03.032943+03
4703	20	-1	830	2019-09-30 15:11:34.794921+03
4704	49	-1	970	2019-09-30 15:14:42.013465+03
4705	40	-2	1430	2019-09-30 15:32:53.825624+03
4706	20	-3	830	2019-09-30 16:31:12.451261+03
4707	21	-2	960	2019-09-30 16:35:29.907546+03
4708	9	-1	2090	2019-09-30 16:41:07.716757+03
4709	34	-2	1550	2019-09-30 16:49:12.627028+03
4710	91	-1	1620	2019-09-30 16:52:32.117149+03
4711	45	-1	1590	2019-09-30 16:55:40.401794+03
4712	96	-1	1570	2019-09-30 16:57:34.503922+03
4713	53	-1	3120	2019-09-30 16:58:04.413614+03
4714	3	17	347	2019-09-30 17:00:28.742752+03
4715	18	-1	910	2019-09-30 17:08:23.816116+03
4716	35	-1	670	2019-09-30 17:21:48.630506+03
4717	35	32	287	2019-09-30 17:26:47.345157+03
4718	35	-1	670	2019-09-30 17:51:23.366964+03
4719	92	-1	630	2019-09-30 17:59:18.052222+03
4720	33	-1	900	2019-09-30 18:11:37.439967+03
4721	2	-1	470	2019-09-30 18:14:26.515307+03
4722	13	-2	460	2019-09-30 18:18:07.495937+03
4723	31	-1	1190	2019-09-30 18:51:02.430981+03
4724	87	-1	2320	2019-09-30 18:53:49.6649+03
4725	30	-1	1140	2019-09-30 19:17:47.73581+03
4726	29	-1	1940	2019-09-30 19:20:28.257838+03
4727	39	-1	910	2019-09-30 19:34:58.923985+03
4728	34	-1	1550	2019-09-30 20:14:28.342647+03
4729	28	-1	1860	2019-09-30 20:18:23.303125+03
4730	26	-1	390	2019-09-30 20:32:02.871442+03
4731	12	-1	1650	2019-09-30 20:35:09.420479+03
4732	37	-2	1290	2019-09-30 20:36:56.360853+03
4733	88	-1	1270	2019-09-30 20:51:43.264637+03
4734	32	-1	710	2019-09-30 21:23:13.013963+03
4735	69	-1	1100	2019-09-30 21:31:17.893969+03
4736	91	-1	1620	2019-09-30 21:36:58.424922+03
4737	14	-1	1350	2019-09-30 21:48:28.695571+03
4738	4	53	828	2019-09-30 21:54:08.25415+03
4739	1	-1	640	2019-09-30 22:03:30.172479+03
4740	17	-1	1500	2019-09-30 22:03:48.246098+03
4741	39	33	375	2019-09-30 22:11:09.027508+03
4742	44	-1	500	2019-09-30 22:23:23.355564+03
4743	71	-2	1030	2019-09-30 22:41:55.11287+03
4744	50	-1	1140	2019-09-30 23:38:50.745659+03
4745	96	-1	1570	2019-09-30 23:44:42.400272+03
4746	46	-2	1270	2019-09-30 23:45:49.436729+03
4747	14	-1	1350	2019-09-30 23:51:05.176265+03
4748	24	-2	950	2019-09-30 23:54:08.023782+03
4749	68	-1	490	2019-09-30 23:56:04.597991+03
4750	78	-1	900	2019-10-01 00:00:02.838351+03
4751	17	-1	1500	2019-10-01 00:35:03.488442+03
4752	73	23	520	2019-10-01 01:26:31.07446+03
4753	42	-1	1790	2019-10-01 02:13:29.331353+03
4754	64	-1	970	2019-10-01 02:51:13.250087+03
4755	94	-1	1230	2019-10-01 02:51:25.899409+03
4756	69	-1	1100	2019-10-01 02:58:42.674373+03
4757	83	-1	1230	2019-10-01 03:27:41.363469+03
4758	46	-2	1270	2019-10-01 04:19:21.247644+03
4759	1	-1	640	2019-10-01 04:26:05.501807+03
4760	41	-3	830	2019-10-01 04:27:59.314622+03
4761	75	-1	830	2019-10-01 04:59:31.272846+03
4762	18	-1	910	2019-10-01 06:06:37.621854+03
4763	93	-1	1620	2019-10-01 06:08:13.156674+03
4764	4	-1	1420	2019-10-01 06:12:23.464716+03
4765	57	-1	1900	2019-10-01 06:42:16.709391+03
4766	29	-1	1940	2019-10-01 06:45:36.195157+03
4767	14	-1	1350	2019-10-01 06:46:40.143474+03
4768	71	-1	1030	2019-10-01 06:49:29.177106+03
4769	96	-2	1570	2019-10-01 06:51:23.832572+03
4770	3	-2	660	2019-10-01 07:18:47.151431+03
4771	18	-1	910	2019-10-01 07:31:19.097072+03
4772	22	-1	1070	2019-10-01 07:44:49.456032+03
4773	25	-2	1100	2019-10-01 07:55:30.937854+03
4774	89	-1	1420	2019-10-01 07:59:52.077804+03
4775	40	-1	1430	2019-10-01 08:01:53.7781+03
4776	64	-1	970	2019-10-01 08:06:43.628784+03
4777	78	-1	900	2019-10-01 09:28:51.092166+03
4778	17	-1	1500	2019-10-01 09:37:30.021687+03
4779	65	-2	490	2019-10-01 09:41:24.666447+03
4780	37	-1	1290	2019-10-01 09:53:19.841771+03
4781	46	-1	1270	2019-10-01 09:53:23.078032+03
4782	74	-1	1010	2019-10-01 09:57:58.697158+03
4783	48	-1	640	2019-10-01 10:06:14.784911+03
4784	37	-1	1290	2019-10-01 10:16:18.325232+03
4785	64	-1	970	2019-10-01 10:43:58.068295+03
4786	9	-1	2090	2019-10-01 10:54:33.357767+03
4787	85	-2	730	2019-10-01 10:59:12.569473+03
4788	23	-1	4390	2019-10-01 11:05:25.923975+03
4789	20	-1	830	2019-10-01 11:16:00.516282+03
4790	95	-1	480	2019-10-01 11:41:38.6185+03
4791	94	-1	1230	2019-10-01 11:44:02.507194+03
4792	18	-1	910	2019-10-01 11:53:10.690815+03
4793	71	-1	1030	2019-10-01 11:59:21.066171+03
4794	53	-1	3120	2019-10-01 12:07:51.489915+03
4795	66	-2	690	2019-10-01 12:31:23.681102+03
4796	91	-1	1620	2019-10-01 12:57:31.85694+03
4797	34	-1	1550	2019-10-01 13:05:53.083432+03
4798	26	-1	390	2019-10-01 13:23:32.494861+03
4799	74	-1	1010	2019-10-01 13:26:26.453058+03
4800	81	-1	1620	2019-10-01 13:36:12.969141+03
4801	21	-2	960	2019-10-01 14:05:24.119134+03
4802	51	-1	1310	2019-10-01 14:17:59.134517+03
4803	55	-1	3480	2019-10-01 14:48:01.794827+03
4804	31	-1	1190	2019-10-01 15:00:41.980398+03
4805	84	-1	2700	2019-10-01 15:48:26.149876+03
4806	72	-1	620	2019-10-01 16:12:56.129981+03
4807	35	-1	670	2019-10-01 16:38:41.743991+03
4808	77	-1	640	2019-10-01 16:45:33.317991+03
4809	28	-1	1860	2019-10-01 17:12:12.140875+03
4810	59	-2	1030	2019-10-01 17:43:13.918233+03
4811	86	-2	910	2019-10-01 17:45:59.730888+03
4812	41	-1	830	2019-10-01 18:15:55.468282+03
4813	47	-1	1480	2019-10-01 18:17:23.976822+03
4814	10	-1	2080	2019-10-01 18:28:42.54975+03
4815	37	-1	1290	2019-10-01 18:42:19.580736+03
4816	33	-1	900	2019-10-01 18:52:14.690128+03
4817	93	-2	1620	2019-10-01 18:55:02.557495+03
4818	52	-1	1090	2019-10-01 19:12:36.602661+03
4819	16	-1	1380	2019-10-01 19:27:21.350301+03
4820	47	-1	1480	2019-10-01 19:38:41.035286+03
4821	86	-2	910	2019-10-01 19:43:41.005522+03
4822	15	-2	2830	2019-10-01 20:00:33.38282+03
4823	53	-1	3120	2019-10-01 20:37:29.980711+03
4824	18	-1	910	2019-10-01 20:55:21.17347+03
4825	46	-1	1270	2019-10-01 21:17:14.980929+03
4826	56	-2	2460	2019-10-01 21:54:57.123937+03
4827	88	-1	1270	2019-10-01 21:55:30.61318+03
4828	18	-1	910	2019-10-01 22:21:11.098784+03
4829	95	-1	480	2019-10-01 22:45:13.555098+03
4830	28	-1	1860	2019-10-01 23:06:45.169561+03
4831	6	-2	980	2019-10-01 23:15:59.034968+03
4832	51	-1	1310	2019-10-01 23:22:33.669194+03
4833	6	-1	980	2019-10-01 23:36:21.133601+03
4834	77	-2	640	2019-10-01 23:38:19.183037+03
4835	67	-1	350	2019-10-02 00:01:36.844322+03
4836	79	-3	550	2019-10-02 00:33:29.142687+03
4837	4	-1	1420	2019-10-02 01:39:49.582394+03
4838	70	-1	760	2019-10-02 02:08:23.648082+03
4839	67	-1	350	2019-10-02 02:41:01.655961+03
4840	30	-1	1140	2019-10-02 02:48:58.814308+03
4841	10	-1	2080	2019-10-02 03:05:30.244007+03
4842	8	-1	1920	2019-10-02 03:26:08.8623+03
4843	36	-2	630	2019-10-02 03:41:27.188015+03
4844	54	-1	3470	2019-10-02 04:05:52.267002+03
4845	94	-1	1230	2019-10-02 04:10:19.712224+03
4846	70	-1	760	2019-10-02 04:17:00.431575+03
4847	4	-1	1420	2019-10-02 04:26:40.965854+03
4848	30	-1	1140	2019-10-02 04:34:30.885351+03
4849	41	-2	830	2019-10-02 04:48:43.622088+03
4850	47	-1	1480	2019-10-02 04:54:06.949408+03
4851	37	-2	1290	2019-10-02 05:09:55.104415+03
4852	30	-1	1140	2019-10-02 05:19:03.715646+03
4853	80	-1	1120	2019-10-02 05:24:57.272141+03
4854	34	-1	1550	2019-10-02 05:26:49.572994+03
4855	46	-1	1270	2019-10-02 05:33:27.706467+03
4856	47	-1	1480	2019-10-02 05:48:36.916043+03
4857	94	-1	1230	2019-10-02 06:37:54.268309+03
4858	91	-1	1620	2019-10-02 07:21:51.914809+03
4859	59	-1	1030	2019-10-02 07:41:43.326686+03
4860	47	-2	1480	2019-10-02 08:04:11.989039+03
4861	36	-2	630	2019-10-02 08:22:54.258247+03
4862	47	-2	1480	2019-10-02 08:25:14.644389+03
4863	76	-1	1070	2019-10-02 08:29:46.319363+03
4864	18	-1	910	2019-10-02 09:44:37.309225+03
4865	63	-1	1780	2019-10-02 09:47:45.941213+03
4866	29	-1	1940	2019-10-02 09:58:11.451736+03
4867	37	-1	1290	2019-10-02 10:25:32.765344+03
4868	90	-1	1780	2019-10-02 11:02:40.331546+03
4869	91	-1	1620	2019-10-02 11:12:11.646259+03
4870	7	-2	810	2019-10-02 11:29:14.801512+03
4871	38	-1	1100	2019-10-02 11:56:26.959076+03
4872	80	-1	1120	2019-10-02 12:06:07.540159+03
4873	42	-1	1790	2019-10-02 12:20:27.152355+03
4874	94	-2	1230	2019-10-02 12:53:47.972059+03
4875	69	-1	1100	2019-10-02 12:54:48.286338+03
4876	15	-2	2830	2019-10-02 12:55:51.142218+03
4877	8	-1	1920	2019-10-02 12:56:31.852769+03
4878	55	-1	3480	2019-10-02 13:09:56.267194+03
4879	56	-1	2460	2019-10-02 13:41:28.573493+03
4880	60	-1	2700	2019-10-02 14:30:32.396304+03
4881	48	-1	640	2019-10-02 14:40:06.003958+03
4882	30	-2	1140	2019-10-02 14:53:14.353197+03
4883	29	-1	1940	2019-10-02 15:04:35.332764+03
4884	46	-1	1270	2019-10-02 15:06:07.487057+03
4885	18	-2	910	2019-10-02 15:06:44.933026+03
4886	94	-1	1230	2019-10-02 15:08:38.666388+03
4887	61	-1	1510	2019-10-02 15:18:25.503021+03
4888	13	-1	460	2019-10-02 15:31:11.123359+03
4889	50	-2	1140	2019-10-02 15:43:42.855908+03
4890	27	-1	880	2019-10-02 15:56:30.836925+03
4891	93	-1	1620	2019-10-02 16:44:58.492202+03
4892	1	-1	640	2019-10-02 16:48:37.82381+03
4893	83	-1	1230	2019-10-02 17:19:37.781175+03
4894	75	-2	830	2019-10-02 17:28:48.174487+03
4895	79	-1	550	2019-10-02 17:52:08.008101+03
4896	46	-1	1270	2019-10-02 17:53:10.316121+03
4897	54	-2	3470	2019-10-02 18:03:46.174917+03
4898	41	-1	830	2019-10-02 18:19:56.432118+03
4899	46	-1	1270	2019-10-02 19:43:46.585957+03
4900	63	-2	1780	2019-10-02 19:47:28.467172+03
4901	76	-1	1070	2019-10-02 19:59:10.822487+03
4902	89	-2	1420	2019-10-02 20:42:23.314725+03
4903	48	-1	640	2019-10-02 21:04:01.824591+03
4904	45	-1	1590	2019-10-02 21:25:45.491329+03
4905	14	-2	1350	2019-10-02 21:57:20.131653+03
4906	69	-1	1100	2019-10-02 21:57:29.232744+03
4907	22	-2	1070	2019-10-02 22:09:10.316547+03
4908	4	-1	1420	2019-10-02 22:10:39.534241+03
4909	14	-2	1350	2019-10-02 22:14:57.762631+03
4910	81	-1	1620	2019-10-02 22:15:42.211005+03
4911	58	-2	2830	2019-10-02 22:56:22.931395+03
4912	6	-2	980	2019-10-02 23:17:03.171034+03
4913	76	-1	1070	2019-10-02 23:41:37.39279+03
4914	71	-1	1030	2019-10-02 23:43:03.012645+03
4915	20	-1	830	2019-10-02 23:51:19.624+03
4916	19	-2	1220	2019-10-03 00:12:42.750415+03
4917	77	-1	640	2019-10-03 00:12:46.977112+03
4918	6	-1	980	2019-10-03 00:26:30.583081+03
4919	46	-1	1270	2019-10-03 01:13:11.531077+03
4920	46	-1	1270	2019-10-03 01:23:39.48502+03
4921	92	-1	630	2019-10-03 01:23:55.788957+03
4922	5	-1	1620	2019-10-03 01:27:04.637568+03
4923	32	-1	710	2019-10-03 01:28:21.545153+03
4924	24	-1	950	2019-10-03 01:52:06.090448+03
4925	37	-1	1290	2019-10-03 01:54:20.152557+03
4926	76	-1	1070	2019-10-03 01:55:12.82334+03
4927	96	-1	1570	2019-10-03 02:10:35.570099+03
4928	1	-1	640	2019-10-03 02:44:02.49223+03
4929	28	-1	1860	2019-10-03 03:21:03.562463+03
4930	60	-1	2700	2019-10-03 03:27:38.039497+03
4931	95	-1	480	2019-10-03 03:51:30.057577+03
4932	13	-2	460	2019-10-03 04:18:57.432823+03
4933	60	-2	2700	2019-10-03 04:20:36.621307+03
4934	43	-2	380	2019-10-03 04:34:02.715637+03
4935	32	-1	710	2019-10-03 04:50:12.747798+03
4936	77	-1	640	2019-10-03 05:05:42.078913+03
4937	60	-1	2700	2019-10-03 05:21:47.919746+03
4938	19	-1	1220	2019-10-03 05:45:25.407006+03
4939	6	-1	980	2019-10-03 06:09:15.832763+03
4940	96	-1	1570	2019-10-03 06:24:51.078074+03
4941	35	-1	670	2019-10-03 06:25:56.114764+03
4942	88	-1	1270	2019-10-03 06:46:05.124662+03
4943	6	-2	980	2019-10-03 06:56:58.375857+03
4944	27	-1	880	2019-10-03 07:11:11.619467+03
4945	1	-1	640	2019-10-03 07:14:35.761555+03
4946	26	-1	390	2019-10-03 07:36:16.921043+03
4947	54	-1	3470	2019-10-03 07:39:15.451756+03
4948	75	-1	830	2019-10-03 07:40:26.835392+03
4949	1	-1	640	2019-10-03 07:41:52.891222+03
4950	48	-1	640	2019-10-03 07:53:06.085956+03
4951	59	-1	1030	2019-10-03 08:12:35.592338+03
4952	78	-2	900	2019-10-03 09:30:04.405993+03
4953	40	-1	1430	2019-10-03 09:52:31.972171+03
4954	17	-1	1500	2019-10-03 10:01:48.527212+03
4955	38	-1	1100	2019-10-03 10:12:16.112416+03
4956	44	-1	500	2019-10-03 10:37:08.366953+03
4957	5	-2	1620	2019-10-03 10:41:53.405401+03
4958	90	-2	1780	2019-10-03 11:46:18.478419+03
4959	25	-1	1100	2019-10-03 11:53:43.121774+03
4960	84	-1	2700	2019-10-03 11:56:06.847712+03
4961	88	-1	1270	2019-10-03 12:28:19.215155+03
4962	44	-1	500	2019-10-03 12:33:08.021155+03
4963	12	-1	1650	2019-10-03 13:13:26.996199+03
4964	86	-1	910	2019-10-03 13:30:17.61715+03
4965	19	-1	1220	2019-10-03 13:41:57.534338+03
4966	38	-1	1100	2019-10-03 13:44:44.181434+03
4967	7	-1	810	2019-10-03 13:54:01.535419+03
4968	61	19	905	2019-10-03 14:39:16.21284+03
4969	63	-2	1780	2019-10-03 15:36:01.128772+03
4970	21	-2	960	2019-10-03 15:59:26.691671+03
4971	8	-1	1920	2019-10-03 16:23:02.049781+03
4972	1	-1	640	2019-10-03 16:27:51.330266+03
4973	3	-1	660	2019-10-03 16:38:34.850903+03
4974	93	-2	1620	2019-10-03 17:35:52.774465+03
4975	27	-1	880	2019-10-03 17:40:28.603019+03
4976	41	-1	830	2019-10-03 17:54:51.948296+03
4977	14	-1	1350	2019-10-03 18:13:40.377355+03
4978	48	-1	640	2019-10-03 18:13:44.467108+03
4979	82	-1	560	2019-10-03 18:18:03.034391+03
4980	44	-1	500	2019-10-03 19:04:39.03668+03
4981	84	-2	2700	2019-10-03 19:19:36.549865+03
4982	73	-1	960	2019-10-03 20:45:34.779907+03
4983	29	-1	1940	2019-10-03 20:48:08.045043+03
4984	53	-1	3120	2019-10-03 20:51:35.722696+03
4985	25	-1	1100	2019-10-03 20:55:07.306579+03
4986	37	-2	1290	2019-10-03 20:58:55.005838+03
4987	87	-1	2320	2019-10-03 21:18:23.003186+03
4988	82	-1	560	2019-10-03 21:23:19.238161+03
4989	65	-1	490	2019-10-03 21:29:05.544617+03
4990	83	-1	1230	2019-10-03 21:47:19.85511+03
4991	38	-1	1100	2019-10-03 21:50:54.193536+03
4992	78	-1	900	2019-10-03 21:57:41.175664+03
4993	64	-1	970	2019-10-03 22:00:35.612191+03
4994	77	-1	640	2019-10-03 22:28:37.346012+03
4995	20	-1	830	2019-10-03 22:34:07.421432+03
4996	84	-2	2700	2019-10-03 22:51:17.480198+03
4997	57	-1	1900	2019-10-03 22:57:12.421204+03
4998	89	-1	1420	2019-10-03 23:27:04.12538+03
4999	96	-1	1570	2019-10-03 23:30:34.813011+03
5000	96	-1	1570	2019-10-03 23:56:34.146469+03
5001	87	-1	2320	2019-10-04 00:05:30.42077+03
5002	67	-1	350	2019-10-04 00:10:31.421924+03
5003	3	-1	660	2019-10-04 00:31:14.692977+03
5004	70	-1	760	2019-10-04 00:53:11.668294+03
5005	75	-1	830	2019-10-04 00:54:13.562773+03
5006	15	-1	2830	2019-10-04 01:14:21.505751+03
5007	57	-1	1900	2019-10-04 01:15:07.401212+03
5008	31	-1	1190	2019-10-04 01:18:56.826468+03
5009	16	-2	1380	2019-10-04 01:37:41.157671+03
5010	8	-1	1920	2019-10-04 01:48:01.817541+03
5011	26	-1	390	2019-10-04 01:59:19.891697+03
5012	30	-1	1140	2019-10-04 02:20:32.997416+03
5013	23	-2	4390	2019-10-04 02:37:22.468737+03
5014	11	-1	830	2019-10-04 02:58:43.138128+03
5015	64	-3	970	2019-10-04 03:01:07.649464+03
5016	6	-2	980	2019-10-04 03:14:49.060642+03
5017	86	-2	910	2019-10-04 03:35:04.292726+03
5018	58	-1	2830	2019-10-04 03:46:57.920035+03
5019	64	-1	970	2019-10-04 03:51:11.880285+03
5020	60	-1	2700	2019-10-04 04:10:46.002962+03
5021	32	-1	710	2019-10-04 04:22:27.394708+03
5022	10	-2	2080	2019-10-04 04:39:32.067462+03
5023	79	-2	550	2019-10-04 04:40:53.556165+03
5024	42	-1	1790	2019-10-04 04:43:38.613193+03
5025	10	-1	2080	2019-10-04 04:46:08.529561+03
5026	38	-1	1100	2019-10-04 04:55:22.412114+03
5027	51	-1	1310	2019-10-04 04:57:20.866039+03
5028	21	-1	960	2019-10-04 05:06:31.709915+03
5029	62	-1	1220	2019-10-04 05:21:12.846604+03
5030	21	-1	960	2019-10-04 05:44:21.273288+03
5031	86	-2	910	2019-10-04 05:54:15.053097+03
5032	93	-2	1620	2019-10-04 05:58:23.333971+03
5033	35	-1	670	2019-10-04 06:06:45.567966+03
5034	80	-1	1120	2019-10-04 06:07:55.185356+03
5035	35	-1	670	2019-10-04 06:21:02.195651+03
5036	65	22	246	2019-10-04 06:28:17.80868+03
5037	54	-1	3470	2019-10-04 06:31:52.233676+03
5038	76	-1	1070	2019-10-04 06:56:37.504593+03
5039	75	-1	830	2019-10-04 07:47:59.754928+03
5040	38	-1	1100	2019-10-04 08:00:53.099678+03
5041	55	-2	3480	2019-10-04 08:51:48.791689+03
5042	42	-1	1790	2019-10-04 08:58:25.462299+03
5043	67	-1	350	2019-10-04 09:41:54.053341+03
5044	53	-1	3120	2019-10-04 09:58:47.925384+03
5045	24	-2	950	2019-10-04 10:08:21.580666+03
5046	92	17	294	2019-10-04 10:24:41.387969+03
5047	58	-1	2830	2019-10-04 10:30:30.807284+03
5048	1	-1	640	2019-10-04 10:49:10.58116+03
5049	96	-1	1570	2019-10-04 11:31:43.165998+03
5050	48	-1	640	2019-10-04 11:41:10.481671+03
5051	33	-1	900	2019-10-04 11:55:24.792192+03
5052	89	-1	1420	2019-10-04 12:08:56.140568+03
5053	34	-2	1550	2019-10-04 12:27:18.452803+03
5054	91	-1	1620	2019-10-04 12:34:58.49894+03
5055	12	-2	1650	2019-10-04 12:42:54.323122+03
5056	12	-1	1650	2019-10-04 12:47:04.764485+03
5057	28	-1	1860	2019-10-04 12:54:20.026196+03
5058	76	-1	1070	2019-10-04 13:02:20.348671+03
5059	76	-1	1070	2019-10-04 13:36:19.605182+03
5060	93	-1	1620	2019-10-04 13:43:33.504557+03
5061	27	-1	880	2019-10-04 14:08:57.410049+03
5062	58	-2	2830	2019-10-04 14:47:26.273167+03
5063	81	-3	1620	2019-10-04 15:06:47.441562+03
5064	14	-2	1350	2019-10-04 15:09:05.65188+03
5065	35	-1	670	2019-10-04 15:48:56.185303+03
5066	53	-1	3120	2019-10-04 15:50:11.56129+03
5067	82	-2	560	2019-10-04 15:54:55.118292+03
5068	12	-1	1650	2019-10-04 16:03:13.630189+03
5069	24	-1	950	2019-10-04 16:06:14.753962+03
5070	7	-1	810	2019-10-04 16:08:29.965083+03
5071	41	-1	830	2019-10-04 16:10:06.481056+03
5072	26	-1	390	2019-10-04 16:18:43.835371+03
5073	20	42	422	2019-10-04 16:35:26.112554+03
5074	90	-1	1780	2019-10-04 16:42:55.716244+03
5075	14	-1	1350	2019-10-04 16:50:44.813775+03
5076	76	-1	1070	2019-10-04 17:04:14.448129+03
5077	87	-1	2320	2019-10-04 17:05:27.150616+03
5078	59	-2	1030	2019-10-04 17:28:32.528499+03
5079	70	-2	760	2019-10-04 17:39:42.061042+03
5080	47	-2	1480	2019-10-04 17:40:05.521431+03
5081	34	-1	1550	2019-10-04 18:05:27.273282+03
5082	70	-1	760	2019-10-04 18:05:36.753469+03
5083	75	-2	830	2019-10-04 18:09:00.178452+03
5084	51	-1	1310	2019-10-04 18:41:36.466476+03
5085	40	-1	1430	2019-10-04 18:41:58.920053+03
5086	87	-2	2320	2019-10-04 19:01:11.313757+03
5087	31	-1	1190	2019-10-04 19:02:06.743813+03
5088	29	-1	1940	2019-10-04 19:55:40.466215+03
5089	33	-1	900	2019-10-04 19:59:46.316241+03
5090	62	-2	1220	2019-10-04 20:30:18.571842+03
5091	40	-1	1430	2019-10-04 20:46:10.354157+03
5092	7	-1	810	2019-10-04 21:03:48.276709+03
5093	70	-2	760	2019-10-04 21:05:24.890678+03
5094	63	-1	1780	2019-10-04 21:23:41.320784+03
5095	87	-1	2320	2019-10-04 21:53:46.785685+03
5096	14	-1	1350	2019-10-04 23:09:54.690835+03
5097	50	-1	1140	2019-10-04 23:15:01.889717+03
5098	21	-1	960	2019-10-04 23:48:38.329767+03
5099	12	-1	1650	2019-10-04 23:54:35.409258+03
5100	18	-2	910	2019-10-04 23:55:53.429103+03
5101	64	-1	970	2019-10-04 23:55:56.268364+03
5102	95	-1	480	2019-10-05 00:49:49.62889+03
5103	3	-2	660	2019-10-05 00:58:35.802956+03
5104	63	-1	1780	2019-10-05 01:30:37.16319+03
5105	75	-1	830	2019-10-05 01:33:35.081764+03
5106	53	-1	3120	2019-10-05 01:36:58.908853+03
5107	40	-2	1430	2019-10-05 01:49:39.638958+03
5108	95	-1	480	2019-10-05 02:11:57.53417+03
5109	87	-2	2320	2019-10-05 02:19:57.444734+03
5110	70	-1	760	2019-10-05 02:21:06.161998+03
5111	71	-2	1030	2019-10-05 02:33:54.043692+03
5112	33	-1	900	2019-10-05 02:42:07.485532+03
5113	90	-1	1780	2019-10-05 02:56:25.95683+03
5114	53	-2	3120	2019-10-05 03:38:53.273141+03
5115	54	-1	3470	2019-10-05 03:41:22.466514+03
5116	70	-1	760	2019-10-05 03:58:31.663496+03
5117	75	-1	830	2019-10-05 04:33:00.353339+03
5118	37	-2	1290	2019-10-05 04:39:47.968419+03
5119	94	-1	1230	2019-10-05 05:22:33.242926+03
5120	63	-1	1780	2019-10-05 05:55:48.835529+03
5121	46	35	542	2019-10-05 06:32:39.630169+03
5122	52	-1	1090	2019-10-05 06:48:50.158298+03
5123	42	-1	1790	2019-10-05 07:43:28.936798+03
5124	84	-1	2700	2019-10-05 07:53:08.211688+03
5125	52	-1	1090	2019-10-05 07:53:22.383098+03
5126	5	-1	1620	2019-10-05 08:02:11.694328+03
5127	30	-1	1140	2019-10-05 08:19:37.680153+03
5128	7	29	354	2019-10-05 08:31:17.044395+03
5129	92	-1	630	2019-10-05 08:44:50.289159+03
5130	68	-1	490	2019-10-05 08:51:50.782826+03
5131	95	-1	480	2019-10-05 08:57:18.825634+03
5132	86	-1	910	2019-10-05 09:02:41.421107+03
5133	6	-1	980	2019-10-05 09:25:10.043394+03
5134	10	-2	2080	2019-10-05 09:25:34.512116+03
5135	52	26	513	2019-10-05 10:04:28.31017+03
5136	17	-1	1500	2019-10-05 10:16:09.413453+03
5137	25	-1	1100	2019-10-05 10:18:16.675575+03
5138	68	-1	490	2019-10-05 10:25:20.053979+03
5139	87	33	947	2019-10-05 10:47:16.77699+03
5140	40	-1	1430	2019-10-05 10:47:46.694248+03
5141	93	-1	1620	2019-10-05 10:58:43.715913+03
5142	46	-1	1270	2019-10-05 11:00:00.134181+03
5143	8	-1	1920	2019-10-05 11:12:51.753417+03
5144	42	-1	1790	2019-10-05 11:19:11.729052+03
5145	35	-1	670	2019-10-05 11:24:07.765035+03
5146	53	-1	3120	2019-10-05 12:06:33.892049+03
5147	18	-2	910	2019-10-05 12:30:13.489607+03
5148	68	-1	490	2019-10-05 12:41:01.679145+03
5149	56	-1	2460	2019-10-05 12:55:01.932053+03
5150	59	-2	1030	2019-10-05 13:07:10.808547+03
5151	89	-1	1420	2019-10-05 13:17:00.185501+03
5152	71	-1	1030	2019-10-05 13:27:39.76873+03
5153	31	-1	1190	2019-10-05 13:28:28.728449+03
5154	92	-1	630	2019-10-05 13:33:36.250316+03
5155	96	-1	1570	2019-10-05 13:47:19.913944+03
5156	33	-1	900	2019-10-05 13:55:11.779987+03
5157	54	-1	3470	2019-10-05 14:00:12.29831+03
5158	40	-1	1430	2019-10-05 14:00:28.584815+03
5159	93	-1	1620	2019-10-05 14:00:29.171453+03
5160	22	44	513	2019-10-05 14:15:53.287937+03
5161	54	-1	3470	2019-10-05 14:24:50.92777+03
5162	13	-1	460	2019-10-05 14:28:34.720605+03
5163	10	-2	2080	2019-10-05 14:30:43.748103+03
5164	5	-1	1620	2019-10-05 14:32:31.692496+03
5165	22	-1	1070	2019-10-05 14:48:00.522436+03
5166	8	-1	1920	2019-10-05 14:51:09.19308+03
5167	72	-1	620	2019-10-05 15:01:24.704408+03
5168	71	-1	1030	2019-10-05 15:09:24.3894+03
5169	49	-1	970	2019-10-05 15:45:42.220237+03
5170	37	-1	1290	2019-10-05 15:49:23.169765+03
5171	90	-1	1780	2019-10-05 16:23:21.847312+03
5172	76	-1	1070	2019-10-05 16:27:24.587757+03
5173	3	-1	660	2019-10-05 17:17:35.627583+03
5174	86	-2	910	2019-10-05 17:18:09.541607+03
5175	78	-1	900	2019-10-05 17:21:38.373632+03
5176	31	-1	1190	2019-10-05 17:22:52.860609+03
5177	37	-1	1290	2019-10-05 17:27:42.690483+03
5178	94	-2	1230	2019-10-05 17:47:12.27979+03
5179	38	-2	1100	2019-10-05 17:58:37.633279+03
5180	12	-1	1650	2019-10-05 18:05:39.846304+03
5181	53	-1	3120	2019-10-05 18:22:00.00054+03
5182	44	-1	500	2019-10-05 18:23:28.671269+03
5183	13	-1	460	2019-10-05 18:45:48.616222+03
5184	40	-1	1430	2019-10-05 19:13:24.195414+03
5185	16	-1	1380	2019-10-05 19:43:46.492733+03
5186	29	-1	1940	2019-10-05 19:54:29.721105+03
5187	2	-1	470	2019-10-05 19:56:46.986457+03
5188	43	-1	380	2019-10-05 20:04:05.014536+03
5189	60	-1	2700	2019-10-05 20:22:58.794254+03
5190	53	-1	3120	2019-10-05 20:35:38.695459+03
5191	29	-2	1940	2019-10-05 20:44:08.399952+03
5192	22	-2	1070	2019-10-05 20:51:57.119695+03
5193	39	-1	910	2019-10-05 21:00:52.106543+03
5194	95	-1	480	2019-10-05 21:11:12.687144+03
5195	13	-1	460	2019-10-05 21:32:17.682912+03
5196	2	-1	470	2019-10-05 22:10:42.910896+03
5197	3	-1	660	2019-10-05 22:12:21.761853+03
5198	9	-1	2090	2019-10-05 22:24:18.242764+03
5199	57	-1	1900	2019-10-05 22:32:36.747551+03
5200	95	-1	480	2019-10-05 22:45:19.460297+03
5201	22	-2	1070	2019-10-05 22:46:48.524346+03
5202	60	-1	2700	2019-10-05 22:51:35.434187+03
5203	18	-2	910	2019-10-05 23:09:48.891812+03
5204	71	-2	1030	2019-10-05 23:12:04.766507+03
5205	9	-1	2090	2019-10-05 23:38:33.31749+03
5206	3	-1	660	2019-10-05 23:45:20.297004+03
5207	96	-1	1570	2019-10-05 23:47:48.694605+03
5208	39	-1	910	2019-10-05 23:51:46.073336+03
5209	11	-2	830	2019-10-06 00:04:14.574831+03
5210	9	-1	2090	2019-10-06 00:49:22.660642+03
5211	8	-1	1920	2019-10-06 00:49:46.784044+03
5212	65	-1	490	2019-10-06 00:52:31.270575+03
5213	18	-1	910	2019-10-06 00:55:17.691307+03
5214	84	-1	2700	2019-10-06 00:57:08.165856+03
5215	70	-1	760	2019-10-06 01:15:46.759528+03
5216	29	-1	1940	2019-10-06 01:19:35.542691+03
5217	76	-1	1070	2019-10-06 01:22:48.441146+03
5218	90	-2	1780	2019-10-06 01:56:10.141795+03
5219	78	-2	900	2019-10-06 02:10:43.584452+03
5220	50	-1	1140	2019-10-06 02:17:36.730534+03
5221	4	-1	1420	2019-10-06 02:19:30.710197+03
5222	62	-1	1220	2019-10-06 02:22:23.378243+03
5223	79	-1	550	2019-10-06 02:40:21.528838+03
5224	43	-1	380	2019-10-06 02:40:21.837647+03
5225	23	-1	4390	2019-10-06 02:53:13.978146+03
5226	12	-1	1650	2019-10-06 03:52:22.186292+03
5227	47	-1	1480	2019-10-06 03:54:37.739938+03
5228	91	-1	1620	2019-10-06 04:09:39.864943+03
5229	80	-3	1120	2019-10-06 04:14:21.449091+03
5230	27	-1	880	2019-10-06 04:34:52.924125+03
5231	12	-1	1650	2019-10-06 06:29:37.447315+03
5232	81	-1	1620	2019-10-06 06:34:11.189716+03
5233	64	-1	970	2019-10-06 06:35:06.008076+03
5234	82	-1	560	2019-10-06 06:35:13.862358+03
5235	89	-2	1420	2019-10-06 06:50:18.866776+03
5236	46	-1	1270	2019-10-06 06:50:25.289237+03
5237	14	-1	1350	2019-10-06 07:01:11.572334+03
5238	60	23	1547	2019-10-06 07:06:45.963502+03
5239	29	-1	1940	2019-10-06 07:11:20.585147+03
5240	58	-1	2830	2019-10-06 07:24:39.130848+03
5241	92	-1	630	2019-10-06 07:43:40.979164+03
5242	30	-1	1140	2019-10-06 07:45:55.730556+03
5243	6	-1	980	2019-10-06 07:46:00.219435+03
5244	57	-2	1900	2019-10-06 07:52:50.549019+03
5245	79	25	318	2019-10-06 08:02:23.900573+03
5246	20	-1	830	2019-10-06 08:20:02.624314+03
5247	35	-1	670	2019-10-06 08:34:00.193797+03
5248	73	-1	960	2019-10-06 08:37:04.816375+03
5249	3	-1	660	2019-10-06 09:17:32.630756+03
5250	4	-2	1420	2019-10-06 09:23:00.8971+03
5251	79	-1	550	2019-10-06 09:28:37.041093+03
5252	4	-2	1420	2019-10-06 09:43:24.515402+03
5253	24	-2	950	2019-10-06 10:23:41.99184+03
5254	87	-1	2320	2019-10-06 10:31:34.745191+03
5255	56	-1	2460	2019-10-06 10:34:58.766855+03
5256	88	-1	1270	2019-10-06 10:50:17.284618+03
5257	10	-1	2080	2019-10-06 11:06:32.19716+03
5258	53	-1	3120	2019-10-06 11:24:12.487859+03
5259	90	-1	1780	2019-10-06 11:38:42.049288+03
5260	92	-1	630	2019-10-06 11:39:32.30044+03
5261	35	-1	670	2019-10-06 11:51:58.566285+03
5262	93	-2	1620	2019-10-06 12:01:59.433295+03
5263	76	-1	1070	2019-10-06 12:05:16.142006+03
5264	76	-1	1070	2019-10-06 12:11:49.108898+03
5265	47	-2	1480	2019-10-06 12:16:48.127612+03
5266	55	-1	3480	2019-10-06 12:37:56.106597+03
5267	55	-2	3480	2019-10-06 12:50:23.672332+03
5268	18	-2	910	2019-10-06 12:51:11.251+03
5269	47	-1	1480	2019-10-06 13:09:24.622378+03
5270	46	-1	1270	2019-10-06 13:21:40.445877+03
5271	39	-1	910	2019-10-06 13:21:50.918567+03
5272	18	-1	910	2019-10-06 13:27:08.984165+03
5273	84	-1	2700	2019-10-06 13:41:06.487397+03
5274	58	-1	2830	2019-10-06 14:10:07.269037+03
5275	64	-1	970	2019-10-06 14:11:27.241924+03
5276	56	-2	2460	2019-10-06 15:11:44.085767+03
5277	46	-2	1270	2019-10-06 15:32:58.787755+03
5278	39	-1	910	2019-10-06 16:04:57.246093+03
5279	95	-1	480	2019-10-06 17:00:23.59347+03
5280	4	-1	1420	2019-10-06 17:11:22.154648+03
5281	93	-1	1620	2019-10-06 17:30:00.642025+03
5282	73	-1	960	2019-10-06 17:30:25.231915+03
5283	6	-2	980	2019-10-06 17:35:06.168055+03
5284	10	-1	2080	2019-10-06 19:03:12.804101+03
5285	94	-1	1230	2019-10-06 19:26:30.993256+03
5286	63	-1	1780	2019-10-06 19:50:00.258946+03
5287	60	-2	2700	2019-10-06 20:16:40.748818+03
5288	70	-2	760	2019-10-06 20:25:14.191207+03
5289	46	-2	1270	2019-10-06 20:49:18.249782+03
5290	63	-1	1780	2019-10-06 20:49:30.749927+03
5291	92	-1	630	2019-10-06 20:51:39.164505+03
5292	9	-1	2090	2019-10-06 21:01:13.699172+03
5293	93	-1	1620	2019-10-06 21:02:43.109835+03
5294	38	-1	1100	2019-10-06 21:22:38.999209+03
5295	1	-2	640	2019-10-06 21:26:44.075687+03
5296	95	-1	480	2019-10-06 21:27:39.59516+03
5297	11	-1	830	2019-10-06 21:35:21.83376+03
5298	10	-2	2080	2019-10-06 21:40:29.513277+03
5299	46	-2	1270	2019-10-06 21:42:15.326735+03
5300	21	27	515	2019-10-06 21:43:03.742437+03
5301	28	-1	1860	2019-10-06 21:43:42.232856+03
5302	53	-1	3120	2019-10-06 21:48:43.818692+03
5303	11	-1	830	2019-10-06 21:51:37.534099+03
5304	19	-1	1220	2019-10-06 22:02:06.157695+03
5305	76	-2	1070	2019-10-06 22:02:54.379663+03
5306	14	-1	1350	2019-10-06 22:03:49.229864+03
5307	76	-1	1070	2019-10-06 22:33:01.430744+03
5308	19	-1	1220	2019-10-06 22:41:28.050375+03
5309	61	-1	1510	2019-10-06 22:44:47.202815+03
5310	30	-1	1140	2019-10-06 23:09:03.236442+03
5311	94	-2	1230	2019-10-06 23:13:54.919771+03
5312	22	-1	1070	2019-10-06 23:18:48.965438+03
5313	26	-1	390	2019-10-06 23:54:26.268551+03
5314	34	29	642	2019-10-07 00:19:18.81098+03
5315	84	-1	2700	2019-10-07 00:28:54.785613+03
5316	13	-1	460	2019-10-07 00:29:04.409279+03
5317	77	-1	640	2019-10-07 00:38:38.989929+03
5318	79	-1	550	2019-10-07 00:59:30.460743+03
5319	69	-1	1100	2019-10-07 01:10:39.375202+03
5320	96	-1	1570	2019-10-07 01:29:01.714338+03
5321	44	-2	500	2019-10-07 01:42:59.261909+03
5322	87	-1	2320	2019-10-07 02:09:05.788761+03
5323	87	-1	2320	2019-10-07 02:14:02.80853+03
5324	96	-1	1570	2019-10-07 02:33:07.032889+03
5325	32	-2	710	2019-10-07 03:06:26.36915+03
5326	84	-1	2700	2019-10-07 03:41:27.680545+03
5327	76	-2	1070	2019-10-07 03:50:45.999568+03
5328	93	-2	1620	2019-10-07 04:22:58.198663+03
5329	35	-1	670	2019-10-07 04:30:10.742137+03
5330	76	-1	1070	2019-10-07 04:39:13.891772+03
5331	30	-1	1140	2019-10-07 04:45:20.2251+03
5332	19	-1	1220	2019-10-07 05:04:09.661153+03
5333	46	-2	1270	2019-10-07 05:34:59.975265+03
5334	29	-1	1940	2019-10-07 06:03:18.576376+03
5335	5	28	858	2019-10-07 06:04:34.780369+03
5336	4	-1	1420	2019-10-07 06:18:06.496051+03
5337	47	-2	1480	2019-10-07 06:26:55.740372+03
5338	85	-1	730	2019-10-07 06:49:27.546101+03
5339	92	-1	630	2019-10-07 06:55:23.128851+03
5340	56	-1	2460	2019-10-07 06:58:12.457285+03
5341	70	-1	760	2019-10-07 07:11:01.632748+03
5342	58	-1	2830	2019-10-07 07:24:03.411858+03
5343	40	-1	1430	2019-10-07 07:27:34.507296+03
5344	87	-1	2320	2019-10-07 07:28:49.722175+03
5345	51	-1	1310	2019-10-07 07:36:43.098459+03
5346	49	-1	970	2019-10-07 07:43:11.420304+03
5347	32	-2	710	2019-10-07 08:09:33.460864+03
5348	27	-1	880	2019-10-07 08:16:45.679539+03
5349	10	-1	2080	2019-10-07 09:26:57.208053+03
5350	22	-1	1070	2019-10-07 09:52:30.970699+03
5351	90	-1	1780	2019-10-07 10:12:18.682639+03
5352	18	-2	910	2019-10-07 10:18:26.714747+03
5353	66	-1	690	2019-10-07 10:41:34.770607+03
5354	40	-3	1430	2019-10-07 10:44:56.186037+03
5355	85	-1	730	2019-10-07 10:46:12.734026+03
5356	90	-1	1780	2019-10-07 10:58:10.697032+03
5357	46	-1	1270	2019-10-07 10:59:12.70089+03
5358	3	-2	660	2019-10-07 11:03:16.404381+03
5359	50	-2	1140	2019-10-07 11:13:53.62243+03
5360	39	-2	910	2019-10-07 11:36:54.481251+03
5361	13	-1	460	2019-10-07 11:54:00.114101+03
5362	6	-1	980	2019-10-07 11:56:07.862618+03
5363	48	-2	640	2019-10-07 12:11:44.153226+03
5364	10	-1	2080	2019-10-07 12:41:16.603045+03
5365	49	-2	970	2019-10-07 12:45:28.58316+03
5366	31	-2	1190	2019-10-07 12:53:57.208701+03
5367	55	32	1641	2019-10-07 13:10:52.718866+03
5368	24	-1	950	2019-10-07 13:42:32.631455+03
5369	38	-1	1100	2019-10-07 13:53:15.93651+03
5370	47	-1	1480	2019-10-07 14:57:27.943892+03
5371	41	-1	830	2019-10-07 15:03:15.577313+03
5372	23	-1	4390	2019-10-07 15:11:56.649845+03
5373	16	-1	1380	2019-10-07 15:46:37.986969+03
5374	32	-1	710	2019-10-07 15:52:03.262262+03
5375	77	-1	640	2019-10-07 15:58:42.880594+03
5376	56	-1	2460	2019-10-07 16:21:18.526281+03
5377	49	-2	970	2019-10-07 16:21:21.343159+03
5378	77	-1	640	2019-10-07 16:22:21.500637+03
5379	21	-2	960	2019-10-07 16:32:43.941691+03
5380	84	-1	2700	2019-10-07 16:39:32.055747+03
5381	60	-2	2700	2019-10-07 17:28:15.474328+03
5382	75	-1	830	2019-10-07 17:29:36.789312+03
5383	44	-1	500	2019-10-07 18:02:35.011669+03
5384	18	-2	910	2019-10-07 18:34:33.484915+03
5385	14	-2	1350	2019-10-07 18:57:32.616829+03
5386	96	-1	1570	2019-10-07 19:24:46.308585+03
5387	56	-1	2460	2019-10-07 19:49:58.907156+03
5388	87	-1	2320	2019-10-07 20:25:30.672098+03
5389	77	-1	640	2019-10-07 20:26:05.356679+03
5390	92	-1	630	2019-10-07 21:05:17.055891+03
5391	10	-2	2080	2019-10-07 21:24:43.947606+03
5392	37	-1	1290	2019-10-07 21:29:25.491377+03
5393	84	32	1313	2019-10-07 22:03:55.471171+03
5394	34	-1	1550	2019-10-07 22:19:30.51494+03
5395	18	35	521	2019-10-07 22:25:40.916909+03
5396	13	-1	460	2019-10-07 22:36:53.713448+03
5397	57	-1	1900	2019-10-07 22:48:31.777592+03
5398	10	-1	2080	2019-10-07 23:05:45.643607+03
5399	88	-1	1270	2019-10-07 23:17:26.732178+03
5400	34	-1	1550	2019-10-07 23:45:00.342028+03
5401	94	-1	1230	2019-10-07 23:52:43.631691+03
5402	68	-1	490	2019-10-08 00:36:01.253464+03
5403	84	-1	2700	2019-10-08 00:52:50.667791+03
5404	34	-1	1550	2019-10-08 00:55:25.753791+03
5405	85	-1	730	2019-10-08 01:02:41.511742+03
5406	39	-2	910	2019-10-08 01:12:26.102851+03
5407	79	-1	550	2019-10-08 01:41:29.527544+03
5408	21	-1	960	2019-10-08 01:50:37.677347+03
5409	60	-1	2700	2019-10-08 01:58:21.658427+03
5410	33	-1	900	2019-10-08 02:10:48.618782+03
5411	3	-1	660	2019-10-08 02:42:52.409786+03
5412	6	-1	980	2019-10-08 02:45:58.228976+03
5413	63	-1	1780	2019-10-08 02:50:06.48523+03
5414	85	21	293	2019-10-08 02:55:03.937549+03
5415	40	-1	1430	2019-10-08 03:06:47.939647+03
5416	5	-1	1620	2019-10-08 03:11:49.47927+03
5417	59	-1	1030	2019-10-08 03:30:24.75716+03
5418	9	-2	2090	2019-10-08 03:32:25.480645+03
5419	27	19	400	2019-10-08 04:37:54.508432+03
5420	81	-1	1620	2019-10-08 04:38:30.677658+03
5421	36	-2	630	2019-10-08 04:54:36.536646+03
5422	76	-1	1070	2019-10-08 05:04:38.255618+03
5423	83	-1	1230	2019-10-08 05:05:08.851374+03
5424	53	-1	3120	2019-10-08 05:16:16.765613+03
5425	30	-1	1140	2019-10-08 05:37:45.40302+03
5426	24	-1	950	2019-10-08 06:00:44.633612+03
5427	48	-1	640	2019-10-08 06:21:58.468843+03
5428	20	-1	830	2019-10-08 06:22:54.517318+03
5429	80	-2	1120	2019-10-08 07:08:33.03879+03
5430	66	-1	690	2019-10-08 07:29:54.832473+03
5431	31	-1	1190	2019-10-08 08:44:54.347326+03
5432	2	-1	470	2019-10-08 09:08:09.491326+03
5433	93	-1	1620	2019-10-08 09:30:55.708459+03
5434	39	-1	910	2019-10-08 09:39:14.928772+03
5435	10	-1	2080	2019-10-08 10:05:52.05235+03
5436	37	-1	1290	2019-10-08 10:08:58.252078+03
5437	49	-1	970	2019-10-08 10:34:59.912087+03
5438	20	-1	830	2019-10-08 10:37:03.233546+03
5439	36	-2	630	2019-10-08 10:41:05.685872+03
5440	21	-2	960	2019-10-08 11:01:02.913296+03
5441	21	-1	960	2019-10-08 11:01:51.454832+03
5442	88	-1	1270	2019-10-08 11:01:52.530907+03
5443	93	-1	1620	2019-10-08 11:02:06.469978+03
5444	64	-1	970	2019-10-08 11:23:41.440653+03
5445	53	-1	3120	2019-10-08 11:32:39.556547+03
5446	4	-1	1420	2019-10-08 11:38:29.84574+03
5447	70	27	305	2019-10-08 11:42:11.980125+03
5448	80	-1	1120	2019-10-08 11:47:49.395253+03
5449	55	-2	3480	2019-10-08 11:47:57.024657+03
5450	6	39	535	2019-10-08 12:51:07.115423+03
5451	53	-1	3120	2019-10-08 12:54:18.370345+03
5452	79	-1	550	2019-10-08 13:07:57.580517+03
5453	40	-1	1430	2019-10-08 13:13:10.754895+03
5454	67	-1	350	2019-10-08 13:20:20.847972+03
5455	18	-1	910	2019-10-08 13:38:11.36825+03
5456	42	31	854	2019-10-08 13:39:30.450198+03
5457	68	-1	490	2019-10-08 14:01:45.951641+03
5458	4	-1	1420	2019-10-08 14:54:00.719024+03
5459	20	-1	830	2019-10-08 15:41:07.743873+03
5460	37	-1	1290	2019-10-08 16:11:56.740169+03
5461	6	-1	980	2019-10-08 16:22:22.27887+03
5462	73	-1	960	2019-10-08 16:49:00.783977+03
5463	54	29	1690	2019-10-08 17:13:14.021375+03
5464	64	-1	970	2019-10-08 17:18:09.321323+03
5465	77	33	281	2019-10-08 17:30:03.894103+03
5466	89	-2	1420	2019-10-08 18:15:08.298972+03
5467	76	-2	1070	2019-10-08 18:33:40.044894+03
5468	13	-1	460	2019-10-08 19:04:35.400884+03
5469	43	-1	380	2019-10-08 19:53:26.819906+03
5470	30	-2	1140	2019-10-08 19:56:47.290952+03
5471	24	-1	950	2019-10-08 20:23:57.203293+03
5472	42	-1	1790	2019-10-08 20:35:48.53428+03
5473	94	-1	1230	2019-10-08 20:38:27.163944+03
5474	58	-1	2830	2019-10-08 20:41:23.843413+03
5475	86	-1	910	2019-10-08 20:50:42.376202+03
5476	56	-1	2460	2019-10-08 21:27:47.450149+03
5477	28	-2	1860	2019-10-08 21:49:33.885569+03
5478	30	-1	1140	2019-10-08 22:07:41.811747+03
5479	84	-1	2700	2019-10-08 22:12:55.154235+03
5480	4	-1	1420	2019-10-08 22:32:03.072138+03
5481	14	-1	1350	2019-10-08 23:07:32.925505+03
5482	17	-1	1500	2019-10-08 23:13:35.504973+03
5483	37	-2	1290	2019-10-08 23:34:37.051394+03
5484	7	-1	810	2019-10-08 23:48:44.994326+03
5485	56	-1	2460	2019-10-08 23:57:14.831553+03
5486	18	-1	910	2019-10-09 00:05:57.871531+03
5487	29	-1	1940	2019-10-09 00:14:15.050215+03
5488	83	-1	1230	2019-10-09 00:16:22.637759+03
5489	40	32	661	2019-10-09 00:16:29.14666+03
5490	75	-1	830	2019-10-09 00:48:15.5988+03
5491	4	-1	1420	2019-10-09 01:11:50.261942+03
5492	76	24	455	2019-10-09 01:38:33.40651+03
5493	79	-1	550	2019-10-09 02:04:09.633138+03
5494	78	17	402	2019-10-09 02:15:46.537172+03
5495	45	-1	1590	2019-10-09 02:19:29.795687+03
5496	43	-2	380	2019-10-09 02:42:26.167144+03
5497	32	-2	710	2019-10-09 03:38:46.14651+03
5498	94	-2	1230	2019-10-09 03:39:36.067452+03
5499	44	-1	500	2019-10-09 03:57:58.997668+03
5500	42	-1	1790	2019-10-09 04:37:14.798252+03
5501	48	-1	640	2019-10-09 05:23:43.529957+03
5502	90	-1	1780	2019-10-09 05:41:47.512397+03
5503	48	-1	640	2019-10-09 06:11:47.9118+03
5504	24	-1	950	2019-10-09 06:14:12.777947+03
5505	39	-1	910	2019-10-09 06:34:12.876403+03
5506	40	-1	1430	2019-10-09 06:44:23.965481+03
5507	64	-2	970	2019-10-09 06:47:23.471513+03
5508	52	-1	1090	2019-10-09 07:19:02.389516+03
5509	40	-1	1430	2019-10-09 07:19:29.402829+03
5510	96	-2	1570	2019-10-09 07:39:43.170515+03
5511	31	-1	1190	2019-10-09 07:41:09.98544+03
5512	77	-2	640	2019-10-09 07:56:50.999138+03
5513	58	-1	2830	2019-10-09 08:13:19.516247+03
5514	12	-1	1650	2019-10-09 08:24:03.301141+03
5515	44	-2	500	2019-10-09 08:41:57.114658+03
5516	23	-1	4390	2019-10-09 08:55:45.692003+03
5517	75	-1	830	2019-10-09 08:57:41.335339+03
5518	3	-1	660	2019-10-09 09:01:41.03549+03
5519	1	-2	640	2019-10-09 09:04:33.827795+03
5520	4	-1	1420	2019-10-09 09:27:07.947928+03
5521	38	-1	1100	2019-10-09 09:54:50.482398+03
5522	49	42	564	2019-10-09 10:12:37.281665+03
5523	32	-1	710	2019-10-09 10:15:49.638285+03
5524	10	-1	2080	2019-10-09 10:17:45.76316+03
5525	48	-1	640	2019-10-09 10:30:41.789369+03
5526	21	-1	960	2019-10-09 10:40:36.525406+03
5527	26	-1	390	2019-10-09 11:02:02.972501+03
5528	45	-1	1590	2019-10-09 11:13:20.233512+03
5529	71	-1	1030	2019-10-09 11:20:34.01315+03
5530	37	-1	1290	2019-10-09 11:29:56.327397+03
5531	22	-1	1070	2019-10-09 11:46:30.610935+03
5532	21	-1	960	2019-10-09 12:14:29.214547+03
5533	93	-1	1620	2019-10-09 12:16:52.671769+03
5534	43	-1	380	2019-10-09 12:28:35.471819+03
5535	84	-1	2700	2019-10-09 12:29:50.693969+03
5536	75	-1	830	2019-10-09 13:05:45.797156+03
5537	11	-2	830	2019-10-09 13:11:55.962409+03
5538	14	-1	1350	2019-10-09 13:19:26.011342+03
5539	35	-2	670	2019-10-09 13:56:24.21645+03
5540	89	-1	1420	2019-10-09 14:25:19.62615+03
5541	77	-2	640	2019-10-09 14:35:17.486593+03
5542	93	-1	1620	2019-10-09 14:40:31.169775+03
5543	51	-1	1310	2019-10-09 14:50:36.817+03
5544	9	-1	2090	2019-10-09 14:57:45.769033+03
5545	12	-1	1650	2019-10-09 15:16:44.149584+03
5546	76	-1	1070	2019-10-09 15:22:00.251127+03
5547	49	-1	970	2019-10-09 15:27:10.301797+03
5548	38	-1	1100	2019-10-09 15:54:32.267487+03
5549	77	-2	640	2019-10-09 16:22:13.543455+03
5550	75	-1	830	2019-10-09 16:38:23.760832+03
5551	10	-1	2080	2019-10-09 16:43:14.407194+03
5552	38	-1	1100	2019-10-09 16:49:42.491792+03
5553	33	-1	900	2019-10-09 17:14:50.550088+03
5554	11	-1	830	2019-10-09 17:30:48.690686+03
5555	12	-1	1650	2019-10-09 17:41:22.345905+03
5556	82	-1	560	2019-10-09 17:52:51.149228+03
5557	29	-1	1940	2019-10-09 17:54:27.449757+03
5558	81	-1	1620	2019-10-09 18:26:28.651177+03
5559	33	-1	900	2019-10-09 18:48:43.92525+03
5560	85	-1	730	2019-10-09 19:09:48.334492+03
5561	13	37	254	2019-10-09 19:10:02.963603+03
5562	30	40	554	2019-10-09 19:40:46.62304+03
5563	95	-1	480	2019-10-09 19:59:25.036371+03
5564	40	-1	1430	2019-10-09 20:01:03.623392+03
5565	95	-1	480	2019-10-09 20:01:38.849594+03
5566	4	-1	1420	2019-10-09 20:08:58.001381+03
5567	46	-2	1270	2019-10-09 20:43:09.051352+03
5568	31	-1	1190	2019-10-09 20:44:54.324625+03
5569	11	-1	830	2019-10-09 20:50:39.14995+03
5570	54	-1	3470	2019-10-09 20:53:28.5996+03
5571	27	-1	880	2019-10-09 20:54:41.240895+03
5572	74	-1	1010	2019-10-09 21:14:16.129027+03
5573	6	-1	980	2019-10-09 21:14:42.94854+03
5574	20	-1	830	2019-10-09 21:15:37.864093+03
5575	46	-1	1270	2019-10-09 21:29:00.034709+03
5576	85	-1	730	2019-10-09 21:38:41.825703+03
5577	71	-1	1030	2019-10-09 21:49:14.353217+03
5578	90	-1	1780	2019-10-09 21:57:42.326676+03
5579	51	-1	1310	2019-10-09 22:21:24.522596+03
5580	54	-1	3470	2019-10-09 23:02:14.306351+03
5581	62	-1	1220	2019-10-09 23:21:03.464648+03
5582	27	-2	880	2019-10-09 23:42:22.323443+03
5583	46	-1	1270	2019-10-09 23:56:37.23388+03
5584	43	-1	380	2019-10-10 00:34:07.608943+03
5585	52	-1	1090	2019-10-10 00:44:26.422963+03
5586	86	-1	910	2019-10-10 01:02:38.373976+03
5587	12	35	709	2019-10-10 01:09:37.234053+03
5588	41	-1	830	2019-10-10 01:51:31.712303+03
5589	89	-1	1420	2019-10-10 01:51:33.405179+03
5590	11	-1	830	2019-10-10 01:51:40.027003+03
5591	78	-1	900	2019-10-10 01:55:03.590659+03
5592	73	-1	960	2019-10-10 02:04:49.229582+03
5593	81	22	842	2019-10-10 02:10:59.196724+03
5594	40	-1	1430	2019-10-10 02:14:29.654541+03
5595	78	-1	900	2019-10-10 02:26:29.275889+03
5596	16	-1	1380	2019-10-10 02:32:14.98316+03
5597	16	-2	1380	2019-10-10 03:27:47.876421+03
5598	89	-2	1420	2019-10-10 03:35:28.066613+03
5599	5	-1	1620	2019-10-10 03:37:15.073808+03
5600	94	-1	1230	2019-10-10 04:14:33.029448+03
5601	94	-1	1230	2019-10-10 04:19:51.555067+03
5602	35	-1	670	2019-10-10 04:31:30.584094+03
5603	20	-1	830	2019-10-10 04:35:10.555217+03
5604	46	-1	1270	2019-10-10 05:00:02.9712+03
5605	88	-1	1270	2019-10-10 05:00:10.305064+03
5606	11	-1	830	2019-10-10 05:19:39.318983+03
5607	29	-1	1940	2019-10-10 05:25:53.379567+03
5608	96	-2	1570	2019-10-10 05:26:28.235933+03
5609	3	-1	660	2019-10-10 05:37:30.441459+03
5610	46	-1	1270	2019-10-10 05:46:32.740257+03
5611	63	-2	1780	2019-10-10 06:23:47.924776+03
5612	33	-1	900	2019-10-10 06:30:19.781727+03
5613	3	-1	660	2019-10-10 06:31:48.581057+03
5614	5	-1	1620	2019-10-10 07:29:50.915122+03
5615	34	-2	1550	2019-10-10 07:58:06.276181+03
5616	10	-2	2080	2019-10-10 08:04:06.005762+03
5617	96	-1	1570	2019-10-10 08:20:03.274562+03
5618	22	-1	1070	2019-10-10 08:24:41.467611+03
5619	80	-1	1120	2019-10-10 09:01:28.416453+03
5620	4	-2	1420	2019-10-10 09:12:19.970023+03
5621	18	-1	910	2019-10-10 09:18:12.290049+03
5622	81	-1	1620	2019-10-10 09:21:42.417495+03
5623	81	-2	1620	2019-10-10 09:56:31.736727+03
5624	58	-1	2830	2019-10-10 10:23:34.908394+03
5625	62	-1	1220	2019-10-10 10:29:54.270937+03
5626	23	-2	4390	2019-10-10 10:40:36.093454+03
5627	93	-1	1620	2019-10-10 11:21:00.60189+03
5628	17	-1	1500	2019-10-10 11:50:24.357546+03
5629	71	-1	1030	2019-10-10 11:51:37.217493+03
5630	54	-1	3470	2019-10-10 11:58:55.684353+03
5631	80	-1	1120	2019-10-10 12:24:49.698289+03
5632	28	-1	1860	2019-10-10 12:50:15.667013+03
5633	25	-1	1100	2019-10-10 12:58:57.983881+03
5634	59	-1	1030	2019-10-10 13:12:53.06676+03
5635	78	-2	900	2019-10-10 13:19:04.782022+03
5636	88	-2	1270	2019-10-10 13:25:47.039738+03
5637	76	-1	1070	2019-10-10 13:27:41.268665+03
5638	4	-1	1420	2019-10-10 13:27:45.774698+03
5639	87	-1	2320	2019-10-10 13:39:43.847032+03
5640	25	-2	1100	2019-10-10 13:43:41.840925+03
5641	70	-1	760	2019-10-10 14:19:38.278583+03
5642	9	-1	2090	2019-10-10 14:40:54.754963+03
5643	45	-1	1590	2019-10-10 14:51:01.246991+03
5644	35	-1	670	2019-10-10 14:54:16.257294+03
5645	76	-1	1070	2019-10-10 15:31:09.607602+03
5646	47	-1	1480	2019-10-10 15:34:54.992676+03
5647	30	-1	1140	2019-10-10 15:58:39.079838+03
5648	12	-1	1650	2019-10-10 16:21:22.975639+03
5649	77	-2	640	2019-10-10 16:49:10.14219+03
5650	36	-1	630	2019-10-10 17:07:22.023322+03
5651	7	-2	810	2019-10-10 17:12:44.049226+03
5652	53	-1	3120	2019-10-10 17:37:10.307145+03
5653	65	-1	490	2019-10-10 17:43:41.244809+03
5654	2	-1	470	2019-10-10 18:10:19.726202+03
5655	56	-1	2460	2019-10-10 18:41:31.746974+03
5656	89	39	842	2019-10-10 19:27:43.844365+03
5657	86	-1	910	2019-10-10 19:50:44.665748+03
5658	16	-1	1380	2019-10-10 19:52:24.653067+03
5659	40	-1	1430	2019-10-10 20:06:03.559684+03
5660	32	-1	710	2019-10-10 20:13:48.841306+03
5661	31	-2	1190	2019-10-10 20:16:34.012175+03
5662	96	-2	1570	2019-10-10 20:35:11.245148+03
5663	38	-1	1100	2019-10-10 20:39:47.497519+03
5664	12	-1	1650	2019-10-10 21:08:30.350842+03
5665	95	-1	480	2019-10-10 21:10:25.888238+03
5666	1	-1	640	2019-10-10 21:21:05.046809+03
5667	76	-1	1070	2019-10-10 21:56:15.518433+03
5668	86	-1	910	2019-10-10 22:07:15.229109+03
5669	86	-1	910	2019-10-10 22:09:21.871569+03
5670	10	-1	2080	2019-10-10 22:32:12.806198+03
5671	89	-2	1420	2019-10-10 22:38:40.575345+03
5672	21	-1	960	2019-10-10 22:45:42.76059+03
5673	4	-1	1420	2019-10-10 23:06:02.628924+03
5674	73	-1	960	2019-10-10 23:13:01.49685+03
5675	93	-1	1620	2019-10-10 23:31:31.151601+03
5676	49	-2	970	2019-10-10 23:43:20.29051+03
5677	30	-2	1140	2019-10-11 00:20:50.600518+03
5678	64	-2	970	2019-10-11 00:30:35.861147+03
5679	80	-1	1120	2019-10-11 00:57:43.431042+03
5680	6	-1	980	2019-10-11 01:28:50.034199+03
5681	33	-1	900	2019-10-11 01:58:02.530695+03
5682	38	-2	1100	2019-10-11 02:19:59.731582+03
5683	21	-2	960	2019-10-11 02:26:15.267638+03
5684	52	-1	1090	2019-10-11 02:29:32.729077+03
5685	15	-1	2830	2019-10-11 03:36:50.077135+03
5686	79	-1	550	2019-10-11 04:00:23.07299+03
5687	61	-3	1510	2019-10-11 04:11:04.27357+03
5688	26	-1	390	2019-10-11 04:12:44.891661+03
5689	25	-2	1100	2019-10-11 04:15:38.074754+03
5690	19	-1	1220	2019-10-11 04:24:52.594099+03
5691	67	-1	350	2019-10-11 04:34:26.414225+03
5692	89	-1	1420	2019-10-11 04:42:34.916389+03
5693	4	-1	1420	2019-10-11 05:03:02.342304+03
5694	56	-1	2460	2019-10-11 05:04:47.112482+03
5695	9	-2	2090	2019-10-11 05:20:58.096994+03
5696	56	-2	2460	2019-10-11 05:24:57.365155+03
5697	13	-1	460	2019-10-11 05:31:41.987311+03
5698	96	-1	1570	2019-10-11 05:32:10.226636+03
5699	14	-2	1350	2019-10-11 05:59:28.404882+03
5700	69	-1	1100	2019-10-11 06:23:14.254053+03
5701	29	-1	1940	2019-10-11 07:06:15.934779+03
5702	16	-1	1380	2019-10-11 07:20:05.830871+03
5703	66	-1	690	2019-10-11 07:36:04.360678+03
5704	10	-1	2080	2019-10-11 07:40:43.507788+03
5705	57	-1	1900	2019-10-11 07:53:36.542808+03
5706	6	-1	980	2019-10-11 07:54:21.244252+03
5707	51	-1	1310	2019-10-11 07:56:57.425609+03
5708	96	-1	1570	2019-10-11 08:00:13.043174+03
5709	10	-1	2080	2019-10-11 08:21:09.263404+03
5710	87	-1	2320	2019-10-11 08:30:11.940849+03
5711	50	-1	1140	2019-10-11 08:44:15.700487+03
5712	79	-2	550	2019-10-11 08:49:06.888247+03
5713	56	37	1076	2019-10-11 09:15:01.284729+03
5714	87	-1	2320	2019-10-11 09:32:44.399822+03
5715	49	-1	970	2019-10-11 09:35:00.475017+03
5716	54	-2	3470	2019-10-11 09:54:17.954231+03
5717	31	-1	1190	2019-10-11 09:59:08.706278+03
5718	14	-2	1350	2019-10-11 10:21:01.961278+03
5719	55	-2	3480	2019-10-11 10:32:32.457559+03
5720	35	-1	670	2019-10-11 10:40:04.720167+03
5721	86	-1	910	2019-10-11 10:42:26.961329+03
5722	55	-1	3480	2019-10-11 10:47:33.086319+03
5723	28	-1	1860	2019-10-11 10:51:54.712899+03
5724	45	-1	1590	2019-10-11 11:09:35.706225+03
5725	5	-2	1620	2019-10-11 11:31:53.005002+03
5726	6	-1	980	2019-10-11 11:42:07.874512+03
5727	23	26	2565	2019-10-11 12:17:40.426607+03
5728	46	-1	1270	2019-10-11 12:41:24.912759+03
5729	32	-1	710	2019-10-11 12:47:34.64351+03
5730	57	-1	1900	2019-10-11 13:21:43.567321+03
5731	61	-1	1510	2019-10-11 13:30:50.28538+03
5732	37	-1	1290	2019-10-11 13:38:32.726351+03
5733	38	-1	1100	2019-10-11 13:50:40.01398+03
5734	59	-1	1030	2019-10-11 14:11:40.223385+03
5735	14	-1	1350	2019-10-11 15:56:22.878906+03
5736	64	-1	970	2019-10-11 16:01:13.192791+03
5737	61	-1	1510	2019-10-11 16:12:20.300353+03
5738	20	-1	830	2019-10-11 16:15:48.024396+03
5739	18	-1	910	2019-10-11 16:20:02.663434+03
5740	7	-2	810	2019-10-11 16:23:42.418217+03
5741	79	-1	550	2019-10-11 16:38:23.311075+03
5742	54	-2	3470	2019-10-11 17:19:09.355008+03
5743	96	-1	1570	2019-10-11 17:20:26.787795+03
5744	7	-1	810	2019-10-11 17:25:33.588952+03
5745	67	-1	350	2019-10-11 17:32:27.478607+03
5746	47	-1	1480	2019-10-11 17:36:22.868363+03
5747	90	-1	1780	2019-10-11 17:56:20.883657+03
5748	33	-2	900	2019-10-11 17:58:30.045954+03
5749	17	-2	1500	2019-10-11 17:58:38.938501+03
5750	31	-1	1190	2019-10-11 18:28:23.239868+03
5751	23	-1	4390	2019-10-11 18:29:25.349431+03
5752	72	9	356	2019-10-11 18:47:03.707853+03
5753	37	-2	1290	2019-10-11 18:49:02.060495+03
5754	42	-1	1790	2019-10-11 19:20:39.490625+03
5755	47	-1	1480	2019-10-11 19:21:38.136185+03
5756	10	-1	2080	2019-10-11 19:29:34.372215+03
5757	71	-1	1030	2019-10-11 19:34:21.983737+03
5758	13	-1	460	2019-10-11 19:57:10.778227+03
5759	91	-1	1620	2019-10-11 20:00:59.176444+03
5760	49	-1	970	2019-10-11 20:08:12.845794+03
5761	42	-1	1790	2019-10-11 20:12:25.392619+03
5762	73	-1	960	2019-10-11 20:15:43.489492+03
5763	69	-1	1100	2019-10-11 20:21:15.216948+03
5764	81	-1	1620	2019-10-11 20:47:07.691004+03
5765	91	-1	1620	2019-10-11 20:55:03.750365+03
5766	20	-2	830	2019-10-11 20:55:48.075289+03
5767	77	-2	640	2019-10-11 21:30:57.926352+03
5768	95	-1	480	2019-10-11 22:14:53.585336+03
5769	25	-2	1100	2019-10-11 22:33:20.87598+03
5770	76	-1	1070	2019-10-11 22:40:56.162464+03
5771	32	34	377	2019-10-11 22:54:23.103323+03
5772	18	-1	910	2019-10-11 23:04:01.579975+03
5773	39	-1	910	2019-10-11 23:22:25.847608+03
5774	20	-2	830	2019-10-11 23:22:52.838472+03
5775	77	-2	640	2019-10-11 23:28:09.242118+03
5776	27	-1	880	2019-10-11 23:36:37.31837+03
5777	37	-1	1290	2019-10-11 23:45:55.173992+03
5778	88	-1	1270	2019-10-11 23:56:33.742224+03
5779	20	-2	830	2019-10-12 00:06:01.661921+03
5780	77	-1	640	2019-10-12 00:46:06.899249+03
5781	12	-1	1650	2019-10-12 00:51:03.785099+03
5782	77	-1	640	2019-10-12 00:56:59.522112+03
5783	70	-2	760	2019-10-12 01:00:53.449306+03
5784	78	-1	900	2019-10-12 01:05:55.370757+03
5785	91	-1	1620	2019-10-12 01:14:47.750234+03
5786	51	-1	1310	2019-10-12 01:23:52.808452+03
5787	28	-1	1860	2019-10-12 01:40:07.572737+03
5788	18	-1	910	2019-10-12 02:07:06.885007+03
5789	70	-1	760	2019-10-12 02:58:34.141796+03
5790	96	-1	1570	2019-10-12 03:22:47.103642+03
5791	36	-1	630	2019-10-12 03:34:32.753111+03
5792	11	-2	830	2019-10-12 03:56:56.365828+03
5793	85	-1	730	2019-10-12 04:05:01.42734+03
5794	8	-1	1920	2019-10-12 04:54:50.279512+03
5795	50	-2	1140	2019-10-12 05:08:25.761974+03
5796	21	-1	960	2019-10-12 05:19:52.759562+03
5797	56	-1	2460	2019-10-12 05:46:14.434294+03
5798	45	30	870	2019-10-12 05:48:36.599151+03
5799	77	-1	640	2019-10-12 06:20:35.458697+03
5800	76	-2	1070	2019-10-12 06:48:58.705792+03
5801	70	-1	760	2019-10-12 06:49:45.040532+03
5802	68	-1	490	2019-10-12 06:59:47.410074+03
5803	69	-2	1100	2019-10-12 07:02:42.391452+03
5804	20	-1	830	2019-10-12 07:08:51.133553+03
5805	71	-1	1030	2019-10-12 07:09:44.00123+03
5806	87	-1	2320	2019-10-12 07:17:41.317117+03
5807	10	-1	2080	2019-10-12 07:30:37.029231+03
5808	27	-2	880	2019-10-12 07:54:13.830342+03
5809	73	-1	960	2019-10-12 07:58:44.204369+03
5810	42	-1	1790	2019-10-12 08:03:58.611387+03
5811	70	-1	760	2019-10-12 08:06:40.782997+03
5812	55	-2	3480	2019-10-12 08:20:55.089034+03
5813	36	-1	630	2019-10-12 08:22:00.54944+03
5814	34	-2	1550	2019-10-12 08:26:22.769595+03
5815	32	-1	710	2019-10-12 08:27:13.682901+03
5816	45	-1	1590	2019-10-12 08:32:02.199376+03
5817	96	-1	1570	2019-10-12 08:41:53.93123+03
5818	77	-1	640	2019-10-12 09:22:32.894041+03
5819	95	-1	480	2019-10-12 09:28:45.22585+03
5820	5	-1	1620	2019-10-12 09:57:42.484415+03
5821	31	-1	1190	2019-10-12 10:01:15.267965+03
5822	80	-1	1120	2019-10-12 10:24:53.967175+03
5823	54	-1	3470	2019-10-12 10:26:23.097221+03
5824	91	-2	1620	2019-10-12 10:40:08.994399+03
5825	35	-1	670	2019-10-12 11:18:06.408953+03
5826	4	-1	1420	2019-10-12 11:31:12.227702+03
5827	42	-1	1790	2019-10-12 11:41:59.29968+03
5828	76	-1	1070	2019-10-12 11:51:40.712688+03
5829	91	-1	1620	2019-10-12 12:24:29.43145+03
5830	76	-1	1070	2019-10-12 12:27:25.891928+03
5831	59	-1	1030	2019-10-12 12:50:47.191392+03
5832	74	-1	1010	2019-10-12 13:39:49.60522+03
5833	36	-1	630	2019-10-12 13:51:33.436482+03
5834	64	-1	970	2019-10-12 13:51:43.84048+03
5835	5	-1	1620	2019-10-12 13:58:41.643147+03
5836	45	-1	1590	2019-10-12 13:59:47.099074+03
5837	73	-1	960	2019-10-12 14:03:44.385212+03
5838	33	-2	900	2019-10-12 14:07:13.899148+03
5839	26	-1	390	2019-10-12 14:14:20.474554+03
5840	86	27	475	2019-10-12 14:22:34.474664+03
5841	69	-1	1100	2019-10-12 14:25:12.931795+03
5842	93	31	730	2019-10-12 14:34:25.618931+03
5843	63	-1	1780	2019-10-12 15:12:24.463376+03
5844	51	-1	1310	2019-10-12 15:20:37.827695+03
5845	6	-2	980	2019-10-12 15:26:16.643577+03
5846	61	-1	1510	2019-10-12 16:13:58.901151+03
5847	79	-1	550	2019-10-12 16:21:31.889763+03
5848	89	-1	1420	2019-10-12 16:22:18.539013+03
5849	87	-1	2320	2019-10-12 17:02:25.128912+03
5850	48	-1	640	2019-10-12 17:07:33.475542+03
5851	21	-1	960	2019-10-12 17:18:17.519123+03
5852	77	-1	640	2019-10-12 17:25:43.022408+03
5853	32	-1	710	2019-10-12 17:32:52.844324+03
5854	80	-1	1120	2019-10-12 17:33:28.136112+03
5855	51	-2	1310	2019-10-12 17:37:21.933081+03
5856	48	26	316	2019-10-12 18:28:29.680927+03
5857	42	-2	1790	2019-10-12 18:42:36.698508+03
5858	44	26	248	2019-10-12 19:04:43.810854+03
5859	73	-1	960	2019-10-12 19:51:24.891004+03
5860	75	-1	830	2019-10-12 20:31:58.388452+03
5861	40	-1	1430	2019-10-12 20:39:55.722546+03
5862	32	-1	710	2019-10-12 20:42:26.640578+03
5863	75	-1	830	2019-10-12 21:14:13.707466+03
5864	4	-2	1420	2019-10-12 21:15:22.639252+03
5865	26	27	155	2019-10-12 21:37:18.571941+03
5866	90	-1	1780	2019-10-12 21:39:04.692413+03
5867	90	-1	1780	2019-10-12 22:07:58.708861+03
5868	55	-1	3480	2019-10-12 22:47:51.26843+03
5869	53	-1	3120	2019-10-12 23:14:04.412048+03
5870	6	-1	980	2019-10-12 23:19:25.157868+03
5871	56	-1	2460	2019-10-12 23:37:20.135555+03
5872	15	-2	2830	2019-10-12 23:39:13.110435+03
5873	74	-1	1010	2019-10-12 23:40:18.393197+03
5874	8	-1	1920	2019-10-12 23:55:13.283423+03
5875	64	-1	970	2019-10-13 00:04:25.559988+03
5876	41	-1	830	2019-10-13 00:39:53.872234+03
5877	95	-1	480	2019-10-13 00:46:53.914265+03
5878	45	-1	1590	2019-10-13 01:28:40.147631+03
5879	96	-1	1570	2019-10-13 01:36:38.708918+03
5880	33	-2	900	2019-10-13 01:38:46.901941+03
5881	35	-2	670	2019-10-13 02:06:38.153856+03
5882	72	-2	620	2019-10-13 02:07:13.753819+03
5883	42	-1	1790	2019-10-13 02:08:17.888652+03
5884	57	-2	1900	2019-10-13 02:16:04.006659+03
5885	20	-1	830	2019-10-13 02:37:41.789976+03
5886	76	-1	1070	2019-10-13 03:00:08.632114+03
5887	21	-1	960	2019-10-13 03:18:56.784516+03
5888	3	16	279	2019-10-13 03:19:20.709767+03
5889	7	-1	810	2019-10-13 03:43:33.918527+03
5890	95	28	240	2019-10-13 04:04:34.409584+03
5891	41	-1	830	2019-10-13 04:52:18.918299+03
5892	27	-1	880	2019-10-13 05:25:48.066044+03
5893	59	-1	1030	2019-10-13 05:28:57.160406+03
5894	29	-1	1940	2019-10-13 05:32:44.19758+03
5895	43	-1	380	2019-10-13 05:38:19.667323+03
5896	8	-1	1920	2019-10-13 05:39:17.255949+03
5897	7	-1	810	2019-10-13 05:42:18.333695+03
5898	3	-1	660	2019-10-13 05:56:00.531512+03
5899	12	-1	1650	2019-10-13 05:56:41.333799+03
5900	61	-1	1510	2019-10-13 06:00:01.073385+03
5901	86	-1	910	2019-10-13 06:01:46.443352+03
5902	78	-2	900	2019-10-13 06:02:50.703571+03
5903	17	-1	1500	2019-10-13 06:20:48.487778+03
5904	4	-1	1420	2019-10-13 06:24:03.341726+03
5905	13	-1	460	2019-10-13 07:05:17.414156+03
5906	29	-1	1940	2019-10-13 07:11:16.586227+03
5907	60	-2	2700	2019-10-13 07:20:08.140921+03
5908	68	-2	490	2019-10-13 07:36:57.057347+03
5909	8	-1	1920	2019-10-13 07:55:00.919041+03
5910	87	-1	2320	2019-10-13 08:08:08.728317+03
5911	1	-1	640	2019-10-13 08:13:29.199893+03
5912	79	-2	550	2019-10-13 08:37:27.830203+03
5913	21	-2	960	2019-10-13 08:39:47.450203+03
5914	20	-1	830	2019-10-13 08:43:22.541038+03
5915	59	-1	1030	2019-10-13 08:44:36.304584+03
5916	8	-1	1920	2019-10-13 09:22:32.075331+03
5917	47	42	614	2019-10-13 09:29:11.900651+03
5918	70	-1	760	2019-10-13 09:35:33.027597+03
5919	90	-2	1780	2019-10-13 09:36:49.199038+03
5920	11	-1	830	2019-10-13 09:43:56.660036+03
5921	15	-1	2830	2019-10-13 09:45:02.487737+03
5922	85	-1	730	2019-10-13 09:47:05.055253+03
5923	58	-1	2830	2019-10-13 09:52:02.349596+03
5924	69	-1	1100	2019-10-13 10:24:44.088649+03
5925	44	-2	500	2019-10-13 10:24:52.07024+03
5926	29	-1	1940	2019-10-13 10:38:18.120653+03
5927	57	-2	1900	2019-10-13 10:48:17.611677+03
5928	92	-1	630	2019-10-13 11:13:38.330942+03
5929	60	-2	2700	2019-10-13 11:15:07.244242+03
5930	19	-1	1220	2019-10-13 11:26:13.908641+03
5931	12	-1	1650	2019-10-13 11:37:20.02563+03
5932	32	-1	710	2019-10-13 11:56:49.643449+03
5933	4	-2	1420	2019-10-13 12:23:41.36697+03
5934	39	-1	910	2019-10-13 12:51:40.418831+03
5935	89	-1	1420	2019-10-13 13:04:27.667513+03
5936	86	-1	910	2019-10-13 13:08:00.430525+03
5937	31	-1	1190	2019-10-13 13:11:19.266267+03
5938	57	-1	1900	2019-10-13 13:22:01.342203+03
5939	81	-1	1620	2019-10-13 13:43:14.525284+03
5940	87	-1	2320	2019-10-13 14:04:44.93606+03
5941	19	-1	1220	2019-10-13 14:05:39.351775+03
5942	19	-1	1220	2019-10-13 14:09:29.866791+03
5943	79	-1	550	2019-10-13 14:17:01.109856+03
5944	73	-1	960	2019-10-13 14:58:44.671478+03
5945	64	-1	970	2019-10-13 14:59:26.519404+03
5946	91	-2	1620	2019-10-13 15:26:06.024048+03
5947	76	-1	1070	2019-10-13 16:01:58.366202+03
5948	45	-1	1590	2019-10-13 16:05:43.369997+03
5949	5	-1	1620	2019-10-13 16:17:32.92578+03
5950	36	-2	630	2019-10-13 16:32:05.284255+03
5951	10	-1	2080	2019-10-13 17:18:29.05409+03
5952	95	-1	480	2019-10-13 17:42:26.716674+03
5953	56	-1	2460	2019-10-13 17:44:10.240719+03
5954	12	-1	1650	2019-10-13 17:55:18.007504+03
5955	28	-1	1860	2019-10-13 18:55:28.306577+03
5956	17	-1	1500	2019-10-13 18:57:15.702215+03
5957	95	-1	480	2019-10-13 18:57:35.769993+03
5958	51	-1	1310	2019-10-13 18:58:49.885068+03
5959	84	-1	2700	2019-10-13 18:59:21.687863+03
5960	36	-2	630	2019-10-13 19:11:16.027314+03
5961	47	-1	1480	2019-10-13 19:29:29.144876+03
5962	10	-2	2080	2019-10-13 19:30:13.142249+03
5963	43	-1	380	2019-10-13 19:38:21.315538+03
5964	7	-1	810	2019-10-13 19:41:45.337675+03
5965	23	-1	4390	2019-10-13 19:46:40.949532+03
5966	96	-1	1570	2019-10-13 20:50:59.154994+03
5967	33	-1	900	2019-10-13 21:07:07.488133+03
5968	71	-1	1030	2019-10-13 21:21:09.622509+03
5969	93	-1	1620	2019-10-13 21:28:57.601382+03
5970	41	-1	830	2019-10-13 21:39:31.978148+03
5971	48	-1	640	2019-10-13 21:41:34.053691+03
5972	88	-1	1270	2019-10-13 21:52:24.604498+03
5973	12	-1	1650	2019-10-13 22:00:47.290288+03
5974	55	-1	3480	2019-10-13 22:22:45.344683+03
5975	12	-1	1650	2019-10-13 22:28:14.966669+03
5976	26	-1	390	2019-10-13 22:31:01.074456+03
5977	61	-1	1510	2019-10-13 22:49:12.573931+03
5978	45	-1	1590	2019-10-13 23:01:57.213588+03
5979	69	19	617	2019-10-13 23:02:57.64096+03
5980	11	-1	830	2019-10-13 23:16:46.811272+03
5981	26	-1	390	2019-10-13 23:24:48.323843+03
5982	49	-1	970	2019-10-13 23:32:00.696152+03
5983	5	-2	1620	2019-10-13 23:41:03.843221+03
5984	5	-1	1620	2019-10-14 00:27:35.278964+03
5985	60	-1	2700	2019-10-14 01:45:46.442581+03
5986	18	-1	910	2019-10-14 01:53:40.686854+03
5987	46	-1	1270	2019-10-14 01:57:30.923839+03
5988	3	-1	660	2019-10-14 02:06:54.743034+03
5989	22	-2	1070	2019-10-14 02:11:47.297119+03
5990	40	-2	1430	2019-10-14 02:35:03.248188+03
5991	92	-1	630	2019-10-14 02:43:23.878119+03
5992	23	-2	4390	2019-10-14 03:13:20.500601+03
5993	85	-1	730	2019-10-14 03:56:07.265606+03
5994	12	-1	1650	2019-10-14 03:58:49.743581+03
5995	12	-1	1650	2019-10-14 04:10:51.574216+03
5996	47	-1	1480	2019-10-14 04:39:48.795405+03
5997	60	-1	2700	2019-10-14 04:44:58.708844+03
5998	51	-1	1310	2019-10-14 04:53:27.320569+03
5999	56	-1	2460	2019-10-14 05:03:42.892575+03
6000	95	-1	480	2019-10-14 05:03:50.510466+03
6001	65	-1	490	2019-10-14 05:06:55.56727+03
6002	46	-1	1270	2019-10-14 05:16:52.278202+03
6003	12	-1	1650	2019-10-14 05:24:52.832808+03
6004	14	29	714	2019-10-14 05:39:36.499605+03
6005	47	-1	1480	2019-10-14 05:50:20.10581+03
6006	51	-1	1310	2019-10-14 05:57:44.363262+03
6007	48	-1	640	2019-10-14 06:15:19.518064+03
6008	15	-1	2830	2019-10-14 06:25:50.328786+03
6009	69	-2	1100	2019-10-14 06:31:49.553079+03
6010	18	-2	910	2019-10-14 06:48:57.266564+03
6011	34	-1	1550	2019-10-14 06:50:13.559831+03
6012	19	-1	1220	2019-10-14 06:55:12.293744+03
6013	22	-1	1070	2019-10-14 07:00:24.254299+03
6014	13	-2	460	2019-10-14 07:17:38.805914+03
6015	65	-1	490	2019-10-14 07:42:59.171355+03
6016	10	-2	2080	2019-10-14 07:52:14.589423+03
6017	71	-1	1030	2019-10-14 08:17:54.238826+03
6018	6	-2	980	2019-10-14 08:20:49.329795+03
6019	24	-1	950	2019-10-14 08:37:59.432934+03
6020	32	-2	710	2019-10-14 08:49:09.757077+03
6021	30	-1	1140	2019-10-14 08:51:01.04183+03
6022	86	-2	910	2019-10-14 08:51:28.04347+03
6023	45	-1	1590	2019-10-14 09:04:57.371254+03
6024	70	-1	760	2019-10-14 09:12:01.737646+03
6025	87	-1	2320	2019-10-14 09:14:57.204365+03
6026	41	-2	830	2019-10-14 09:16:19.353791+03
6027	56	-1	2460	2019-10-14 09:58:25.544369+03
6028	65	-1	490	2019-10-14 09:58:48.394138+03
6029	66	-1	690	2019-10-14 10:03:52.312947+03
6030	78	-1	900	2019-10-14 10:05:12.342058+03
6031	31	-1	1190	2019-10-14 10:29:17.096325+03
6032	94	21	658	2019-10-14 10:42:18.730174+03
6033	23	-1	4390	2019-10-14 10:43:57.17569+03
6034	79	-1	550	2019-10-14 11:24:50.102074+03
6035	47	-1	1480	2019-10-14 11:32:17.966605+03
6036	34	-1	1550	2019-10-14 11:47:24.410358+03
6037	42	-2	1790	2019-10-14 11:53:28.58001+03
6038	29	-1	1940	2019-10-14 12:01:48.891954+03
6039	12	-1	1650	2019-10-14 12:06:26.021063+03
6040	40	-1	1430	2019-10-14 12:13:44.147906+03
6041	84	-1	2700	2019-10-14 12:15:39.643803+03
6042	56	-1	2460	2019-10-14 12:17:47.818283+03
6043	14	-1	1350	2019-10-14 12:28:41.77442+03
6044	17	-2	1500	2019-10-14 12:45:24.198455+03
6045	14	-1	1350	2019-10-14 12:49:14.564464+03
6046	82	-1	560	2019-10-14 13:21:02.24399+03
6047	49	-1	970	2019-10-14 13:29:35.968568+03
6048	17	-1	1500	2019-10-14 13:31:51.205345+03
6049	73	-1	960	2019-10-14 13:42:10.93345+03
6050	27	-1	880	2019-10-14 14:03:29.424834+03
6051	60	-1	2700	2019-10-14 14:03:57.349779+03
6052	87	-2	2320	2019-10-14 14:08:18.329565+03
6053	78	-1	900	2019-10-14 14:13:20.554055+03
6054	75	-1	830	2019-10-14 14:51:44.508317+03
6055	6	-1	980	2019-10-14 15:09:54.801714+03
6056	20	-3	830	2019-10-14 15:44:02.891433+03
6057	96	31	710	2019-10-14 15:46:02.03776+03
6058	88	-2	1270	2019-10-14 15:46:35.104356+03
6059	4	-1	1420	2019-10-14 16:18:44.910719+03
6060	54	-1	3470	2019-10-14 16:27:53.719229+03
6061	79	-1	550	2019-10-14 17:02:30.456336+03
6062	71	35	595	2019-10-14 17:15:24.332259+03
6063	47	-1	1480	2019-10-14 17:34:25.93905+03
6064	39	-1	910	2019-10-14 17:44:10.164547+03
6065	85	-1	730	2019-10-14 17:57:41.302079+03
6066	20	-1	830	2019-10-14 18:09:44.964716+03
6067	29	-1	1940	2019-10-14 18:26:33.756174+03
6068	69	-1	1100	2019-10-14 18:53:20.028895+03
6069	6	-1	980	2019-10-14 19:04:26.536311+03
6070	94	-1	1230	2019-10-14 19:06:01.266+03
6071	58	-1	2830	2019-10-14 19:10:31.554974+03
6072	4	-1	1420	2019-10-14 19:10:37.191976+03
6073	59	-1	1030	2019-10-14 19:15:12.900175+03
6074	95	-1	480	2019-10-14 19:23:51.801227+03
6075	67	-1	350	2019-10-14 19:50:04.112665+03
6076	35	-1	670	2019-10-14 20:53:08.434548+03
6077	11	-1	830	2019-10-14 22:07:09.710575+03
6078	81	-1	1620	2019-10-14 22:07:28.177658+03
6079	37	-2	1290	2019-10-14 22:15:04.182966+03
6080	21	-1	960	2019-10-14 22:16:07.861439+03
6081	34	-1	1550	2019-10-14 22:35:21.752181+03
6082	92	-1	630	2019-10-14 22:37:21.269329+03
6083	32	-1	710	2019-10-14 22:53:19.150671+03
6084	77	-1	640	2019-10-14 23:04:37.664403+03
6085	24	-1	950	2019-10-14 23:08:15.024198+03
6086	17	-1	1500	2019-10-14 23:25:48.534539+03
6087	80	-1	1120	2019-10-14 23:40:34.240275+03
6088	31	-1	1190	2019-10-14 23:43:23.335094+03
6089	74	-1	1010	2019-10-15 00:32:09.085195+03
6090	67	33	175	2019-10-15 01:01:58.529113+03
6091	18	-1	910	2019-10-15 01:33:27.900289+03
6092	35	-1	670	2019-10-15 01:33:57.780864+03
6093	87	-1	2320	2019-10-15 01:39:00.413086+03
6094	20	-2	830	2019-10-15 01:59:10.3679+03
6095	54	-1	3470	2019-10-15 01:59:10.459199+03
6096	57	-2	1900	2019-10-15 02:40:44.490718+03
6097	93	-1	1620	2019-10-15 02:54:14.001267+03
6098	92	-1	630	2019-10-15 03:06:57.250014+03
6099	75	-1	830	2019-10-15 03:09:48.213584+03
6100	10	-1	2080	2019-10-15 03:16:45.968583+03
6101	41	-1	830	2019-10-15 03:17:11.801874+03
6102	59	-1	1030	2019-10-15 04:14:37.500086+03
6103	73	-1	960	2019-10-15 04:20:26.165787+03
6104	89	-1	1420	2019-10-15 04:23:12.064369+03
6105	17	-1	1500	2019-10-15 04:28:51.141787+03
6106	57	-1	1900	2019-10-15 04:32:55.622363+03
6107	1	-2	640	2019-10-15 05:20:34.890995+03
6108	33	-1	900	2019-10-15 05:40:42.207127+03
6109	43	-2	380	2019-10-15 05:55:15.976846+03
6110	47	-1	1480	2019-10-15 06:01:03.802473+03
6111	36	-1	630	2019-10-15 06:27:45.285695+03
6112	47	-1	1480	2019-10-15 06:38:30.397593+03
6113	45	-1	1590	2019-10-15 06:45:54.354199+03
6114	79	-1	550	2019-10-15 07:01:47.189555+03
6115	10	32	1225	2019-10-15 07:19:30.454351+03
6116	85	-1	730	2019-10-15 07:19:37.176828+03
6117	83	-1	1230	2019-10-15 07:21:43.549579+03
6118	96	-1	1570	2019-10-15 07:50:15.873007+03
6119	9	-1	2090	2019-10-15 07:59:16.161128+03
6120	40	-1	1430	2019-10-15 08:04:08.088409+03
6121	47	-2	1480	2019-10-15 08:10:00.579394+03
6122	74	-2	1010	2019-10-15 08:30:56.694122+03
6123	13	-1	460	2019-10-15 09:20:53.789751+03
6124	11	-1	830	2019-10-15 09:27:19.513192+03
6125	71	-1	1030	2019-10-15 09:42:49.888891+03
6126	85	-1	730	2019-10-15 10:54:10.084041+03
6127	39	-1	910	2019-10-15 11:00:47.674132+03
6128	83	-1	1230	2019-10-15 11:48:17.277985+03
6129	30	-1	1140	2019-10-15 12:02:08.031236+03
6130	56	-2	2460	2019-10-15 12:02:42.049107+03
6131	76	-2	1070	2019-10-15 12:07:39.02049+03
6132	68	-1	490	2019-10-15 12:15:43.485786+03
6133	42	-1	1790	2019-10-15 12:53:00.189357+03
6134	21	-1	960	2019-10-15 12:53:47.055082+03
6135	38	-1	1100	2019-10-15 12:57:58.442411+03
6136	58	-1	2830	2019-10-15 13:12:21.001316+03
6137	6	-1	980	2019-10-15 13:26:52.732184+03
6138	4	-1	1420	2019-10-15 13:38:57.46217+03
6139	87	-1	2320	2019-10-15 13:51:54.426047+03
6140	13	-1	460	2019-10-15 14:28:55.410988+03
6141	78	-1	900	2019-10-15 15:07:26.823955+03
6142	83	-2	1230	2019-10-15 15:15:48.201476+03
6143	40	-2	1430	2019-10-15 15:34:59.038277+03
6144	77	-2	640	2019-10-15 15:35:39.165285+03
6145	50	-1	1140	2019-10-15 15:36:06.704231+03
6146	8	-1	1920	2019-10-15 16:19:24.341281+03
6147	45	-1	1590	2019-10-15 16:47:37.476711+03
6148	41	-1	830	2019-10-15 17:15:08.420961+03
6149	19	-1	1220	2019-10-15 17:19:21.323738+03
6150	60	-3	2700	2019-10-15 17:23:21.549081+03
6151	57	-2	1900	2019-10-15 17:40:49.932079+03
6152	18	-1	910	2019-10-15 17:43:50.731757+03
6153	80	-1	1120	2019-10-15 17:50:51.024011+03
6154	19	-2	1220	2019-10-15 18:05:18.814488+03
6155	46	-1	1270	2019-10-15 18:10:37.979689+03
6156	37	-1	1290	2019-10-15 18:31:43.351465+03
6157	32	-1	710	2019-10-15 18:43:06.433661+03
6158	91	-1	1620	2019-10-15 18:47:01.62618+03
6159	14	-2	1350	2019-10-15 18:49:28.278208+03
6160	59	-1	1030	2019-10-15 19:45:29.843095+03
6161	31	-1	1190	2019-10-15 19:48:57.113009+03
6162	46	-2	1270	2019-10-15 19:51:33.768065+03
6163	19	-1	1220	2019-10-15 20:23:02.615424+03
6164	65	-1	490	2019-10-15 20:23:08.126277+03
6165	80	-2	1120	2019-10-15 20:27:45.12549+03
6166	56	-1	2460	2019-10-15 20:35:45.217557+03
6167	34	-1	1550	2019-10-15 20:43:09.532799+03
6168	14	-1	1350	2019-10-15 20:55:25.953863+03
6169	26	-1	390	2019-10-15 21:09:16.025975+03
6170	23	-1	4390	2019-10-15 21:22:44.072699+03
6171	7	-1	810	2019-10-15 21:42:25.522803+03
6172	6	-1	980	2019-10-15 21:46:36.925559+03
6173	42	-1	1790	2019-10-15 21:47:20.900774+03
6174	34	-1	1550	2019-10-15 21:55:31.878547+03
6175	4	-1	1420	2019-10-15 22:31:20.331932+03
6176	7	-2	810	2019-10-15 23:00:22.964221+03
6177	61	-1	1510	2019-10-15 23:32:59.010657+03
6178	13	-1	460	2019-10-15 23:57:09.316872+03
6179	63	-1	1780	2019-10-16 00:00:51.270331+03
6180	71	-1	1030	2019-10-16 00:09:24.934062+03
6181	58	-1	2830	2019-10-16 00:18:32.849492+03
6182	57	-1	1900	2019-10-16 00:22:14.511632+03
6183	58	-1	2830	2019-10-16 00:24:34.404319+03
6184	8	-1	1920	2019-10-16 00:26:45.407827+03
6185	46	-1	1270	2019-10-16 01:03:37.952711+03
6186	90	-1	1780	2019-10-16 01:08:18.319864+03
6187	68	-1	490	2019-10-16 01:28:57.317616+03
6188	71	-1	1030	2019-10-16 01:36:48.736902+03
6189	67	-1	350	2019-10-16 01:38:30.80551+03
6190	21	-1	960	2019-10-16 01:51:59.413575+03
6191	81	-1	1620	2019-10-16 01:59:30.633014+03
6192	63	-1	1780	2019-10-16 02:00:43.151282+03
6193	88	-2	1270	2019-10-16 02:10:27.906175+03
6194	72	-1	620	2019-10-16 02:12:53.865856+03
6195	42	-2	1790	2019-10-16 02:29:36.711466+03
6196	35	-1	670	2019-10-16 02:40:08.407104+03
6197	86	-2	910	2019-10-16 02:41:26.924936+03
6198	35	-1	670	2019-10-16 02:43:14.20063+03
6199	41	-1	830	2019-10-16 03:08:30.994554+03
6200	47	-1	1480	2019-10-16 03:13:34.84456+03
6201	78	-1	900	2019-10-16 03:45:45.963666+03
6202	55	-2	3480	2019-10-16 03:52:47.831099+03
6203	29	-1	1940	2019-10-16 03:53:57.934544+03
6204	22	-1	1070	2019-10-16 04:08:33.749476+03
6205	83	-1	1230	2019-10-16 04:24:24.663485+03
6206	78	-1	900	2019-10-16 04:35:00.489287+03
6207	57	-1	1900	2019-10-16 04:50:53.961649+03
6208	12	-1	1650	2019-10-16 05:29:26.120888+03
6209	54	-1	3470	2019-10-16 06:00:34.987176+03
6210	35	-1	670	2019-10-16 06:06:43.770803+03
6211	4	-1	1420	2019-10-16 06:14:49.261846+03
6212	27	-1	880	2019-10-16 06:42:23.108179+03
6213	27	-1	880	2019-10-16 07:34:40.913949+03
6214	49	-1	970	2019-10-16 08:00:31.002263+03
6215	62	14	495	2019-10-16 08:04:24.049201+03
6216	58	-1	2830	2019-10-16 08:33:05.750761+03
6217	84	-1	2700	2019-10-16 08:47:05.049111+03
6218	95	-1	480	2019-10-16 08:50:58.729587+03
6219	57	-2	1900	2019-10-16 08:51:49.990684+03
6220	85	-1	730	2019-10-16 08:52:31.030116+03
6221	52	-1	1090	2019-10-16 09:11:54.22985+03
6222	9	-1	2090	2019-10-16 09:30:22.049456+03
6223	88	-1	1270	2019-10-16 09:37:24.014415+03
6224	7	-1	810	2019-10-16 09:38:31.130362+03
6225	13	-1	460	2019-10-16 10:18:06.737183+03
6226	23	-1	4390	2019-10-16 10:44:46.406367+03
6227	5	-2	1620	2019-10-16 10:46:05.348411+03
6228	51	-1	1310	2019-10-16 10:50:06.631274+03
6229	25	-1	1100	2019-10-16 11:26:57.035729+03
6230	71	-1	1030	2019-10-16 11:33:13.206242+03
6231	1	-1	640	2019-10-16 11:36:15.140707+03
6232	27	-1	880	2019-10-16 11:36:18.142647+03
6233	46	-1	1270	2019-10-16 11:45:51.7626+03
6234	13	-1	460	2019-10-16 11:51:19.973076+03
6235	34	-1	1550	2019-10-16 11:53:46.416676+03
6236	67	-2	350	2019-10-16 12:03:41.98074+03
6237	57	-2	1900	2019-10-16 12:19:59.837141+03
6238	93	-1	1620	2019-10-16 12:30:25.097122+03
6239	69	-1	1100	2019-10-16 12:38:59.630517+03
6240	55	-2	3480	2019-10-16 12:44:34.161842+03
6241	82	20	228	2019-10-16 13:16:55.53021+03
6242	77	-1	640	2019-10-16 13:23:11.901557+03
6243	22	-1	1070	2019-10-16 14:46:25.599093+03
6244	40	-2	1430	2019-10-16 14:50:14.062699+03
6245	2	-1	470	2019-10-16 15:10:25.338795+03
6246	96	-1	1570	2019-10-16 15:34:28.749592+03
6247	10	-1	2080	2019-10-16 15:48:18.325725+03
6248	84	-1	2700	2019-10-16 15:54:02.605964+03
6249	30	-1	1140	2019-10-16 15:57:01.288138+03
6250	87	-1	2320	2019-10-16 16:02:44.776807+03
6251	61	-1	1510	2019-10-16 16:39:36.689142+03
6252	10	-1	2080	2019-10-16 16:58:02.158462+03
6253	30	-1	1140	2019-10-16 16:59:00.509568+03
6254	12	-1	1650	2019-10-16 17:10:53.34789+03
6255	33	-1	900	2019-10-16 17:20:46.028556+03
6256	2	-1	470	2019-10-16 17:44:02.79438+03
6257	95	-2	480	2019-10-16 17:54:39.079378+03
6258	25	-1	1100	2019-10-16 18:08:00.259141+03
6259	69	-2	1100	2019-10-16 18:08:42.475913+03
6260	18	-1	910	2019-10-16 18:09:00.718299+03
6261	29	-1	1940	2019-10-16 18:53:24.657642+03
6262	75	-1	830	2019-10-16 19:01:42.208421+03
6263	74	-1	1010	2019-10-16 19:04:32.14431+03
6264	81	-1	1620	2019-10-16 19:43:00.258353+03
6265	18	-1	910	2019-10-16 19:46:33.083688+03
6266	67	-1	350	2019-10-16 20:10:40.413742+03
6267	54	-1	3470	2019-10-16 20:56:07.07678+03
6268	67	-1	350	2019-10-16 21:23:43.172472+03
6269	90	-1	1780	2019-10-16 21:31:06.449316+03
6270	7	-1	810	2019-10-16 21:37:29.473453+03
6271	95	-1	480	2019-10-16 22:08:14.843339+03
6272	89	-1	1420	2019-10-16 22:13:50.601111+03
6273	24	-1	950	2019-10-16 22:14:25.733891+03
6274	21	-1	960	2019-10-16 22:16:08.720219+03
6275	6	-1	980	2019-10-16 22:16:55.271804+03
6276	12	-1	1650	2019-10-16 22:27:29.922785+03
6277	17	-1	1500	2019-10-16 22:32:15.260294+03
6278	77	-2	640	2019-10-16 22:43:34.188751+03
6279	54	-1	3470	2019-10-16 23:06:40.238326+03
6280	94	-1	1230	2019-10-16 23:07:07.265683+03
6281	64	-1	970	2019-10-16 23:08:17.535884+03
6282	20	-1	830	2019-10-16 23:12:13.284246+03
6283	52	-1	1090	2019-10-16 23:12:18.369038+03
6284	95	-1	480	2019-10-16 23:24:12.118899+03
6285	60	-2	2700	2019-10-16 23:48:17.554173+03
6286	80	-1	1120	2019-10-17 00:21:29.274498+03
6287	84	-1	2700	2019-10-17 00:46:02.186568+03
6288	82	-2	560	2019-10-17 00:46:49.205324+03
6289	34	-1	1550	2019-10-17 01:01:53.062349+03
6290	43	13	171	2019-10-17 01:03:36.884029+03
6291	1	-2	640	2019-10-17 01:06:55.964352+03
6292	49	-1	970	2019-10-17 01:11:56.328092+03
6293	78	-2	900	2019-10-17 01:29:13.215593+03
6294	6	-1	980	2019-10-17 01:55:50.703686+03
6295	59	-1	1030	2019-10-17 01:57:02.176823+03
6296	96	-1	1570	2019-10-17 02:14:19.70119+03
6297	36	-1	630	2019-10-17 02:20:13.324253+03
6298	54	-1	3470	2019-10-17 02:23:24.480559+03
6299	83	29	574	2019-10-17 02:48:12.750437+03
6300	29	-1	1940	2019-10-17 03:25:49.856912+03
6301	77	-1	640	2019-10-17 03:28:42.102589+03
6302	71	-1	1030	2019-10-17 03:59:18.815933+03
6303	43	-1	380	2019-10-17 04:10:39.927249+03
6304	15	-1	2830	2019-10-17 04:23:02.009103+03
6305	93	-1	1620	2019-10-17 04:37:14.119836+03
6306	54	-1	3470	2019-10-17 04:37:58.856923+03
6307	41	-1	830	2019-10-17 05:18:53.64689+03
6308	7	-1	810	2019-10-17 05:36:41.125788+03
6309	17	-1	1500	2019-10-17 06:11:40.485036+03
6310	21	-1	960	2019-10-17 06:19:07.305479+03
6311	75	-1	830	2019-10-17 06:59:28.486529+03
6312	32	-1	710	2019-10-17 07:05:33.014731+03
6313	33	-1	900	2019-10-17 07:06:02.274277+03
6314	27	-2	880	2019-10-17 07:10:46.949881+03
6315	67	-1	350	2019-10-17 07:41:20.647889+03
6316	74	-1	1010	2019-10-17 07:57:10.104156+03
6317	25	16	483	2019-10-17 08:03:29.832274+03
6318	93	-2	1620	2019-10-17 08:22:45.581789+03
6319	61	-2	1510	2019-10-17 08:27:34.402944+03
6320	49	-1	970	2019-10-17 08:36:37.003385+03
6321	95	-1	480	2019-10-17 08:41:56.687172+03
6322	57	-2	1900	2019-10-17 09:30:03.773311+03
6323	19	-1	1220	2019-10-17 10:13:49.059089+03
6324	62	-2	1220	2019-10-17 10:25:21.758974+03
6325	51	13	536	2019-10-17 10:35:34.119187+03
6326	23	-1	4390	2019-10-17 10:37:44.605576+03
6327	22	-1	1070	2019-10-17 10:42:34.935701+03
6328	46	-1	1270	2019-10-17 10:43:22.867474+03
6329	6	-2	980	2019-10-17 11:28:44.76472+03
6330	16	-2	1380	2019-10-17 11:34:34.96058+03
6331	82	-1	560	2019-10-17 11:36:57.233354+03
6332	4	-1	1420	2019-10-17 11:39:57.3158+03
6333	89	-2	1420	2019-10-17 11:41:57.965414+03
6334	30	-1	1140	2019-10-17 12:14:17.50441+03
6335	55	-1	3480	2019-10-17 12:26:59.170913+03
6336	53	-2	3120	2019-10-17 12:31:09.451812+03
6337	38	-1	1100	2019-10-17 13:04:05.000891+03
6338	57	34	974	2019-10-17 13:11:29.450964+03
6339	12	-1	1650	2019-10-17 14:10:18.885162+03
6340	29	-1	1940	2019-10-17 14:10:46.90399+03
6341	34	-1	1550	2019-10-17 14:32:56.269435+03
6342	17	-1	1500	2019-10-17 14:46:51.714776+03
6343	37	-1	1290	2019-10-17 15:03:16.337194+03
6344	73	-1	960	2019-10-17 15:45:22.188738+03
6345	53	-1	3120	2019-10-17 15:47:56.157507+03
6346	24	19	470	2019-10-17 16:33:26.565264+03
6347	84	-1	2700	2019-10-17 17:07:14.635968+03
6348	41	-1	830	2019-10-17 17:12:17.163989+03
6349	32	-1	710	2019-10-17 17:43:20.293287+03
6350	10	-2	2080	2019-10-17 17:44:04.306578+03
6351	29	-1	1940	2019-10-17 18:02:54.804159+03
6352	96	-1	1570	2019-10-17 18:05:51.733611+03
6353	29	-1	1940	2019-10-17 18:29:33.740598+03
6354	68	-2	490	2019-10-17 18:31:08.765489+03
6355	25	-1	1100	2019-10-17 18:31:49.436241+03
6356	49	-1	970	2019-10-17 19:01:50.532104+03
6357	19	-1	1220	2019-10-17 19:12:02.537463+03
6358	74	-2	1010	2019-10-17 19:13:06.256762+03
6359	46	-2	1270	2019-10-17 19:13:42.500938+03
6360	14	-2	1350	2019-10-17 19:15:51.695691+03
6361	10	-1	2080	2019-10-17 19:26:50.103939+03
6362	96	-1	1570	2019-10-17 19:38:03.424485+03
6363	22	-1	1070	2019-10-17 20:09:27.948612+03
6364	67	-1	350	2019-10-17 20:17:36.839098+03
6365	7	-1	810	2019-10-17 20:45:26.233507+03
6366	1	-1	640	2019-10-17 20:53:52.637439+03
6367	57	-1	1900	2019-10-17 21:12:25.914982+03
6368	87	-1	2320	2019-10-17 21:37:40.412358+03
6369	79	-2	550	2019-10-17 21:41:35.385163+03
6370	23	-1	4390	2019-10-17 21:46:08.941607+03
6371	4	-1	1420	2019-10-17 21:49:27.329581+03
6372	3	-1	660	2019-10-17 21:59:11.758978+03
6373	14	-1	1350	2019-10-17 22:16:47.39816+03
6374	6	-1	980	2019-10-17 22:38:52.905454+03
6375	37	-1	1290	2019-10-17 22:43:20.227004+03
6376	10	-1	2080	2019-10-17 23:05:20.170044+03
6377	71	-1	1030	2019-10-17 23:06:38.155149+03
6378	9	-1	2090	2019-10-17 23:19:46.083791+03
6379	12	-1	1650	2019-10-17 23:57:42.963751+03
6380	92	-1	630	2019-10-18 00:01:18.99927+03
6381	5	-1	1620	2019-10-18 00:15:10.011871+03
6382	33	-1	900	2019-10-18 00:16:44.988289+03
6383	41	-1	830	2019-10-18 00:21:51.040057+03
6384	30	-1	1140	2019-10-18 00:52:03.416643+03
6385	47	-1	1480	2019-10-18 01:42:22.637107+03
6386	44	-1	500	2019-10-18 01:49:10.70644+03
6387	96	-1	1570	2019-10-18 02:20:10.037388+03
6388	95	-2	480	2019-10-18 02:34:24.291289+03
6389	87	-1	2320	2019-10-18 02:38:13.752826+03
6390	29	-1	1940	2019-10-18 02:46:02.30476+03
6391	22	-1	1070	2019-10-18 02:47:06.926831+03
6392	18	-1	910	2019-10-18 02:48:38.696544+03
6393	70	-1	760	2019-10-18 02:50:18.659486+03
6394	62	-1	1220	2019-10-18 02:50:23.25056+03
6395	59	-2	1030	2019-10-18 03:21:50.22563+03
6396	38	-1	1100	2019-10-18 03:27:12.615222+03
6397	29	-1	1940	2019-10-18 03:28:39.580258+03
6398	27	-1	880	2019-10-18 03:30:17.255556+03
6399	51	-1	1310	2019-10-18 04:00:18.722111+03
6400	14	-1	1350	2019-10-18 04:01:55.62635+03
6401	78	-1	900	2019-10-18 05:04:06.822101+03
6402	56	-1	2460	2019-10-18 05:09:02.026025+03
6403	64	-1	970	2019-10-18 05:35:51.095603+03
6404	78	-1	900	2019-10-18 05:42:03.649419+03
6405	74	-1	1010	2019-10-18 05:44:22.46354+03
6406	77	-1	640	2019-10-18 05:51:06.562953+03
6407	14	-1	1350	2019-10-18 06:03:04.932787+03
6408	57	-2	1900	2019-10-18 06:12:34.291994+03
6409	80	-1	1120	2019-10-18 06:22:18.904302+03
6410	29	-1	1940	2019-10-18 06:28:57.923522+03
6411	20	-1	830	2019-10-18 06:30:16.963149+03
6412	36	-1	630	2019-10-18 06:40:13.152286+03
6413	45	-1	1590	2019-10-18 07:16:36.541232+03
6414	89	-2	1420	2019-10-18 07:33:43.285445+03
6415	33	-2	900	2019-10-18 08:02:11.896074+03
6416	31	-2	1190	2019-10-18 08:09:03.129728+03
6417	87	-1	2320	2019-10-18 08:22:53.527668+03
6418	70	-1	760	2019-10-18 08:24:30.29081+03
6419	27	-1	880	2019-10-18 08:28:57.999175+03
6420	88	21	530	2019-10-18 08:52:59.347867+03
6421	34	-1	1550	2019-10-18 08:56:41.417757+03
6422	30	-1	1140	2019-10-18 09:06:22.550808+03
6423	7	-1	810	2019-10-18 09:12:09.698793+03
6424	69	-1	1100	2019-10-18 09:22:48.184238+03
6425	37	-2	1290	2019-10-18 09:56:25.629899+03
6426	34	-1	1550	2019-10-18 10:02:58.140931+03
6427	75	-1	830	2019-10-18 10:03:30.734566+03
6428	71	-1	1030	2019-10-18 10:33:37.853668+03
6429	50	-1	1140	2019-10-18 10:40:10.551623+03
6430	71	-1	1030	2019-10-18 11:03:28.569829+03
6431	49	-1	970	2019-10-18 11:13:22.606459+03
6432	38	-1	1100	2019-10-18 11:18:40.068178+03
6433	61	-1	1510	2019-10-18 11:24:20.50333+03
6434	94	-1	1230	2019-10-18 11:32:33.765567+03
6435	38	-1	1100	2019-10-18 12:08:00.097823+03
6436	59	-1	1030	2019-10-18 13:25:22.517558+03
6437	83	-1	1230	2019-10-18 13:49:53.502273+03
6438	41	-1	830	2019-10-18 13:56:04.260552+03
6439	3	-1	660	2019-10-18 14:32:15.210662+03
6440	64	-1	970	2019-10-18 14:52:34.704224+03
6441	90	-1	1780	2019-10-18 15:05:46.230331+03
6442	96	-2	1570	2019-10-18 15:17:28.944876+03
6443	77	-1	640	2019-10-18 15:45:10.454149+03
6444	42	-2	1790	2019-10-18 15:45:26.358558+03
6445	95	-1	480	2019-10-18 15:49:03.632537+03
6446	60	-1	2700	2019-10-18 16:03:30.178724+03
6447	71	-2	1030	2019-10-18 16:24:12.699281+03
6448	14	-1	1350	2019-10-18 16:29:18.032418+03
6449	47	-2	1480	2019-10-18 17:17:56.49967+03
6450	59	-1	1030	2019-10-18 17:25:05.765057+03
6451	27	-1	880	2019-10-18 18:03:43.636117+03
6452	66	13	377	2019-10-18 18:04:37.362963+03
6453	12	-1	1650	2019-10-18 18:11:24.732755+03
6454	87	-1	2320	2019-10-18 18:26:12.844306+03
6455	4	-1	1420	2019-10-18 18:34:33.632299+03
6456	75	-1	830	2019-10-18 18:42:52.802288+03
6457	77	-1	640	2019-10-18 18:55:19.808818+03
6458	24	-2	950	2019-10-18 19:24:53.769182+03
6459	34	-1	1550	2019-10-18 19:35:47.114448+03
6460	43	-1	380	2019-10-18 19:42:48.508341+03
6461	22	-2	1070	2019-10-18 19:59:07.16616+03
6462	46	-1	1270	2019-10-18 20:23:33.341098+03
6463	48	-2	640	2019-10-18 20:47:26.272855+03
6464	74	25	433	2019-10-18 21:25:43.417674+03
6465	1	-1	640	2019-10-18 21:46:14.351631+03
6466	64	-1	970	2019-10-18 22:03:58.425441+03
6467	91	-1	1620	2019-10-18 22:08:48.302415+03
6468	59	-2	1030	2019-10-18 22:09:18.442125+03
6469	14	-1	1350	2019-10-18 22:34:07.442311+03
6470	78	-1	900	2019-10-18 23:13:21.369436+03
6471	5	-2	1620	2019-10-18 23:18:20.854274+03
6472	36	-1	630	2019-10-18 23:35:21.388743+03
6473	3	-1	660	2019-10-18 23:44:18.100411+03
6474	59	-1	1030	2019-10-18 23:45:55.127936+03
6475	64	-1	970	2019-10-19 00:03:19.767165+03
6476	36	-1	630	2019-10-19 00:10:15.547776+03
6477	78	24	361	2019-10-19 00:36:20.604648+03
6478	59	-1	1030	2019-10-19 00:50:57.568096+03
6479	58	-2	2830	2019-10-19 02:00:18.381434+03
6480	68	-1	490	2019-10-19 02:05:27.199937+03
6481	45	-1	1590	2019-10-19 02:09:09.029619+03
6482	10	-1	2080	2019-10-19 02:25:37.167518+03
6483	85	-1	730	2019-10-19 02:50:05.920596+03
6484	69	-1	1100	2019-10-19 03:14:53.622519+03
6485	86	-2	910	2019-10-19 03:26:44.205772+03
6486	14	-1	1350	2019-10-19 04:07:03.0765+03
6487	6	-1	980	2019-10-19 04:11:32.363751+03
6488	42	-1	1790	2019-10-19 04:15:15.159439+03
6489	55	-1	3480	2019-10-19 04:17:44.090872+03
6490	14	-2	1350	2019-10-19 04:23:58.423597+03
6491	57	-1	1900	2019-10-19 05:24:40.687454+03
6492	21	-1	960	2019-10-19 05:31:34.810982+03
6493	71	-1	1030	2019-10-19 05:35:58.797197+03
6494	55	-1	3480	2019-10-19 05:43:53.261667+03
6495	35	-1	670	2019-10-19 05:45:36.974655+03
6496	69	-2	1100	2019-10-19 05:50:10.597631+03
6497	7	-1	810	2019-10-19 06:13:17.571395+03
6498	87	-2	2320	2019-10-19 07:08:38.749917+03
6499	58	-1	2830	2019-10-19 07:17:34.32582+03
6500	49	-1	970	2019-10-19 07:37:14.620862+03
6501	18	-1	910	2019-10-19 08:03:17.536632+03
6502	93	-1	1620	2019-10-19 08:05:39.565097+03
6503	82	-1	560	2019-10-19 08:37:13.800598+03
6504	30	-1	1140	2019-10-19 08:45:53.675831+03
6505	63	-1	1780	2019-10-19 08:47:10.414943+03
6506	96	-1	1570	2019-10-19 08:56:11.195583+03
6507	18	-1	910	2019-10-19 09:26:45.606344+03
6508	77	-2	640	2019-10-19 09:33:55.674595+03
6509	81	-1	1620	2019-10-19 09:43:48.670484+03
6510	91	-1	1620	2019-10-19 10:09:45.394589+03
6511	39	-1	910	2019-10-19 10:53:53.031811+03
6512	67	-1	350	2019-10-19 11:05:04.758309+03
6513	79	-1	550	2019-10-19 11:28:12.910532+03
6514	73	-1	960	2019-10-19 12:01:12.291118+03
6515	83	-1	1230	2019-10-19 12:01:43.634262+03
6516	94	-1	1230	2019-10-19 12:11:08.331353+03
6517	74	-1	1010	2019-10-19 12:19:02.271829+03
6518	2	-1	470	2019-10-19 12:20:41.377016+03
6519	4	-1	1420	2019-10-19 12:29:10.972969+03
6520	91	-1	1620	2019-10-19 12:53:46.767611+03
6521	69	-1	1100	2019-10-19 12:57:20.514256+03
6522	5	-1	1620	2019-10-19 13:28:47.438937+03
6523	90	-1	1780	2019-10-19 13:44:22.238429+03
6524	57	-2	1900	2019-10-19 14:10:25.801757+03
6525	91	-1	1620	2019-10-19 14:35:37.333098+03
6526	77	-1	640	2019-10-19 14:53:01.023927+03
6527	64	-2	970	2019-10-19 14:57:05.386645+03
6528	14	-1	1350	2019-10-19 16:39:45.685659+03
6529	94	-1	1230	2019-10-19 16:42:21.139423+03
6530	49	-1	970	2019-10-19 16:45:19.844498+03
6531	55	-2	3480	2019-10-19 16:52:23.785355+03
6532	22	-1	1070	2019-10-19 16:59:56.547018+03
6533	26	-1	390	2019-10-19 17:01:16.498048+03
6534	82	-2	560	2019-10-19 17:19:22.228127+03
6535	6	-1	980	2019-10-19 17:34:28.977918+03
6536	49	-1	970	2019-10-19 17:40:16.070795+03
6537	21	-1	960	2019-10-19 17:48:16.650959+03
6538	30	-2	1140	2019-10-19 18:24:40.995287+03
6539	24	-1	950	2019-10-19 18:27:35.132985+03
6540	58	-1	2830	2019-10-19 19:25:29.944018+03
6541	49	-1	970	2019-10-19 19:30:29.751284+03
6542	42	-1	1790	2019-10-19 19:35:07.792413+03
6543	29	-1	1940	2019-10-19 19:41:25.363289+03
6544	12	-1	1650	2019-10-19 19:58:55.059449+03
6545	71	-1	1030	2019-10-19 20:04:45.829773+03
6546	32	-1	710	2019-10-19 20:21:55.47131+03
6547	10	-1	2080	2019-10-19 20:27:29.126574+03
6548	70	-1	760	2019-10-19 20:33:21.921502+03
6549	63	-1	1780	2019-10-19 21:02:08.216103+03
6550	86	-1	910	2019-10-19 21:38:27.425073+03
6551	82	-1	560	2019-10-19 22:53:45.344641+03
6552	71	-1	1030	2019-10-19 23:03:26.334652+03
6553	32	-1	710	2019-10-19 23:10:18.641503+03
6554	89	-1	1420	2019-10-19 23:10:52.888164+03
6555	58	-1	2830	2019-10-19 23:32:28.415508+03
6556	63	-1	1780	2019-10-20 00:24:14.797253+03
6557	72	-2	620	2019-10-20 00:41:31.863734+03
6558	13	-1	460	2019-10-20 00:51:41.150734+03
6559	20	-1	830	2019-10-20 01:00:03.588956+03
6560	70	-1	760	2019-10-20 01:00:25.092852+03
6561	77	-1	640	2019-10-20 01:01:06.781532+03
6562	55	-2	3480	2019-10-20 01:03:41.663505+03
6563	94	-3	1230	2019-10-20 01:07:49.912228+03
6564	66	-1	690	2019-10-20 01:12:58.93092+03
6565	29	-1	1940	2019-10-20 01:16:18.454662+03
6566	12	-1	1650	2019-10-20 01:16:32.134146+03
6567	16	15	827	2019-10-20 01:36:27.708121+03
6568	45	-2	1590	2019-10-20 01:43:29.232372+03
6569	83	-1	1230	2019-10-20 02:00:08.744465+03
6570	8	-1	1920	2019-10-20 02:42:55.613482+03
6571	69	-1	1100	2019-10-20 02:59:54.924852+03
6572	50	-1	1140	2019-10-20 03:04:11.04084+03
6573	8	-1	1920	2019-10-20 03:11:39.341887+03
6574	17	-1	1500	2019-10-20 03:21:46.161577+03
6575	95	-1	480	2019-10-20 04:06:47.276116+03
6576	47	-2	1480	2019-10-20 04:19:40.896492+03
6577	34	-2	1550	2019-10-20 04:22:06.28857+03
6578	73	-2	960	2019-10-20 04:32:51.026638+03
6579	26	-2	390	2019-10-20 04:34:33.682374+03
6580	9	-1	2090	2019-10-20 04:35:41.982779+03
6581	11	-1	830	2019-10-20 04:53:32.426465+03
6582	33	-1	900	2019-10-20 04:56:50.038923+03
6583	40	-1	1430	2019-10-20 04:59:07.959702+03
6584	60	-2	2700	2019-10-20 05:12:29.633427+03
6585	79	-2	550	2019-10-20 05:14:23.088964+03
6586	85	-1	730	2019-10-20 05:21:04.234041+03
6587	22	-2	1070	2019-10-20 05:24:18.458206+03
6588	83	-2	1230	2019-10-20 06:00:55.909448+03
6589	52	-2	1090	2019-10-20 06:06:09.306367+03
6590	52	-1	1090	2019-10-20 06:22:47.278549+03
6591	58	-1	2830	2019-10-20 06:25:56.062112+03
6592	7	-1	810	2019-10-20 06:28:04.625619+03
6593	48	-2	640	2019-10-20 06:45:26.352666+03
6594	46	-2	1270	2019-10-20 07:15:45.348872+03
6595	74	-2	1010	2019-10-20 07:30:38.043609+03
6596	51	-2	1310	2019-10-20 07:41:28.799587+03
6597	64	-1	970	2019-10-20 07:56:25.89993+03
6598	96	-1	1570	2019-10-20 08:11:03.763074+03
6599	30	-1	1140	2019-10-20 08:13:31.459674+03
6600	13	-1	460	2019-10-20 08:28:58.342934+03
6601	44	-1	500	2019-10-20 08:39:44.2494+03
6602	44	-1	500	2019-10-20 08:42:00.63665+03
6603	9	-1	2090	2019-10-20 09:16:56.401897+03
6604	67	-2	350	2019-10-20 09:30:57.977219+03
6605	58	-1	2830	2019-10-20 09:37:33.523077+03
6606	60	-1	2700	2019-10-20 09:49:59.443386+03
6607	29	-1	1940	2019-10-20 09:54:55.44696+03
6608	47	-1	1480	2019-10-20 10:03:30.624264+03
6609	16	-2	1380	2019-10-20 10:18:06.573979+03
6610	50	-1	1140	2019-10-20 10:42:02.30955+03
6611	68	-1	490	2019-10-20 11:16:41.669863+03
6612	1	-1	640	2019-10-20 11:43:33.779957+03
6613	38	-1	1100	2019-10-20 12:07:11.722324+03
6614	54	-1	3470	2019-10-20 12:37:14.936362+03
6615	96	-1	1570	2019-10-20 12:39:19.244153+03
6616	20	-1	830	2019-10-20 13:09:21.740547+03
6617	31	30	705	2019-10-20 13:40:19.100211+03
6618	15	-2	2830	2019-10-20 13:52:00.062627+03
6619	79	-1	550	2019-10-20 13:52:29.064772+03
6620	13	-1	460	2019-10-20 14:16:31.021642+03
6621	67	-1	350	2019-10-20 14:27:48.816389+03
6622	86	-1	910	2019-10-20 15:02:20.372433+03
6623	60	-2	2700	2019-10-20 15:12:33.729107+03
6624	10	-1	2080	2019-10-20 15:13:41.714697+03
6625	22	-2	1070	2019-10-20 15:38:56.604951+03
6626	65	-2	490	2019-10-20 15:41:46.833849+03
6627	4	-2	1420	2019-10-20 15:54:51.669685+03
6628	1	-1	640	2019-10-20 15:56:52.927458+03
6629	6	-1	980	2019-10-20 16:04:31.147996+03
6630	68	-1	490	2019-10-20 16:11:47.116342+03
6631	82	-1	560	2019-10-20 16:39:16.945948+03
6632	31	-1	1190	2019-10-20 16:41:25.084015+03
6633	69	-1	1100	2019-10-20 16:42:31.049109+03
6634	14	-2	1350	2019-10-20 17:01:54.51256+03
6635	71	-1	1030	2019-10-20 18:10:45.625436+03
6636	36	-1	630	2019-10-20 18:20:05.756506+03
6637	79	-1	550	2019-10-20 18:29:31.245256+03
6638	96	-1	1570	2019-10-20 18:45:46.251638+03
6639	75	-1	830	2019-10-20 19:55:16.001757+03
6640	85	-1	730	2019-10-20 20:08:04.181416+03
6641	5	-1	1620	2019-10-20 20:10:02.015868+03
6642	87	-1	2320	2019-10-20 20:34:01.85178+03
6643	49	-1	970	2019-10-20 20:34:39.184266+03
6644	92	-1	630	2019-10-20 20:53:02.579665+03
6645	47	-1	1480	2019-10-20 21:10:42.441567+03
6646	26	-1	390	2019-10-20 21:14:19.365238+03
6647	7	-1	810	2019-10-20 21:36:46.608736+03
6648	33	-1	900	2019-10-20 21:55:52.38986+03
6649	67	-1	350	2019-10-20 21:56:12.194287+03
6650	29	-2	1940	2019-10-20 22:09:31.067792+03
6651	82	-1	560	2019-10-20 22:25:13.729551+03
6652	92	-1	630	2019-10-20 22:36:35.975252+03
6653	95	-2	480	2019-10-20 22:55:49.403209+03
6654	74	-1	1010	2019-10-20 23:16:58.098428+03
6655	84	-1	2700	2019-10-20 23:27:31.228413+03
6656	57	-1	1900	2019-10-20 23:28:37.844032+03
6657	67	-2	350	2019-10-21 00:38:27.501561+03
6658	60	20	1285	2019-10-21 01:16:38.259981+03
6659	42	-2	1790	2019-10-21 01:28:48.373705+03
6660	30	-1	1140	2019-10-21 01:51:34.452696+03
6661	18	-1	910	2019-10-21 02:12:57.49964+03
6662	5	-1	1620	2019-10-21 02:16:23.620986+03
6663	39	-1	910	2019-10-21 02:41:55.659201+03
6664	29	-1	1940	2019-10-21 02:54:25.722101+03
6665	68	-1	490	2019-10-21 03:05:04.951169+03
6666	14	-1	1350	2019-10-21 03:35:38.646699+03
6667	81	-1	1620	2019-10-21 03:49:59.597309+03
6668	93	-1	1620	2019-10-21 04:00:26.38601+03
6669	44	-1	500	2019-10-21 05:23:55.342803+03
6670	41	24	396	2019-10-21 05:25:33.621699+03
6671	12	-1	1650	2019-10-21 05:37:05.470238+03
6672	75	-2	830	2019-10-21 05:55:56.233486+03
6673	74	-1	1010	2019-10-21 05:57:23.464208+03
6674	77	-1	640	2019-10-21 06:51:28.967393+03
6675	92	-1	630	2019-10-21 06:55:42.410498+03
6676	4	-1	1420	2019-10-21 06:58:04.747369+03
6677	8	-1	1920	2019-10-21 07:24:31.395562+03
6678	54	-1	3470	2019-10-21 07:40:23.031953+03
6679	14	-1	1350	2019-10-21 07:48:23.446767+03
6680	73	-1	960	2019-10-21 08:04:22.63095+03
6681	43	-1	380	2019-10-21 08:41:37.156383+03
6682	20	-1	830	2019-10-21 08:48:48.110786+03
6683	80	-1	1120	2019-10-21 08:49:18.721062+03
6684	89	-2	1420	2019-10-21 09:20:45.653157+03
6685	83	-1	1230	2019-10-21 09:37:55.594159+03
6686	49	-1	970	2019-10-21 10:04:32.83769+03
6687	47	-1	1480	2019-10-21 10:04:47.128849+03
6688	42	-1	1790	2019-10-21 10:40:41.730956+03
6689	38	-1	1100	2019-10-21 10:43:18.998819+03
6690	60	-1	2700	2019-10-21 11:20:50.878232+03
6691	46	-2	1270	2019-10-21 11:51:16.746419+03
6692	50	-2	1140	2019-10-21 11:56:25.164598+03
6693	8	-1	1920	2019-10-21 12:05:58.841055+03
6694	80	-1	1120	2019-10-21 12:09:41.046333+03
6695	21	-1	960	2019-10-21 12:48:24.191725+03
6696	52	-2	1090	2019-10-21 13:23:34.21025+03
6697	96	-1	1570	2019-10-21 13:55:27.74574+03
6698	61	-1	1510	2019-10-21 14:00:39.522203+03
6699	90	-1	1780	2019-10-21 14:08:12.630079+03
6700	26	-1	390	2019-10-21 14:29:03.224807+03
6701	40	-1	1430	2019-10-21 14:30:37.23548+03
6702	38	-2	1100	2019-10-21 14:33:07.214496+03
6703	61	-1	1510	2019-10-21 14:50:24.635397+03
6704	87	-1	2320	2019-10-21 15:05:33.583176+03
6705	60	-1	2700	2019-10-21 15:11:08.11887+03
6706	1	-1	640	2019-10-21 15:38:36.266871+03
6707	75	-2	830	2019-10-21 15:56:14.289205+03
6708	25	-1	1100	2019-10-21 16:02:25.832095+03
6709	86	-1	910	2019-10-21 16:29:53.77324+03
6710	64	29	407	2019-10-21 16:34:32.243996+03
6711	80	-1	1120	2019-10-21 16:35:55.804015+03
6712	35	-1	670	2019-10-21 16:56:18.41568+03
6713	28	-1	1860	2019-10-21 17:12:23.394024+03
6714	42	-1	1790	2019-10-21 17:28:50.561204+03
6715	70	-1	760	2019-10-21 17:59:59.268006+03
6716	40	-1	1430	2019-10-21 18:17:45.932278+03
6717	37	-1	1290	2019-10-21 18:20:52.313555+03
6718	91	-3	1620	2019-10-21 18:57:34.617148+03
6719	80	-1	1120	2019-10-21 19:09:21.565362+03
6720	20	-1	830	2019-10-21 19:16:33.60843+03
6721	87	-2	2320	2019-10-21 19:17:36.996766+03
6722	19	-1	1220	2019-10-21 19:26:36.98359+03
6723	14	-1	1350	2019-10-21 19:33:17.145256+03
6724	51	-1	1310	2019-10-21 19:34:02.199177+03
6725	56	-2	2460	2019-10-21 20:38:10.301759+03
6726	57	-1	1900	2019-10-21 20:49:11.893565+03
6727	68	25	230	2019-10-21 20:52:49.949008+03
6728	11	-1	830	2019-10-21 21:36:16.648907+03
6729	49	-1	970	2019-10-21 22:11:41.294135+03
6730	27	-1	880	2019-10-21 22:20:26.386657+03
6731	51	-1	1310	2019-10-21 22:45:52.874932+03
6732	21	-2	960	2019-10-21 22:55:34.857981+03
6733	3	-2	660	2019-10-21 23:06:47.688454+03
6734	23	-1	4390	2019-10-21 23:07:19.341418+03
6735	14	-1	1350	2019-10-21 23:11:47.291688+03
6736	88	-1	1270	2019-10-22 00:19:16.198325+03
6737	86	-1	910	2019-10-22 01:51:11.134645+03
6738	13	-1	460	2019-10-22 02:15:29.03656+03
6739	29	-2	1940	2019-10-22 02:24:45.73208+03
6740	36	32	359	2019-10-22 02:48:54.684131+03
6741	34	-2	1550	2019-10-22 02:49:40.898135+03
6742	5	-1	1620	2019-10-22 03:01:15.68423+03
6743	36	-1	630	2019-10-22 03:04:02.973684+03
6744	48	-1	640	2019-10-22 03:12:24.446945+03
6745	30	-2	1140	2019-10-22 03:18:09.726789+03
6746	63	-1	1780	2019-10-22 03:50:36.35371+03
6747	23	-1	4390	2019-10-22 03:57:42.098782+03
6748	86	-1	910	2019-10-22 04:24:47.054012+03
6749	74	-2	1010	2019-10-22 04:41:50.236187+03
6750	3	-2	660	2019-10-22 05:06:42.368338+03
6751	74	-1	1010	2019-10-22 05:09:06.813122+03
6752	31	-1	1190	2019-10-22 05:30:34.120733+03
6753	76	-1	1070	2019-10-22 05:43:21.53512+03
6754	46	-1	1270	2019-10-22 06:04:20.440335+03
6755	73	-1	960	2019-10-22 06:17:29.28359+03
6756	37	26	616	2019-10-22 06:39:32.334419+03
6757	20	-2	830	2019-10-22 07:11:07.761066+03
6758	87	-1	2320	2019-10-22 07:11:08.852229+03
6759	21	-1	960	2019-10-22 07:14:40.16448+03
6760	55	-1	3480	2019-10-22 07:25:09.235666+03
6761	4	-2	1420	2019-10-22 07:58:27.446676+03
6762	11	22	440	2019-10-22 08:07:40.735109+03
6763	96	-1	1570	2019-10-22 08:54:44.279039+03
6764	27	-1	880	2019-10-22 08:55:39.126492+03
6765	67	-2	350	2019-10-22 08:58:00.210924+03
6766	8	-1	1920	2019-10-22 09:42:08.354679+03
6767	47	-1	1480	2019-10-22 09:44:53.237076+03
6768	57	-1	1900	2019-10-22 09:46:24.083228+03
6769	74	-1	1010	2019-10-22 09:52:21.743043+03
6770	52	-1	1090	2019-10-22 10:04:42.11117+03
6771	40	-1	1430	2019-10-22 10:30:39.91691+03
6772	91	-1	1620	2019-10-22 10:46:37.355558+03
6773	79	-2	550	2019-10-22 10:46:49.460112+03
6774	50	-1	1140	2019-10-22 11:32:08.111731+03
6775	36	-1	630	2019-10-22 11:37:12.27429+03
6776	32	-1	710	2019-10-22 11:41:02.889672+03
6777	77	-1	640	2019-10-22 11:57:23.857744+03
6778	15	22	1617	2019-10-22 12:02:46.206988+03
6779	7	-2	810	2019-10-22 12:12:32.275921+03
6780	39	-1	910	2019-10-22 12:25:24.84506+03
6781	79	21	285	2019-10-22 13:16:31.132823+03
6782	62	-1	1220	2019-10-22 13:28:01.47973+03
6783	31	-1	1190	2019-10-22 13:50:59.788533+03
6784	53	28	1710	2019-10-22 13:53:30.111532+03
6785	44	-1	500	2019-10-22 14:05:03.762657+03
6786	93	-1	1620	2019-10-22 14:05:37.482175+03
6787	32	-1	710	2019-10-22 14:06:05.362028+03
6788	8	-1	1920	2019-10-22 14:10:06.050232+03
6789	7	-1	810	2019-10-22 14:29:57.541253+03
6790	9	-3	2090	2019-10-22 14:37:40.92036+03
6791	83	-1	1230	2019-10-22 15:41:44.296605+03
6792	47	-1	1480	2019-10-22 16:08:51.181745+03
6793	61	-1	1510	2019-10-22 16:58:29.880835+03
6794	40	-1	1430	2019-10-22 17:10:07.647365+03
6795	75	25	377	2019-10-22 17:17:11.203612+03
6796	4	-1	1420	2019-10-22 17:44:28.86018+03
6797	7	-1	810	2019-10-22 18:14:59.743645+03
6798	71	-1	1030	2019-10-22 18:18:29.575781+03
6799	50	-2	1140	2019-10-22 18:21:49.597119+03
6800	84	-1	2700	2019-10-22 18:26:26.10243+03
6801	46	25	759	2019-10-22 19:23:39.456234+03
6802	7	-1	810	2019-10-22 19:28:53.123387+03
6803	75	-1	830	2019-10-22 19:29:29.871115+03
6804	54	-1	3470	2019-10-22 19:31:27.810921+03
6805	76	-2	1070	2019-10-22 19:55:53.158325+03
6806	63	-1	1780	2019-10-22 20:21:13.909898+03
6807	54	-1	3470	2019-10-22 20:29:45.760291+03
6808	46	-1	1270	2019-10-22 21:08:17.620741+03
6809	63	27	825	2019-10-22 21:25:34.832692+03
6810	64	-1	970	2019-10-22 22:02:11.213281+03
6811	64	-1	970	2019-10-22 22:05:35.466361+03
6812	58	-1	2830	2019-10-22 22:19:10.169058+03
6813	82	-1	560	2019-10-22 22:23:27.664369+03
6814	59	-1	1030	2019-10-22 22:44:08.251775+03
6815	14	-2	1350	2019-10-22 22:48:36.004203+03
6816	13	-2	460	2019-10-22 23:13:48.549339+03
6817	86	-2	910	2019-10-22 23:21:19.350794+03
6818	20	-2	830	2019-10-22 23:35:17.210119+03
6819	27	-1	880	2019-10-22 23:36:44.267086+03
6820	69	-1	1100	2019-10-22 23:56:46.016361+03
6821	39	-1	910	2019-10-23 00:31:18.800293+03
6822	37	-1	1290	2019-10-23 00:33:21.998152+03
6823	57	-1	1900	2019-10-23 00:35:43.865342+03
6824	9	19	1206	2019-10-23 00:45:18.745619+03
6825	12	-1	1650	2019-10-23 00:58:50.514392+03
6826	55	-1	3480	2019-10-23 01:05:15.540248+03
6827	85	-1	730	2019-10-23 01:56:00.101992+03
6828	12	-1	1650	2019-10-23 02:12:28.525244+03
6829	49	-1	970	2019-10-23 02:34:04.877142+03
6830	94	-1	1230	2019-10-23 02:36:18.884348+03
6831	72	-2	620	2019-10-23 02:46:55.911001+03
6832	83	-1	1230	2019-10-23 03:20:17.896926+03
6833	23	-1	4390	2019-10-23 03:25:14.341054+03
6834	32	-2	710	2019-10-23 03:26:56.679315+03
6835	89	-1	1420	2019-10-23 03:28:05.198343+03
6836	79	-1	550	2019-10-23 03:39:13.321552+03
6837	89	-2	1420	2019-10-23 04:01:09.258603+03
6838	67	-1	350	2019-10-23 04:10:29.7263+03
6839	7	-1	810	2019-10-23 04:20:10.549139+03
6840	84	-1	2700	2019-10-23 04:32:09.958388+03
6841	74	-1	1010	2019-10-23 05:17:50.081508+03
6842	80	-1	1120	2019-10-23 05:37:01.085595+03
6843	68	-1	490	2019-10-23 05:43:48.253589+03
6844	49	-1	970	2019-10-23 05:50:56.652102+03
6845	39	-1	910	2019-10-23 05:57:52.478423+03
6846	83	-2	1230	2019-10-23 06:13:28.648889+03
6847	4	-1	1420	2019-10-23 06:16:22.924078+03
6848	70	-1	760	2019-10-23 06:26:16.376491+03
6849	56	-1	2460	2019-10-23 07:07:07.799495+03
6850	18	-1	910	2019-10-23 07:24:08.797719+03
6851	93	-1	1620	2019-10-23 07:26:02.280199+03
6852	96	-1	1570	2019-10-23 07:52:52.986586+03
6853	84	-1	2700	2019-10-23 08:01:56.324699+03
6854	2	-2	470	2019-10-23 08:07:13.545702+03
6855	63	-1	1780	2019-10-23 08:21:45.233376+03
6856	25	-1	1100	2019-10-23 08:42:33.586843+03
6857	84	-3	2700	2019-10-23 09:48:03.044541+03
6858	49	-1	970	2019-10-23 10:03:03.469821+03
6859	84	-1	2700	2019-10-23 10:03:28.975043+03
6860	27	-1	880	2019-10-23 10:33:00.10419+03
6861	12	-1	1650	2019-10-23 11:01:04.639724+03
6862	18	-2	910	2019-10-23 11:04:23.130424+03
6863	8	-2	1920	2019-10-23 11:06:08.47069+03
6864	35	-1	670	2019-10-23 11:06:38.383285+03
6865	6	-1	980	2019-10-23 11:17:36.272658+03
6866	12	-2	1650	2019-10-23 11:35:08.37173+03
6867	13	-1	460	2019-10-23 11:49:48.121133+03
6868	48	-1	640	2019-10-23 11:58:14.712446+03
6869	37	-1	1290	2019-10-23 12:53:07.162672+03
6870	53	-1	3120	2019-10-23 12:59:43.065996+03
6871	20	-1	830	2019-10-23 13:17:06.490022+03
6872	50	-1	1140	2019-10-23 13:20:36.442289+03
6873	35	-2	670	2019-10-23 13:39:10.956381+03
6874	50	-1	1140	2019-10-23 13:51:12.358938+03
6875	7	-1	810	2019-10-23 13:56:06.680841+03
6876	18	-2	910	2019-10-23 15:54:55.30892+03
6877	85	-1	730	2019-10-23 16:04:46.765953+03
6878	29	-1	1940	2019-10-23 16:06:32.199436+03
6879	92	-1	630	2019-10-23 16:12:58.712817+03
6880	29	-1	1940	2019-10-23 16:21:09.620918+03
6881	10	-3	2080	2019-10-23 16:40:30.19461+03
6882	26	-2	390	2019-10-23 17:07:14.776152+03
6883	79	-1	550	2019-10-23 17:17:20.066168+03
6884	89	-1	1420	2019-10-23 18:28:00.068424+03
6885	48	-1	640	2019-10-23 18:36:45.514864+03
6886	54	-1	3470	2019-10-23 18:51:11.373583+03
6887	45	-1	1590	2019-10-23 19:04:52.735682+03
6888	48	-1	640	2019-10-23 19:33:44.187401+03
6889	85	-1	730	2019-10-23 19:41:50.767402+03
6890	11	-1	830	2019-10-23 19:55:20.679578+03
6891	64	-1	970	2019-10-23 19:56:01.077699+03
6892	46	-1	1270	2019-10-23 20:03:11.343921+03
6893	17	-2	1500	2019-10-23 20:18:55.261418+03
6894	12	-1	1650	2019-10-23 20:54:46.100854+03
6895	9	-1	2090	2019-10-23 20:56:42.51266+03
6896	81	-2	1620	2019-10-23 21:46:47.08835+03
6897	84	-1	2700	2019-10-23 22:01:04.588297+03
6898	89	-1	1420	2019-10-23 22:17:47.791877+03
6899	96	-1	1570	2019-10-23 23:05:05.659496+03
6900	56	-1	2460	2019-10-23 23:23:47.29506+03
6901	78	-1	900	2019-10-23 23:25:09.680961+03
6902	58	28	1614	2019-10-23 23:32:12.612158+03
6903	36	-1	630	2019-10-23 23:32:55.698871+03
6904	11	-1	830	2019-10-24 00:24:48.263593+03
6905	3	-1	660	2019-10-24 00:33:06.689935+03
6906	56	-1	2460	2019-10-24 00:35:27.09748+03
6907	54	-1	3470	2019-10-24 00:58:29.418037+03
6908	51	-1	1310	2019-10-24 01:06:38.484854+03
6909	15	-1	2830	2019-10-24 01:36:33.641699+03
6910	79	-1	550	2019-10-24 01:51:54.822685+03
6911	89	-1	1420	2019-10-24 02:16:15.384437+03
6912	51	-1	1310	2019-10-24 02:17:40.554601+03
6913	4	-2	1420	2019-10-24 02:42:43.701013+03
6914	80	-2	1120	2019-10-24 02:42:56.032794+03
6915	77	31	370	2019-10-24 02:54:43.353131+03
6916	34	-1	1550	2019-10-24 03:13:27.293751+03
6917	26	-1	390	2019-10-24 03:29:50.735175+03
6918	84	-1	2700	2019-10-24 03:45:33.696561+03
6919	96	-2	1570	2019-10-24 03:52:26.419117+03
6920	79	-2	550	2019-10-24 03:53:40.252695+03
6921	71	-1	1030	2019-10-24 04:17:26.189881+03
6922	79	-1	550	2019-10-24 04:20:04.342502+03
6923	7	-1	810	2019-10-24 04:26:19.900085+03
6924	22	-1	1070	2019-10-24 04:40:11.125971+03
6925	23	-1	4390	2019-10-24 05:18:48.783342+03
6926	69	-2	1100	2019-10-24 05:41:41.186767+03
6927	26	-1	390	2019-10-24 05:51:15.366524+03
6928	46	-1	1270	2019-10-24 05:54:37.750118+03
6929	56	-1	2460	2019-10-24 06:01:24.317707+03
6930	76	-1	1070	2019-10-24 06:06:06.026351+03
6931	21	26	429	2019-10-24 06:20:20.38519+03
6932	54	-1	3470	2019-10-24 06:34:57.777925+03
6933	42	-1	1790	2019-10-24 06:37:26.921312+03
6934	73	-1	960	2019-10-24 06:58:27.432402+03
6935	3	-2	660	2019-10-24 07:00:25.933092+03
6936	7	28	365	2019-10-24 07:06:39.211518+03
6937	67	-1	350	2019-10-24 07:23:54.259869+03
6938	83	-1	1230	2019-10-24 07:30:07.896325+03
6939	4	-1	1420	2019-10-24 07:44:32.562601+03
6940	96	-1	1570	2019-10-24 07:54:56.493241+03
6941	81	-1	1620	2019-10-24 07:59:35.263101+03
6942	17	32	625	2019-10-24 08:02:25.52889+03
6943	31	-1	1190	2019-10-24 09:12:24.551367+03
6944	76	-1	1070	2019-10-24 09:26:19.988112+03
6945	40	-1	1430	2019-10-24 09:37:26.642587+03
6946	73	-2	960	2019-10-24 09:59:37.067905+03
6947	29	-1	1940	2019-10-24 10:33:09.124857+03
6948	13	-2	460	2019-10-24 10:45:11.963298+03
6949	75	-1	830	2019-10-24 10:46:06.31521+03
6950	69	-2	1100	2019-10-24 11:00:37.583534+03
6951	67	-1	350	2019-10-24 11:05:14.136107+03
6952	62	-2	1220	2019-10-24 11:05:56.336703+03
6953	31	-1	1190	2019-10-24 11:41:44.449003+03
6954	87	-1	2320	2019-10-24 11:58:24.883155+03
6955	66	-1	690	2019-10-24 12:06:37.446186+03
6956	29	41	963	2019-10-24 12:11:18.422453+03
6957	33	-1	900	2019-10-24 12:16:33.941244+03
6958	54	-1	3470	2019-10-24 12:20:14.174986+03
6959	71	-1	1030	2019-10-24 12:20:57.148541+03
6960	88	-1	1270	2019-10-24 12:41:07.530991+03
6961	13	-1	460	2019-10-24 12:59:04.135181+03
6962	59	-1	1030	2019-10-24 13:06:47.418196+03
6963	40	-1	1430	2019-10-24 13:14:20.699899+03
6964	73	-1	960	2019-10-24 13:22:43.783109+03
6965	84	-2	2700	2019-10-24 13:26:42.62816+03
6966	71	-1	1030	2019-10-24 13:46:37.849202+03
6967	67	-1	350	2019-10-24 13:54:14.816299+03
6968	35	-1	670	2019-10-24 14:00:08.078032+03
6969	49	-1	970	2019-10-24 14:26:38.618587+03
6970	88	-1	1270	2019-10-24 14:29:35.964622+03
6971	65	-2	490	2019-10-24 15:08:13.311348+03
6972	46	-1	1270	2019-10-24 15:32:30.48769+03
6973	54	-1	3470	2019-10-24 15:47:54.873866+03
6974	95	-1	480	2019-10-24 15:51:53.552665+03
6975	52	-1	1090	2019-10-24 16:07:47.943703+03
6976	80	-1	1120	2019-10-24 16:08:36.557749+03
6977	41	-1	830	2019-10-24 16:16:46.242451+03
6978	79	-1	550	2019-10-24 16:46:33.901812+03
6979	37	-1	1290	2019-10-24 17:01:02.924735+03
6980	52	-1	1090	2019-10-24 17:04:10.998758+03
6981	95	-1	480	2019-10-24 17:08:48.10108+03
6982	47	-1	1480	2019-10-24 17:12:55.709121+03
6983	15	-1	2830	2019-10-24 17:35:14.597476+03
6984	56	-1	2460	2019-10-24 17:42:47.586457+03
6985	32	-1	710	2019-10-24 17:47:39.083858+03
6986	31	-1	1190	2019-10-24 17:53:46.371055+03
6987	94	-2	1230	2019-10-24 18:05:24.813438+03
6988	23	-1	4390	2019-10-24 18:10:11.369534+03
6989	90	22	1006	2019-10-24 18:14:58.924959+03
6990	32	-1	710	2019-10-24 18:36:12.1592+03
6991	27	27	442	2019-10-24 18:36:29.114137+03
6992	84	-2	2700	2019-10-24 18:48:41.832811+03
6993	54	-1	3470	2019-10-24 19:11:17.448452+03
6994	26	-1	390	2019-10-24 19:53:30.888414+03
6995	52	-1	1090	2019-10-24 20:03:52.985047+03
6996	4	-1	1420	2019-10-24 20:18:32.925739+03
6997	24	-1	950	2019-10-24 20:26:31.98272+03
6998	36	-2	630	2019-10-24 20:50:55.165009+03
6999	80	34	477	2019-10-24 21:10:52.914194+03
7000	81	-1	1620	2019-10-24 21:27:42.473389+03
7001	75	-2	830	2019-10-24 21:51:37.964922+03
7002	54	-1	3470	2019-10-24 21:51:45.962285+03
7003	5	-1	1620	2019-10-24 22:23:58.127401+03
7004	49	-1	970	2019-10-24 22:30:28.908585+03
7005	96	-1	1570	2019-10-24 22:33:54.37818+03
7006	82	-2	560	2019-10-24 22:34:41.892367+03
7007	72	-1	620	2019-10-24 22:35:21.286854+03
7008	22	-2	1070	2019-10-24 23:06:22.269481+03
7009	80	-1	1120	2019-10-24 23:18:45.245212+03
7010	11	-1	830	2019-10-24 23:26:15.441396+03
7011	38	-1	1100	2019-10-24 23:33:49.641553+03
7012	90	-1	1780	2019-10-25 00:11:39.904997+03
7013	91	-1	1620	2019-10-25 00:20:48.079819+03
7014	45	-1	1590	2019-10-25 00:34:22.925469+03
7015	33	-1	900	2019-10-25 00:39:44.064434+03
7016	42	-1	1790	2019-10-25 00:51:15.409259+03
7017	4	-1	1420	2019-10-25 00:58:27.062276+03
7018	11	-1	830	2019-10-25 01:18:31.646166+03
7019	32	-1	710	2019-10-25 01:23:46.458828+03
7020	5	-2	1620	2019-10-25 01:36:29.214026+03
7021	84	-1	2700	2019-10-25 01:40:29.467909+03
7022	14	-1	1350	2019-10-25 01:51:45.421833+03
7023	28	-2	1860	2019-10-25 02:02:32.541847+03
7024	44	-1	500	2019-10-25 02:04:29.158385+03
7025	71	-1	1030	2019-10-25 02:14:20.249859+03
7026	5	-1	1620	2019-10-25 02:25:09.30999+03
7027	86	-1	910	2019-10-25 02:29:34.982318+03
7028	19	-1	1220	2019-10-25 02:55:55.681111+03
7029	41	-1	830	2019-10-25 02:57:22.448428+03
7030	89	-1	1420	2019-10-25 04:23:13.781424+03
7031	89	-1	1420	2019-10-25 04:24:10.137505+03
7032	5	-2	1620	2019-10-25 05:01:23.928614+03
7033	95	-1	480	2019-10-25 05:10:41.958951+03
7034	39	-1	910	2019-10-25 05:11:02.869733+03
7035	90	-1	1780	2019-10-25 05:34:04.133497+03
7036	47	-1	1480	2019-10-25 06:21:07.863368+03
7037	18	-1	910	2019-10-25 06:41:57.915375+03
7038	96	-1	1570	2019-10-25 06:44:40.253046+03
7039	37	-1	1290	2019-10-25 06:45:16.78287+03
7040	56	-1	2460	2019-10-25 06:49:58.54028+03
7041	94	-1	1230	2019-10-25 07:00:31.576432+03
7042	4	-1	1420	2019-10-25 07:11:55.250949+03
7043	36	-2	630	2019-10-25 07:29:59.872929+03
7044	79	-1	550	2019-10-25 07:41:21.648612+03
7045	48	-1	640	2019-10-25 08:00:26.204395+03
7046	39	-2	910	2019-10-25 08:41:35.594744+03
7047	3	-1	660	2019-10-25 09:02:09.740044+03
7048	24	-2	950	2019-10-25 09:11:49.19984+03
7049	35	-1	670	2019-10-25 09:59:25.624442+03
7050	90	-1	1780	2019-10-25 10:01:40.091577+03
7051	4	-1	1420	2019-10-25 10:09:43.097498+03
7052	5	-1	1620	2019-10-25 10:12:57.186468+03
7053	29	-1	1940	2019-10-25 10:17:18.354937+03
7054	15	-1	2830	2019-10-25 10:47:41.042552+03
7055	11	-1	830	2019-10-25 11:17:00.62706+03
7056	14	-1	1350	2019-10-25 11:21:04.285161+03
7057	4	-1	1420	2019-10-25 11:39:15.542978+03
7058	96	-1	1570	2019-10-25 12:02:17.713905+03
7059	33	-1	900	2019-10-25 12:30:23.959984+03
7060	44	-1	500	2019-10-25 12:48:25.645517+03
7061	63	-1	1780	2019-10-25 12:59:46.746494+03
7062	23	-2	4390	2019-10-25 13:08:07.528649+03
7063	9	-1	2090	2019-10-25 13:14:43.181729+03
7064	64	-1	970	2019-10-25 13:39:18.323799+03
7065	89	-2	1420	2019-10-25 13:42:30.23603+03
7066	46	-1	1270	2019-10-25 14:12:46.95842+03
7067	29	-1	1940	2019-10-25 15:08:20.089849+03
7068	67	-1	350	2019-10-25 15:12:44.402058+03
7069	47	-2	1480	2019-10-25 15:13:30.973343+03
7070	90	-1	1780	2019-10-25 15:17:43.257729+03
7071	93	-1	1620	2019-10-25 15:31:08.976014+03
7072	5	-1	1620	2019-10-25 15:50:09.092328+03
7073	95	-2	480	2019-10-25 15:53:00.345468+03
7074	62	-1	1220	2019-10-25 15:53:14.927834+03
7075	19	-1	1220	2019-10-25 15:58:10.327624+03
7076	71	-2	1030	2019-10-25 16:01:09.337799+03
7077	10	-1	2080	2019-10-25 16:16:02.826804+03
7078	76	-1	1070	2019-10-25 16:19:23.004998+03
7079	72	7	356	2019-10-25 16:27:16.556783+03
7080	71	-1	1030	2019-10-25 16:31:37.005934+03
7081	1	-1	640	2019-10-25 16:51:10.793363+03
7082	83	-1	1230	2019-10-25 16:56:37.50346+03
7083	40	-1	1430	2019-10-25 16:59:54.338083+03
7084	58	-1	2830	2019-10-25 17:09:27.532668+03
7085	8	-1	1920	2019-10-25 17:15:31.727875+03
7086	8	-1	1920	2019-10-25 17:15:44.615968+03
7087	75	-2	830	2019-10-25 17:49:24.547676+03
7088	76	-1	1070	2019-10-25 17:54:33.461078+03
7089	47	-1	1480	2019-10-25 18:11:16.442389+03
7090	53	-1	3120	2019-10-25 18:18:31.241954+03
7091	61	-1	1510	2019-10-25 19:18:19.180933+03
7092	54	-1	3470	2019-10-25 19:24:00.213607+03
7093	51	-1	1310	2019-10-25 19:24:18.10334+03
7094	59	-3	1030	2019-10-25 19:45:35.517083+03
7095	48	-1	640	2019-10-25 20:15:56.13382+03
7096	31	-1	1190	2019-10-25 20:27:56.385378+03
7097	93	-1	1620	2019-10-25 20:34:53.785099+03
7098	14	-1	1350	2019-10-25 20:53:49.259776+03
7099	56	-2	2460	2019-10-25 21:25:43.489538+03
7100	4	-1	1420	2019-10-25 21:32:41.009802+03
7101	41	-2	830	2019-10-25 21:34:00.697761+03
7102	24	-1	950	2019-10-25 22:06:11.2769+03
7103	76	-1	1070	2019-10-25 22:16:17.825764+03
7104	79	-1	550	2019-10-25 22:31:49.839475+03
7105	82	-1	560	2019-10-25 22:32:29.864129+03
7106	41	-1	830	2019-10-25 22:41:41.484555+03
7107	30	-1	1140	2019-10-25 23:19:48.192985+03
7108	7	-1	810	2019-10-25 23:24:40.960508+03
7109	33	-1	900	2019-10-25 23:54:59.212044+03
7110	90	-1	1780	2019-10-26 00:05:11.10617+03
7111	23	-1	4390	2019-10-26 01:12:43.27809+03
7112	27	-2	880	2019-10-26 01:22:12.363748+03
7113	75	-1	830	2019-10-26 01:22:20.248442+03
7114	57	-1	1900	2019-10-26 01:37:47.537001+03
7115	76	-1	1070	2019-10-26 01:46:20.208766+03
7116	20	-1	830	2019-10-26 02:34:47.402994+03
7117	93	-1	1620	2019-10-26 03:05:23.942689+03
7118	18	-2	910	2019-10-26 03:09:55.967224+03
7119	49	-1	970	2019-10-26 03:25:07.876896+03
7120	71	-2	1030	2019-10-26 04:08:38.705839+03
7121	63	-1	1780	2019-10-26 04:21:20.082004+03
7122	47	-1	1480	2019-10-26 04:23:52.487735+03
7123	49	-2	970	2019-10-26 04:32:14.046489+03
7124	90	-2	1780	2019-10-26 04:37:10.638192+03
7125	47	-2	1480	2019-10-26 04:38:22.201675+03
7126	8	-1	1920	2019-10-26 04:41:24.897037+03
7127	53	-1	3120	2019-10-26 04:56:06.486321+03
7128	13	-1	460	2019-10-26 05:08:30.844341+03
7129	47	-2	1480	2019-10-26 05:10:26.991113+03
7130	5	-1	1620	2019-10-26 05:15:13.610003+03
7131	38	-2	1100	2019-10-26 05:21:09.356058+03
7132	60	-1	2700	2019-10-26 05:31:01.019961+03
7133	33	38	440	2019-10-26 05:34:22.28757+03
7134	91	-2	1620	2019-10-26 06:18:55.190589+03
7135	7	-1	810	2019-10-26 06:42:59.923238+03
7136	56	-1	2460	2019-10-26 06:46:57.313672+03
7137	80	-1	1120	2019-10-26 08:23:10.182237+03
7138	31	-1	1190	2019-10-26 10:10:53.635755+03
7139	61	-1	1510	2019-10-26 10:17:13.136353+03
7140	22	-1	1070	2019-10-26 10:45:22.373933+03
7141	35	-1	670	2019-10-26 11:03:37.767558+03
7142	47	-2	1480	2019-10-26 11:25:04.410134+03
7143	39	-1	910	2019-10-26 11:45:50.325952+03
7144	53	-1	3120	2019-10-26 11:52:34.304711+03
7145	83	-1	1230	2019-10-26 12:00:18.4726+03
7146	79	-1	550	2019-10-26 12:09:39.47626+03
7147	64	-1	970	2019-10-26 12:16:04.095371+03
7148	13	-1	460	2019-10-26 13:07:33.951463+03
7149	79	-1	550	2019-10-26 13:25:22.816443+03
7150	57	-1	1900	2019-10-26 13:46:34.185051+03
7151	14	-1	1350	2019-10-26 13:56:34.88832+03
7152	91	28	908	2019-10-26 14:00:01.812356+03
7153	57	-2	1900	2019-10-26 14:18:59.001504+03
7154	86	-2	910	2019-10-26 14:24:18.411562+03
7155	84	-1	2700	2019-10-26 14:36:00.371344+03
7156	94	-1	1230	2019-10-26 15:09:59.815289+03
7157	32	-1	710	2019-10-26 15:35:41.295932+03
7158	95	-1	480	2019-10-26 15:36:13.950088+03
7159	66	-2	690	2019-10-26 15:41:05.353327+03
7160	30	-1	1140	2019-10-26 15:55:08.270023+03
7161	94	-1	1230	2019-10-26 16:00:53.933141+03
7162	4	30	588	2019-10-26 16:09:52.4945+03
7163	32	-1	710	2019-10-26 16:11:14.072251+03
7164	90	-1	1780	2019-10-26 16:19:48.095093+03
7165	5	29	892	2019-10-26 17:00:47.700912+03
7166	50	21	607	2019-10-26 17:20:02.242794+03
7167	76	-1	1070	2019-10-26 17:31:29.512472+03
7168	80	-1	1120	2019-10-26 18:02:45.218716+03
7169	32	-2	710	2019-10-26 18:07:59.442078+03
7170	4	-1	1420	2019-10-26 18:21:10.236715+03
7171	15	-1	2830	2019-10-26 18:25:02.168693+03
7172	84	-1	2700	2019-10-26 18:40:57.072953+03
7173	36	-1	630	2019-10-26 18:47:34.590507+03
7174	47	-1	1480	2019-10-26 19:33:18.604793+03
7175	86	-1	910	2019-10-26 19:33:32.263324+03
7176	24	-1	950	2019-10-26 19:52:17.274194+03
7177	29	-1	1940	2019-10-26 20:11:22.946846+03
7178	13	-1	460	2019-10-26 20:42:49.512632+03
7179	2	-1	470	2019-10-26 20:53:33.66916+03
7180	57	-1	1900	2019-10-26 21:01:41.958788+03
7181	25	-1	1100	2019-10-26 21:02:21.57655+03
7182	4	-2	1420	2019-10-26 21:21:05.502367+03
7183	15	-1	2830	2019-10-26 21:27:13.538857+03
7184	58	-1	2830	2019-10-26 21:38:59.060275+03
7185	30	-2	1140	2019-10-26 21:44:43.700272+03
7186	30	-1	1140	2019-10-26 21:46:17.220662+03
7187	29	-2	1940	2019-10-26 21:46:51.655334+03
7188	36	-1	630	2019-10-26 22:04:29.978029+03
7189	94	-1	1230	2019-10-26 22:04:57.358135+03
7190	46	-1	1270	2019-10-26 22:05:51.107514+03
7191	87	-2	2320	2019-10-26 22:43:14.769419+03
7192	20	-1	830	2019-10-26 23:20:02.382173+03
7193	62	-1	1220	2019-10-27 00:01:38.693634+03
7194	57	-1	1900	2019-10-27 00:02:21.607375+03
7195	22	-2	1070	2019-10-27 00:08:35.849648+03
7196	32	-1	710	2019-10-27 00:23:07.175341+03
7197	91	-1	1620	2019-10-27 00:39:48.995961+03
7198	74	-2	1010	2019-10-27 00:39:59.223085+03
7199	57	-1	1900	2019-10-27 01:06:19.071446+03
7200	30	-1	1140	2019-10-27 01:59:58.371691+03
7201	74	-1	1010	2019-10-27 02:00:05.94913+03
7202	70	-1	760	2019-10-27 02:34:50.506859+03
7203	86	-1	910	2019-10-27 03:12:48.657968+03
7204	55	-1	3480	2019-10-27 03:19:57.861232+03
7205	22	-2	1070	2019-10-27 03:40:57.338498+03
7206	8	-1	1920	2019-10-27 03:56:40.185056+03
7207	85	-1	730	2019-10-27 04:03:06.160463+03
7208	15	-2	2830	2019-10-27 04:03:27.671123+03
7209	18	-2	910	2019-10-27 04:18:03.378019+03
7210	11	-2	830	2019-10-27 04:47:06.677921+03
7211	96	-2	1570	2019-10-27 05:50:38.828875+03
7212	96	-2	1570	2019-10-27 06:29:57.054634+03
7213	90	-1	1780	2019-10-27 06:54:57.550983+03
7214	54	-1	3470	2019-10-27 07:12:24.400833+03
7215	16	-1	1380	2019-10-27 07:28:42.277229+03
7216	51	-1	1310	2019-10-27 07:53:01.348308+03
7217	29	-1	1940	2019-10-27 07:54:18.299044+03
7218	40	-1	1430	2019-10-27 08:00:06.575547+03
7219	31	-1	1190	2019-10-27 08:29:04.88608+03
7220	59	31	596	2019-10-27 08:50:57.099453+03
7221	18	-1	910	2019-10-27 08:52:33.21785+03
7222	12	-1	1650	2019-10-27 09:25:17.65367+03
7223	34	-1	1550	2019-10-27 09:33:19.340353+03
7224	36	-1	630	2019-10-27 09:55:27.482486+03
7225	6	-1	980	2019-10-27 10:00:16.503665+03
7226	63	-2	1780	2019-10-27 10:10:34.01258+03
7227	26	-2	390	2019-10-27 11:03:38.094303+03
7228	8	29	824	2019-10-27 11:05:26.572394+03
7229	95	-2	480	2019-10-27 11:12:26.792645+03
7230	50	-2	1140	2019-10-27 11:16:26.65702+03
7231	10	-1	2080	2019-10-27 11:21:46.554373+03
7232	27	-1	880	2019-10-27 11:22:58.305462+03
7233	65	-1	490	2019-10-27 11:32:55.974105+03
7234	53	-1	3120	2019-10-27 11:35:30.492174+03
7235	31	-2	1190	2019-10-27 11:48:14.161355+03
7236	96	-1	1570	2019-10-27 11:53:42.055036+03
7237	62	-1	1220	2019-10-27 12:55:33.278205+03
7238	67	-2	350	2019-10-27 13:17:42.439723+03
7239	72	-1	620	2019-10-27 13:22:29.717311+03
7240	27	-1	880	2019-10-27 13:43:13.370873+03
7241	21	-1	960	2019-10-27 14:04:59.99289+03
7242	16	-1	1380	2019-10-27 14:26:24.919729+03
7243	54	-1	3470	2019-10-27 14:39:45.988652+03
7244	32	-1	710	2019-10-27 14:42:29.939525+03
7245	35	-1	670	2019-10-27 14:59:16.7253+03
7246	80	-1	1120	2019-10-27 15:01:53.644036+03
7247	83	-1	1230	2019-10-27 15:46:04.797604+03
7248	3	-2	660	2019-10-27 15:47:09.121991+03
7249	68	-1	490	2019-10-27 16:04:06.24513+03
7250	3	-1	660	2019-10-27 16:30:30.441079+03
7251	19	-1	1220	2019-10-27 16:49:27.062211+03
7252	50	-1	1140	2019-10-27 17:27:37.156851+03
7253	7	-1	810	2019-10-27 17:45:22.635959+03
7254	86	-2	910	2019-10-27 18:04:40.925415+03
7255	1	-1	640	2019-10-27 18:36:31.514975+03
7256	4	-1	1420	2019-10-27 18:39:35.666708+03
7257	26	-1	390	2019-10-27 19:01:00.709118+03
7258	1	-1	640	2019-10-27 19:52:49.233969+03
7259	45	-2	1590	2019-10-27 19:55:22.046289+03
7260	55	-1	3480	2019-10-27 20:01:19.800613+03
7261	64	-1	970	2019-10-27 20:12:46.160391+03
7262	7	-1	810	2019-10-27 20:27:15.929411+03
7263	27	-1	880	2019-10-27 20:28:51.409807+03
7264	40	-1	1430	2019-10-27 20:33:05.932964+03
7265	28	-1	1860	2019-10-27 20:42:21.390059+03
7266	83	-1	1230	2019-10-27 21:36:00.431191+03
7267	90	-2	1780	2019-10-27 22:04:31.014128+03
7268	36	-1	630	2019-10-27 22:20:36.133065+03
7269	61	21	681	2019-10-27 22:44:17.336618+03
7270	15	-1	2830	2019-10-27 22:44:58.585242+03
7271	4	-2	1420	2019-10-27 22:57:32.994908+03
7272	29	-1	1940	2019-10-27 23:16:18.328407+03
7273	5	-1	1620	2019-10-27 23:16:18.95231+03
7274	89	-1	1420	2019-10-27 23:25:39.861613+03
7275	6	-1	980	2019-10-27 23:28:42.503942+03
7276	89	-1	1420	2019-10-27 23:51:09.903615+03
7277	23	-1	4390	2019-10-28 00:02:55.24136+03
7278	8	-1	1920	2019-10-28 00:25:34.728911+03
7279	96	-1	1570	2019-10-28 00:25:46.071421+03
7280	90	-1	1780	2019-10-28 00:38:17.527363+03
7281	75	-1	830	2019-10-28 00:46:20.963097+03
7282	56	-1	2460	2019-10-28 01:16:58.847312+03
7283	6	-2	980	2019-10-28 01:28:50.326833+03
7284	38	-1	1100	2019-10-28 01:31:31.102848+03
7285	83	-1	1230	2019-10-28 01:43:09.898034+03
7286	76	-1	1070	2019-10-28 01:52:29.852643+03
7287	52	-1	1090	2019-10-28 01:53:00.341945+03
7288	83	-1	1230	2019-10-28 02:03:31.382263+03
7289	47	-1	1480	2019-10-28 02:14:18.743238+03
7290	73	31	536	2019-10-28 02:21:38.855199+03
7291	29	-1	1940	2019-10-28 02:29:54.685498+03
7292	12	-1	1650	2019-10-28 03:30:47.385894+03
7293	49	-2	970	2019-10-28 04:02:31.188113+03
7294	48	-1	640	2019-10-28 04:28:17.6253+03
7295	14	-1	1350	2019-10-28 04:43:48.224289+03
7296	93	-1	1620	2019-10-28 05:00:32.936191+03
7297	5	-1	1620	2019-10-28 05:17:38.098177+03
7298	10	-1	2080	2019-10-28 05:20:15.954693+03
7299	60	-1	2700	2019-10-28 05:43:32.045711+03
7300	62	-1	1220	2019-10-28 06:20:03.528067+03
7301	96	-1	1570	2019-10-28 06:25:04.342542+03
7302	18	-1	910	2019-10-28 06:25:30.616672+03
7303	80	-2	1120	2019-10-28 06:31:07.019781+03
7304	54	29	1650	2019-10-28 06:40:59.432915+03
7305	56	-2	2460	2019-10-28 07:01:40.358232+03
7306	14	31	650	2019-10-28 07:32:05.095419+03
7307	82	-1	560	2019-10-28 07:33:31.787377+03
7308	93	-1	1620	2019-10-28 07:45:57.126327+03
7309	32	-1	710	2019-10-28 07:49:24.520452+03
7310	24	-1	950	2019-10-28 07:54:29.398074+03
7311	8	-1	1920	2019-10-28 08:12:40.984725+03
7312	7	-1	810	2019-10-28 08:36:20.146495+03
7313	20	-2	830	2019-10-28 08:54:11.424444+03
7314	29	-2	1940	2019-10-28 09:01:05.840248+03
7315	28	-1	1860	2019-10-28 09:27:15.876307+03
7316	67	-1	350	2019-10-28 09:37:37.088258+03
7317	35	25	387	2019-10-28 10:17:04.46367+03
7318	65	-1	490	2019-10-28 10:30:57.826847+03
7319	27	-1	880	2019-10-28 10:44:52.355848+03
7320	18	-1	910	2019-10-28 10:46:47.953826+03
7321	86	-1	910	2019-10-28 11:11:43.904184+03
7322	63	-1	1780	2019-10-28 11:12:49.66268+03
7323	43	-1	380	2019-10-28 11:31:49.915069+03
7324	13	-1	460	2019-10-28 11:41:14.240863+03
7325	14	-1	1350	2019-10-28 11:43:01.709991+03
7326	8	-1	1920	2019-10-28 11:46:15.406071+03
7327	20	-1	830	2019-10-28 12:10:08.471972+03
7328	12	-1	1650	2019-10-28 12:20:45.402267+03
7329	23	-1	4390	2019-10-28 12:22:48.621296+03
7330	32	-2	710	2019-10-28 12:36:14.529548+03
7331	4	-1	1420	2019-10-28 12:49:25.992494+03
7332	90	-1	1780	2019-10-28 12:50:20.093052+03
7333	79	-1	550	2019-10-28 13:25:53.188395+03
7334	21	-1	960	2019-10-28 13:45:38.209215+03
7335	48	-1	640	2019-10-28 14:54:38.185118+03
7336	68	-1	490	2019-10-28 15:03:13.177443+03
7337	40	-1	1430	2019-10-28 15:04:39.566797+03
7338	77	-2	640	2019-10-28 15:29:43.722097+03
7339	30	-1	1140	2019-10-28 15:30:00.985099+03
7340	44	-1	500	2019-10-28 15:30:29.235548+03
7341	22	-2	1070	2019-10-28 15:56:23.44775+03
7342	5	-1	1620	2019-10-28 16:03:47.431971+03
7343	43	-1	380	2019-10-28 16:10:18.816321+03
7344	56	-3	2460	2019-10-28 16:12:22.810483+03
7345	94	-1	1230	2019-10-28 16:35:41.861496+03
7346	1	23	294	2019-10-28 16:56:55.447987+03
7347	83	-1	1230	2019-10-28 17:06:39.319765+03
7348	41	-1	830	2019-10-28 17:10:45.00543+03
7349	47	-1	1480	2019-10-28 17:10:46.313868+03
7350	26	-2	390	2019-10-28 17:25:04.657915+03
7351	35	-1	670	2019-10-28 17:31:05.990677+03
7352	84	-1	2700	2019-10-28 18:16:44.910829+03
7353	38	34	558	2019-10-28 18:29:17.741159+03
7354	2	18	209	2019-10-28 18:47:09.757179+03
7355	56	-2	2460	2019-10-28 18:49:47.926718+03
7356	35	-1	670	2019-10-28 19:21:38.25868+03
7357	70	-1	760	2019-10-28 19:36:25.109644+03
7358	74	-1	1010	2019-10-28 19:58:52.980818+03
7359	8	-2	1920	2019-10-28 20:33:06.386123+03
7360	32	-1	710	2019-10-28 20:48:09.598091+03
7361	14	-1	1350	2019-10-28 21:00:29.283859+03
7362	76	-1	1070	2019-10-28 21:30:57.017175+03
7363	34	-1	1550	2019-10-28 21:34:22.475028+03
7364	20	-1	830	2019-10-28 21:45:41.464695+03
7365	59	-1	1030	2019-10-28 22:07:53.748476+03
7366	92	-1	630	2019-10-28 22:10:10.581064+03
7367	70	-1	760	2019-10-28 22:12:03.288521+03
7368	96	-2	1570	2019-10-28 22:12:12.039018+03
7369	92	20	320	2019-10-28 22:13:40.344454+03
7370	33	-3	900	2019-10-28 22:21:40.159704+03
7371	77	-1	640	2019-10-28 22:22:24.40467+03
7372	37	-2	1290	2019-10-28 22:25:35.283507+03
7373	81	-1	1620	2019-10-28 22:30:00.197876+03
7374	59	-1	1030	2019-10-28 22:31:57.512189+03
7375	95	-1	480	2019-10-28 23:11:46.942537+03
7376	36	-1	630	2019-10-28 23:45:15.345908+03
7377	50	-1	1140	2019-10-28 23:57:16.936676+03
7378	18	-2	910	2019-10-29 00:11:36.839544+03
7379	10	-1	2080	2019-10-29 00:20:31.139689+03
7380	44	-2	500	2019-10-29 00:24:18.85646+03
7381	6	-2	980	2019-10-29 00:25:35.873617+03
7382	8	-2	1920	2019-10-29 00:30:52.649692+03
7383	29	-2	1940	2019-10-29 00:37:04.205904+03
7384	30	-1	1140	2019-10-29 00:41:37.100078+03
7385	82	-1	560	2019-10-29 00:58:47.329162+03
7386	1	-1	640	2019-10-29 01:15:37.128792+03
7387	58	-1	2830	2019-10-29 01:38:03.775316+03
7388	36	-1	630	2019-10-29 02:38:18.519549+03
7389	30	-1	1140	2019-10-29 02:51:40.880362+03
7390	76	39	624	2019-10-29 03:01:07.153904+03
7391	33	-1	900	2019-10-29 03:10:40.491469+03
7392	32	-1	710	2019-10-29 03:39:15.144649+03
7393	60	-2	2700	2019-10-29 03:45:16.908489+03
7394	15	-1	2830	2019-10-29 03:46:08.160579+03
7395	4	-1	1420	2019-10-29 03:50:17.922725+03
7396	44	-2	500	2019-10-29 04:15:09.92839+03
7397	92	-2	630	2019-10-29 04:56:14.661625+03
7398	15	-2	2830	2019-10-29 04:57:24.988871+03
7399	34	-1	1550	2019-10-29 05:25:00.695428+03
7400	76	-1	1070	2019-10-29 05:28:52.870301+03
7401	33	-1	900	2019-10-29 05:55:01.671506+03
7402	19	-1	1220	2019-10-29 06:01:59.206287+03
7403	19	-1	1220	2019-10-29 06:14:45.972323+03
7404	30	-1	1140	2019-10-29 06:16:31.559507+03
7405	92	-2	630	2019-10-29 07:37:23.90007+03
7406	79	-1	550	2019-10-29 07:58:31.081852+03
7407	37	-2	1290	2019-10-29 08:03:58.442889+03
7408	12	-1	1650	2019-10-29 08:14:56.995205+03
7409	48	-1	640	2019-10-29 08:48:27.933012+03
7410	32	-1	710	2019-10-29 08:51:23.377376+03
7411	51	-1	1310	2019-10-29 09:05:09.689933+03
7412	39	-1	910	2019-10-29 09:15:46.592981+03
7413	29	-1	1940	2019-10-29 09:24:03.084807+03
7414	18	-1	910	2019-10-29 09:45:56.656146+03
7415	82	-1	560	2019-10-29 10:01:34.856201+03
7416	47	-1	1480	2019-10-29 10:09:40.197835+03
7417	87	-1	2320	2019-10-29 10:12:04.662196+03
7418	49	-1	970	2019-10-29 10:35:01.198329+03
7419	56	-2	2460	2019-10-29 11:24:37.874821+03
7420	93	-2	1620	2019-10-29 12:10:12.533041+03
7421	35	-1	670	2019-10-29 12:11:17.44884+03
7422	76	-1	1070	2019-10-29 12:36:32.838911+03
7423	70	-1	760	2019-10-29 13:20:12.237817+03
7424	79	-1	550	2019-10-29 13:26:34.5277+03
7425	51	-1	1310	2019-10-29 13:41:19.757407+03
7426	17	-1	1500	2019-10-29 14:31:01.437707+03
7427	87	37	1151	2019-10-29 14:33:47.837062+03
7428	87	-1	2320	2019-10-29 15:06:43.510921+03
7429	22	-1	1070	2019-10-29 15:10:55.575944+03
7430	23	-1	4390	2019-10-29 16:19:46.25594+03
7431	22	-1	1070	2019-10-29 16:24:00.488937+03
7432	96	26	735	2019-10-29 16:26:22.360364+03
7433	80	-1	1120	2019-10-29 16:42:23.095822+03
7434	20	-1	830	2019-10-29 16:52:34.989864+03
7435	88	-2	1270	2019-10-29 17:21:53.82736+03
7436	83	-1	1230	2019-10-29 17:23:10.238845+03
7437	95	-1	480	2019-10-29 17:28:03.401462+03
7438	43	-1	380	2019-10-29 17:28:30.931059+03
7439	24	-2	950	2019-10-29 18:00:40.370572+03
7440	77	-1	640	2019-10-29 18:01:02.796077+03
7441	17	-2	1500	2019-10-29 18:15:48.880424+03
7442	18	-1	910	2019-10-29 18:26:26.403419+03
7443	87	-1	2320	2019-10-29 19:01:38.328434+03
7444	94	-1	1230	2019-10-29 19:05:03.527537+03
7445	1	-1	640	2019-10-29 19:49:19.217983+03
7446	80	-1	1120	2019-10-29 20:06:14.261149+03
7447	37	-1	1290	2019-10-29 21:25:36.70568+03
7448	39	-1	910	2019-10-29 21:41:30.159053+03
7449	85	-1	730	2019-10-29 21:56:37.814824+03
7450	28	-1	1860	2019-10-29 22:05:36.591743+03
7451	7	-1	810	2019-10-29 22:23:43.284174+03
7452	18	-1	910	2019-10-29 22:25:00.232617+03
7453	28	27	765	2019-10-29 23:24:32.456445+03
7454	88	-2	1270	2019-10-29 23:31:46.167268+03
7455	29	-1	1940	2019-10-29 23:34:50.435593+03
7456	87	-2	2320	2019-10-29 23:39:45.975792+03
7457	93	-1	1620	2019-10-29 23:40:44.876787+03
7458	61	-1	1510	2019-10-29 23:45:49.086283+03
7459	54	-1	3470	2019-10-29 23:50:02.834865+03
7460	34	-1	1550	2019-10-30 00:31:29.228986+03
7461	12	-2	1650	2019-10-30 00:41:36.163655+03
7462	42	-1	1790	2019-10-30 01:07:09.852929+03
7463	40	-1	1430	2019-10-30 01:46:04.271522+03
7464	11	-1	830	2019-10-30 01:57:40.926521+03
7465	28	-1	1860	2019-10-30 02:12:23.296495+03
7466	36	-1	630	2019-10-30 02:20:22.091522+03
7467	37	-1	1290	2019-10-30 02:21:44.262798+03
7468	35	-1	670	2019-10-30 02:23:38.985896+03
7469	46	-1	1270	2019-10-30 03:15:56.75852+03
7470	18	26	435	2019-10-30 03:31:37.109293+03
7471	69	33	512	2019-10-30 03:46:56.263583+03
7472	39	-1	910	2019-10-30 03:58:47.850924+03
7473	4	-1	1420	2019-10-30 03:59:47.936567+03
7474	2	-1	470	2019-10-30 04:01:41.326196+03
7475	72	-1	620	2019-10-30 04:06:39.977388+03
7476	35	-1	670	2019-10-30 04:33:07.433892+03
7477	71	-1	1030	2019-10-30 04:33:59.063733+03
7478	35	-1	670	2019-10-30 04:43:47.569995+03
7479	56	-2	2460	2019-10-30 04:45:12.860129+03
7480	36	-1	630	2019-10-30 04:50:48.916012+03
7481	33	-1	900	2019-10-30 05:05:17.942374+03
7482	69	-1	1100	2019-10-30 05:30:16.584116+03
7483	67	-1	350	2019-10-30 05:47:43.24725+03
7484	11	-1	830	2019-10-30 05:56:29.427835+03
7485	35	-1	670	2019-10-30 06:58:00.792438+03
7486	29	-1	1940	2019-10-30 07:38:59.558059+03
7487	89	-1	1420	2019-10-30 08:18:02.090728+03
7488	14	-1	1350	2019-10-30 08:24:14.432906+03
7489	67	-1	350	2019-10-30 08:36:16.551334+03
7490	91	-1	1620	2019-10-30 08:40:31.623355+03
7491	59	-1	1030	2019-10-30 09:08:08.49418+03
7492	24	-2	950	2019-10-30 09:19:23.258671+03
7493	36	-1	630	2019-10-30 09:22:39.803682+03
7494	4	-1	1420	2019-10-30 09:35:31.419723+03
7495	33	-1	900	2019-10-30 09:47:14.604914+03
7496	96	-1	1570	2019-10-30 09:52:44.80159+03
7497	88	-1	1270	2019-10-30 10:07:21.371781+03
7498	70	-1	760	2019-10-30 10:09:24.23789+03
7499	40	-1	1430	2019-10-30 10:11:06.743801+03
7500	4	-1	1420	2019-10-30 10:26:23.554995+03
7501	9	-2	2090	2019-10-30 10:33:39.507236+03
7502	47	-1	1480	2019-10-30 11:15:24.142932+03
7503	54	-1	3470	2019-10-30 11:52:04.552581+03
7504	44	-1	500	2019-10-30 12:50:44.253877+03
7505	77	-1	640	2019-10-30 13:00:38.621498+03
7506	96	-2	1570	2019-10-30 13:31:29.572243+03
7507	82	-1	560	2019-10-30 13:50:27.000552+03
7508	73	-2	960	2019-10-30 13:53:51.731875+03
7509	41	-1	830	2019-10-30 14:15:36.132134+03
7510	84	-1	2700	2019-10-30 14:24:00.94888+03
7511	6	-1	980	2019-10-30 14:55:43.348252+03
7512	42	-1	1790	2019-10-30 15:20:48.113889+03
7513	17	-1	1500	2019-10-30 15:42:32.854789+03
7514	96	-2	1570	2019-10-30 15:42:46.629417+03
7515	72	-1	620	2019-10-30 15:56:20.11236+03
7516	45	-1	1590	2019-10-30 15:58:31.363298+03
7517	86	-1	910	2019-10-30 16:24:19.948942+03
7518	87	-1	2320	2019-10-30 16:41:51.745586+03
7519	91	-1	1620	2019-10-30 16:45:02.815599+03
7520	8	-1	1920	2019-10-30 17:32:24.134587+03
7521	32	-1	710	2019-10-30 17:42:44.809035+03
7522	26	-1	390	2019-10-30 18:40:30.858994+03
7523	38	-1	1100	2019-10-30 19:13:21.591014+03
7524	40	-1	1430	2019-10-30 19:31:59.629203+03
7525	94	-2	1230	2019-10-30 19:44:55.292513+03
7526	46	-1	1270	2019-10-30 20:11:42.059909+03
7527	14	-1	1350	2019-10-30 20:27:34.672057+03
7528	56	-1	2460	2019-10-30 20:33:02.227546+03
7529	39	-1	910	2019-10-30 21:14:56.682773+03
7530	24	-1	950	2019-10-30 21:16:02.032669+03
7531	4	-1	1420	2019-10-30 21:50:58.076934+03
7532	55	-1	3480	2019-10-30 22:26:08.672513+03
7533	34	-1	1550	2019-10-30 22:32:23.84933+03
7534	5	-1	1620	2019-10-30 22:47:12.865755+03
7535	90	-1	1780	2019-10-30 22:53:09.480298+03
7536	38	-1	1100	2019-10-30 22:56:55.115708+03
7537	79	-2	550	2019-10-30 23:00:22.537022+03
7538	44	-2	500	2019-10-30 23:11:34.227053+03
7539	47	-2	1480	2019-10-30 23:25:58.579669+03
7540	20	-1	830	2019-10-31 00:16:05.549963+03
7541	54	-1	3470	2019-10-31 01:12:04.59449+03
7542	33	-1	900	2019-10-31 02:05:36.132322+03
7543	49	-3	970	2019-10-31 02:20:46.27533+03
7544	61	-1	1510	2019-10-31 02:31:22.173251+03
7545	60	-1	2700	2019-10-31 02:34:06.387078+03
7546	75	-1	830	2019-10-31 03:00:36.336242+03
7547	17	-1	1500	2019-10-31 03:01:38.362828+03
7548	94	-1	1230	2019-10-31 03:19:27.747452+03
7549	60	-1	2700	2019-10-31 03:28:58.112928+03
7550	43	-1	380	2019-10-31 03:30:08.813818+03
7551	84	-1	2700	2019-10-31 03:31:21.470404+03
7552	88	-1	1270	2019-10-31 04:15:42.448143+03
7553	3	-1	660	2019-10-31 04:18:33.784783+03
7554	23	-1	4390	2019-10-31 04:27:19.456504+03
7555	50	-2	1140	2019-10-31 04:33:02.16394+03
7556	20	25	368	2019-10-31 04:38:55.756261+03
7557	4	-1	1420	2019-10-31 04:58:33.662234+03
7558	80	-1	1120	2019-10-31 05:07:25.11881+03
7559	3	19	275	2019-10-31 05:08:34.925826+03
7560	47	-1	1480	2019-10-31 05:13:20.885048+03
7561	6	-1	980	2019-10-31 05:21:35.573357+03
7562	81	-1	1620	2019-10-31 05:46:10.10053+03
7563	60	-2	2700	2019-10-31 05:48:21.087361+03
7564	80	-2	1120	2019-10-31 05:54:37.287708+03
7565	38	-1	1100	2019-10-31 06:04:22.688287+03
7566	84	-1	2700	2019-10-31 06:30:54.688129+03
7567	4	-2	1420	2019-10-31 06:34:33.399742+03
7568	34	-1	1550	2019-10-31 06:36:11.458446+03
7569	38	-1	1100	2019-10-31 07:02:23.558011+03
7570	14	-2	1350	2019-10-31 07:05:42.198223+03
7571	81	-1	1620	2019-10-31 07:08:08.046697+03
7572	43	-1	380	2019-10-31 07:21:48.531952+03
7573	96	-1	1570	2019-10-31 07:38:56.190469+03
7574	48	-1	640	2019-10-31 08:15:32.227706+03
7575	86	-2	910	2019-10-31 08:19:43.838348+03
7576	9	-1	2090	2019-10-31 08:20:07.773563+03
7577	82	-1	560	2019-10-31 08:25:14.690283+03
7578	14	-1	1350	2019-10-31 08:30:24.511404+03
7579	22	-1	1070	2019-10-31 09:24:35.884625+03
7580	86	-1	910	2019-10-31 09:41:02.929157+03
7581	60	-1	2700	2019-10-31 09:41:26.116247+03
7582	33	-1	900	2019-10-31 09:42:29.383062+03
7583	28	-1	1860	2019-10-31 09:51:55.325415+03
7584	31	-1	1190	2019-10-31 09:57:19.628408+03
7585	84	-1	2700	2019-10-31 10:05:38.805656+03
7586	25	-1	1100	2019-10-31 10:23:15.351741+03
7587	86	40	496	2019-10-31 10:26:32.520032+03
7588	19	-2	1220	2019-10-31 10:42:49.549695+03
7589	62	-1	1220	2019-10-31 11:02:17.696178+03
7590	58	-1	2830	2019-10-31 11:03:24.434458+03
7591	76	-1	1070	2019-10-31 11:19:28.527954+03
7592	89	-1	1420	2019-10-31 11:51:16.693294+03
7593	10	-1	2080	2019-10-31 11:56:30.163454+03
7594	75	-2	830	2019-10-31 12:01:57.085095+03
7595	47	-1	1480	2019-10-31 12:05:13.821043+03
7596	64	-2	970	2019-10-31 12:24:57.349006+03
7597	63	-2	1780	2019-10-31 12:37:02.384229+03
7598	37	-1	1290	2019-10-31 12:40:03.423794+03
7599	55	-2	3480	2019-10-31 13:07:06.293055+03
7600	56	-1	2460	2019-10-31 14:14:31.047028+03
7601	62	-1	1220	2019-10-31 14:21:48.640175+03
7602	8	-1	1920	2019-10-31 15:20:24.32334+03
7603	66	-1	690	2019-10-31 16:04:29.921061+03
7604	64	-1	970	2019-10-31 16:14:35.536569+03
7605	76	-1	1070	2019-10-31 16:24:47.070247+03
7606	5	-1	1620	2019-10-31 16:27:04.600282+03
7607	81	-1	1620	2019-10-31 16:28:24.201812+03
7608	25	-2	1100	2019-10-31 16:35:02.061208+03
7609	58	-1	2830	2019-10-31 16:59:57.176411+03
7610	54	-1	3470	2019-10-31 18:47:49.913086+03
7611	89	-1	1420	2019-10-31 19:09:01.609128+03
7612	65	-1	490	2019-10-31 19:14:12.207986+03
7613	39	-1	910	2019-10-31 19:33:04.093458+03
7614	87	-1	2320	2019-10-31 19:54:34.739398+03
7615	87	-1	2320	2019-10-31 19:58:39.027484+03
7616	84	34	1243	2019-10-31 20:15:18.380026+03
7617	26	-1	390	2019-10-31 20:20:30.393102+03
7618	60	-2	2700	2019-10-31 20:30:19.290702+03
7619	10	-1	2080	2019-10-31 20:33:53.55411+03
7620	33	-1	900	2019-10-31 20:35:20.917011+03
7621	74	-1	1010	2019-10-31 20:53:42.3836+03
7622	84	-2	2700	2019-10-31 21:26:01.149983+03
7623	73	-2	960	2019-10-31 22:07:28.265729+03
7624	28	-1	1860	2019-10-31 22:20:26.483788+03
7625	81	-1	1620	2019-10-31 22:24:11.881062+03
7626	9	-1	2090	2019-10-31 22:28:13.661217+03
7627	1	-1	640	2019-10-31 22:33:37.75516+03
7628	33	-1	900	2019-10-31 22:34:45.143451+03
7629	16	-1	1380	2019-10-31 22:43:00.39301+03
7630	7	-1	810	2019-10-31 22:49:35.710742+03
7631	85	-2	730	2019-10-31 22:56:10.818813+03
7632	7	-1	810	2019-10-31 23:24:05.310497+03
7633	56	-1	2460	2019-10-31 23:28:21.622454+03
7634	81	-2	1620	2019-10-31 23:38:07.567124+03
7635	10	-1	2080	2019-10-31 23:45:49.443672+03
7636	11	-1	830	2019-11-01 00:48:13.330624+03
7637	23	-1	4390	2019-11-01 00:57:38.297924+03
7638	20	-1	830	2019-11-01 01:11:09.248752+03
7639	40	-2	1430	2019-11-01 01:54:27.244792+03
7640	89	-1	1420	2019-11-01 02:04:56.484933+03
7641	26	-1	390	2019-11-01 02:12:13.315957+03
7642	12	-1	1650	2019-11-01 02:21:51.643922+03
7643	7	-1	810	2019-11-01 02:29:46.247229+03
7644	47	38	674	2019-11-01 02:50:05.29928+03
7645	30	-1	1140	2019-11-01 03:02:00.2774+03
7646	21	-1	960	2019-11-01 03:38:23.928568+03
7647	33	-1	900	2019-11-01 03:41:42.498111+03
7648	54	-2	3470	2019-11-01 03:48:17.138802+03
7649	85	-1	730	2019-11-01 03:48:38.156461+03
7650	5	-1	1620	2019-11-01 04:01:39.605027+03
7651	30	-1	1140	2019-11-01 04:17:24.339055+03
7652	94	-1	1230	2019-11-01 04:38:53.453477+03
7653	80	-1	1120	2019-11-01 04:45:07.124207+03
7654	90	-1	1780	2019-11-01 04:53:01.051669+03
7655	46	-1	1270	2019-11-01 05:05:00.126585+03
7656	49	-1	970	2019-11-01 05:28:47.830779+03
7657	11	-1	830	2019-11-01 05:46:38.523113+03
7658	8	-1	1920	2019-11-01 05:49:15.51665+03
7659	24	-1	950	2019-11-01 06:05:10.699695+03
7660	30	-1	1140	2019-11-01 06:30:17.531584+03
7661	35	-2	670	2019-11-01 06:45:57.083483+03
7662	41	-1	830	2019-11-01 06:47:12.440763+03
7663	15	-1	2830	2019-11-01 07:07:43.453881+03
7664	41	-2	830	2019-11-01 07:24:11.501602+03
7665	4	-1	1420	2019-11-01 07:24:13.988655+03
7666	69	-1	1100	2019-11-01 07:34:39.658564+03
7667	70	-1	760	2019-11-01 07:36:52.592392+03
7668	27	-1	880	2019-11-01 08:47:06.577966+03
7669	46	-3	1270	2019-11-01 08:57:52.613599+03
7670	88	-2	1270	2019-11-01 09:08:46.619145+03
7671	29	-2	1940	2019-11-01 09:20:51.162791+03
7672	23	-2	4390	2019-11-01 09:39:28.651096+03
7673	72	-1	620	2019-11-01 09:43:14.513928+03
7674	74	-2	1010	2019-11-01 09:51:01.703828+03
7675	78	-2	900	2019-11-01 09:52:49.285682+03
7676	8	-1	1920	2019-11-01 09:56:57.805402+03
7677	54	-1	3470	2019-11-01 11:15:34.696555+03
7678	58	-1	2830	2019-11-01 11:32:01.842417+03
7679	55	-1	3480	2019-11-01 11:39:45.733208+03
7680	82	-1	560	2019-11-01 11:54:20.190106+03
7681	61	-1	1510	2019-11-01 11:58:32.396925+03
7682	81	-1	1620	2019-11-01 12:05:43.358421+03
7683	42	-1	1790	2019-11-01 12:23:52.126144+03
7684	67	-1	350	2019-11-01 12:23:52.475231+03
7685	26	-1	390	2019-11-01 12:44:13.367887+03
7686	32	-1	710	2019-11-01 12:54:35.84863+03
7687	40	-1	1430	2019-11-01 13:32:30.410669+03
7688	51	-2	1310	2019-11-01 13:34:27.592317+03
7689	48	-1	640	2019-11-01 13:45:03.770796+03
7690	11	-1	830	2019-11-01 13:50:26.438812+03
7691	37	-1	1290	2019-11-01 14:01:52.491012+03
7692	71	-1	1030	2019-11-01 14:23:59.374765+03
7693	96	-1	1570	2019-11-01 14:55:23.695833+03
7694	24	-1	950	2019-11-01 15:22:31.00675+03
7695	80	-1	1120	2019-11-01 15:46:07.450238+03
7696	70	-2	760	2019-11-01 16:04:49.822122+03
7697	67	-1	350	2019-11-01 16:23:21.222645+03
7698	94	26	644	2019-11-01 16:36:28.256553+03
7699	63	-1	1780	2019-11-01 16:54:58.63011+03
7700	64	-1	970	2019-11-01 17:34:47.897712+03
7701	38	-1	1100	2019-11-01 17:47:10.029508+03
7702	68	-2	490	2019-11-01 17:50:28.981264+03
7703	91	-1	1620	2019-11-01 18:04:43.328061+03
7704	94	-1	1230	2019-11-01 18:21:46.944849+03
7705	40	-1	1430	2019-11-01 18:38:35.32162+03
7706	49	-1	970	2019-11-01 18:50:07.796224+03
7707	2	-1	470	2019-11-01 18:52:47.927366+03
7708	76	-1	1070	2019-11-01 18:55:07.881684+03
7709	13	-1	460	2019-11-01 19:15:00.614756+03
7710	1	-2	640	2019-11-01 19:20:43.622617+03
7711	25	-1	1100	2019-11-01 19:26:38.33576+03
7712	76	-1	1070	2019-11-01 19:30:03.845952+03
7713	66	-2	690	2019-11-01 19:47:17.709368+03
7714	48	-1	640	2019-11-01 19:51:35.38945+03
7715	43	-1	380	2019-11-01 20:14:03.749006+03
7716	46	-1	1270	2019-11-01 20:19:23.127907+03
7717	13	-1	460	2019-11-01 20:32:10.850503+03
7718	58	-1	2830	2019-11-01 20:33:45.967659+03
7719	48	-1	640	2019-11-01 20:42:29.579515+03
7720	85	-1	730	2019-11-01 20:48:05.927932+03
7721	69	-1	1100	2019-11-01 20:48:12.537688+03
7722	43	-1	380	2019-11-01 20:49:47.354481+03
7723	83	-1	1230	2019-11-01 20:51:37.741657+03
7724	76	-1	1070	2019-11-01 20:57:08.79812+03
7725	38	-1	1100	2019-11-01 21:10:00.076074+03
7726	95	-1	480	2019-11-01 21:38:54.836747+03
7727	45	-1	1590	2019-11-01 21:42:03.936456+03
7728	93	-2	1620	2019-11-01 21:43:59.453767+03
7729	44	-2	500	2019-11-01 22:08:06.371516+03
7730	25	-1	1100	2019-11-01 22:32:05.363381+03
7731	38	-2	1100	2019-11-01 22:33:37.120546+03
7732	47	-1	1480	2019-11-01 22:38:47.442995+03
7733	52	-2	1090	2019-11-01 22:49:59.61397+03
7734	8	-1	1920	2019-11-01 23:13:25.224134+03
7735	75	-1	830	2019-11-01 23:50:10.738099+03
7736	39	-1	910	2019-11-02 00:11:41.679597+03
7737	1	-1	640	2019-11-02 01:23:18.151805+03
7738	40	27	581	2019-11-02 01:49:58.564076+03
7739	47	-1	1480	2019-11-02 02:03:10.002614+03
7740	95	-1	480	2019-11-02 02:06:29.097315+03
7741	2	-1	470	2019-11-02 02:10:05.981974+03
7742	77	-1	640	2019-11-02 02:19:05.779951+03
7743	76	-1	1070	2019-11-02 02:28:17.248644+03
7744	69	-1	1100	2019-11-02 02:59:53.347374+03
7745	81	21	946	2019-11-02 03:16:59.485304+03
7746	95	26	202	2019-11-02 03:25:31.343351+03
7747	59	-2	1030	2019-11-02 03:27:17.628333+03
7748	37	-1	1290	2019-11-02 03:29:43.962924+03
7749	57	-1	1900	2019-11-02 03:51:02.067231+03
7750	46	-1	1270	2019-11-02 03:52:41.305042+03
7751	14	-1	1350	2019-11-02 03:53:14.134887+03
7752	8	-2	1920	2019-11-02 03:57:39.151216+03
7753	77	-1	640	2019-11-02 04:01:03.47532+03
7754	61	-1	1510	2019-11-02 04:25:46.318882+03
7755	65	-1	490	2019-11-02 04:43:10.195594+03
7756	18	-1	910	2019-11-02 04:59:22.849477+03
7757	7	-2	810	2019-11-02 05:17:02.617382+03
7758	24	-2	950	2019-11-02 05:25:11.018937+03
7759	29	-1	1940	2019-11-02 06:04:05.005778+03
7760	47	-1	1480	2019-11-02 06:04:31.984272+03
7761	39	-1	910	2019-11-02 06:10:52.681161+03
7762	36	-2	630	2019-11-02 06:20:14.616791+03
7763	45	-1	1590	2019-11-02 06:23:57.66714+03
7764	52	-1	1090	2019-11-02 06:28:28.468883+03
7765	42	-1	1790	2019-11-02 06:29:22.952473+03
7766	44	-1	500	2019-11-02 07:11:34.382535+03
7767	17	-1	1500	2019-11-02 07:22:21.20123+03
7768	54	-1	3470	2019-11-02 07:46:11.385389+03
7769	33	-1	900	2019-11-02 07:56:48.560509+03
7770	47	-1	1480	2019-11-02 08:14:19.326711+03
7771	72	-1	620	2019-11-02 08:33:37.618683+03
7772	32	-1	710	2019-11-02 09:02:49.856268+03
7773	32	31	380	2019-11-02 09:08:04.686685+03
7774	83	-1	1230	2019-11-02 09:31:35.400355+03
7775	2	-1	470	2019-11-02 09:37:53.046846+03
7776	21	-1	960	2019-11-02 10:08:27.019757+03
7777	18	-1	910	2019-11-02 10:16:51.357701+03
7778	77	-1	640	2019-11-02 10:19:19.395874+03
7779	78	-2	900	2019-11-02 10:25:38.481995+03
7780	47	-1	1480	2019-11-02 10:26:33.962423+03
7781	67	-1	350	2019-11-02 10:30:21.127155+03
7782	2	-1	470	2019-11-02 10:51:07.62512+03
7783	76	-1	1070	2019-11-02 11:19:20.776635+03
7784	47	-1	1480	2019-11-02 11:54:20.893353+03
7785	58	-1	2830	2019-11-02 12:07:59.626212+03
7786	35	-1	670	2019-11-02 12:29:03.355805+03
7787	83	-1	1230	2019-11-02 13:16:00.80483+03
7788	25	-1	1100	2019-11-02 13:43:42.624284+03
7789	13	-1	460	2019-11-02 13:46:15.473482+03
7790	46	-1	1270	2019-11-02 13:53:18.159342+03
7791	20	-1	830	2019-11-02 14:18:59.885589+03
7792	67	-1	350	2019-11-02 14:32:18.317553+03
7793	71	-2	1030	2019-11-02 14:33:49.87641+03
7794	36	-1	630	2019-11-02 14:38:14.791592+03
7795	9	-2	2090	2019-11-02 14:56:58.3605+03
7796	71	-1	1030	2019-11-02 15:02:47.443993+03
7797	65	-2	490	2019-11-02 15:15:14.835647+03
7798	45	-1	1590	2019-11-02 15:19:15.763537+03
7799	61	-2	1510	2019-11-02 15:28:21.906268+03
7800	36	-1	630	2019-11-02 15:42:28.394549+03
7801	81	-1	1620	2019-11-02 15:42:29.149594+03
7802	96	-2	1570	2019-11-02 15:51:00.293329+03
7803	22	-1	1070	2019-11-02 16:01:10.149999+03
7804	83	-1	1230	2019-11-02 16:10:20.725929+03
7805	42	-1	1790	2019-11-02 16:23:49.482922+03
7806	83	-1	1230	2019-11-02 16:33:07.052066+03
7807	58	-1	2830	2019-11-02 16:37:45.485686+03
7808	81	-2	1620	2019-11-02 16:54:37.362607+03
7809	53	-1	3120	2019-11-02 17:38:07.138814+03
7810	48	-2	640	2019-11-02 17:55:31.738169+03
7811	2	-1	470	2019-11-02 18:11:02.800764+03
7812	21	-1	960	2019-11-02 18:15:00.79757+03
7813	4	-2	1420	2019-11-02 18:15:31.406461+03
7814	91	-1	1620	2019-11-02 18:24:53.183459+03
7815	87	-2	2320	2019-11-02 18:34:23.860308+03
7816	89	-2	1420	2019-11-02 18:36:19.71407+03
7817	53	-1	3120	2019-11-02 18:48:37.038311+03
7818	56	-1	2460	2019-11-02 18:50:16.269435+03
7819	42	37	927	2019-11-02 19:14:02.945208+03
7820	64	-1	970	2019-11-02 19:22:08.999555+03
7821	74	-1	1010	2019-11-02 19:28:58.394443+03
7822	81	-1	1620	2019-11-02 19:59:12.326353+03
7823	88	-1	1270	2019-11-02 20:23:56.369902+03
7824	77	-1	640	2019-11-02 20:42:58.246307+03
7825	35	-1	670	2019-11-02 20:53:22.320036+03
7826	77	-1	640	2019-11-02 21:08:53.887239+03
7827	87	-1	2320	2019-11-02 21:32:06.935244+03
7828	1	-1	640	2019-11-02 21:39:42.24+03
7829	6	-1	980	2019-11-02 21:55:41.361033+03
7830	89	-1	1420	2019-11-02 22:13:56.151801+03
7831	2	-1	470	2019-11-02 22:22:42.611204+03
7832	27	-2	880	2019-11-02 22:26:04.920219+03
7833	38	-2	1100	2019-11-02 22:27:58.213025+03
7834	36	-2	630	2019-11-02 22:29:35.416257+03
7835	61	-1	1510	2019-11-02 22:45:43.815882+03
7836	4	-1	1420	2019-11-02 22:54:02.640676+03
7837	4	-2	1420	2019-11-03 00:56:04.058899+03
7838	42	-1	1790	2019-11-03 01:08:16.395013+03
7839	21	-1	960	2019-11-03 01:17:18.311488+03
7840	88	-1	1270	2019-11-03 01:27:45.489715+03
7841	14	-1	1350	2019-11-03 01:37:12.838982+03
7842	59	-1	1030	2019-11-03 02:00:46.871566+03
7843	88	-1	1270	2019-11-03 02:00:52.796468+03
7844	15	-1	2830	2019-11-03 02:52:22.070194+03
7845	51	23	788	2019-11-03 03:03:02.633782+03
7846	52	-2	1090	2019-11-03 03:03:10.696022+03
7847	54	-1	3470	2019-11-03 03:10:09.139517+03
7848	29	-1	1940	2019-11-03 03:10:36.610835+03
7849	31	-1	1190	2019-11-03 03:28:31.431388+03
7850	47	-1	1480	2019-11-03 03:38:59.142215+03
7851	87	-1	2320	2019-11-03 03:47:27.269643+03
7852	63	-1	1780	2019-11-03 04:03:03.401845+03
7853	41	-1	830	2019-11-03 04:04:20.657035+03
7854	91	-1	1620	2019-11-03 04:08:38.495061+03
7855	96	-1	1570	2019-11-03 04:21:48.042559+03
7856	20	-1	830	2019-11-03 04:25:29.865173+03
7857	43	-2	380	2019-11-03 04:29:20.858292+03
7858	41	-1	830	2019-11-03 04:42:54.654408+03
7859	22	-1	1070	2019-11-03 04:55:11.920419+03
7860	19	-1	1220	2019-11-03 05:13:51.073207+03
7861	91	-1	1620	2019-11-03 05:47:26.338525+03
7862	17	-1	1500	2019-11-03 05:49:27.926008+03
7863	94	-1	1230	2019-11-03 05:56:06.052709+03
7864	25	-1	1100	2019-11-03 05:57:05.833468+03
7865	36	-1	630	2019-11-03 07:36:48.616147+03
7866	55	-1	3480	2019-11-03 07:37:46.195803+03
7867	12	-1	1650	2019-11-03 08:09:26.627063+03
7868	76	-1	1070	2019-11-03 08:14:25.305918+03
7869	10	-1	2080	2019-11-03 08:14:57.696648+03
7870	83	-2	1230	2019-11-03 08:29:32.723342+03
7871	82	-1	560	2019-11-03 08:36:00.033278+03
7872	18	-1	910	2019-11-03 08:49:12.822077+03
7873	34	28	871	2019-11-03 09:26:30.411709+03
7874	30	-1	1140	2019-11-03 09:28:55.757+03
7875	50	-1	1140	2019-11-03 09:31:58.358102+03
7876	18	-1	910	2019-11-03 10:02:04.995347+03
7877	26	-2	390	2019-11-03 10:02:46.330387+03
7878	81	-2	1620	2019-11-03 10:04:22.60203+03
7879	46	-1	1270	2019-11-03 10:05:43.424153+03
7880	34	-1	1550	2019-11-03 10:13:34.548921+03
7881	82	22	274	2019-11-03 10:35:54.235044+03
7882	37	-1	1290	2019-11-03 10:49:26.02523+03
7883	24	-1	950	2019-11-03 11:08:49.395528+03
7884	35	-1	670	2019-11-03 11:10:58.343134+03
7885	17	-1	1500	2019-11-03 11:11:42.301653+03
7886	27	-1	880	2019-11-03 11:36:58.666942+03
7887	57	-1	1900	2019-11-03 11:41:14.808391+03
7888	56	41	1364	2019-11-03 11:41:24.647725+03
7889	55	-2	3480	2019-11-03 11:42:28.978153+03
7890	78	-2	900	2019-11-03 12:10:08.220334+03
7891	34	-1	1550	2019-11-03 12:12:38.696858+03
7892	6	-1	980	2019-11-03 12:37:02.422727+03
7893	8	-1	1920	2019-11-03 12:40:59.626336+03
7894	41	-1	830	2019-11-03 12:45:15.365372+03
7895	74	-1	1010	2019-11-03 12:53:55.488038+03
7896	33	-1	900	2019-11-03 12:59:13.562277+03
7897	13	-1	460	2019-11-03 13:15:59.060107+03
7898	77	-1	640	2019-11-03 13:18:22.919354+03
7899	43	-1	380	2019-11-03 13:32:46.384697+03
7900	42	-2	1790	2019-11-03 13:46:27.330739+03
7901	17	-1	1500	2019-11-03 13:49:22.153864+03
7902	14	-1	1350	2019-11-03 14:01:43.353443+03
7903	1	-1	640	2019-11-03 14:47:06.64977+03
7904	12	50	796	2019-11-03 15:02:52.41978+03
7905	76	-1	1070	2019-11-03 15:04:42.180802+03
7906	20	-1	830	2019-11-03 15:14:56.402552+03
7907	55	22	1529	2019-11-03 15:38:38.376022+03
7908	77	-1	640	2019-11-03 15:46:03.628815+03
7909	67	-1	350	2019-11-03 16:42:37.767191+03
7910	17	-2	1500	2019-11-03 17:11:28.519179+03
7911	96	-1	1570	2019-11-03 17:14:18.592667+03
7912	11	-2	830	2019-11-03 17:38:51.316715+03
7913	40	-2	1430	2019-11-03 17:39:09.970821+03
7914	40	-1	1430	2019-11-03 18:30:34.220269+03
7915	29	-1	1940	2019-11-03 18:36:23.202234+03
7916	49	-1	970	2019-11-03 18:37:58.866346+03
7917	44	-1	500	2019-11-03 18:55:12.3824+03
7918	75	-2	830	2019-11-03 19:18:29.934883+03
7919	26	-1	390	2019-11-03 19:29:21.388514+03
7920	28	-1	1860	2019-11-03 19:31:04.12431+03
7921	38	-1	1100	2019-11-03 19:32:39.401204+03
7922	70	-1	760	2019-11-03 19:39:40.290615+03
7923	63	-1	1780	2019-11-03 19:43:11.240796+03
7924	56	-2	2460	2019-11-03 20:02:01.749018+03
7925	5	-1	1620	2019-11-03 20:02:08.33117+03
7926	3	-1	660	2019-11-03 20:04:23.578562+03
7927	35	-1	670	2019-11-03 20:32:48.091813+03
7928	46	-1	1270	2019-11-03 20:41:51.50003+03
7929	28	-1	1860	2019-11-03 20:45:00.074325+03
7930	55	-1	3480	2019-11-03 20:59:24.677584+03
7931	48	-1	640	2019-11-03 21:02:10.655092+03
7932	83	-1	1230	2019-11-03 21:05:29.813834+03
7933	19	-1	1220	2019-11-03 21:28:00.26233+03
7934	8	-1	1920	2019-11-03 21:56:48.764211+03
7935	81	-1	1620	2019-11-03 22:02:37.081979+03
7936	89	-1	1420	2019-11-03 22:07:22.482657+03
7937	49	-2	970	2019-11-03 22:09:55.830627+03
7938	83	-1	1230	2019-11-03 22:41:40.210202+03
7939	94	-1	1230	2019-11-03 23:19:51.889106+03
7940	31	-1	1190	2019-11-03 23:24:13.27014+03
7941	22	-1	1070	2019-11-03 23:25:25.57949+03
7942	26	-2	390	2019-11-03 23:26:32.843853+03
7943	26	27	174	2019-11-03 23:58:31.5815+03
7944	60	-1	2700	2019-11-04 00:02:50.369246+03
7945	54	-2	3470	2019-11-04 01:46:12.532204+03
7946	73	-3	960	2019-11-04 01:51:37.706637+03
7947	33	-1	900	2019-11-04 01:51:54.981919+03
7948	63	-1	1780	2019-11-04 02:07:46.819238+03
7949	96	-1	1570	2019-11-04 02:14:04.2769+03
7950	56	-2	2460	2019-11-04 02:35:11.130402+03
7951	95	-1	480	2019-11-04 02:41:28.420513+03
7952	17	-1	1500	2019-11-04 02:54:07.38125+03
7953	35	-1	670	2019-11-04 02:55:05.295658+03
7954	17	-1	1500	2019-11-04 02:55:19.415771+03
7955	14	-2	1350	2019-11-04 03:26:36.999306+03
7956	52	-1	1090	2019-11-04 04:07:42.904131+03
7957	10	-2	2080	2019-11-04 04:08:37.593098+03
7958	70	-1	760	2019-11-04 04:13:32.249707+03
7959	21	-1	960	2019-11-04 04:26:02.689271+03
7960	44	-1	500	2019-11-04 04:31:22.232628+03
7961	50	-1	1140	2019-11-04 04:56:14.03603+03
7962	71	-2	1030	2019-11-04 05:43:02.154631+03
7963	26	-1	390	2019-11-04 06:07:43.172316+03
7964	27	-2	880	2019-11-04 06:25:59.177709+03
7965	42	-1	1790	2019-11-04 06:40:28.113724+03
7966	37	-1	1290	2019-11-04 07:06:55.416345+03
7967	24	24	526	2019-11-04 07:29:47.609853+03
7968	63	-1	1780	2019-11-04 07:34:58.898411+03
7969	38	-2	1100	2019-11-04 07:37:05.338322+03
7970	95	-1	480	2019-11-04 07:48:04.885576+03
7971	64	-2	970	2019-11-04 08:15:48.440068+03
7972	4	-2	1420	2019-11-04 08:24:04.272749+03
7973	71	-1	1030	2019-11-04 09:13:52.057444+03
7974	68	-1	490	2019-11-04 09:33:41.919661+03
7975	3	-1	660	2019-11-04 09:39:56.609041+03
7976	26	-1	390	2019-11-04 10:01:29.639784+03
7977	15	-1	2830	2019-11-04 10:22:03.436634+03
7978	24	-1	950	2019-11-04 10:59:24.312616+03
7979	88	-2	1270	2019-11-04 10:59:37.152368+03
7980	61	-1	1510	2019-11-04 11:01:06.704839+03
7981	55	-1	3480	2019-11-04 11:52:54.054241+03
7982	80	-1	1120	2019-11-04 12:02:12.697842+03
7983	93	-2	1620	2019-11-04 12:03:39.318915+03
7984	74	-1	1010	2019-11-04 12:04:51.477821+03
7985	84	-1	2700	2019-11-04 12:05:03.407908+03
7986	27	-2	880	2019-11-04 12:19:22.393433+03
7987	32	-2	710	2019-11-04 12:37:03.391614+03
7988	96	-2	1570	2019-11-04 13:08:14.39674+03
7989	38	-1	1100	2019-11-04 13:31:23.642413+03
7990	83	-1	1230	2019-11-04 13:31:33.975932+03
7991	57	-1	1900	2019-11-04 13:41:51.496969+03
7992	37	-1	1290	2019-11-04 13:48:16.76846+03
7993	51	-1	1310	2019-11-04 14:22:24.241909+03
7994	8	-1	1920	2019-11-04 14:30:37.260496+03
7995	49	-1	970	2019-11-04 14:32:06.176726+03
7996	72	-1	620	2019-11-04 14:41:25.045245+03
7997	84	-1	2700	2019-11-04 14:52:00.165575+03
7998	37	-2	1290	2019-11-04 14:57:41.22084+03
7999	43	16	155	2019-11-04 15:02:39.140657+03
8000	74	-1	1010	2019-11-04 15:07:33.056953+03
8001	6	-1	980	2019-11-04 15:25:41.686054+03
8002	22	-1	1070	2019-11-04 16:23:00.905482+03
8003	83	31	613	2019-11-04 16:24:58.680753+03
8004	10	-2	2080	2019-11-04 16:36:36.735491+03
8005	10	-1	2080	2019-11-04 17:37:29.118754+03
8006	35	-2	670	2019-11-04 17:41:35.123901+03
8007	11	-1	830	2019-11-04 18:24:52.909757+03
8008	24	-1	950	2019-11-04 19:12:54.506716+03
8009	28	-2	1860	2019-11-04 19:31:16.900018+03
8010	55	-2	3480	2019-11-04 20:06:22.194442+03
8011	93	-2	1620	2019-11-04 20:27:18.679071+03
8012	8	-1	1920	2019-11-04 20:35:06.017353+03
8013	53	-2	3120	2019-11-04 20:35:55.359034+03
8014	80	-1	1120	2019-11-04 21:34:28.592274+03
8015	60	-1	2700	2019-11-04 22:10:51.866069+03
8016	19	30	602	2019-11-04 22:24:07.017303+03
8017	17	-2	1500	2019-11-04 22:51:26.568895+03
8018	57	-1	1900	2019-11-04 23:02:07.284894+03
8019	61	-1	1510	2019-11-04 23:41:30.142274+03
8020	78	-1	900	2019-11-05 00:01:03.792843+03
8021	79	-1	550	2019-11-05 00:13:45.175039+03
8022	87	-1	2320	2019-11-05 00:20:23.736125+03
8023	47	-1	1480	2019-11-05 00:38:47.814711+03
8024	88	-1	1270	2019-11-05 00:42:01.242571+03
8025	57	-2	1900	2019-11-05 00:56:56.946301+03
8026	56	-1	2460	2019-11-05 01:07:51.868369+03
8027	16	-1	1380	2019-11-05 01:12:45.571162+03
8028	72	-1	620	2019-11-05 01:27:37.611785+03
8029	61	-1	1510	2019-11-05 01:29:42.062604+03
8030	26	-2	390	2019-11-05 02:03:11.404326+03
8031	91	-1	1620	2019-11-05 02:13:59.380723+03
8032	82	-1	560	2019-11-05 02:29:41.284414+03
8033	76	-1	1070	2019-11-05 02:29:52.581835+03
8034	44	-2	500	2019-11-05 02:58:47.348122+03
8035	12	-2	1650	2019-11-05 03:13:47.747599+03
8036	18	-1	910	2019-11-05 03:21:56.577881+03
8037	19	-1	1220	2019-11-05 03:23:13.990222+03
8038	65	-2	490	2019-11-05 03:32:09.288792+03
8039	42	-1	1790	2019-11-05 03:47:29.641766+03
8040	56	-1	2460	2019-11-05 03:56:42.244696+03
8041	39	-2	910	2019-11-05 04:06:45.21935+03
8042	30	-1	1140	2019-11-05 04:27:43.88069+03
8043	70	-1	760	2019-11-05 04:35:27.470829+03
8044	83	-2	1230	2019-11-05 04:38:31.983469+03
8045	5	-1	1620	2019-11-05 05:01:15.460381+03
8046	85	15	384	2019-11-05 05:05:44.582263+03
8047	86	-1	910	2019-11-05 05:06:29.968419+03
8048	89	-1	1420	2019-11-05 05:38:02.352728+03
8049	1	-2	640	2019-11-05 06:00:40.554955+03
8050	16	-1	1380	2019-11-05 06:18:00.232761+03
8051	78	-1	900	2019-11-05 06:18:47.79753+03
8052	54	-1	3470	2019-11-05 06:37:49.243827+03
8053	85	-1	730	2019-11-05 06:50:12.445722+03
8054	59	-1	1030	2019-11-05 07:00:12.08676+03
8055	91	-1	1620	2019-11-05 07:08:01.678026+03
8056	95	-2	480	2019-11-05 07:34:19.257785+03
8057	70	-1	760	2019-11-05 07:59:44.902638+03
8058	20	-1	830	2019-11-05 08:06:22.640777+03
8059	9	-1	2090	2019-11-05 08:19:52.391372+03
8060	74	-1	1010	2019-11-05 08:20:26.845248+03
8061	51	-1	1310	2019-11-05 08:29:04.581524+03
8062	61	-1	1510	2019-11-05 09:12:36.918255+03
8063	82	-1	560	2019-11-05 09:14:00.336405+03
8064	86	-1	910	2019-11-05 09:21:11.340439+03
8065	42	-1	1790	2019-11-05 10:02:03.514208+03
8066	58	-2	2830	2019-11-05 10:05:44.175772+03
8067	79	-1	550	2019-11-05 10:10:35.391294+03
8068	17	-1	1500	2019-11-05 10:11:39.281745+03
8069	70	-1	760	2019-11-05 10:24:58.483501+03
8070	93	-1	1620	2019-11-05 11:17:39.270562+03
8071	43	-1	380	2019-11-05 12:14:11.539976+03
8072	12	-1	1650	2019-11-05 12:47:07.2847+03
8073	37	-1	1290	2019-11-05 12:58:36.223939+03
8074	4	-1	1420	2019-11-05 13:17:31.716047+03
8075	63	-1	1780	2019-11-05 13:23:06.917424+03
8076	1	-1	640	2019-11-05 13:44:18.139524+03
8077	41	-1	830	2019-11-05 13:47:31.204429+03
8078	61	-1	1510	2019-11-05 13:49:07.10829+03
8079	83	-1	1230	2019-11-05 14:17:20.842822+03
8080	67	-1	350	2019-11-05 14:26:47.563076+03
8081	18	-1	910	2019-11-05 14:35:28.929469+03
8082	81	-2	1620	2019-11-05 14:38:02.156329+03
8083	63	-1	1780	2019-11-05 15:04:43.950518+03
8084	54	-2	3470	2019-11-05 15:22:06.591414+03
8085	12	-1	1650	2019-11-05 15:24:23.691657+03
8086	81	-1	1620	2019-11-05 15:25:12.246418+03
8087	68	-1	490	2019-11-05 15:35:43.629764+03
8088	41	-1	830	2019-11-05 16:04:29.646229+03
8089	49	-1	970	2019-11-05 16:12:04.254759+03
8090	13	-2	460	2019-11-05 16:12:04.919258+03
8091	20	-1	830	2019-11-05 16:14:20.864867+03
8092	8	-1	1920	2019-11-05 16:52:31.518677+03
8093	35	-1	670	2019-11-05 18:04:00.948759+03
8094	42	-2	1790	2019-11-05 18:18:13.452362+03
8095	23	-2	4390	2019-11-05 18:20:35.659919+03
8096	77	-1	640	2019-11-05 18:52:57.050223+03
8097	37	-1	1290	2019-11-05 18:53:34.656216+03
8098	83	-2	1230	2019-11-05 18:57:10.224731+03
8099	70	30	426	2019-11-05 19:37:46.83177+03
8100	79	-1	550	2019-11-05 19:47:10.718139+03
8101	84	-1	2700	2019-11-05 20:04:19.303783+03
8102	52	-1	1090	2019-11-05 20:30:55.485541+03
8103	33	-1	900	2019-11-05 20:48:25.777003+03
8104	57	-1	1900	2019-11-05 20:50:39.575915+03
8105	49	-1	970	2019-11-05 21:02:15.21958+03
8106	93	-2	1620	2019-11-05 21:33:56.890786+03
8107	6	-1	980	2019-11-05 21:51:00.852983+03
8108	21	-1	960	2019-11-05 21:57:19.695789+03
8109	14	-1	1350	2019-11-05 21:59:28.220084+03
8110	17	-1	1500	2019-11-05 22:22:27.540013+03
8111	19	-1	1220	2019-11-05 22:24:03.190441+03
8112	81	-1	1620	2019-11-05 22:28:43.418404+03
8113	49	33	492	2019-11-05 22:38:22.790079+03
8114	53	-1	3120	2019-11-05 22:45:12.488282+03
8115	82	-1	560	2019-11-05 22:50:26.945309+03
8116	26	-1	390	2019-11-05 23:28:08.187611+03
8117	56	-1	2460	2019-11-05 23:44:09.737523+03
8118	23	27	2146	2019-11-06 00:31:25.05502+03
8119	17	-1	1500	2019-11-06 00:42:30.545905+03
8120	19	-1	1220	2019-11-06 00:44:04.26+03
8121	87	-3	2320	2019-11-06 01:15:05.78182+03
8122	13	-1	460	2019-11-06 01:32:16.074269+03
8123	40	-1	1430	2019-11-06 02:11:11.27147+03
8124	94	-1	1230	2019-11-06 02:40:01.919036+03
8125	91	-1	1620	2019-11-06 02:41:26.896737+03
8126	96	-1	1570	2019-11-06 02:42:42.737634+03
8127	92	-1	630	2019-11-06 02:49:09.879873+03
8128	92	-1	630	2019-11-06 03:10:35.816136+03
8129	18	-1	910	2019-11-06 05:07:11.425374+03
8130	14	-1	1350	2019-11-06 05:18:55.41563+03
8131	28	-1	1860	2019-11-06 05:22:40.814134+03
8132	65	-1	490	2019-11-06 05:23:56.783861+03
8133	90	-1	1780	2019-11-06 05:25:07.362601+03
8134	91	-1	1620	2019-11-06 05:35:07.854251+03
8135	92	-2	630	2019-11-06 05:53:21.392707+03
8136	20	-1	830	2019-11-06 05:54:48.94625+03
8137	62	-1	1220	2019-11-06 06:32:15.402667+03
8138	31	-1	1190	2019-11-06 06:49:25.674849+03
8139	51	-1	1310	2019-11-06 07:05:13.041593+03
8140	57	-1	1900	2019-11-06 07:27:39.20902+03
8141	33	-1	900	2019-11-06 07:36:57.641035+03
8142	19	-1	1220	2019-11-06 07:55:02.057237+03
8143	17	-2	1500	2019-11-06 08:05:17.043477+03
8144	23	-1	4390	2019-11-06 08:12:12.196404+03
8145	96	-1	1570	2019-11-06 08:34:09.266381+03
8146	26	-1	390	2019-11-06 09:29:50.509897+03
8147	33	-1	900	2019-11-06 09:54:18.799522+03
8148	45	-1	1590	2019-11-06 10:24:03.997725+03
8149	54	-1	3470	2019-11-06 10:30:16.963477+03
8150	77	-1	640	2019-11-06 10:50:35.937625+03
8151	46	-1	1270	2019-11-06 11:05:57.267999+03
8152	29	-1	1940	2019-11-06 11:18:43.227927+03
8153	87	-1	2320	2019-11-06 11:23:05.387139+03
8154	58	-1	2830	2019-11-06 11:36:58.104518+03
8155	55	-1	3480	2019-11-06 11:47:03.810781+03
8156	56	-1	2460	2019-11-06 11:53:36.533772+03
8157	81	-1	1620	2019-11-06 11:58:08.630854+03
8158	37	-1	1290	2019-11-06 12:08:39.848404+03
8159	47	-1	1480	2019-11-06 12:26:02.127333+03
8160	77	-1	640	2019-11-06 12:28:52.715858+03
8161	56	-2	2460	2019-11-06 12:29:31.289847+03
8162	15	-2	2830	2019-11-06 12:46:06.444349+03
8163	85	-1	730	2019-11-06 12:56:08.878127+03
8164	77	-1	640	2019-11-06 14:03:55.345771+03
8165	96	-1	1570	2019-11-06 14:11:10.900514+03
8166	67	41	153	2019-11-06 14:29:41.545487+03
8167	5	-1	1620	2019-11-06 14:36:41.896828+03
8168	9	-1	2090	2019-11-06 15:00:50.585555+03
8169	53	-1	3120	2019-11-06 15:02:44.148129+03
8170	8	-1	1920	2019-11-06 15:22:01.094466+03
8171	55	-1	3480	2019-11-06 15:22:35.68394+03
8172	34	-2	1550	2019-11-06 15:22:44.334163+03
8173	72	-1	620	2019-11-06 16:14:07.539463+03
8174	36	-1	630	2019-11-06 16:15:15.284695+03
8175	60	-1	2700	2019-11-06 16:36:23.700544+03
8176	51	-1	1310	2019-11-06 16:36:27.006417+03
8177	34	-1	1550	2019-11-06 17:28:27.101538+03
8178	83	-1	1230	2019-11-06 17:43:40.851124+03
8179	77	-2	640	2019-11-06 17:48:50.620574+03
8180	29	-1	1940	2019-11-06 18:27:13.289393+03
8181	65	-1	490	2019-11-06 19:08:32.266369+03
8182	61	-1	1510	2019-11-06 19:12:32.166789+03
8183	17	-1	1500	2019-11-06 19:20:08.695048+03
8184	37	-1	1290	2019-11-06 19:32:27.894414+03
8185	57	-1	1900	2019-11-06 20:30:24.495841+03
8186	15	-1	2830	2019-11-06 20:45:16.493939+03
8187	90	-1	1780	2019-11-06 20:59:25.647046+03
8188	83	-1	1230	2019-11-06 21:35:00.066116+03
8189	19	-1	1220	2019-11-06 22:07:28.542067+03
8190	43	-2	380	2019-11-06 22:38:29.237525+03
8191	93	-1	1620	2019-11-06 23:02:08.695249+03
8192	51	-1	1310	2019-11-06 23:13:18.056505+03
8193	16	-2	1380	2019-11-06 23:32:58.205469+03
8194	96	-1	1570	2019-11-06 23:53:50.242812+03
8195	67	-1	350	2019-11-07 00:40:56.166822+03
8196	92	-1	630	2019-11-07 00:41:42.126888+03
8197	14	-1	1350	2019-11-07 00:46:39.963764+03
8198	63	-1	1780	2019-11-07 00:58:53.297605+03
8199	1	-1	640	2019-11-07 01:06:30.284218+03
8200	39	-1	910	2019-11-07 01:13:55.619841+03
8201	48	-1	640	2019-11-07 01:41:20.043443+03
8202	61	-1	1510	2019-11-07 01:47:33.868267+03
8203	56	-1	2460	2019-11-07 02:05:28.338415+03
8204	71	-1	1030	2019-11-07 02:17:42.841526+03
8205	52	-2	1090	2019-11-07 02:23:27.40523+03
8206	25	-1	1100	2019-11-07 02:50:42.114903+03
8207	76	-1	1070	2019-11-07 03:18:34.665775+03
8208	39	31	523	2019-11-07 03:24:31.999052+03
8209	26	-1	390	2019-11-07 03:26:55.665059+03
8210	91	-1	1620	2019-11-07 03:58:24.764467+03
8211	62	-1	1220	2019-11-07 03:59:32.291075+03
8212	1	-1	640	2019-11-07 03:59:52.227611+03
8213	57	-1	1900	2019-11-07 04:07:55.875446+03
8214	67	-1	350	2019-11-07 04:18:44.581936+03
8215	86	-2	910	2019-11-07 04:51:04.382752+03
8216	95	-1	480	2019-11-07 04:53:33.098534+03
8217	70	-1	760	2019-11-07 05:33:27.070608+03
8218	64	-1	970	2019-11-07 05:44:20.285088+03
8219	42	-1	1790	2019-11-07 05:46:44.0502+03
8220	53	-1	3120	2019-11-07 05:50:23.192298+03
8221	14	-2	1350	2019-11-07 06:11:37.567161+03
8222	32	-1	710	2019-11-07 06:22:11.712531+03
8223	66	-1	690	2019-11-07 06:52:00.990499+03
8224	10	-1	2080	2019-11-07 07:06:30.697513+03
8225	40	-2	1430	2019-11-07 07:16:56.52429+03
8226	11	-2	830	2019-11-07 07:51:03.831572+03
8227	26	-1	390	2019-11-07 07:55:39.909054+03
8228	70	-1	760	2019-11-07 08:17:56.833827+03
8229	88	-1	1270	2019-11-07 08:56:57.674599+03
8230	70	-1	760	2019-11-07 09:11:06.885749+03
8231	4	-1	1420	2019-11-07 09:35:04.336626+03
8232	29	-1	1940	2019-11-07 09:40:06.766889+03
8233	4	-1	1420	2019-11-07 09:50:05.7982+03
8234	18	-2	910	2019-11-07 09:55:22.318883+03
8235	88	-1	1270	2019-11-07 10:23:25.741218+03
8236	83	-1	1230	2019-11-07 10:38:24.360135+03
8237	56	-1	2460	2019-11-07 10:39:25.070466+03
8238	12	-1	1650	2019-11-07 10:40:47.657775+03
8239	24	-1	950	2019-11-07 11:01:08.371846+03
8240	39	-1	910	2019-11-07 11:03:40.129996+03
8241	43	-1	380	2019-11-07 11:06:30.905837+03
8242	63	-1	1780	2019-11-07 11:12:51.823503+03
8243	3	-1	660	2019-11-07 11:21:22.343583+03
8244	5	-1	1620	2019-11-07 11:23:02.285665+03
8245	61	-1	1510	2019-11-07 11:47:34.433808+03
8246	30	-1	1140	2019-11-07 11:47:35.436429+03
8247	95	-2	480	2019-11-07 12:03:06.786685+03
8248	64	-1	970	2019-11-07 12:21:09.710527+03
8249	68	-1	490	2019-11-07 12:24:03.233687+03
8250	51	-1	1310	2019-11-07 12:36:53.906376+03
8251	40	-1	1430	2019-11-07 12:49:15.057063+03
8252	74	-1	1010	2019-11-07 13:03:04.623323+03
8253	15	-1	2830	2019-11-07 13:06:11.277707+03
8254	53	-1	3120	2019-11-07 13:09:00.321223+03
8255	40	-1	1430	2019-11-07 13:18:00.65107+03
8256	65	-1	490	2019-11-07 13:25:38.689984+03
8257	80	-1	1120	2019-11-07 13:27:35.821155+03
8258	4	-1	1420	2019-11-07 13:36:23.17437+03
8259	75	-1	830	2019-11-07 13:44:52.989968+03
8260	34	-1	1550	2019-11-07 13:55:14.160547+03
8261	18	-2	910	2019-11-07 13:58:08.697816+03
8262	46	-1	1270	2019-11-07 14:40:37.242495+03
8263	93	-1	1620	2019-11-07 14:46:47.974613+03
8264	83	-2	1230	2019-11-07 15:21:30.896319+03
8265	42	-2	1790	2019-11-07 15:35:36.001271+03
8266	29	-1	1940	2019-11-07 15:40:19.938141+03
8267	12	-1	1650	2019-11-07 15:50:21.323909+03
8268	85	-1	730	2019-11-07 16:03:17.017502+03
8269	17	-1	1500	2019-11-07 16:04:59.650239+03
8270	25	-1	1100	2019-11-07 16:27:00.281174+03
8271	34	-1	1550	2019-11-07 16:58:51.854326+03
8272	7	-1	810	2019-11-07 17:08:00.22261+03
8273	5	-2	1620	2019-11-07 17:20:01.245273+03
8274	45	-1	1590	2019-11-07 17:38:59.083756+03
8275	91	-1	1620	2019-11-07 17:44:25.122857+03
8276	57	-1	1900	2019-11-07 18:06:59.808034+03
8277	58	-2	2830	2019-11-07 18:42:30.940401+03
8278	1	-1	640	2019-11-07 18:56:37.284613+03
8279	86	-1	910	2019-11-07 19:05:40.089535+03
8280	95	-1	480	2019-11-07 19:07:26.475743+03
8281	34	-3	1550	2019-11-07 19:07:42.015+03
8282	5	-1	1620	2019-11-07 19:17:46.112276+03
8283	25	-1	1100	2019-11-07 19:40:17.011461+03
8284	12	-1	1650	2019-11-07 19:48:27.272701+03
8285	11	-1	830	2019-11-07 20:07:40.978479+03
8286	81	-1	1620	2019-11-07 20:29:31.600745+03
8287	47	-3	1480	2019-11-07 20:30:28.518303+03
8288	24	-2	950	2019-11-07 20:42:47.805928+03
8289	8	-1	1920	2019-11-07 21:15:10.959253+03
8290	21	-1	960	2019-11-07 21:33:55.57795+03
8291	61	-1	1510	2019-11-07 22:17:04.859612+03
8292	1	-1	640	2019-11-07 22:41:43.822607+03
8293	39	-1	910	2019-11-07 22:43:17.673586+03
8294	53	-1	3120	2019-11-07 23:05:45.140343+03
8295	69	-1	1100	2019-11-07 23:14:50.351307+03
8296	7	-1	810	2019-11-07 23:22:43.125174+03
8297	91	-1	1620	2019-11-07 23:29:14.840433+03
8298	95	-1	480	2019-11-07 23:46:56.603694+03
8299	81	-1	1620	2019-11-07 23:56:13.94159+03
8300	56	-1	2460	2019-11-08 00:04:58.383099+03
8301	68	-1	490	2019-11-08 00:17:20.371303+03
8302	82	-1	560	2019-11-08 00:19:08.556408+03
8303	47	-1	1480	2019-11-08 00:37:40.559832+03
8304	44	-1	500	2019-11-08 00:39:57.449667+03
8305	28	-1	1860	2019-11-08 00:41:51.433817+03
8306	35	-1	670	2019-11-08 00:52:18.965909+03
8307	83	-1	1230	2019-11-08 01:21:11.511923+03
8308	20	-1	830	2019-11-08 01:38:59.445437+03
8309	87	-1	2320	2019-11-08 01:48:20.932561+03
8310	21	-2	960	2019-11-08 02:08:01.763232+03
8311	16	-1	1380	2019-11-08 02:12:39.110861+03
8312	8	-1	1920	2019-11-08 02:51:12.964022+03
8313	44	22	283	2019-11-08 03:00:52.527593+03
8314	13	-1	460	2019-11-08 03:06:35.391293+03
8315	74	-2	1010	2019-11-08 04:58:28.545257+03
8316	45	-1	1590	2019-11-08 05:25:14.634823+03
8317	70	-1	760	2019-11-08 05:27:46.141747+03
8318	7	-1	810	2019-11-08 06:03:55.675655+03
8319	34	-1	1550	2019-11-08 06:05:00.686039+03
8320	10	-1	2080	2019-11-08 06:07:14.054896+03
8321	80	-1	1120	2019-11-08 06:24:24.617807+03
8322	36	-1	630	2019-11-08 07:20:25.161882+03
8323	34	-1	1550	2019-11-08 07:30:14.965264+03
8324	95	-1	480	2019-11-08 07:40:44.437957+03
8325	60	-2	2700	2019-11-08 07:57:49.284372+03
8326	80	-2	1120	2019-11-08 08:08:05.984567+03
8327	74	23	495	2019-11-08 08:10:50.896126+03
8328	26	-1	390	2019-11-08 08:44:16.75699+03
8329	17	-1	1500	2019-11-08 08:46:27.031984+03
8330	33	-1	900	2019-11-08 08:54:05.397922+03
8331	29	-1	1940	2019-11-08 09:11:50.103609+03
8332	10	-2	2080	2019-11-08 09:26:08.494479+03
8333	77	-2	640	2019-11-08 09:44:13.256208+03
8334	12	-1	1650	2019-11-08 10:10:10.532976+03
8335	56	-1	2460	2019-11-08 10:12:17.566752+03
8336	51	-1	1310	2019-11-08 10:22:45.296237+03
8337	13	-2	460	2019-11-08 10:57:13.851198+03
8338	71	-1	1030	2019-11-08 11:10:09.142946+03
8339	83	-1	1230	2019-11-08 11:14:55.746932+03
8340	90	-1	1780	2019-11-08 11:42:20.752398+03
8341	4	-1	1420	2019-11-08 11:45:21.093841+03
8342	26	-2	390	2019-11-08 12:07:53.734928+03
8343	44	-1	500	2019-11-08 12:24:47.878452+03
8344	87	-1	2320	2019-11-08 12:42:18.763209+03
8345	77	-1	640	2019-11-08 12:51:26.917556+03
8346	81	-1	1620	2019-11-08 13:01:35.960216+03
8347	82	-1	560	2019-11-08 13:06:28.162826+03
8348	61	-2	1510	2019-11-08 13:13:52.148445+03
8349	13	-1	460	2019-11-08 14:01:34.554008+03
8350	1	-2	640	2019-11-08 14:20:58.584718+03
8351	86	-1	910	2019-11-08 14:24:30.662811+03
8352	4	-2	1420	2019-11-08 14:24:50.040687+03
8353	77	-1	640	2019-11-08 14:26:17.320113+03
8354	22	-1	1070	2019-11-08 14:34:52.546815+03
8355	4	43	725	2019-11-08 14:48:09.956445+03
8356	82	-1	560	2019-11-08 14:57:36.356581+03
8357	14	-1	1350	2019-11-08 15:18:41.971937+03
8358	67	-1	350	2019-11-08 15:39:52.862504+03
8359	96	-1	1570	2019-11-08 16:41:34.221528+03
8360	88	-1	1270	2019-11-08 16:54:09.575189+03
8361	75	-2	830	2019-11-08 16:58:21.139781+03
8362	60	-1	2700	2019-11-08 17:02:22.240434+03
8363	24	-1	950	2019-11-08 17:03:50.021081+03
8364	88	-1	1270	2019-11-08 17:09:47.0682+03
8365	2	-1	470	2019-11-08 17:30:21.864377+03
8366	31	-1	1190	2019-11-08 17:45:57.81806+03
8367	64	-2	970	2019-11-08 17:47:48.146413+03
8368	93	-2	1620	2019-11-08 18:29:33.973656+03
8369	86	-1	910	2019-11-08 18:31:50.965969+03
8370	89	-1	1420	2019-11-08 18:32:34.543313+03
8371	75	-2	830	2019-11-08 18:35:12.147984+03
8372	51	-1	1310	2019-11-08 18:51:11.204214+03
8373	81	-1	1620	2019-11-08 18:55:42.578717+03
8374	44	-1	500	2019-11-08 19:12:51.860553+03
8375	47	-2	1480	2019-11-08 19:53:24.639012+03
8376	51	-1	1310	2019-11-08 19:54:09.215402+03
8377	54	-1	3470	2019-11-08 20:15:50.751617+03
8378	76	-1	1070	2019-11-08 20:17:34.584026+03
8379	89	-1	1420	2019-11-08 20:28:14.595645+03
8380	42	-1	1790	2019-11-08 20:28:22.769074+03
8381	23	-2	4390	2019-11-08 20:35:37.3524+03
8382	19	-1	1220	2019-11-08 20:39:40.101484+03
8383	35	-2	670	2019-11-08 20:43:15.798039+03
8384	32	-1	710	2019-11-08 21:16:19.211622+03
8385	67	-1	350	2019-11-08 21:22:52.154537+03
8386	28	-2	1860	2019-11-08 21:23:50.826038+03
8387	28	-1	1860	2019-11-08 21:36:02.086617+03
8388	22	-1	1070	2019-11-08 21:45:19.462184+03
8389	33	-1	900	2019-11-08 22:40:59.528013+03
8390	88	35	523	2019-11-08 22:43:04.381328+03
8391	79	-1	550	2019-11-08 22:54:20.454537+03
8392	49	-1	970	2019-11-08 23:10:09.409371+03
8393	8	-2	1920	2019-11-08 23:14:40.513423+03
8394	19	-1	1220	2019-11-08 23:41:45.237467+03
8395	24	-1	950	2019-11-08 23:48:18.505634+03
8396	70	-1	760	2019-11-09 00:12:43.746237+03
8397	32	-2	710	2019-11-09 00:55:04.905424+03
8398	28	-1	1860	2019-11-09 01:00:41.239917+03
8399	18	-1	910	2019-11-09 01:09:17.685566+03
8400	29	-2	1940	2019-11-09 01:12:39.10175+03
8401	68	-1	490	2019-11-09 02:00:20.182248+03
8402	52	-1	1090	2019-11-09 02:12:25.55929+03
8403	42	-1	1790	2019-11-09 02:23:45.444358+03
8404	46	-1	1270	2019-11-09 02:32:37.24128+03
8405	54	-1	3470	2019-11-09 02:38:08.233522+03
8406	70	-1	760	2019-11-09 02:52:58.448817+03
8407	39	-2	910	2019-11-09 03:20:02.118318+03
8408	49	-1	970	2019-11-09 03:33:44.059616+03
8409	21	-1	960	2019-11-09 04:04:29.982519+03
8410	38	-1	1100	2019-11-09 04:05:18.368222+03
8411	84	-1	2700	2019-11-09 04:40:49.9695+03
8412	14	-1	1350	2019-11-09 05:25:40.739198+03
8413	84	-1	2700	2019-11-09 05:29:40.677311+03
8414	9	-1	2090	2019-11-09 06:12:40.643769+03
8415	22	-1	1070	2019-11-09 06:22:28.673636+03
8416	80	-3	1120	2019-11-09 06:28:50.002697+03
8417	96	-1	1570	2019-11-09 06:58:03.895456+03
8418	9	-2	2090	2019-11-09 06:58:56.980001+03
8419	26	-1	390	2019-11-09 07:11:27.248126+03
8420	43	-1	380	2019-11-09 08:07:17.793819+03
8421	40	-1	1430	2019-11-09 08:12:27.821932+03
8422	71	-2	1030	2019-11-09 08:26:17.471351+03
8423	32	-1	710	2019-11-09 08:29:14.348237+03
8424	27	-2	880	2019-11-09 08:33:35.929559+03
8425	40	-1	1430	2019-11-09 08:57:09.752499+03
8426	96	-2	1570	2019-11-09 09:13:41.210409+03
8427	58	-1	2830	2019-11-09 09:23:08.34346+03
8428	63	-1	1780	2019-11-09 09:27:37.970339+03
8429	52	-1	1090	2019-11-09 10:14:50.886907+03
8430	87	-1	2320	2019-11-09 10:22:53.514262+03
8431	85	-1	730	2019-11-09 10:25:14.008314+03
8432	12	-2	1650	2019-11-09 10:32:11.915229+03
8433	79	-1	550	2019-11-09 10:35:24.88118+03
8434	12	-1	1650	2019-11-09 10:53:10.62905+03
8435	74	-1	1010	2019-11-09 11:05:29.068632+03
8436	68	-1	490	2019-11-09 11:11:43.77229+03
8437	54	-1	3470	2019-11-09 11:16:01.402548+03
8438	58	-1	2830	2019-11-09 11:21:01.285541+03
8439	33	-1	900	2019-11-09 11:30:02.742297+03
8440	32	-1	710	2019-11-09 11:34:38.5121+03
8441	68	-2	490	2019-11-09 12:02:29.910805+03
8442	77	-1	640	2019-11-09 12:10:30.415708+03
8443	40	-1	1430	2019-11-09 12:40:40.953555+03
8444	62	-1	1220	2019-11-09 13:01:05.354084+03
8445	36	-1	630	2019-11-09 13:16:26.137411+03
8446	23	-2	4390	2019-11-09 13:24:02.757752+03
8447	42	-1	1790	2019-11-09 13:33:08.716825+03
8448	96	-1	1570	2019-11-09 13:41:25.790977+03
8449	55	-1	3480	2019-11-09 14:02:28.865998+03
8450	36	-2	630	2019-11-09 14:35:57.911145+03
8451	28	-1	1860	2019-11-09 14:38:38.37153+03
8452	92	-1	630	2019-11-09 15:10:15.138911+03
8453	74	-1	1010	2019-11-09 15:38:58.733131+03
8454	79	21	235	2019-11-09 15:44:47.947048+03
8455	75	-3	830	2019-11-09 16:04:26.249+03
8456	34	-1	1550	2019-11-09 16:09:27.033332+03
8457	35	-1	670	2019-11-09 16:16:22.810058+03
8458	1	-2	640	2019-11-09 16:18:27.568325+03
8459	70	-1	760	2019-11-09 16:36:02.467086+03
8460	49	-1	970	2019-11-09 16:56:35.839479+03
8461	55	-1	3480	2019-11-09 16:59:15.029399+03
8462	6	-1	980	2019-11-09 17:04:52.670049+03
8463	44	-1	500	2019-11-09 17:05:38.432973+03
8464	84	-2	2700	2019-11-09 17:12:51.907637+03
8465	3	-1	660	2019-11-09 17:13:53.712072+03
8466	22	39	501	2019-11-09 17:18:22.61243+03
8467	84	-1	2700	2019-11-09 17:23:58.149368+03
8468	14	-1	1350	2019-11-09 17:49:49.009321+03
8469	83	-2	1230	2019-11-09 18:05:22.571899+03
8470	20	-1	830	2019-11-09 18:13:31.351759+03
8471	74	-1	1010	2019-11-09 18:45:00.852895+03
8472	28	-1	1860	2019-11-09 18:52:25.884907+03
8473	60	28	1494	2019-11-09 19:07:06.03223+03
8474	20	-1	830	2019-11-09 19:13:44.326653+03
8475	63	-2	1780	2019-11-09 19:25:41.936531+03
8476	87	-1	2320	2019-11-09 19:44:23.552357+03
8477	58	-1	2830	2019-11-09 20:06:38.718518+03
8478	8	-2	1920	2019-11-09 20:08:24.892014+03
8479	33	-1	900	2019-11-09 20:12:24.479123+03
8480	4	-1	1420	2019-11-09 20:15:22.230485+03
8481	39	-1	910	2019-11-09 20:15:41.243786+03
8482	58	-1	2830	2019-11-09 20:27:44.960595+03
8483	52	27	595	2019-11-09 20:54:38.031963+03
8484	13	-1	460	2019-11-09 21:01:33.868796+03
8485	58	-2	2830	2019-11-09 21:36:26.514955+03
8486	74	-2	1010	2019-11-09 21:51:02.770847+03
8487	50	-1	1140	2019-11-09 21:54:33.019919+03
8488	18	-1	910	2019-11-09 21:56:04.186382+03
8489	12	-1	1650	2019-11-09 22:55:42.348281+03
8490	96	-1	1570	2019-11-09 23:20:42.10564+03
8491	71	45	519	2019-11-09 23:27:17.121404+03
8492	6	-2	980	2019-11-09 23:27:27.874364+03
8493	82	-1	560	2019-11-09 23:33:52.533304+03
8494	15	-1	2830	2019-11-09 23:43:20.98647+03
8495	63	-1	1780	2019-11-09 23:57:50.491555+03
8496	35	-2	670	2019-11-10 00:03:50.387687+03
8497	28	-1	1860	2019-11-10 00:05:04.313291+03
8498	15	-2	2830	2019-11-10 00:13:35.021401+03
8499	3	-1	660	2019-11-10 00:24:05.129149+03
8500	5	-2	1620	2019-11-10 01:17:29.198647+03
8501	83	-1	1230	2019-11-10 01:37:58.529835+03
8502	6	-1	980	2019-11-10 01:42:06.435932+03
8503	69	-2	1100	2019-11-10 01:43:59.474378+03
8504	45	-1	1590	2019-11-10 02:36:14.851881+03
8505	22	-1	1070	2019-11-10 02:39:07.89266+03
8506	64	-1	970	2019-11-10 02:50:43.989506+03
8507	12	-1	1650	2019-11-10 03:04:49.514776+03
8508	9	-1	2090	2019-11-10 03:36:17.659877+03
8509	40	-1	1430	2019-11-10 04:01:01.681375+03
8510	62	19	511	2019-11-10 04:11:51.613437+03
8511	32	-1	710	2019-11-10 04:48:59.510295+03
8512	18	-1	910	2019-11-10 05:25:06.594749+03
8513	52	-1	1090	2019-11-10 05:33:41.249286+03
8514	51	-1	1310	2019-11-10 05:35:25.366983+03
8515	18	-1	910	2019-11-10 05:36:18.934587+03
8516	43	-1	380	2019-11-10 05:54:16.17951+03
8517	24	-1	950	2019-11-10 05:55:29.432189+03
8518	90	-1	1780	2019-11-10 07:25:50.490551+03
8519	31	-1	1190	2019-11-10 07:31:22.229608+03
8520	82	-1	560	2019-11-10 07:33:57.386267+03
8521	96	-2	1570	2019-11-10 07:38:54.977872+03
8522	49	-1	970	2019-11-10 07:42:54.96891+03
8523	27	-1	880	2019-11-10 07:44:58.091361+03
8524	37	-2	1290	2019-11-10 08:02:20.372955+03
8525	81	-1	1620	2019-11-10 08:04:34.362839+03
8526	96	32	700	2019-11-10 08:48:08.361109+03
8527	78	-1	900	2019-11-10 09:15:59.196837+03
8528	76	-1	1070	2019-11-10 09:27:30.596236+03
8529	4	-2	1420	2019-11-10 09:40:33.896673+03
8530	40	-1	1430	2019-11-10 09:42:25.629765+03
8531	8	-1	1920	2019-11-10 09:49:11.589442+03
8532	49	-1	970	2019-11-10 09:52:57.53936+03
8533	78	-1	900	2019-11-10 10:06:26.065503+03
8534	3	-1	660	2019-11-10 10:39:45.415533+03
8535	88	-1	1270	2019-11-10 11:11:21.21783+03
8536	19	-1	1220	2019-11-10 11:14:19.345466+03
8537	12	-2	1650	2019-11-10 11:25:24.121775+03
8538	54	-1	3470	2019-11-10 11:29:57.003802+03
8539	85	-2	730	2019-11-10 11:37:03.33502+03
8540	6	40	575	2019-11-10 11:39:20.788444+03
8541	60	-2	2700	2019-11-10 11:44:33.631642+03
8542	46	-1	1270	2019-11-10 11:46:22.02679+03
8543	23	-1	4390	2019-11-10 11:51:19.775285+03
8544	60	-1	2700	2019-11-10 11:54:32.83647+03
8545	52	-1	1090	2019-11-10 12:32:26.280977+03
8546	88	-1	1270	2019-11-10 13:05:27.16538+03
8547	12	-1	1650	2019-11-10 13:23:40.457344+03
8548	72	13	262	2019-11-10 13:32:42.572989+03
8549	4	-1	1420	2019-11-10 13:50:52.952886+03
8550	88	-1	1270	2019-11-10 14:35:18.005945+03
8551	12	-1	1650	2019-11-10 14:35:58.901248+03
8552	39	-2	910	2019-11-10 14:41:26.396384+03
8553	40	-3	1430	2019-11-10 14:45:14.640045+03
8554	3	-2	660	2019-11-10 15:23:53.007325+03
8555	17	-1	1500	2019-11-10 15:31:08.977349+03
8556	32	-1	710	2019-11-10 16:08:33.998824+03
8557	2	-1	470	2019-11-10 16:13:12.584259+03
8558	38	-2	1100	2019-11-10 16:34:54.799475+03
8559	31	-1	1190	2019-11-10 16:36:38.338674+03
8560	68	-1	490	2019-11-10 16:41:27.428979+03
8561	70	-1	760	2019-11-10 16:47:52.556317+03
8562	83	-1	1230	2019-11-10 17:09:50.476195+03
8563	80	-1	1120	2019-11-10 17:23:14.921562+03
8564	17	-1	1500	2019-11-10 17:31:56.854828+03
8565	7	-1	810	2019-11-10 17:43:16.863547+03
8566	10	-1	2080	2019-11-10 17:44:06.454799+03
8567	9	-3	2090	2019-11-10 17:44:11.859044+03
8568	68	-1	490	2019-11-10 17:46:29.347808+03
8569	93	19	845	2019-11-10 17:49:05.512644+03
8570	18	-1	910	2019-11-10 17:52:00.910366+03
8571	47	-2	1480	2019-11-10 19:05:47.653033+03
8572	38	-2	1100	2019-11-10 19:16:02.800572+03
8573	30	-1	1140	2019-11-10 19:25:12.699243+03
8574	10	-1	2080	2019-11-10 19:30:38.994327+03
8575	96	-2	1570	2019-11-10 19:33:05.133014+03
8576	96	-1	1570	2019-11-10 19:58:31.48704+03
8577	96	-1	1570	2019-11-10 20:01:42.281828+03
8578	48	-2	640	2019-11-10 20:16:47.775784+03
8579	70	-1	760	2019-11-10 20:47:08.286778+03
8580	72	-1	620	2019-11-10 21:18:43.957365+03
8581	34	-1	1550	2019-11-10 21:47:41.871692+03
8582	47	-1	1480	2019-11-10 22:00:09.19869+03
8583	67	-1	350	2019-11-10 22:12:20.457297+03
8584	81	-1	1620	2019-11-10 22:12:46.375476+03
8585	83	-1	1230	2019-11-10 22:16:09.240343+03
8586	11	-1	830	2019-11-10 22:18:54.155692+03
8587	78	-1	900	2019-11-10 22:27:14.824394+03
8588	83	-1	1230	2019-11-10 22:31:20.929892+03
8589	62	-1	1220	2019-11-10 22:39:13.152655+03
8590	56	-1	2460	2019-11-10 22:51:37.707487+03
8591	31	-1	1190	2019-11-10 22:55:44.529593+03
8592	80	-1	1120	2019-11-10 23:04:25.170651+03
8593	8	-1	1920	2019-11-10 23:45:58.678802+03
8594	61	-2	1510	2019-11-10 23:48:39.082165+03
8595	47	-1	1480	2019-11-10 23:51:41.920632+03
8596	48	-1	640	2019-11-10 23:59:50.756596+03
8597	27	-1	880	2019-11-11 00:23:54.156598+03
8598	75	-1	830	2019-11-11 00:38:05.180864+03
8599	71	-1	1030	2019-11-11 00:38:39.406058+03
8600	59	-2	1030	2019-11-11 00:42:34.639925+03
8601	55	-1	3480	2019-11-11 01:01:10.442099+03
8602	96	-2	1570	2019-11-11 01:20:28.070018+03
8603	51	-2	1310	2019-11-11 01:22:28.202483+03
8604	54	-1	3470	2019-11-11 01:40:45.911288+03
8605	6	-1	980	2019-11-11 01:42:58.264287+03
8606	19	-1	1220	2019-11-11 02:29:07.041164+03
8607	61	-1	1510	2019-11-11 02:39:47.557343+03
8608	21	-2	960	2019-11-11 02:57:21.069719+03
8609	20	-1	830	2019-11-11 03:22:19.849545+03
8610	36	-1	630	2019-11-11 03:27:09.733249+03
8611	14	-1	1350	2019-11-11 03:37:00.412348+03
8612	72	-2	620	2019-11-11 03:40:40.485227+03
8613	75	-1	830	2019-11-11 03:51:18.889321+03
8614	73	-2	960	2019-11-11 03:55:36.439203+03
8615	96	-1	1570	2019-11-11 04:22:19.587822+03
8616	56	-1	2460	2019-11-11 04:38:38.020986+03
8617	60	-1	2700	2019-11-11 04:52:55.26318+03
8618	64	-1	970	2019-11-11 05:00:15.739291+03
8619	64	-1	970	2019-11-11 05:09:34.507096+03
8620	42	-1	1790	2019-11-11 05:11:07.723054+03
8621	69	-1	1100	2019-11-11 05:11:46.310619+03
8622	84	-2	2700	2019-11-11 05:11:51.955222+03
8623	60	-1	2700	2019-11-11 05:24:01.082379+03
8624	46	-1	1270	2019-11-11 05:34:31.217812+03
8625	89	-1	1420	2019-11-11 05:36:14.264714+03
8626	48	-1	640	2019-11-11 05:36:36.483987+03
8627	3	-1	660	2019-11-11 05:39:34.913711+03
8628	78	-1	900	2019-11-11 06:07:01.501396+03
8629	90	-1	1780	2019-11-11 06:45:22.834828+03
8630	10	-1	2080	2019-11-11 06:55:39.578789+03
8631	21	-1	960	2019-11-11 06:57:41.145771+03
8632	5	-1	1620	2019-11-11 06:58:48.61428+03
8633	4	-1	1420	2019-11-11 07:03:45.564303+03
8634	4	-1	1420	2019-11-11 07:19:54.488456+03
8635	81	-2	1620	2019-11-11 07:30:13.232616+03
8636	83	-1	1230	2019-11-11 07:33:34.474647+03
8637	6	-1	980	2019-11-11 08:08:23.842376+03
8638	59	-1	1030	2019-11-11 08:12:35.105614+03
8639	48	29	353	2019-11-11 08:35:00.291644+03
8640	95	-2	480	2019-11-11 08:35:37.385496+03
8641	39	-1	910	2019-11-11 09:01:05.690275+03
8642	77	-1	640	2019-11-11 09:07:30.325013+03
8643	75	-1	830	2019-11-11 09:08:38.979667+03
8644	58	-2	2830	2019-11-11 09:27:18.409698+03
8645	48	-1	640	2019-11-11 09:37:12.112959+03
8646	85	-1	730	2019-11-11 09:42:01.091528+03
8647	63	-1	1780	2019-11-11 09:52:38.514718+03
8648	41	-1	830	2019-11-11 10:02:22.188478+03
8649	82	-2	560	2019-11-11 11:03:22.629291+03
8650	36	-1	630	2019-11-11 11:21:03.495526+03
8651	38	-2	1100	2019-11-11 11:24:46.099916+03
8652	90	-1	1780	2019-11-11 11:29:32.074773+03
8653	22	-1	1070	2019-11-11 11:55:04.168547+03
8654	82	-1	560	2019-11-11 12:43:49.801502+03
8655	6	-1	980	2019-11-11 12:54:42.056126+03
8656	61	25	621	2019-11-11 13:01:00.964656+03
8657	62	-2	1220	2019-11-11 13:10:01.788821+03
8658	82	-1	560	2019-11-11 13:47:47.391614+03
8659	52	-2	1090	2019-11-11 14:07:47.639962+03
8660	22	-1	1070	2019-11-11 14:36:32.542731+03
8661	26	-2	390	2019-11-11 14:38:09.273107+03
8662	91	-1	1620	2019-11-11 14:43:28.953578+03
8663	70	-1	760	2019-11-11 14:57:03.045705+03
8664	60	-1	2700	2019-11-11 15:18:42.424893+03
8665	88	-1	1270	2019-11-11 15:29:32.788057+03
8666	53	-2	3120	2019-11-11 15:46:34.046497+03
8667	40	-1	1430	2019-11-11 15:50:43.399577+03
8668	65	-1	490	2019-11-11 16:11:03.13529+03
8669	81	-1	1620	2019-11-11 16:21:53.664593+03
8670	59	-1	1030	2019-11-11 16:27:42.295923+03
8671	11	-1	830	2019-11-11 16:33:50.320567+03
8672	7	-1	810	2019-11-11 16:43:11.388405+03
8673	63	-1	1780	2019-11-11 17:22:07.395164+03
8674	10	30	999	2019-11-11 17:25:04.40137+03
8675	21	-1	960	2019-11-11 17:49:38.074261+03
8676	21	-1	960	2019-11-11 18:04:38.344689+03
8677	4	-2	1420	2019-11-11 18:25:25.987991+03
8678	64	-1	970	2019-11-11 18:43:29.880233+03
8679	47	-2	1480	2019-11-11 18:53:55.317218+03
8680	40	-2	1430	2019-11-11 18:54:34.126432+03
8681	27	-1	880	2019-11-11 19:15:58.247455+03
8682	23	-1	4390	2019-11-11 19:35:25.515453+03
8683	17	-1	1500	2019-11-11 19:36:14.260326+03
8684	56	-1	2460	2019-11-11 19:41:53.519819+03
8685	49	-1	970	2019-11-11 20:05:51.798047+03
8686	70	-1	760	2019-11-11 20:12:53.066913+03
8687	87	-1	2320	2019-11-11 20:17:07.66464+03
8688	33	-1	900	2019-11-11 20:23:10.000173+03
8689	42	-1	1790	2019-11-11 20:27:51.456404+03
8690	92	-1	630	2019-11-11 20:30:13.264816+03
8691	7	-1	810	2019-11-11 20:44:22.447264+03
8692	96	-3	1570	2019-11-11 21:00:51.448626+03
8693	45	-1	1590	2019-11-11 21:08:06.233979+03
8694	61	-1	1510	2019-11-11 21:16:35.912622+03
8695	10	-1	2080	2019-11-11 22:03:31.262453+03
8696	76	-2	1070	2019-11-11 22:03:32.375849+03
8697	20	-1	830	2019-11-11 22:28:59.058885+03
8698	30	-1	1140	2019-11-11 22:37:59.604849+03
8699	67	-1	350	2019-11-11 22:48:03.012581+03
8700	76	-1	1070	2019-11-11 22:53:07.489436+03
8701	22	-2	1070	2019-11-11 22:58:58.502104+03
8702	5	-1	1620	2019-11-11 23:05:27.338141+03
8703	80	-1	1120	2019-11-11 23:07:01.409103+03
8704	95	-1	480	2019-11-11 23:35:48.594979+03
8705	17	-1	1500	2019-11-11 23:47:07.469686+03
8706	20	-1	830	2019-11-12 00:16:35.993156+03
8707	33	-1	900	2019-11-12 00:25:43.241597+03
8708	84	-1	2700	2019-11-12 00:37:14.883836+03
8709	64	-1	970	2019-11-12 00:53:54.801608+03
8710	34	-1	1550	2019-11-12 01:11:43.031427+03
8711	43	-1	380	2019-11-12 01:18:23.72184+03
8712	35	-1	670	2019-11-12 01:29:29.750261+03
8713	12	-1	1650	2019-11-12 01:40:27.840978+03
8714	86	-1	910	2019-11-12 01:56:22.069769+03
8715	27	-2	880	2019-11-12 01:56:23.260133+03
8716	91	-1	1620	2019-11-12 02:01:33.871449+03
8717	46	-1	1270	2019-11-12 02:08:43.376265+03
8718	28	-1	1860	2019-11-12 02:44:58.058887+03
8719	6	-1	980	2019-11-12 02:48:03.142559+03
8720	90	20	977	2019-11-12 02:58:03.71683+03
8721	19	-1	1220	2019-11-12 03:03:21.718274+03
8722	89	-1	1420	2019-11-12 03:05:53.614094+03
8723	65	21	259	2019-11-12 03:11:32.467621+03
8724	48	-1	640	2019-11-12 03:13:19.154017+03
8725	8	-1	1920	2019-11-12 03:16:06.638209+03
8726	41	-1	830	2019-11-12 03:34:36.83062+03
8727	4	-2	1420	2019-11-12 03:38:59.444783+03
8728	20	-1	830	2019-11-12 03:49:35.306913+03
8729	44	-1	500	2019-11-12 03:52:37.807542+03
8730	57	-1	1900	2019-11-12 06:03:19.047374+03
8731	34	-1	1550	2019-11-12 06:07:06.016032+03
8732	38	-1	1100	2019-11-12 07:13:52.834625+03
8733	8	34	1050	2019-11-12 07:29:10.25993+03
8734	49	-2	970	2019-11-12 07:33:45.269697+03
8735	90	-2	1780	2019-11-12 07:38:43.400185+03
8736	71	-1	1030	2019-11-12 07:44:15.489251+03
8737	92	-1	630	2019-11-12 08:00:57.530315+03
8738	8	-2	1920	2019-11-12 08:01:56.336443+03
8739	10	-1	2080	2019-11-12 08:13:43.157737+03
8740	33	-1	900	2019-11-12 08:33:30.843365+03
8741	45	-1	1590	2019-11-12 08:41:50.484286+03
8742	16	-2	1380	2019-11-12 08:42:24.196049+03
8743	75	30	431	2019-11-12 08:54:15.839843+03
8744	96	-1	1570	2019-11-12 09:22:20.48501+03
8745	54	-1	3470	2019-11-12 09:28:31.282777+03
8746	86	-1	910	2019-11-12 10:23:57.905168+03
8747	28	-2	1860	2019-11-12 10:33:35.555749+03
8748	71	-1	1030	2019-11-12 10:35:23.313887+03
8749	94	-1	1230	2019-11-12 10:49:07.448439+03
8750	66	-2	690	2019-11-12 11:15:43.080486+03
8751	22	-1	1070	2019-11-12 11:38:16.919456+03
8752	87	-1	2320	2019-11-12 11:41:57.092248+03
8753	49	-2	970	2019-11-12 12:25:47.525203+03
8754	77	-2	640	2019-11-12 12:33:52.624238+03
8755	68	-2	490	2019-11-12 12:51:01.106166+03
8756	21	-1	960	2019-11-12 13:31:09.519941+03
8757	37	-1	1290	2019-11-12 13:54:49.82154+03
8758	13	28	194	2019-11-12 14:04:34.737226+03
8759	1	-1	640	2019-11-12 14:09:09.197805+03
8760	95	-1	480	2019-11-12 14:25:57.788188+03
8761	96	-2	1570	2019-11-12 14:36:56.070555+03
8762	96	-1	1570	2019-11-12 14:49:50.123568+03
8763	70	-1	760	2019-11-12 14:51:45.482744+03
8764	71	-1	1030	2019-11-12 15:04:37.212148+03
8765	37	-1	1290	2019-11-12 15:08:52.765344+03
8766	12	-1	1650	2019-11-12 15:48:09.433525+03
8767	23	-1	4390	2019-11-12 16:05:55.372981+03
8768	29	-1	1940	2019-11-12 16:12:30.018051+03
8769	72	-1	620	2019-11-12 16:36:29.439303+03
8770	70	-1	760	2019-11-12 16:54:38.711848+03
8771	89	38	720	2019-11-12 17:06:31.961241+03
8772	71	-1	1030	2019-11-12 17:16:24.15036+03
8773	94	-1	1230	2019-11-12 17:23:58.045491+03
8774	60	-2	2700	2019-11-12 17:27:28.77143+03
8775	90	-1	1780	2019-11-12 18:31:09.74963+03
8776	63	-1	1780	2019-11-12 18:33:05.438364+03
8777	22	-1	1070	2019-11-12 18:54:15.053088+03
8778	52	-1	1090	2019-11-12 19:06:28.349326+03
8779	38	-1	1100	2019-11-12 20:38:59.971287+03
8780	9	-1	2090	2019-11-12 20:42:46.702673+03
8781	13	-1	460	2019-11-12 21:10:24.671733+03
8782	95	-1	480	2019-11-12 21:21:08.949818+03
8783	19	-1	1220	2019-11-12 21:24:59.768753+03
8784	4	-1	1420	2019-11-12 21:28:01.428004+03
8785	26	-2	390	2019-11-12 21:29:41.65697+03
8786	46	-1	1270	2019-11-12 21:53:59.066656+03
8787	77	-1	640	2019-11-12 22:02:51.799304+03
8788	1	-2	640	2019-11-12 22:40:06.724082+03
8789	86	-1	910	2019-11-12 22:44:12.002272+03
8790	96	-1	1570	2019-11-12 22:45:15.686949+03
8791	89	-1	1420	2019-11-12 22:49:48.48618+03
8792	70	-1	760	2019-11-13 00:13:56.590582+03
8793	83	-1	1230	2019-11-13 00:31:56.984852+03
8794	7	-1	810	2019-11-13 00:54:02.935094+03
8795	95	-2	480	2019-11-13 01:17:54.438714+03
8796	29	-2	1940	2019-11-13 01:26:59.200532+03
8797	74	-1	1010	2019-11-13 01:34:20.151024+03
8798	95	-1	480	2019-11-13 01:37:11.234165+03
8799	59	-1	1030	2019-11-13 01:52:44.744838+03
8800	7	-1	810	2019-11-13 02:05:59.254482+03
8801	54	-1	3470	2019-11-13 02:17:57.935023+03
8802	38	-2	1100	2019-11-13 02:25:52.180379+03
8803	64	-1	970	2019-11-13 02:47:46.166382+03
8804	69	-1	1100	2019-11-13 02:49:38.093302+03
8805	34	-1	1550	2019-11-13 02:59:23.010372+03
8806	7	-1	810	2019-11-13 03:30:31.702941+03
8807	67	-1	350	2019-11-13 04:20:51.368696+03
8808	28	-1	1860	2019-11-13 04:56:37.173677+03
8809	54	-1	3470	2019-11-13 05:01:32.292774+03
8810	83	-1	1230	2019-11-13 05:09:37.196681+03
8811	37	31	695	2019-11-13 05:41:51.764476+03
8812	14	-1	1350	2019-11-13 05:48:06.307507+03
8813	88	-1	1270	2019-11-13 06:21:39.47869+03
8814	93	-1	1620	2019-11-13 06:58:49.506763+03
8815	54	-2	3470	2019-11-13 07:10:49.856679+03
8816	85	-1	730	2019-11-13 07:25:05.19689+03
8817	63	-1	1780	2019-11-13 07:38:49.957076+03
8818	75	-2	830	2019-11-13 07:41:39.792346+03
8819	59	-1	1030	2019-11-13 07:48:43.318916+03
8820	69	-1	1100	2019-11-13 08:14:59.757282+03
8821	96	-1	1570	2019-11-13 08:57:53.189466+03
8822	65	-1	490	2019-11-13 09:11:17.438675+03
8823	13	-1	460	2019-11-13 09:17:33.239646+03
8824	6	-1	980	2019-11-13 09:17:56.764196+03
8825	59	-1	1030	2019-11-13 09:30:57.985163+03
8826	38	-1	1100	2019-11-13 09:52:55.50147+03
8827	17	-2	1500	2019-11-13 09:58:32.485152+03
8828	32	-1	710	2019-11-13 10:09:59.106682+03
8829	12	-1	1650	2019-11-13 10:36:10.064882+03
8830	93	-1	1620	2019-11-13 10:52:12.999841+03
8831	56	-1	2460	2019-11-13 11:00:42.717399+03
8832	89	-1	1420	2019-11-13 11:28:08.622652+03
8833	73	-1	960	2019-11-13 11:51:04.042616+03
8834	25	-1	1100	2019-11-13 12:09:36.662117+03
8835	81	31	770	2019-11-13 12:11:13.195504+03
8836	66	-1	690	2019-11-13 12:13:59.63733+03
8837	58	-1	2830	2019-11-13 12:18:42.534781+03
8838	2	-1	470	2019-11-13 12:31:31.113739+03
8839	33	-1	900	2019-11-13 13:15:19.188115+03
8840	47	-1	1480	2019-11-13 13:56:43.148346+03
8841	39	-1	910	2019-11-13 14:15:21.458127+03
8842	23	-1	4390	2019-11-13 14:17:45.058573+03
8843	18	-1	910	2019-11-13 14:19:48.240664+03
8844	57	-1	1900	2019-11-13 14:20:09.793458+03
8845	14	-2	1350	2019-11-13 14:25:59.162758+03
8846	36	-2	630	2019-11-13 14:34:55.912871+03
8847	17	-1	1500	2019-11-13 14:35:35.732577+03
8848	1	-1	640	2019-11-13 14:36:56.410349+03
8849	79	-1	550	2019-11-13 14:56:24.686996+03
8850	37	-3	1290	2019-11-13 16:17:33.071531+03
8851	39	-1	910	2019-11-13 16:37:21.70085+03
8852	39	-1	910	2019-11-13 17:31:12.475998+03
8853	3	-1	660	2019-11-13 17:35:58.670559+03
8854	39	-1	910	2019-11-13 17:37:17.019867+03
8855	69	-1	1100	2019-11-13 18:51:29.094352+03
8856	54	-1	3470	2019-11-13 19:15:22.328544+03
8857	56	-1	2460	2019-11-13 19:31:58.125329+03
8858	93	-2	1620	2019-11-13 19:38:49.171951+03
8859	93	-1	1620	2019-11-13 19:58:41.665913+03
8860	89	-1	1420	2019-11-13 20:12:13.357124+03
8861	63	-1	1780	2019-11-13 20:14:56.182149+03
8862	12	-1	1650	2019-11-13 20:25:34.861517+03
8863	30	-1	1140	2019-11-13 20:39:42.39967+03
8864	42	-1	1790	2019-11-13 20:39:52.813453+03
8865	81	-1	1620	2019-11-13 20:59:16.249306+03
8866	12	-1	1650	2019-11-13 21:09:41.683156+03
8867	34	-1	1550	2019-11-13 21:36:46.452461+03
8868	14	-3	1350	2019-11-13 21:48:44.587142+03
8869	1	28	307	2019-11-13 22:08:55.509871+03
8870	39	-1	910	2019-11-13 22:12:14.422106+03
8871	77	-1	640	2019-11-13 22:17:08.959387+03
8872	76	-1	1070	2019-11-13 22:28:17.431426+03
8873	79	-1	550	2019-11-13 22:40:06.625288+03
8874	75	-1	830	2019-11-13 22:52:37.54562+03
8875	22	-1	1070	2019-11-13 23:02:04.800255+03
8876	30	-1	1140	2019-11-13 23:32:18.607762+03
8877	39	-1	910	2019-11-13 23:56:16.833577+03
8878	77	-1	640	2019-11-14 00:23:29.722393+03
8879	47	-1	1480	2019-11-14 00:27:54.68784+03
8880	54	-1	3470	2019-11-14 00:28:37.043843+03
8881	20	-1	830	2019-11-14 00:30:54.037754+03
8882	57	-1	1900	2019-11-14 01:11:12.47762+03
8883	4	-2	1420	2019-11-14 01:45:11.951382+03
8884	22	-1	1070	2019-11-14 01:47:48.390504+03
8885	59	-1	1030	2019-11-14 01:57:06.986695+03
8886	86	-1	910	2019-11-14 02:17:38.681458+03
8887	82	-1	560	2019-11-14 02:40:40.024467+03
8888	78	-1	900	2019-11-14 03:25:30.73512+03
8889	4	-1	1420	2019-11-14 03:44:14.377248+03
8890	36	21	270	2019-11-14 04:30:39.35249+03
8891	96	-1	1570	2019-11-14 04:39:10.416765+03
8892	86	-1	910	2019-11-14 04:43:46.726538+03
8893	63	-1	1780	2019-11-14 04:59:11.195038+03
8894	96	-1	1570	2019-11-14 05:59:47.865335+03
8895	6	-1	980	2019-11-14 06:00:01.694059+03
8896	25	-1	1100	2019-11-14 06:15:11.255548+03
8897	73	-1	960	2019-11-14 06:31:00.670413+03
8898	72	-2	620	2019-11-14 07:23:55.090734+03
8899	54	-1	3470	2019-11-14 07:24:33.360685+03
8900	84	-1	2700	2019-11-14 07:38:46.414913+03
8901	5	-1	1620	2019-11-14 07:39:48.832324+03
8902	16	-1	1380	2019-11-14 08:25:46.199436+03
8903	35	25	333	2019-11-14 08:37:57.222315+03
8904	47	-1	1480	2019-11-14 08:58:18.658352+03
8905	56	-1	2460	2019-11-14 09:44:25.964087+03
8906	10	-1	2080	2019-11-14 09:47:10.362991+03
8907	74	-1	1010	2019-11-14 09:48:42.359974+03
8908	1	-1	640	2019-11-14 10:43:39.586025+03
8909	11	-1	830	2019-11-14 10:51:27.227587+03
8910	31	-1	1190	2019-11-14 12:22:47.015626+03
8911	67	-1	350	2019-11-14 12:23:34.927816+03
8912	80	-1	1120	2019-11-14 12:33:15.310286+03
8913	10	-2	2080	2019-11-14 12:42:23.619663+03
8914	89	-1	1420	2019-11-14 12:49:06.703799+03
8915	33	-1	900	2019-11-14 12:55:00.96902+03
8916	69	-1	1100	2019-11-14 13:08:13.121269+03
8917	89	-2	1420	2019-11-14 13:18:23.8327+03
8918	17	-1	1500	2019-11-14 13:26:03.556543+03
8919	63	19	792	2019-11-14 13:50:48.626625+03
8920	18	-2	910	2019-11-14 14:14:57.460108+03
8921	51	-1	1310	2019-11-14 14:57:20.737595+03
8922	84	-1	2700	2019-11-14 15:27:20.332186+03
8923	38	-1	1100	2019-11-14 15:29:45.553545+03
8924	33	-1	900	2019-11-14 16:05:19.619662+03
8925	30	-2	1140	2019-11-14 16:07:43.557621+03
8926	32	-1	710	2019-11-14 16:29:26.941495+03
8927	55	-1	3480	2019-11-14 16:56:03.659192+03
8928	31	-1	1190	2019-11-14 17:08:03.734295+03
8929	79	-1	550	2019-11-14 17:53:29.048197+03
8930	69	-1	1100	2019-11-14 18:00:10.077432+03
8931	69	-1	1100	2019-11-14 18:02:02.427997+03
8932	95	-1	480	2019-11-14 18:13:54.502011+03
8933	47	-1	1480	2019-11-14 18:20:20.240151+03
8934	80	-1	1120	2019-11-14 18:21:07.693372+03
8935	17	-1	1500	2019-11-14 18:27:35.466124+03
8936	95	-1	480	2019-11-14 18:39:03.108563+03
8937	25	15	449	2019-11-14 18:57:04.407907+03
8938	36	-1	630	2019-11-14 19:03:08.00694+03
8939	22	-1	1070	2019-11-14 19:18:44.794033+03
8940	10	-1	2080	2019-11-14 19:20:04.788197+03
8941	58	-1	2830	2019-11-14 19:44:18.003982+03
8942	56	-2	2460	2019-11-14 19:50:39.694974+03
8943	56	-1	2460	2019-11-14 19:55:47.67639+03
8944	61	-1	1510	2019-11-14 20:28:49.527041+03
8945	46	-1	1270	2019-11-14 20:46:25.485455+03
8946	10	-1	2080	2019-11-14 21:04:21.232082+03
8947	8	-1	1920	2019-11-14 22:18:29.400361+03
8948	48	-2	640	2019-11-14 22:32:38.484369+03
8949	41	-1	830	2019-11-14 22:37:00.08446+03
8950	26	-1	390	2019-11-14 23:10:31.670373+03
8951	39	-1	910	2019-11-14 23:13:21.633313+03
8952	82	-2	560	2019-11-14 23:56:05.405075+03
8953	11	-1	830	2019-11-14 23:56:12.897402+03
8954	64	-2	970	2019-11-14 23:57:17.246766+03
8955	38	-2	1100	2019-11-15 00:17:11.063481+03
8956	37	-1	1290	2019-11-15 00:20:44.150804+03
8957	3	-1	660	2019-11-15 00:21:12.837209+03
8958	34	-2	1550	2019-11-15 00:21:19.94075+03
8959	92	-1	630	2019-11-15 00:59:37.505432+03
8960	9	-1	2090	2019-11-15 01:46:35.312221+03
8961	12	-1	1650	2019-11-15 02:42:41.491598+03
8962	59	-2	1030	2019-11-15 02:46:52.921492+03
8963	18	-1	910	2019-11-15 03:02:21.203705+03
8964	12	-1	1650	2019-11-15 03:35:21.778683+03
8965	13	-2	460	2019-11-15 03:38:16.209271+03
8966	6	-1	980	2019-11-15 03:43:41.074578+03
8967	45	-2	1590	2019-11-15 03:52:28.263842+03
8968	10	-1	2080	2019-11-15 04:21:56.943358+03
8969	93	-1	1620	2019-11-15 04:23:16.172283+03
8970	6	-1	980	2019-11-15 04:40:59.757444+03
8971	79	-1	550	2019-11-15 04:54:23.648354+03
8972	46	43	573	2019-11-15 04:54:34.766475+03
8973	69	-1	1100	2019-11-15 05:03:04.569664+03
8974	37	-1	1290	2019-11-15 05:04:25.668362+03
8975	5	-1	1620	2019-11-15 05:31:23.154979+03
8976	41	-1	830	2019-11-15 05:32:30.931696+03
8977	35	-1	670	2019-11-15 05:33:59.444903+03
8978	51	-2	1310	2019-11-15 05:52:57.617898+03
8979	28	-1	1860	2019-11-15 06:03:00.911021+03
8980	69	-1	1100	2019-11-15 06:25:16.557124+03
8981	65	-1	490	2019-11-15 06:35:46.562729+03
8982	47	-1	1480	2019-11-15 07:07:25.391874+03
8983	89	-1	1420	2019-11-15 07:25:02.300144+03
8984	37	-1	1290	2019-11-15 07:26:30.516128+03
8985	80	-2	1120	2019-11-15 07:28:35.741863+03
8986	71	-2	1030	2019-11-15 07:33:05.072877+03
8987	36	-1	630	2019-11-15 07:35:29.045155+03
8988	65	-1	490	2019-11-15 07:40:46.222761+03
8989	34	-1	1550	2019-11-15 07:52:06.376119+03
8990	70	-1	760	2019-11-15 08:19:23.069756+03
8991	26	-1	390	2019-11-15 08:24:35.594503+03
8992	32	-1	710	2019-11-15 08:41:14.103348+03
8993	39	-1	910	2019-11-15 08:54:56.451874+03
8994	29	-2	1940	2019-11-15 09:12:45.709513+03
8995	50	-1	1140	2019-11-15 09:23:43.262802+03
8996	37	-2	1290	2019-11-15 09:32:55.569979+03
8997	12	-1	1650	2019-11-15 09:41:59.924176+03
8998	59	-2	1030	2019-11-15 10:13:19.844486+03
8999	58	-2	2830	2019-11-15 10:28:53.694678+03
9000	9	26	955	2019-11-15 11:22:17.217651+03
9001	57	-1	1900	2019-11-15 11:57:14.524984+03
9002	88	-1	1270	2019-11-15 12:27:13.319977+03
9003	86	-1	910	2019-11-15 12:41:52.97622+03
9004	5	-1	1620	2019-11-15 13:05:11.610358+03
9005	37	-1	1290	2019-11-15 13:06:43.695274+03
9006	61	-1	1510	2019-11-15 13:07:26.481081+03
9007	30	-1	1140	2019-11-15 13:18:05.737191+03
9008	67	-1	350	2019-11-15 13:53:49.887348+03
9009	53	-1	3120	2019-11-15 14:01:06.938519+03
9010	81	-2	1620	2019-11-15 14:18:50.60799+03
9011	46	-2	1270	2019-11-15 14:33:37.876285+03
9012	1	-1	640	2019-11-15 14:39:30.055661+03
9013	71	-1	1030	2019-11-15 14:44:56.779049+03
9014	49	-1	970	2019-11-15 14:45:24.999133+03
9015	24	-1	950	2019-11-15 14:55:36.68055+03
9016	28	-1	1860	2019-11-15 15:00:38.796906+03
9017	21	-1	960	2019-11-15 15:12:54.120999+03
9018	48	-1	640	2019-11-15 15:17:02.919531+03
9019	11	17	355	2019-11-15 15:57:50.649235+03
9020	37	-1	1290	2019-11-15 15:59:50.024039+03
9021	20	-1	830	2019-11-15 16:38:02.328078+03
9022	88	-2	1270	2019-11-15 17:15:53.195474+03
9023	41	-1	830	2019-11-15 17:35:17.295822+03
9024	57	-1	1900	2019-11-15 18:31:40.924704+03
9025	90	-1	1780	2019-11-15 18:32:04.347145+03
9026	49	-1	970	2019-11-15 18:33:10.443375+03
9027	7	-2	810	2019-11-15 18:42:47.226457+03
9028	17	27	868	2019-11-15 18:44:49.980472+03
9029	31	-1	1190	2019-11-15 18:50:38.047713+03
9030	46	-2	1270	2019-11-15 18:55:13.029266+03
9031	71	-1	1030	2019-11-15 18:55:21.704015+03
9032	60	-2	2700	2019-11-15 19:06:01.505199+03
9033	85	-1	730	2019-11-15 19:11:38.802481+03
9034	36	-1	630	2019-11-15 19:37:10.876921+03
9035	15	-1	2830	2019-11-15 19:50:57.053095+03
9036	6	-1	980	2019-11-15 20:13:11.256687+03
9037	46	-1	1270	2019-11-15 20:28:58.431108+03
9038	91	-1	1620	2019-11-15 20:33:15.204981+03
9039	6	-1	980	2019-11-15 20:49:22.008314+03
9040	6	-1	980	2019-11-15 20:52:27.801631+03
9041	46	-1	1270	2019-11-15 20:57:03.110665+03
9042	29	-2	1940	2019-11-15 21:16:49.855817+03
9043	47	-1	1480	2019-11-15 21:36:53.204763+03
9044	6	-1	980	2019-11-15 22:06:33.209816+03
9045	59	-1	1030	2019-11-15 22:11:45.554669+03
9046	57	-1	1900	2019-11-15 22:35:19.406248+03
9047	36	-1	630	2019-11-15 22:43:00.105674+03
9048	42	-2	1790	2019-11-15 22:48:31.66966+03
9049	45	-1	1590	2019-11-15 23:11:06.04706+03
9050	35	-1	670	2019-11-15 23:42:04.803252+03
9051	13	-2	460	2019-11-15 23:57:41.370583+03
9052	4	-1	1420	2019-11-16 00:13:14.510143+03
9053	49	-1	970	2019-11-16 00:59:19.621551+03
9054	4	-1	1420	2019-11-16 01:25:21.105229+03
9055	4	-1	1420	2019-11-16 01:29:42.066974+03
9056	87	-1	2320	2019-11-16 02:08:34.586885+03
9057	22	-2	1070	2019-11-16 02:25:39.939087+03
9058	18	-1	910	2019-11-16 02:47:51.037152+03
9059	19	-1	1220	2019-11-16 02:52:22.566126+03
9060	44	-1	500	2019-11-16 02:53:54.199777+03
9061	16	-2	1380	2019-11-16 03:56:40.820745+03
9062	21	-1	960	2019-11-16 04:17:18.345269+03
9063	29	-1	1940	2019-11-16 05:16:45.676616+03
9064	82	-1	560	2019-11-16 05:44:22.927106+03
9065	33	-1	900	2019-11-16 05:50:17.141085+03
9066	45	-1	1590	2019-11-16 05:58:19.435688+03
9067	51	-1	1310	2019-11-16 06:18:51.147713+03
9068	45	26	682	2019-11-16 06:53:55.625334+03
9069	73	-1	960	2019-11-16 07:26:18.905642+03
9070	64	-1	970	2019-11-16 08:13:03.232532+03
9071	17	-1	1500	2019-11-16 08:17:13.059225+03
9072	23	-1	4390	2019-11-16 08:24:29.307835+03
9073	78	-2	900	2019-11-16 08:40:36.10102+03
9074	27	-1	880	2019-11-16 08:50:55.759935+03
9075	83	-1	1230	2019-11-16 08:52:26.085145+03
9076	41	-1	830	2019-11-16 08:53:23.433487+03
9077	39	-2	910	2019-11-16 08:58:52.32347+03
9078	77	-1	640	2019-11-16 09:29:26.772449+03
9079	73	-1	960	2019-11-16 09:36:01.918824+03
9080	48	-1	640	2019-11-16 09:37:23.394225+03
9081	47	-1	1480	2019-11-16 10:47:06.545884+03
9082	58	-1	2830	2019-11-16 11:08:28.071909+03
9083	54	-1	3470	2019-11-16 11:11:16.714104+03
9084	49	-1	970	2019-11-16 11:40:53.459526+03
9085	23	-2	4390	2019-11-16 12:09:46.175291+03
9086	60	-1	2700	2019-11-16 12:18:14.162156+03
9087	10	-1	2080	2019-11-16 12:38:39.949994+03
9088	32	-3	710	2019-11-16 12:44:15.875841+03
9089	28	-1	1860	2019-11-16 12:59:33.783379+03
9090	47	-1	1480	2019-11-16 13:10:58.831236+03
9091	77	-1	640	2019-11-16 13:22:08.368066+03
9092	37	-1	1290	2019-11-16 13:29:38.540305+03
9093	7	-1	810	2019-11-16 13:31:42.122331+03
9094	67	-1	350	2019-11-16 13:33:28.111257+03
9095	34	-1	1550	2019-11-16 13:43:23.783687+03
9096	15	17	1482	2019-11-16 13:57:20.107626+03
9097	8	-2	1920	2019-11-16 14:17:19.664246+03
9098	17	-1	1500	2019-11-16 14:21:52.052343+03
9099	29	-1	1940	2019-11-16 14:31:03.333201+03
9100	80	-1	1120	2019-11-16 14:48:29.9589+03
9101	21	-1	960	2019-11-16 15:03:24.274218+03
9102	14	-1	1350	2019-11-16 15:24:08.222452+03
9103	26	-1	390	2019-11-16 15:34:23.680601+03
9104	49	-1	970	2019-11-16 15:46:44.324283+03
9105	88	-1	1270	2019-11-16 15:51:26.084127+03
9106	24	-1	950	2019-11-16 16:01:28.388484+03
9107	58	-1	2830	2019-11-16 16:19:24.804844+03
9108	83	-1	1230	2019-11-16 16:30:10.694642+03
9109	80	-1	1120	2019-11-16 16:33:44.868357+03
9110	54	25	1635	2019-11-16 16:42:08.546017+03
9111	60	-1	2700	2019-11-16 16:48:11.638527+03
9112	86	-1	910	2019-11-16 17:13:16.221001+03
9113	53	-1	3120	2019-11-16 17:27:02.301965+03
9114	73	-2	960	2019-11-16 17:42:38.113106+03
9115	68	-1	490	2019-11-16 17:54:02.08962+03
9116	78	-2	900	2019-11-16 17:59:10.277912+03
9117	77	46	299	2019-11-16 18:08:28.544148+03
9118	12	-1	1650	2019-11-16 18:11:01.155657+03
9119	8	-1	1920	2019-11-16 18:13:05.21511+03
9120	92	-1	630	2019-11-16 18:30:23.305097+03
9121	79	-2	550	2019-11-16 18:35:26.071722+03
9122	54	-1	3470	2019-11-16 18:55:40.630455+03
9123	69	-1	1100	2019-11-16 19:03:14.544789+03
9124	51	-2	1310	2019-11-16 19:07:31.987313+03
9125	86	-1	910	2019-11-16 19:08:32.97529+03
9126	83	-1	1230	2019-11-16 19:17:51.655946+03
9127	62	-1	1220	2019-11-16 19:26:11.854644+03
9128	74	-1	1010	2019-11-16 19:33:50.748562+03
9129	53	-1	3120	2019-11-16 19:36:09.214374+03
9130	11	-1	830	2019-11-16 20:04:56.484034+03
9131	18	-1	910	2019-11-16 20:05:18.845416+03
9132	61	-2	1510	2019-11-16 20:13:37.712361+03
9133	59	-1	1030	2019-11-16 20:25:53.402956+03
9134	40	-1	1430	2019-11-16 20:38:49.65751+03
9135	10	-1	2080	2019-11-16 21:04:49.337925+03
9136	84	-2	2700	2019-11-16 21:37:29.142485+03
9137	34	-1	1550	2019-11-16 21:40:58.439937+03
9138	58	20	1329	2019-11-16 22:15:03.961695+03
9139	32	-2	710	2019-11-16 22:17:52.609692+03
9140	11	-1	830	2019-11-16 22:35:41.508635+03
9141	79	-1	550	2019-11-16 22:46:54.924162+03
9142	30	35	577	2019-11-16 22:51:32.680916+03
9143	31	-1	1190	2019-11-16 23:19:23.850545+03
9144	87	-1	2320	2019-11-16 23:28:00.486267+03
9145	81	-1	1620	2019-11-16 23:32:17.82279+03
9146	86	-1	910	2019-11-16 23:43:36.75212+03
9147	96	-1	1570	2019-11-17 00:05:26.336512+03
9148	46	-1	1270	2019-11-17 00:26:07.696335+03
9149	11	-1	830	2019-11-17 00:48:29.900177+03
9150	35	-1	670	2019-11-17 01:01:09.152738+03
9151	33	-2	900	2019-11-17 01:01:12.301637+03
9152	47	-2	1480	2019-11-17 01:05:11.394446+03
9153	83	-1	1230	2019-11-17 01:16:53.086295+03
9154	50	-2	1140	2019-11-17 01:24:48.724541+03
9155	94	-1	1230	2019-11-17 01:32:05.696529+03
9156	48	-2	640	2019-11-17 01:33:42.88492+03
9157	17	-1	1500	2019-11-17 01:54:07.340261+03
9158	30	-2	1140	2019-11-17 03:19:00.576004+03
9159	63	-1	1780	2019-11-17 03:23:04.002467+03
9160	78	-1	900	2019-11-17 03:42:14.997442+03
9161	41	-1	830	2019-11-17 03:45:49.541167+03
9162	91	-1	1620	2019-11-17 04:22:56.602593+03
9163	76	-1	1070	2019-11-17 04:25:46.177582+03
9164	78	-2	900	2019-11-17 04:30:47.441557+03
9165	93	-1	1620	2019-11-17 04:45:19.530627+03
9166	10	-1	2080	2019-11-17 04:51:26.349283+03
9167	5	-1	1620	2019-11-17 05:07:05.807652+03
9168	27	-1	880	2019-11-17 05:09:49.497107+03
9169	54	-1	3470	2019-11-17 05:34:18.79468+03
9170	13	-1	460	2019-11-17 06:28:22.518901+03
9171	73	-1	960	2019-11-17 06:37:12.160262+03
9172	76	-1	1070	2019-11-17 06:53:07.146297+03
9173	33	-1	900	2019-11-17 07:15:28.076578+03
9174	16	11	627	2019-11-17 07:16:16.30377+03
9175	29	-2	1940	2019-11-17 08:05:49.841747+03
9176	64	-1	970	2019-11-17 08:16:07.326185+03
9177	54	-1	3470	2019-11-17 08:19:06.951708+03
9178	2	-1	470	2019-11-17 08:53:40.779501+03
9179	84	-1	2700	2019-11-17 09:16:14.560687+03
9180	77	-1	640	2019-11-17 10:34:12.817691+03
9181	2	-1	470	2019-11-17 10:44:58.034349+03
9182	26	-1	390	2019-11-17 10:59:21.116795+03
9183	9	-1	2090	2019-11-17 11:11:48.980452+03
9184	96	-1	1570	2019-11-17 12:08:06.866823+03
9185	87	-2	2320	2019-11-17 12:18:22.098707+03
9186	18	-1	910	2019-11-17 12:20:12.190201+03
9187	29	-1	1940	2019-11-17 12:21:21.974968+03
9188	89	-1	1420	2019-11-17 12:41:45.234378+03
9189	92	-1	630	2019-11-17 12:43:21.226333+03
9190	95	-2	480	2019-11-17 13:10:17.447761+03
9191	62	-1	1220	2019-11-17 13:24:16.082915+03
9192	55	-3	3480	2019-11-17 13:25:43.941958+03
9193	30	-1	1140	2019-11-17 13:35:48.578281+03
9194	95	-1	480	2019-11-17 13:43:49.007132+03
9195	32	-1	710	2019-11-17 13:44:10.557623+03
9196	64	-1	970	2019-11-17 13:53:54.667122+03
9197	75	-1	830	2019-11-17 14:54:16.374548+03
9198	94	-2	1230	2019-11-17 15:01:02.536727+03
9199	80	-1	1120	2019-11-17 15:10:57.095465+03
9200	30	-1	1140	2019-11-17 15:23:49.116234+03
9201	22	-1	1070	2019-11-17 15:29:26.334737+03
9202	5	-1	1620	2019-11-17 15:37:44.09827+03
9203	74	-1	1010	2019-11-17 15:39:53.602194+03
9204	6	-1	980	2019-11-17 15:53:23.462169+03
9205	22	-1	1070	2019-11-17 16:14:29.024843+03
9206	18	-1	910	2019-11-17 16:19:18.646739+03
9207	4	-1	1420	2019-11-17 16:23:19.479199+03
9208	87	-1	2320	2019-11-17 16:58:03.810718+03
9209	49	-2	970	2019-11-17 17:23:58.318583+03
9210	95	-2	480	2019-11-17 17:53:33.073198+03
9211	50	-1	1140	2019-11-17 17:59:20.598544+03
9212	27	-1	880	2019-11-17 18:06:12.358978+03
9213	29	-1	1940	2019-11-17 18:09:21.806084+03
9214	3	-1	660	2019-11-17 18:20:03.630062+03
9215	25	-1	1100	2019-11-17 19:06:55.601858+03
9216	3	-2	660	2019-11-17 19:58:25.679494+03
9217	86	-1	910	2019-11-17 19:59:34.111855+03
9218	29	-1	1940	2019-11-17 20:06:37.187398+03
9219	17	-2	1500	2019-11-17 21:04:39.482584+03
9220	4	-1	1420	2019-11-17 21:09:16.027357+03
9221	77	-2	640	2019-11-17 21:18:17.634755+03
9222	79	-1	550	2019-11-17 21:25:53.646962+03
9223	96	-1	1570	2019-11-17 21:43:19.258357+03
9224	53	-1	3120	2019-11-17 21:43:19.524821+03
9225	37	-1	1290	2019-11-17 21:48:21.12013+03
9226	9	-1	2090	2019-11-17 21:49:40.333427+03
9227	96	-1	1570	2019-11-17 21:49:46.021285+03
9228	80	-1	1120	2019-11-17 21:51:03.708169+03
9229	54	-1	3470	2019-11-17 21:55:00.360432+03
9230	80	-1	1120	2019-11-17 22:29:52.747255+03
9231	68	-1	490	2019-11-17 22:34:16.796929+03
9232	48	-1	640	2019-11-17 22:37:02.613677+03
9233	91	-1	1620	2019-11-17 22:54:27.790988+03
9234	88	-1	1270	2019-11-17 22:56:38.291574+03
9235	70	-1	760	2019-11-17 23:02:04.753704+03
9236	29	42	1085	2019-11-17 23:08:44.639536+03
9237	14	-1	1350	2019-11-17 23:10:37.896325+03
9238	53	-1	3120	2019-11-17 23:10:42.152539+03
9239	15	-1	2830	2019-11-17 23:11:28.480104+03
9240	76	-1	1070	2019-11-17 23:13:14.732746+03
9241	1	-1	640	2019-11-17 23:17:59.286737+03
9242	82	-1	560	2019-11-17 23:37:04.673409+03
9243	46	-1	1270	2019-11-17 23:48:54.6858+03
9244	93	-1	1620	2019-11-18 00:08:22.521403+03
9245	86	-2	910	2019-11-18 00:24:13.423836+03
9246	74	-1	1010	2019-11-18 00:27:59.082159+03
9247	93	-1	1620	2019-11-18 00:30:39.245378+03
9248	82	-1	560	2019-11-18 00:36:59.375965+03
9249	1	-1	640	2019-11-18 00:39:50.734381+03
9250	40	-1	1430	2019-11-18 00:40:24.284804+03
9251	91	-1	1620	2019-11-18 00:49:20.052364+03
9252	57	25	875	2019-11-18 01:04:40.95374+03
9253	72	-2	620	2019-11-18 01:05:00.358351+03
9254	86	-1	910	2019-11-18 01:16:31.152508+03
9255	90	-2	1780	2019-11-18 01:30:49.676224+03
9256	48	-1	640	2019-11-18 02:10:07.482898+03
9257	58	-1	2830	2019-11-18 02:29:08.141735+03
9258	57	-2	1900	2019-11-18 02:51:52.193917+03
9259	89	-1	1420	2019-11-18 03:00:24.479387+03
9260	51	-1	1310	2019-11-18 03:11:57.974104+03
9261	14	-1	1350	2019-11-18 03:42:02.49557+03
9262	6	-1	980	2019-11-18 03:57:55.789349+03
9263	95	-1	480	2019-11-18 03:59:38.812396+03
9264	95	25	267	2019-11-18 04:10:12.6645+03
9265	23	-1	4390	2019-11-18 04:13:52.346624+03
9266	27	-1	880	2019-11-18 04:16:50.670229+03
9267	6	-1	980	2019-11-18 04:28:19.972203+03
9268	74	-1	1010	2019-11-18 04:43:09.349605+03
9269	3	-1	660	2019-11-18 04:50:36.660759+03
9270	7	-2	810	2019-11-18 04:50:57.637617+03
9271	54	-1	3470	2019-11-18 04:56:47.503483+03
9272	46	-1	1270	2019-11-18 05:10:03.027543+03
9273	29	-1	1940	2019-11-18 05:34:50.882453+03
9274	88	-2	1270	2019-11-18 06:00:40.179559+03
9275	93	-1	1620	2019-11-18 06:03:44.629122+03
9276	61	-1	1510	2019-11-18 06:06:37.170064+03
9277	93	-2	1620	2019-11-18 06:11:48.926409+03
9278	38	-1	1100	2019-11-18 06:30:27.487549+03
9279	91	-1	1620	2019-11-18 06:33:08.978303+03
9280	15	-1	2830	2019-11-18 06:52:46.472097+03
9281	46	-2	1270	2019-11-18 06:54:10.6486+03
9282	66	-1	690	2019-11-18 06:55:46.053083+03
9283	92	-1	630	2019-11-18 06:58:49.473508+03
9284	38	-1	1100	2019-11-18 07:14:10.621316+03
9285	48	-1	640	2019-11-18 07:20:21.693589+03
9286	1	-1	640	2019-11-18 07:27:44.22707+03
9287	21	-2	960	2019-11-18 08:20:18.98306+03
9288	51	-1	1310	2019-11-18 08:23:30.009706+03
9289	4	-1	1420	2019-11-18 08:25:58.032764+03
9290	2	-1	470	2019-11-18 08:26:40.457898+03
9291	66	-1	690	2019-11-18 08:35:19.521835+03
9292	86	-2	910	2019-11-18 09:04:06.07601+03
9293	50	-1	1140	2019-11-18 09:32:41.762622+03
9294	28	-1	1860	2019-11-18 10:03:16.136484+03
9295	50	-1	1140	2019-11-18 10:22:45.504848+03
9296	57	-1	1900	2019-11-18 11:02:28.818282+03
9297	35	-1	670	2019-11-18 11:27:58.923652+03
9298	74	-1	1010	2019-11-18 11:34:02.317075+03
9299	80	-1	1120	2019-11-18 11:36:54.390782+03
9300	47	-1	1480	2019-11-18 11:45:22.996637+03
9301	17	-1	1500	2019-11-18 12:02:34.732743+03
9302	13	-2	460	2019-11-18 12:12:52.861324+03
9303	94	-3	1230	2019-11-18 12:13:21.810972+03
9304	77	-1	640	2019-11-18 12:40:23.501425+03
9305	32	-1	710	2019-11-18 12:47:39.215589+03
9306	26	-1	390	2019-11-18 12:59:39.456091+03
9307	84	-1	2700	2019-11-18 13:01:38.438548+03
9308	57	-1	1900	2019-11-18 13:11:50.573339+03
9309	72	-1	620	2019-11-18 13:14:39.851748+03
9310	88	-1	1270	2019-11-18 13:47:57.644382+03
9311	76	-2	1070	2019-11-18 13:56:17.614289+03
9312	83	-1	1230	2019-11-18 14:05:58.132027+03
9313	47	-1	1480	2019-11-18 14:23:31.603071+03
9314	60	-1	2700	2019-11-18 14:27:02.645119+03
9315	75	-1	830	2019-11-18 15:06:21.812871+03
9316	40	-1	1430	2019-11-18 15:10:49.63741+03
9317	23	-2	4390	2019-11-18 15:18:18.128105+03
9318	56	-2	2460	2019-11-18 15:23:05.973379+03
9319	74	-1	1010	2019-11-18 15:28:33.081828+03
9320	54	-1	3470	2019-11-18 15:35:58.976851+03
9321	21	-1	960	2019-11-18 15:43:59.020983+03
9322	85	-1	730	2019-11-18 15:56:57.792637+03
9323	43	-2	380	2019-11-18 16:35:10.017898+03
9324	52	-1	1090	2019-11-18 16:35:37.046761+03
9325	92	-1	630	2019-11-18 16:58:55.371481+03
9326	26	-1	390	2019-11-18 17:13:29.109418+03
9327	77	-1	640	2019-11-18 18:37:09.574321+03
9328	57	-2	1900	2019-11-18 19:02:59.869095+03
9329	13	-1	460	2019-11-18 19:11:21.758528+03
9330	30	-1	1140	2019-11-18 19:22:20.641998+03
9331	13	-1	460	2019-11-18 19:38:44.207562+03
9332	65	-1	490	2019-11-18 19:42:45.439113+03
9333	74	-2	1010	2019-11-18 20:05:30.589586+03
9334	26	-1	390	2019-11-18 20:25:51.905434+03
9335	18	-1	910	2019-11-18 20:33:22.554081+03
9336	30	-1	1140	2019-11-18 20:51:27.041188+03
9337	88	-2	1270	2019-11-18 21:04:57.735193+03
9338	55	-1	3480	2019-11-18 21:17:44.677248+03
9339	46	-1	1270	2019-11-18 22:10:04.708782+03
9340	39	-1	910	2019-11-18 22:17:23.984772+03
9341	92	-1	630	2019-11-18 22:48:46.706944+03
9342	67	-1	350	2019-11-18 23:07:00.672388+03
9343	78	-1	900	2019-11-18 23:18:58.163061+03
9344	70	-1	760	2019-11-18 23:28:02.946013+03
9345	89	-1	1420	2019-11-19 00:22:50.943687+03
9346	74	-1	1010	2019-11-19 00:28:51.469777+03
9347	59	-1	1030	2019-11-19 00:31:34.061351+03
9348	75	-1	830	2019-11-19 00:32:53.849045+03
9349	30	-2	1140	2019-11-19 00:39:55.518295+03
9350	88	-2	1270	2019-11-19 00:40:11.872812+03
9351	33	-1	900	2019-11-19 00:52:13.197009+03
9352	81	-2	1620	2019-11-19 01:18:31.415878+03
9353	59	-1	1030	2019-11-19 01:31:00.297831+03
9354	68	-1	490	2019-11-19 01:38:26.884984+03
9355	31	-2	1190	2019-11-19 01:55:19.474438+03
9356	92	-1	630	2019-11-19 02:04:35.723448+03
9357	90	-2	1780	2019-11-19 02:06:28.347039+03
9358	8	-2	1920	2019-11-19 02:15:40.876862+03
9359	22	-1	1070	2019-11-19 02:40:20.327107+03
9360	24	-1	950	2019-11-19 03:13:18.810524+03
9361	49	-1	970	2019-11-19 03:23:45.769452+03
9362	19	-1	1220	2019-11-19 03:36:18.06778+03
9363	83	-1	1230	2019-11-19 04:34:52.148146+03
9364	13	-2	460	2019-11-19 04:40:00.435351+03
9365	22	-1	1070	2019-11-19 04:40:21.747249+03
9366	3	-1	660	2019-11-19 04:43:54.983503+03
9367	37	-1	1290	2019-11-19 05:07:56.445822+03
9368	22	-1	1070	2019-11-19 05:18:34.320486+03
9369	76	-1	1070	2019-11-19 06:11:00.553443+03
9370	53	-1	3120	2019-11-19 06:17:37.622762+03
9371	37	-1	1290	2019-11-19 06:19:40.44788+03
9372	42	-1	1790	2019-11-19 06:21:03.548409+03
9373	39	-1	910	2019-11-19 06:26:11.308146+03
9374	61	-1	1510	2019-11-19 06:30:26.768118+03
9375	38	-2	1100	2019-11-19 06:31:02.698387+03
9376	34	-1	1550	2019-11-19 07:02:28.56313+03
9377	8	-1	1920	2019-11-19 07:05:37.921258+03
9378	5	-1	1620	2019-11-19 07:05:59.515492+03
9379	75	-1	830	2019-11-19 07:24:08.021734+03
9380	33	-1	900	2019-11-19 07:28:35.845348+03
9381	87	-3	2320	2019-11-19 07:53:42.24528+03
9382	9	-1	2090	2019-11-19 08:00:35.915772+03
9383	49	-1	970	2019-11-19 08:16:17.535528+03
9384	18	-1	910	2019-11-19 08:17:08.712783+03
9385	78	-2	900	2019-11-19 09:15:34.030683+03
9386	73	-2	960	2019-11-19 09:18:13.864389+03
9387	80	25	491	2019-11-19 09:27:14.498267+03
9388	27	-1	880	2019-11-19 09:35:29.448543+03
9389	55	-1	3480	2019-11-19 10:36:31.307798+03
9390	46	-1	1270	2019-11-19 10:49:05.511356+03
9391	80	-1	1120	2019-11-19 11:17:14.3882+03
9392	77	-1	640	2019-11-19 11:55:14.992888+03
9393	48	-1	640	2019-11-19 12:40:28.375566+03
9394	68	-1	490	2019-11-19 12:42:48.837316+03
9395	7	-1	810	2019-11-19 12:47:26.113722+03
9396	20	-1	830	2019-11-19 12:48:07.384506+03
9397	40	-1	1430	2019-11-19 13:10:41.049149+03
9398	36	-1	630	2019-11-19 13:42:11.272564+03
9399	75	-1	830	2019-11-19 15:06:23.744341+03
9400	38	-1	1100	2019-11-19 15:29:01.343818+03
9401	83	-2	1230	2019-11-19 15:35:21.966917+03
9402	71	-1	1030	2019-11-19 15:49:45.005061+03
9403	14	-1	1350	2019-11-19 16:12:48.084253+03
9404	28	-1	1860	2019-11-19 16:31:19.322516+03
9405	3	-1	660	2019-11-19 16:32:24.237181+03
9406	42	-1	1790	2019-11-19 17:03:48.659412+03
9407	22	-2	1070	2019-11-19 17:06:20.933554+03
9408	3	-1	660	2019-11-19 17:08:06.71495+03
9409	41	-1	830	2019-11-19 17:31:17.49406+03
9410	5	-1	1620	2019-11-19 17:58:47.292702+03
9411	76	-1	1070	2019-11-19 19:07:59.98201+03
9412	7	-2	810	2019-11-19 19:45:25.184319+03
9413	95	-1	480	2019-11-19 19:56:40.633961+03
9414	74	-1	1010	2019-11-19 20:15:56.448245+03
9415	94	-1	1230	2019-11-19 20:18:03.935097+03
9416	11	-1	830	2019-11-19 20:32:33.153865+03
9417	91	-1	1620	2019-11-19 20:42:54.787522+03
9418	8	-1	1920	2019-11-19 20:51:16.472886+03
9419	31	-2	1190	2019-11-19 20:51:39.940528+03
9420	64	-1	970	2019-11-19 21:03:08.935967+03
9421	51	-1	1310	2019-11-19 21:16:33.475903+03
9422	55	-1	3480	2019-11-19 22:13:09.349397+03
9423	43	-1	380	2019-11-19 22:15:40.157598+03
9424	78	20	434	2019-11-19 22:16:08.448805+03
9425	58	-1	2830	2019-11-19 22:29:42.770271+03
9426	21	-1	960	2019-11-19 22:49:53.576803+03
9427	18	39	385	2019-11-19 23:17:28.251058+03
9428	80	-1	1120	2019-11-19 23:34:50.091368+03
9429	49	-1	970	2019-11-19 23:37:44.773577+03
9430	26	-2	390	2019-11-19 23:51:49.871433+03
9431	81	-1	1620	2019-11-19 23:52:31.553603+03
9432	4	-1	1420	2019-11-20 00:02:01.411048+03
9433	95	-2	480	2019-11-20 00:09:09.77544+03
9434	1	-1	640	2019-11-20 00:22:39.470489+03
9435	58	-1	2830	2019-11-20 00:37:35.180744+03
9436	68	-1	490	2019-11-20 00:46:10.886539+03
9437	77	-2	640	2019-11-20 00:48:23.637727+03
9438	41	-1	830	2019-11-20 00:50:24.675488+03
9439	54	-2	3470	2019-11-20 00:54:35.339598+03
9440	31	-1	1190	2019-11-20 01:02:17.834209+03
9441	40	-1	1430	2019-11-20 01:14:10.829951+03
9442	47	-1	1480	2019-11-20 01:44:13.015944+03
9443	4	-2	1420	2019-11-20 01:47:53.452496+03
9444	86	-1	910	2019-11-20 01:50:16.546883+03
9445	20	-1	830	2019-11-20 02:18:16.278238+03
9446	25	-2	1100	2019-11-20 02:37:10.875892+03
9447	23	-1	4390	2019-11-20 02:37:31.430512+03
9448	20	-1	830	2019-11-20 02:40:39.656199+03
9449	89	-2	1420	2019-11-20 02:45:45.61797+03
9450	49	-2	970	2019-11-20 02:49:53.781949+03
9451	90	-1	1780	2019-11-20 03:03:27.549678+03
9452	51	-1	1310	2019-11-20 03:04:58.080546+03
9453	22	-1	1070	2019-11-20 03:09:56.730531+03
9454	92	22	324	2019-11-20 03:19:12.044151+03
9455	56	-2	2460	2019-11-20 03:28:42.832455+03
9456	13	-1	460	2019-11-20 03:31:31.209627+03
9457	70	-1	760	2019-11-20 03:52:01.600419+03
9458	50	-1	1140	2019-11-20 04:04:18.041997+03
9459	17	-1	1500	2019-11-20 04:05:55.054842+03
9460	26	-1	390	2019-11-20 04:29:20.68642+03
9461	71	-1	1030	2019-11-20 04:33:11.998453+03
9462	17	-1	1500	2019-11-20 04:52:43.170415+03
9463	39	-1	910	2019-11-20 05:07:02.514941+03
9464	90	-1	1780	2019-11-20 05:09:47.108425+03
9465	96	-1	1570	2019-11-20 05:41:05.890397+03
9466	30	-2	1140	2019-11-20 05:51:38.623459+03
9467	29	-2	1940	2019-11-20 06:24:16.584048+03
9468	49	-1	970	2019-11-20 06:46:39.005313+03
9469	46	-1	1270	2019-11-20 07:09:01.300502+03
9470	12	-2	1650	2019-11-20 07:21:04.258486+03
9471	37	-2	1290	2019-11-20 07:25:26.170884+03
9472	6	-2	980	2019-11-20 08:32:53.270229+03
9473	94	-1	1230	2019-11-20 09:00:41.777359+03
9474	73	-2	960	2019-11-20 09:02:51.892299+03
9475	93	-2	1620	2019-11-20 11:30:49.411947+03
9476	74	-1	1010	2019-11-20 11:33:37.555754+03
9477	21	-1	960	2019-11-20 11:35:39.810932+03
9478	6	-2	980	2019-11-20 11:53:09.177972+03
9479	36	-1	630	2019-11-20 12:26:57.568542+03
9480	14	33	718	2019-11-20 12:48:34.410959+03
9481	31	-1	1190	2019-11-20 12:49:10.610716+03
9482	18	-1	910	2019-11-20 12:58:52.867705+03
9483	96	-1	1570	2019-11-20 13:03:36.102987+03
9484	93	-2	1620	2019-11-20 13:38:45.648841+03
9485	66	11	398	2019-11-20 13:40:15.326169+03
9486	81	-1	1620	2019-11-20 14:06:29.772881+03
9487	46	-2	1270	2019-11-20 14:13:19.911879+03
9488	89	-1	1420	2019-11-20 14:42:12.885597+03
9489	61	-1	1510	2019-11-20 14:45:00.135704+03
9490	40	-1	1430	2019-11-20 15:10:40.852668+03
9491	42	-2	1790	2019-11-20 15:26:40.216026+03
9492	48	-2	640	2019-11-20 15:28:12.350895+03
9493	20	-1	830	2019-11-20 15:37:07.736235+03
9494	58	-1	2830	2019-11-20 16:39:44.210009+03
9495	17	-1	1500	2019-11-20 16:48:33.075366+03
9496	35	-1	670	2019-11-20 16:49:52.87644+03
9497	45	-1	1590	2019-11-20 16:53:45.102454+03
9498	74	-1	1010	2019-11-20 16:58:11.554856+03
9499	15	-1	2830	2019-11-20 17:02:04.168302+03
9500	34	-1	1550	2019-11-20 17:07:26.025127+03
9501	14	-1	1350	2019-11-20 17:23:51.777461+03
9502	93	-1	1620	2019-11-20 18:02:57.509773+03
9503	79	-1	550	2019-11-20 18:27:25.488136+03
9504	20	-2	830	2019-11-20 18:36:41.856679+03
9505	22	-1	1070	2019-11-20 19:24:15.184554+03
9506	33	-1	900	2019-11-20 19:41:01.636596+03
9507	93	-1	1620	2019-11-20 20:07:31.453875+03
9508	59	-1	1030	2019-11-20 20:17:22.530654+03
9509	38	-1	1100	2019-11-20 20:22:24.996421+03
9510	24	-1	950	2019-11-20 20:24:06.817023+03
9511	90	-1	1780	2019-11-20 20:38:34.298982+03
9512	51	-1	1310	2019-11-20 20:41:29.358804+03
9513	19	-2	1220	2019-11-20 20:56:00.882317+03
9514	17	-1	1500	2019-11-20 21:02:03.078191+03
9515	27	-1	880	2019-11-20 21:02:45.000616+03
9516	23	-1	4390	2019-11-20 21:11:47.005781+03
9517	47	-1	1480	2019-11-20 21:26:33.525038+03
9518	22	-1	1070	2019-11-20 21:29:01.559412+03
9519	41	24	466	2019-11-20 21:39:47.363317+03
9520	85	-1	730	2019-11-20 22:10:03.190113+03
9521	31	35	512	2019-11-20 22:10:06.231999+03
9522	75	-2	830	2019-11-20 22:10:31.84329+03
9523	47	-1	1480	2019-11-20 22:18:11.568115+03
9524	59	-2	1030	2019-11-20 22:18:55.47365+03
9525	94	-1	1230	2019-11-20 22:30:19.779707+03
9526	19	-1	1220	2019-11-20 22:31:38.010463+03
9527	47	-1	1480	2019-11-20 22:45:10.526342+03
9528	56	-1	2460	2019-11-20 23:05:04.863843+03
9529	95	-1	480	2019-11-20 23:53:19.089215+03
9530	22	-3	1070	2019-11-20 23:56:24.101746+03
9531	37	-1	1290	2019-11-21 00:11:32.751443+03
9532	49	-1	970	2019-11-21 01:14:03.628542+03
9533	17	-1	1500	2019-11-21 01:17:06.728484+03
9534	37	-1	1290	2019-11-21 01:19:38.061666+03
9535	46	-1	1270	2019-11-21 01:34:23.396944+03
9536	95	-1	480	2019-11-21 01:42:49.264247+03
9537	55	-1	3480	2019-11-21 01:44:58.215968+03
9538	7	-1	810	2019-11-21 02:10:39.620566+03
9539	12	-2	1650	2019-11-21 02:59:09.563918+03
9540	57	-2	1900	2019-11-21 03:00:49.972464+03
9541	80	-1	1120	2019-11-21 03:11:41.987344+03
9542	71	-1	1030	2019-11-21 03:19:48.534602+03
9543	67	-1	350	2019-11-21 03:49:26.519525+03
9544	54	-2	3470	2019-11-21 03:54:09.13175+03
9545	47	-2	1480	2019-11-21 04:34:36.477173+03
9546	26	-1	390	2019-11-21 05:08:13.749652+03
9547	67	-1	350	2019-11-21 05:32:55.999318+03
9548	15	-1	2830	2019-11-21 05:46:03.370068+03
9549	61	-1	1510	2019-11-21 05:49:26.138429+03
9550	56	-1	2460	2019-11-21 05:50:14.237502+03
9551	37	-1	1290	2019-11-21 06:32:08.459524+03
9552	48	-1	640	2019-11-21 06:35:03.660556+03
9553	83	-2	1230	2019-11-21 07:05:57.994578+03
9554	28	-2	1860	2019-11-21 08:06:12.975836+03
9555	77	-1	640	2019-11-21 08:18:39.226261+03
9556	27	20	364	2019-11-21 08:20:15.44202+03
9557	96	-1	1570	2019-11-21 08:53:56.354219+03
9558	64	30	561	2019-11-21 08:58:32.20182+03
9559	23	-1	4390	2019-11-21 09:02:14.816788+03
9560	91	-1	1620	2019-11-21 09:12:13.859325+03
9561	7	26	395	2019-11-21 09:22:35.52951+03
9562	40	-1	1430	2019-11-21 09:28:31.677139+03
9563	14	-1	1350	2019-11-21 09:55:41.341272+03
9564	24	-2	950	2019-11-21 10:29:42.018537+03
9565	43	-1	380	2019-11-21 10:31:27.749885+03
9566	57	-1	1900	2019-11-21 10:42:31.230228+03
9567	17	-1	1500	2019-11-21 11:18:54.293492+03
9568	56	-1	2460	2019-11-21 11:29:37.737797+03
9569	21	27	571	2019-11-21 12:02:05.869527+03
9570	71	-1	1030	2019-11-21 12:33:09.572427+03
9571	75	-2	830	2019-11-21 12:59:36.278573+03
9572	76	-1	1070	2019-11-21 13:06:45.552998+03
9573	68	-1	490	2019-11-21 13:14:44.693894+03
9574	1	-1	640	2019-11-21 13:57:34.366092+03
9575	95	-1	480	2019-11-21 13:58:03.604007+03
9576	17	-1	1500	2019-11-21 14:07:15.124963+03
9577	20	-1	830	2019-11-21 14:33:37.479118+03
9578	63	-1	1780	2019-11-21 14:37:45.867978+03
9579	54	-1	3470	2019-11-21 14:37:54.851033+03
9580	87	-2	2320	2019-11-21 14:49:08.552795+03
9581	53	-1	3120	2019-11-21 14:52:39.355298+03
9582	1	-1	640	2019-11-21 14:54:45.50728+03
9583	85	-1	730	2019-11-21 15:00:12.118484+03
9584	58	-3	2830	2019-11-21 15:23:33.707782+03
9585	23	-1	4390	2019-11-21 15:42:00.670716+03
9586	95	-1	480	2019-11-21 16:00:21.117172+03
9587	69	-1	1100	2019-11-21 16:13:07.279591+03
9588	10	-1	2080	2019-11-21 16:19:40.91339+03
9589	47	34	612	2019-11-21 16:55:12.339809+03
9590	4	-1	1420	2019-11-21 17:33:59.033654+03
9591	9	-1	2090	2019-11-21 17:39:52.055304+03
9592	32	-1	710	2019-11-21 17:41:57.703535+03
9593	41	-1	830	2019-11-21 17:50:02.031708+03
9594	33	-1	900	2019-11-21 17:53:41.445189+03
9595	13	-1	460	2019-11-21 18:05:41.656191+03
9596	93	31	812	2019-11-21 18:38:22.520971+03
9597	53	-1	3120	2019-11-21 19:01:14.034178+03
9598	72	-1	620	2019-11-21 19:08:59.594789+03
9599	6	-1	980	2019-11-21 19:16:58.779508+03
9600	95	-1	480	2019-11-21 19:43:07.669874+03
9601	56	-2	2460	2019-11-21 19:59:46.263404+03
9602	93	-1	1620	2019-11-21 20:03:58.032384+03
9603	60	-1	2700	2019-11-21 20:08:01.358458+03
9604	47	-1	1480	2019-11-21 20:08:13.54208+03
9605	70	-1	760	2019-11-21 20:24:17.653028+03
9606	53	-1	3120	2019-11-21 21:02:30.833323+03
9607	64	-1	970	2019-11-21 21:03:47.022815+03
9608	49	-1	970	2019-11-21 21:18:58.689955+03
9609	33	-1	900	2019-11-21 22:22:04.987088+03
9610	2	-2	470	2019-11-21 22:22:40.088912+03
9611	80	-1	1120	2019-11-21 22:27:23.975479+03
9612	17	-1	1500	2019-11-21 22:54:08.955134+03
9613	83	36	541	2019-11-21 23:23:49.854577+03
9614	54	-1	3470	2019-11-21 23:45:20.215662+03
9615	80	-1	1120	2019-11-22 00:01:09.911566+03
9616	15	-1	2830	2019-11-22 00:12:49.743509+03
9617	18	-1	910	2019-11-22 00:35:13.811033+03
9618	17	-1	1500	2019-11-22 00:42:58.925516+03
9619	17	-1	1500	2019-11-22 01:03:38.050704+03
9620	63	-1	1780	2019-11-22 01:08:33.090161+03
9621	39	-1	910	2019-11-22 01:08:40.755936+03
9622	19	-1	1220	2019-11-22 01:30:31.387304+03
9623	65	-1	490	2019-11-22 01:42:57.441133+03
9624	26	18	219	2019-11-22 02:09:01.181762+03
9625	74	-1	1010	2019-11-22 02:14:14.302022+03
9626	49	-1	970	2019-11-22 02:16:32.203983+03
9627	21	-1	960	2019-11-22 02:41:40.055572+03
9628	66	-1	690	2019-11-22 02:48:31.922026+03
9629	46	-1	1270	2019-11-22 03:24:02.696246+03
9630	21	-2	960	2019-11-22 03:44:17.227887+03
9631	8	-1	1920	2019-11-22 03:50:41.631424+03
9632	35	-1	670	2019-11-22 03:57:03.266673+03
9633	19	-1	1220	2019-11-22 03:58:05.458869+03
9634	33	-1	900	2019-11-22 04:16:17.922766+03
9635	77	-1	640	2019-11-22 05:04:20.203647+03
9636	17	-1	1500	2019-11-22 05:20:11.644003+03
9637	12	-1	1650	2019-11-22 06:10:10.764171+03
9638	71	-1	1030	2019-11-22 06:19:25.906263+03
9639	96	-2	1570	2019-11-22 06:34:52.013753+03
9640	73	-2	960	2019-11-22 06:41:57.753896+03
9641	3	-1	660	2019-11-22 07:05:24.380088+03
9642	80	-1	1120	2019-11-22 07:21:21.954859+03
9643	7	-1	810	2019-11-22 07:34:11.001274+03
9644	63	-1	1780	2019-11-22 07:47:52.007111+03
9645	53	-2	3120	2019-11-22 07:50:16.318287+03
9646	31	-1	1190	2019-11-22 07:56:07.919157+03
9647	29	-2	1940	2019-11-22 08:03:05.188031+03
9648	22	-1	1070	2019-11-22 08:04:40.855843+03
9649	59	-1	1030	2019-11-22 08:07:58.056421+03
9650	80	-1	1120	2019-11-22 08:21:19.207448+03
9651	29	-1	1940	2019-11-22 09:10:21.483159+03
9652	2	-1	470	2019-11-22 09:13:02.144187+03
9653	32	-2	710	2019-11-22 09:29:19.19785+03
9654	6	-2	980	2019-11-22 09:31:27.023466+03
9655	21	-1	960	2019-11-22 11:18:35.641479+03
9656	88	-1	1270	2019-11-22 11:19:31.456576+03
9657	88	-1	1270	2019-11-22 11:20:13.566709+03
9658	73	-1	960	2019-11-22 11:27:14.026872+03
9659	39	-2	910	2019-11-22 11:32:37.008731+03
9660	84	-1	2700	2019-11-22 11:56:55.930083+03
9661	43	-2	380	2019-11-22 12:03:03.551307+03
9662	61	-1	1510	2019-11-22 12:13:37.653116+03
9663	77	-2	640	2019-11-22 12:23:32.177715+03
9664	70	-1	760	2019-11-22 13:21:04.359067+03
9665	78	-1	900	2019-11-22 13:27:03.0938+03
9666	60	-1	2700	2019-11-22 13:29:31.349875+03
9667	20	-1	830	2019-11-22 13:50:24.455303+03
9668	29	-1	1940	2019-11-22 13:53:54.184915+03
9669	3	27	269	2019-11-22 14:26:34.972263+03
9670	2	-1	470	2019-11-22 14:38:47.785585+03
9671	12	-1	1650	2019-11-22 14:42:44.03143+03
9672	80	-1	1120	2019-11-22 15:00:12.234865+03
9673	22	-1	1070	2019-11-22 15:21:44.20629+03
9674	29	-1	1940	2019-11-22 15:30:04.439536+03
9675	84	-2	2700	2019-11-22 15:35:10.549544+03
9676	56	-1	2460	2019-11-22 15:40:02.975759+03
9677	11	-1	830	2019-11-22 16:09:43.680219+03
9678	94	-1	1230	2019-11-22 16:26:20.962205+03
9679	59	-1	1030	2019-11-22 16:30:06.471693+03
9680	75	-1	830	2019-11-22 16:48:50.923255+03
9681	95	-2	480	2019-11-22 16:55:02.077704+03
9682	34	-1	1550	2019-11-22 17:02:00.360958+03
9683	65	-1	490	2019-11-22 17:25:06.300784+03
9684	15	-1	2830	2019-11-22 17:50:40.740939+03
9685	68	-1	490	2019-11-22 18:05:51.20809+03
9686	74	-1	1010	2019-11-22 18:15:45.844166+03
9687	46	-1	1270	2019-11-22 18:15:58.201342+03
9688	22	-1	1070	2019-11-22 18:41:26.259541+03
9689	43	-1	380	2019-11-22 19:08:02.895908+03
9690	19	-1	1220	2019-11-22 19:21:05.884635+03
9691	94	-1	1230	2019-11-22 19:24:06.475578+03
9692	34	-2	1550	2019-11-22 19:36:06.99946+03
9693	35	-2	670	2019-11-22 19:40:33.431155+03
9694	71	-1	1030	2019-11-22 19:50:15.184107+03
9695	78	-2	900	2019-11-22 19:53:55.254862+03
9696	31	-1	1190	2019-11-22 19:55:50.417725+03
9697	89	-2	1420	2019-11-22 19:59:07.00749+03
9698	77	-2	640	2019-11-22 20:25:25.779667+03
9699	23	-1	4390	2019-11-22 20:32:08.49023+03
9700	14	-1	1350	2019-11-22 20:37:48.915216+03
9701	87	-1	2320	2019-11-22 20:37:50.636661+03
9702	1	-1	640	2019-11-22 20:45:45.994564+03
9703	45	-1	1590	2019-11-22 21:01:44.579113+03
9704	93	-1	1620	2019-11-22 21:24:12.562597+03
9705	28	25	787	2019-11-22 21:37:56.732367+03
9706	87	-1	2320	2019-11-22 21:40:34.113189+03
9707	20	-1	830	2019-11-22 21:42:29.745908+03
9708	33	34	479	2019-11-22 22:05:09.097452+03
9709	63	-2	1780	2019-11-22 22:06:52.744477+03
9710	78	-1	900	2019-11-22 22:09:54.711372+03
9711	8	-1	1920	2019-11-22 22:49:00.442437+03
9712	39	-1	910	2019-11-22 23:26:46.085802+03
9713	49	-1	970	2019-11-23 00:07:45.741744+03
9714	54	-1	3470	2019-11-23 00:16:33.351847+03
9715	56	-1	2460	2019-11-23 00:45:32.583218+03
9716	21	-1	960	2019-11-23 01:11:39.485054+03
9717	57	-1	1900	2019-11-23 01:34:42.845811+03
9718	57	-3	1900	2019-11-23 02:02:44.639217+03
9719	69	-1	1100	2019-11-23 02:09:11.432928+03
9720	1	-1	640	2019-11-23 02:30:26.55278+03
9721	69	-1	1100	2019-11-23 02:33:08.782128+03
9722	37	-1	1290	2019-11-23 02:38:43.488734+03
9723	91	-3	1620	2019-11-23 02:45:25.219988+03
9724	39	-1	910	2019-11-23 03:06:56.500262+03
9725	55	-1	3480	2019-11-23 03:11:34.43869+03
9726	68	-1	490	2019-11-23 03:12:17.516257+03
9727	62	-1	1220	2019-11-23 03:12:23.279258+03
9728	43	-2	380	2019-11-23 03:19:42.449947+03
9729	74	-1	1010	2019-11-23 04:27:08.409696+03
9730	67	-1	350	2019-11-23 04:33:39.726215+03
9731	68	21	279	2019-11-23 04:54:08.236959+03
9732	22	-1	1070	2019-11-23 05:11:58.95834+03
9733	73	-1	960	2019-11-23 05:13:09.442693+03
9734	40	27	669	2019-11-23 05:20:05.663059+03
9735	2	-1	470	2019-11-23 05:20:42.525188+03
9736	36	-2	630	2019-11-23 05:37:13.197238+03
9737	52	-2	1090	2019-11-23 05:37:54.642067+03
9738	34	33	712	2019-11-23 05:38:20.120712+03
9739	33	-2	900	2019-11-23 05:41:35.288919+03
9740	49	-1	970	2019-11-23 05:41:47.661489+03
9741	51	21	767	2019-11-23 05:51:53.128426+03
9742	32	-1	710	2019-11-23 06:03:58.697537+03
9743	95	-2	480	2019-11-23 06:03:59.692509+03
9744	22	-1	1070	2019-11-23 06:08:29.811135+03
9745	44	-3	500	2019-11-23 06:14:27.46093+03
9746	87	-1	2320	2019-11-23 06:24:32.97414+03
9747	1	-1	640	2019-11-23 06:50:16.837647+03
9748	5	-1	1620	2019-11-23 07:03:32.605944+03
9749	18	-1	910	2019-11-23 07:16:44.800385+03
9750	80	-2	1120	2019-11-23 07:44:56.26118+03
9751	92	-1	630	2019-11-23 08:34:28.003713+03
9752	33	-1	900	2019-11-23 08:45:59.966274+03
9753	63	-1	1780	2019-11-23 09:18:39.337526+03
9754	78	-1	900	2019-11-23 09:29:39.105476+03
9755	47	-1	1480	2019-11-23 09:37:22.381489+03
9756	96	-1	1570	2019-11-23 09:37:44.972708+03
9757	6	-1	980	2019-11-23 10:33:14.251902+03
9758	70	-2	760	2019-11-23 11:00:30.713864+03
9759	54	-1	3470	2019-11-23 11:14:12.477072+03
9760	76	-2	1070	2019-11-23 11:27:42.792843+03
9761	69	-1	1100	2019-11-23 12:09:58.536991+03
9762	34	-1	1550	2019-11-23 12:36:37.281211+03
9763	36	-1	630	2019-11-23 12:59:38.176958+03
9764	4	-1	1420	2019-11-23 13:04:51.4343+03
9765	34	-1	1550	2019-11-23 13:49:32.4938+03
9766	44	-1	500	2019-11-23 14:07:16.046291+03
9767	86	-1	910	2019-11-23 14:13:29.603073+03
9768	41	-1	830	2019-11-23 14:35:56.584307+03
9769	74	-1	1010	2019-11-23 14:40:15.893905+03
9770	3	-1	660	2019-11-23 15:18:59.941614+03
9771	22	-1	1070	2019-11-23 15:32:55.570814+03
9772	14	-1	1350	2019-11-23 15:39:57.695116+03
9773	61	-1	1510	2019-11-23 15:50:14.400192+03
9774	94	-1	1230	2019-11-23 16:06:28.898454+03
9775	7	-1	810	2019-11-23 16:11:45.972728+03
9776	38	33	507	2019-11-23 16:14:05.83946+03
9777	68	-1	490	2019-11-23 16:46:52.646066+03
9778	49	-2	970	2019-11-23 16:50:48.108452+03
9779	73	-1	960	2019-11-23 17:11:01.747916+03
9780	9	-1	2090	2019-11-23 17:24:05.176511+03
9781	86	-1	910	2019-11-23 17:38:04.540368+03
9782	18	-1	910	2019-11-23 17:59:59.608253+03
9783	57	-1	1900	2019-11-23 18:28:28.527675+03
9784	75	-1	830	2019-11-23 18:31:44.742393+03
9785	37	-1	1290	2019-11-23 18:37:14.613302+03
9786	6	-2	980	2019-11-23 18:38:59.535277+03
9787	15	-1	2830	2019-11-23 18:45:13.207557+03
9788	88	-1	1270	2019-11-23 18:45:19.160022+03
9789	89	-1	1420	2019-11-23 18:48:38.746599+03
9790	21	-1	960	2019-11-23 18:55:51.850443+03
9791	3	-1	660	2019-11-23 19:33:17.540593+03
9792	44	-1	500	2019-11-23 19:45:02.549634+03
9793	55	-1	3480	2019-11-23 20:18:53.368764+03
9794	32	-1	710	2019-11-23 20:28:26.684849+03
9795	64	-1	970	2019-11-23 20:29:13.854829+03
9796	83	-1	1230	2019-11-23 20:31:22.11206+03
9797	29	-1	1940	2019-11-23 20:31:32.716177+03
9798	51	-1	1310	2019-11-23 21:05:41.263334+03
9799	53	-1	3120	2019-11-23 21:30:18.691171+03
9800	48	-1	640	2019-11-23 21:44:18.68537+03
9801	39	-1	910	2019-11-23 22:06:55.927487+03
9802	55	-2	3480	2019-11-23 22:10:54.560126+03
9803	42	-1	1790	2019-11-23 22:31:51.097618+03
9804	71	-1	1030	2019-11-23 22:43:38.824181+03
9805	46	-2	1270	2019-11-23 23:00:53.874225+03
9806	67	-1	350	2019-11-23 23:08:01.494207+03
9807	88	-2	1270	2019-11-23 23:17:16.957309+03
9808	45	-1	1590	2019-11-23 23:38:18.153786+03
9809	23	-1	4390	2019-11-23 23:52:51.954633+03
9810	33	-1	900	2019-11-24 00:16:42.758656+03
9811	30	-1	1140	2019-11-24 00:20:34.352584+03
9812	70	-1	760	2019-11-24 00:38:12.39917+03
9813	9	-1	2090	2019-11-24 01:01:35.682963+03
9814	74	27	494	2019-11-24 01:36:53.525077+03
9815	61	-1	1510	2019-11-24 01:55:14.292462+03
9816	91	-1	1620	2019-11-24 02:36:13.295573+03
9817	29	-1	1940	2019-11-24 02:54:51.712607+03
9818	49	-1	970	2019-11-24 03:20:01.707806+03
9819	43	17	185	2019-11-24 04:23:13.0015+03
9820	31	-1	1190	2019-11-24 04:33:41.611472+03
9821	49	-1	970	2019-11-24 04:43:41.007039+03
9822	7	-1	810	2019-11-24 04:59:47.901932+03
9823	6	-1	980	2019-11-24 04:59:53.846143+03
9824	10	-1	2080	2019-11-24 05:08:14.306684+03
9825	60	-1	2700	2019-11-24 05:20:46.027173+03
9826	92	-1	630	2019-11-24 05:34:06.733895+03
9827	90	-2	1780	2019-11-24 05:42:34.547874+03
9828	22	-1	1070	2019-11-24 05:59:49.796254+03
9829	65	-2	490	2019-11-24 06:40:10.627569+03
9830	50	-2	1140	2019-11-24 06:50:03.833194+03
9831	74	-1	1010	2019-11-24 07:07:23.513703+03
9832	14	-1	1350	2019-11-24 07:30:28.042835+03
9833	33	-2	900	2019-11-24 07:41:22.237526+03
9834	12	-1	1650	2019-11-24 07:57:01.810193+03
9835	87	-2	2320	2019-11-24 08:07:04.882521+03
9836	89	-1	1420	2019-11-24 08:09:37.921544+03
9837	94	-2	1230	2019-11-24 08:47:16.17702+03
9838	21	-1	960	2019-11-24 08:55:20.693552+03
9839	95	-1	480	2019-11-24 08:55:35.981788+03
9840	46	-1	1270	2019-11-24 09:00:27.760857+03
9841	20	-1	830	2019-11-24 09:02:41.125807+03
9842	94	-1	1230	2019-11-24 09:03:59.748693+03
9843	22	-1	1070	2019-11-24 09:15:17.997266+03
9844	24	-2	950	2019-11-24 09:19:03.542404+03
9845	4	-1	1420	2019-11-24 09:19:56.289867+03
9846	13	-1	460	2019-11-24 09:52:46.334173+03
9847	8	-1	1920	2019-11-24 10:02:31.008547+03
9848	49	-1	970	2019-11-24 10:02:45.922158+03
9849	76	-1	1070	2019-11-24 10:24:50.839857+03
9850	96	-1	1570	2019-11-24 10:51:17.829464+03
9851	25	-1	1100	2019-11-24 11:32:47.644502+03
9852	10	-1	2080	2019-11-24 12:09:55.134889+03
9853	73	-1	960	2019-11-24 12:59:07.175274+03
9854	31	-1	1190	2019-11-24 13:42:08.695148+03
9855	87	31	1210	2019-11-24 13:47:00.876093+03
9856	13	-1	460	2019-11-24 14:03:07.803707+03
9857	56	-1	2460	2019-11-24 14:23:57.185158+03
9858	37	-2	1290	2019-11-24 14:31:42.238818+03
9859	28	-1	1860	2019-11-24 15:08:30.383891+03
9860	90	-1	1780	2019-11-24 15:10:17.058845+03
9861	31	-2	1190	2019-11-24 15:15:51.285293+03
9862	90	-1	1780	2019-11-24 15:24:56.831563+03
9863	5	-1	1620	2019-11-24 15:42:08.363476+03
9864	44	-1	500	2019-11-24 16:25:09.62941+03
9865	51	-1	1310	2019-11-24 16:39:26.451789+03
9866	54	-1	3470	2019-11-24 17:03:27.588792+03
9867	38	-1	1100	2019-11-24 17:19:49.191602+03
9868	82	-1	560	2019-11-24 17:41:28.376154+03
9869	42	-1	1790	2019-11-24 17:52:09.160209+03
9870	37	-1	1290	2019-11-24 18:26:44.08735+03
9871	23	-2	4390	2019-11-24 18:30:55.51282+03
9872	13	-1	460	2019-11-24 18:32:58.869614+03
9873	33	-1	900	2019-11-24 19:39:48.036215+03
9874	6	-1	980	2019-11-24 19:55:51.111849+03
9875	18	-1	910	2019-11-24 20:56:42.767278+03
9876	12	-1	1650	2019-11-24 21:18:09.688262+03
9877	23	-2	4390	2019-11-24 21:22:01.516045+03
9878	12	-1	1650	2019-11-24 21:22:06.920894+03
9879	81	-2	1620	2019-11-24 21:24:36.171338+03
9880	36	-2	630	2019-11-24 21:33:18.909408+03
9881	29	-1	1940	2019-11-24 21:37:35.870755+03
9882	53	26	1654	2019-11-24 21:46:51.428918+03
9883	20	30	440	2019-11-24 23:26:20.415669+03
9884	22	-2	1070	2019-11-24 23:27:44.729967+03
9885	73	-2	960	2019-11-24 23:35:15.454362+03
9886	21	-1	960	2019-11-24 23:39:58.990954+03
9887	56	-1	2460	2019-11-24 23:48:41.583616+03
9888	39	-1	910	2019-11-25 00:03:11.293012+03
9889	43	-2	380	2019-11-25 00:13:15.109863+03
9890	11	-1	830	2019-11-25 00:13:43.592299+03
9891	67	-2	350	2019-11-25 00:18:51.069953+03
9892	17	-1	1500	2019-11-25 00:29:12.955548+03
9893	6	-1	980	2019-11-25 00:34:01.826233+03
9894	49	-1	970	2019-11-25 00:36:22.633581+03
9895	19	-1	1220	2019-11-25 01:05:31.70533+03
9896	82	-2	560	2019-11-25 01:31:07.807096+03
9897	29	-1	1940	2019-11-25 01:47:47.165835+03
9898	71	-1	1030	2019-11-25 01:56:53.379201+03
9899	35	-2	670	2019-11-25 02:11:10.649697+03
9900	79	-1	550	2019-11-25 02:37:05.895944+03
9901	67	-1	350	2019-11-25 03:39:13.149378+03
9902	20	-2	830	2019-11-25 04:14:11.803602+03
9903	75	-1	830	2019-11-25 04:50:47.471185+03
9904	29	-1	1940	2019-11-25 05:00:11.878162+03
9905	22	-1	1070	2019-11-25 05:06:28.378526+03
9906	80	-1	1120	2019-11-25 05:24:46.07857+03
9907	29	-1	1940	2019-11-25 05:51:39.826859+03
9908	75	-1	830	2019-11-25 06:08:56.23033+03
9909	49	40	443	2019-11-25 06:09:20.990325+03
9910	79	-2	550	2019-11-25 06:16:30.863281+03
9911	10	-1	2080	2019-11-25 06:30:00.760649+03
9912	46	-2	1270	2019-11-25 06:31:52.188868+03
9913	34	-1	1550	2019-11-25 06:52:57.484452+03
9914	45	-2	1590	2019-11-25 07:09:08.151627+03
9915	46	-2	1270	2019-11-25 07:24:29.071991+03
9916	53	-1	3120	2019-11-25 07:42:46.2313+03
9917	94	-1	1230	2019-11-25 07:49:49.971441+03
9918	69	-1	1100	2019-11-25 09:01:01.403899+03
9919	55	-1	3480	2019-11-25 09:01:48.794278+03
9920	89	-1	1420	2019-11-25 09:32:51.830926+03
9921	71	-1	1030	2019-11-25 09:54:54.287287+03
9922	94	-2	1230	2019-11-25 10:24:05.400357+03
9923	69	-2	1100	2019-11-25 10:39:19.970818+03
9924	33	-1	900	2019-11-25 11:11:20.722538+03
9925	52	-2	1090	2019-11-25 11:17:44.604062+03
9926	39	-1	910	2019-11-25 11:34:42.778251+03
9927	79	-2	550	2019-11-25 11:38:32.786044+03
9928	4	-1	1420	2019-11-25 11:54:06.01331+03
9929	63	-1	1780	2019-11-25 12:05:55.397978+03
9930	49	-1	970	2019-11-25 12:21:00.965094+03
9931	75	-1	830	2019-11-25 13:05:14.409841+03
9932	64	-1	970	2019-11-25 13:06:03.539236+03
9933	4	-1	1420	2019-11-25 13:33:57.830452+03
9934	90	-1	1780	2019-11-25 13:47:11.460375+03
9935	14	-1	1350	2019-11-25 13:56:15.444689+03
9936	46	-1	1270	2019-11-25 14:02:19.473619+03
9937	42	-1	1790	2019-11-25 14:15:44.92652+03
9938	35	-1	670	2019-11-25 14:43:22.426636+03
9939	89	-1	1420	2019-11-25 14:52:41.640377+03
9940	46	-1	1270	2019-11-25 15:06:17.825578+03
9941	10	-1	2080	2019-11-25 15:11:39.295133+03
9942	40	-1	1430	2019-11-25 15:23:03.422328+03
9943	5	-1	1620	2019-11-25 15:29:14.769278+03
9944	87	-1	2320	2019-11-25 15:38:13.661805+03
9945	7	-1	810	2019-11-25 15:58:11.180909+03
9946	13	-1	460	2019-11-25 16:00:38.783494+03
9947	95	-1	480	2019-11-25 16:08:04.05381+03
9948	13	-1	460	2019-11-25 16:13:18.942363+03
9949	10	-1	2080	2019-11-25 16:31:26.92999+03
9950	17	-1	1500	2019-11-25 16:36:20.263508+03
9951	95	-2	480	2019-11-25 16:41:13.760873+03
9952	65	-1	490	2019-11-25 17:23:00.666264+03
9953	78	-1	900	2019-11-25 18:16:10.589434+03
9954	57	-1	1900	2019-11-25 18:34:41.05741+03
9955	95	-1	480	2019-11-25 18:41:58.014043+03
9956	35	-1	670	2019-11-25 18:45:24.602131+03
9957	72	-1	620	2019-11-25 18:48:38.796391+03
9958	10	-1	2080	2019-11-25 18:54:21.305087+03
9959	32	-1	710	2019-11-25 19:18:54.769097+03
9960	75	-1	830	2019-11-25 19:19:24.442702+03
9961	21	-1	960	2019-11-25 19:49:36.907846+03
9962	71	-2	1030	2019-11-25 19:51:19.448403+03
9963	80	-1	1120	2019-11-25 19:52:03.270369+03
9964	42	-2	1790	2019-11-25 19:59:08.350173+03
9965	19	-1	1220	2019-11-25 20:06:40.811238+03
9966	44	-2	500	2019-11-25 20:27:10.317942+03
9967	87	-1	2320	2019-11-25 20:32:55.017581+03
9968	87	-1	2320	2019-11-25 20:57:10.862174+03
9969	85	-1	730	2019-11-25 21:03:24.881235+03
9970	8	-1	1920	2019-11-25 21:06:54.475357+03
9971	1	-1	640	2019-11-25 21:21:01.725155+03
9972	70	-2	760	2019-11-25 21:28:17.100557+03
9973	7	-1	810	2019-11-25 21:32:10.300914+03
9974	89	-1	1420	2019-11-25 21:33:55.871444+03
9975	55	-1	3480	2019-11-25 22:01:03.505272+03
9976	78	-1	900	2019-11-25 22:11:16.309823+03
9977	10	-1	2080	2019-11-25 22:14:48.479705+03
9978	92	-1	630	2019-11-25 22:20:22.235847+03
9979	75	-1	830	2019-11-25 22:53:25.953649+03
9980	59	-1	1030	2019-11-25 23:39:47.529133+03
9981	49	-1	970	2019-11-25 23:42:08.413973+03
9982	42	-1	1790	2019-11-25 23:43:07.497748+03
9983	40	-1	1430	2019-11-25 23:53:05.253901+03
9984	7	-1	810	2019-11-26 00:00:42.286257+03
9985	57	-1	1900	2019-11-26 00:09:14.965321+03
9986	49	-1	970	2019-11-26 00:43:22.127446+03
9987	87	-2	2320	2019-11-26 00:54:41.797672+03
9988	46	-1	1270	2019-11-26 01:12:41.525262+03
9989	7	-1	810	2019-11-26 01:35:24.733192+03
9990	52	-1	1090	2019-11-26 02:23:53.67328+03
9991	50	-1	1140	2019-11-26 02:25:24.044136+03
9992	7	-1	810	2019-11-26 02:49:26.469562+03
9993	67	-1	350	2019-11-26 02:58:26.354973+03
9994	4	-2	1420	2019-11-26 03:00:03.98523+03
9995	19	-1	1220	2019-11-26 03:18:21.824129+03
9996	67	-2	350	2019-11-26 03:23:17.272472+03
9997	64	-1	970	2019-11-26 03:34:11.063485+03
9998	27	-1	880	2019-11-26 03:38:01.360451+03
9999	39	-1	910	2019-11-26 03:50:08.342009+03
10000	17	-1	1500	2019-11-26 03:54:04.540302+03
10001	48	-1	640	2019-11-26 04:07:55.925843+03
10002	21	-2	960	2019-11-26 04:23:12.204713+03
10003	73	-1	960	2019-11-26 04:56:01.410421+03
10004	49	-1	970	2019-11-26 05:22:53.278306+03
10005	56	-1	2460	2019-11-26 05:31:52.831147+03
10006	86	-1	910	2019-11-26 05:36:51.546571+03
10007	22	-1	1070	2019-11-26 05:37:54.618445+03
10008	8	-2	1920	2019-11-26 05:45:52.378843+03
10009	20	-1	830	2019-11-26 05:49:16.605619+03
10010	58	-1	2830	2019-11-26 06:00:24.023456+03
10011	95	-1	480	2019-11-26 06:07:25.357113+03
10012	61	-1	1510	2019-11-26 06:18:57.329245+03
10013	10	-2	2080	2019-11-26 06:30:11.227471+03
10014	47	-1	1480	2019-11-26 06:41:12.433066+03
10015	2	17	281	2019-11-26 06:56:45.322254+03
10016	42	-1	1790	2019-11-26 06:56:46.74071+03
10017	29	-1	1940	2019-11-26 07:10:18.747474+03
10018	73	-1	960	2019-11-26 07:17:08.808296+03
10019	46	-1	1270	2019-11-26 07:17:30.413169+03
10020	41	-1	830	2019-11-26 07:20:16.676522+03
10021	77	-1	640	2019-11-26 08:03:36.764807+03
10022	12	-2	1650	2019-11-26 08:05:25.903878+03
10023	84	-1	2700	2019-11-26 08:06:32.305724+03
10024	91	20	720	2019-11-26 08:24:54.047222+03
10025	37	-2	1290	2019-11-26 08:42:03.410272+03
10026	77	-1	640	2019-11-26 08:57:37.067068+03
10027	92	-1	630	2019-11-26 09:12:41.549666+03
10028	89	-1	1420	2019-11-26 09:20:12.344475+03
10029	1	-1	640	2019-11-26 09:21:57.817686+03
10030	80	-1	1120	2019-11-26 09:56:20.235872+03
10031	47	-1	1480	2019-11-26 10:05:48.904107+03
10032	49	-1	970	2019-11-26 10:06:53.959698+03
10033	47	-1	1480	2019-11-26 10:26:05.609007+03
10034	17	-1	1500	2019-11-26 10:42:22.001092+03
10035	75	-1	830	2019-11-26 10:43:03.389755+03
10036	44	-2	500	2019-11-26 10:49:12.306919+03
10037	39	25	545	2019-11-26 10:51:06.369529+03
10038	52	-1	1090	2019-11-26 10:51:12.64215+03
10039	78	-1	900	2019-11-26 11:02:56.62854+03
10040	78	-1	900	2019-11-26 11:13:07.62952+03
10041	53	-1	3120	2019-11-26 11:34:06.133351+03
10042	62	-1	1220	2019-11-26 11:53:37.793542+03
10043	42	-1	1790	2019-11-26 11:55:47.393107+03
10044	36	-1	630	2019-11-26 12:16:44.760761+03
10045	65	-1	490	2019-11-26 13:19:14.113234+03
10046	45	-2	1590	2019-11-26 13:28:12.162447+03
10047	79	-2	550	2019-11-26 13:48:54.137265+03
10048	85	-1	730	2019-11-26 13:56:20.637776+03
10049	7	-2	810	2019-11-26 14:15:41.125602+03
10050	31	-1	1190	2019-11-26 14:27:41.091746+03
10051	55	28	1632	2019-11-26 14:33:52.595849+03
10052	40	-2	1430	2019-11-26 14:45:23.08784+03
10053	12	-1	1650	2019-11-26 15:18:38.608645+03
10054	84	-1	2700	2019-11-26 15:20:01.889761+03
10055	96	-1	1570	2019-11-26 15:42:03.374446+03
10056	88	-1	1270	2019-11-26 16:00:57.868938+03
10057	96	-1	1570	2019-11-26 16:13:10.034471+03
10058	74	-2	1010	2019-11-26 16:14:45.251834+03
10059	51	-1	1310	2019-11-26 16:14:57.898539+03
10060	34	-1	1550	2019-11-26 16:24:38.518016+03
10061	49	-1	970	2019-11-26 16:50:42.061598+03
10062	6	-1	980	2019-11-26 17:11:16.394222+03
10063	63	-2	1780	2019-11-26 17:15:14.081324+03
10064	96	-1	1570	2019-11-26 17:20:24.594056+03
10065	26	-1	390	2019-11-26 17:29:56.295731+03
10066	76	-1	1070	2019-11-26 17:51:03.197165+03
10067	5	32	731	2019-11-26 17:55:13.265566+03
10068	37	-1	1290	2019-11-26 18:03:04.332898+03
10069	85	-1	730	2019-11-26 18:11:47.025426+03
10070	39	-1	910	2019-11-26 18:48:35.450312+03
10071	13	-2	460	2019-11-26 18:51:20.704644+03
10072	63	-1	1780	2019-11-26 19:12:49.104944+03
10073	71	-1	1030	2019-11-26 19:16:12.840923+03
10074	89	-1	1420	2019-11-26 19:24:06.81123+03
10075	46	-1	1270	2019-11-26 19:31:28.382851+03
10076	69	-1	1100	2019-11-26 19:47:27.912253+03
10077	5	-1	1620	2019-11-26 19:56:00.140414+03
10078	38	-1	1100	2019-11-26 19:56:58.788318+03
10079	68	-1	490	2019-11-26 20:15:10.794343+03
10080	38	-1	1100	2019-11-26 20:19:41.974399+03
10081	89	-1	1420	2019-11-26 20:20:53.873799+03
10082	67	-1	350	2019-11-26 20:42:19.374506+03
10083	95	-2	480	2019-11-26 20:48:52.313838+03
10084	56	-1	2460	2019-11-26 21:16:10.977988+03
10085	33	-1	900	2019-11-26 21:54:07.273077+03
10086	6	-1	980	2019-11-26 21:54:36.529019+03
10087	1	-1	640	2019-11-26 22:40:07.823936+03
10088	5	-1	1620	2019-11-26 22:41:37.563317+03
10089	8	-1	1920	2019-11-26 22:50:34.545959+03
10090	52	-1	1090	2019-11-26 22:54:47.031549+03
10091	84	-2	2700	2019-11-26 23:11:26.479963+03
10092	4	-2	1420	2019-11-26 23:30:26.890827+03
10093	48	-1	640	2019-11-27 00:17:30.026425+03
10094	13	-1	460	2019-11-27 00:19:16.792372+03
10095	42	-1	1790	2019-11-27 00:22:40.150493+03
10096	53	-1	3120	2019-11-27 00:26:57.355939+03
10097	90	-1	1780	2019-11-27 01:10:54.375004+03
10098	57	-1	1900	2019-11-27 01:39:20.752865+03
10099	31	-1	1190	2019-11-27 01:57:05.26479+03
10100	83	-1	1230	2019-11-27 02:02:25.761202+03
10101	44	-1	500	2019-11-27 02:15:08.431206+03
10102	38	-1	1100	2019-11-27 02:18:22.016287+03
10103	55	-1	3480	2019-11-27 02:26:59.566159+03
10104	5	-1	1620	2019-11-27 02:53:39.852201+03
10105	46	-2	1270	2019-11-27 02:56:30.542147+03
10106	67	-1	350	2019-11-27 03:21:15.121228+03
10107	67	-1	350	2019-11-27 03:45:35.538151+03
10108	41	-1	830	2019-11-27 04:20:37.191297+03
10109	39	-1	910	2019-11-27 04:35:00.219113+03
10110	46	-1	1270	2019-11-27 04:45:57.227855+03
10111	87	-1	2320	2019-11-27 04:47:41.59677+03
10112	33	-2	900	2019-11-27 04:49:43.973746+03
10113	7	-1	810	2019-11-27 05:18:40.376601+03
10114	23	-2	4390	2019-11-27 05:46:06.925719+03
10115	48	-1	640	2019-11-27 06:06:51.600216+03
10116	76	-1	1070	2019-11-27 06:29:08.11934+03
10117	71	-1	1030	2019-11-27 06:30:46.378675+03
10118	78	-1	900	2019-11-27 07:15:29.3571+03
10119	56	-1	2460	2019-11-27 07:29:59.233308+03
10120	46	-1	1270	2019-11-27 07:52:03.33344+03
10121	30	-1	1140	2019-11-27 07:52:27.514325+03
10122	46	-1	1270	2019-11-27 08:10:50.396487+03
10123	39	-2	910	2019-11-27 08:35:14.312572+03
10124	8	-1	1920	2019-11-27 08:50:50.271383+03
10125	58	-1	2830	2019-11-27 09:06:02.216848+03
10126	35	-1	670	2019-11-27 09:10:32.903952+03
10127	58	-2	2830	2019-11-27 09:13:11.935981+03
10128	70	-2	760	2019-11-27 10:18:16.048839+03
10129	93	-1	1620	2019-11-27 10:21:50.229682+03
10130	20	-1	830	2019-11-27 10:32:58.873952+03
10131	80	-1	1120	2019-11-27 10:34:11.40288+03
10132	27	-1	880	2019-11-27 10:45:14.319841+03
10133	36	-2	630	2019-11-27 10:47:03.277346+03
10134	81	-1	1620	2019-11-27 10:48:10.108019+03
10135	94	-1	1230	2019-11-27 10:57:44.487984+03
10136	9	-1	2090	2019-11-27 11:09:35.511469+03
10137	52	-2	1090	2019-11-27 11:40:09.41846+03
10138	90	-2	1780	2019-11-27 11:50:50.023911+03
10139	21	-1	960	2019-11-27 11:51:31.267151+03
10140	80	-1	1120	2019-11-27 11:57:42.401378+03
10141	42	-2	1790	2019-11-27 12:01:50.078427+03
10142	63	-1	1780	2019-11-27 12:15:14.735997+03
10143	72	-1	620	2019-11-27 12:22:39.430212+03
10144	83	-1	1230	2019-11-27 12:34:29.753975+03
10145	17	-1	1500	2019-11-27 12:36:48.002571+03
10146	4	-1	1420	2019-11-27 12:43:34.200045+03
10147	8	-1	1920	2019-11-27 12:48:49.369768+03
10148	53	-1	3120	2019-11-27 13:12:42.587572+03
10149	69	-1	1100	2019-11-27 13:26:06.588157+03
10150	69	-1	1100	2019-11-27 13:55:00.360945+03
10151	17	-1	1500	2019-11-27 13:58:56.792141+03
10152	18	-1	910	2019-11-27 14:05:21.333759+03
10153	70	-2	760	2019-11-27 14:13:16.223642+03
10154	54	-1	3470	2019-11-27 14:50:46.484214+03
10155	25	-1	1100	2019-11-27 14:53:54.06649+03
10156	82	-1	560	2019-11-27 15:06:17.126543+03
10157	88	-1	1270	2019-11-27 15:13:53.447963+03
10158	36	-1	630	2019-11-27 15:51:24.40744+03
10159	13	-3	460	2019-11-27 16:10:13.058863+03
10160	61	-1	1510	2019-11-27 16:12:24.946739+03
10161	2	-1	470	2019-11-27 16:18:34.241797+03
10162	67	-1	350	2019-11-27 16:28:03.248168+03
10163	43	-1	380	2019-11-27 16:34:17.179694+03
10164	14	-2	1350	2019-11-27 17:15:20.430833+03
10165	24	-1	950	2019-11-27 17:18:48.624296+03
10166	40	-1	1430	2019-11-27 17:30:45.920144+03
10167	12	-1	1650	2019-11-27 17:48:33.076982+03
10168	82	20	291	2019-11-27 17:50:37.15702+03
10169	45	-1	1590	2019-11-27 17:54:23.379452+03
10170	7	-1	810	2019-11-27 18:14:05.156528+03
10171	64	-1	970	2019-11-27 18:37:07.341686+03
10172	81	-1	1620	2019-11-27 18:47:52.700027+03
10173	12	-1	1650	2019-11-27 18:51:05.388701+03
10174	90	-1	1780	2019-11-27 19:23:59.626419+03
10175	70	-1	760	2019-11-27 19:40:26.872635+03
10176	54	-1	3470	2019-11-27 20:23:56.67194+03
10177	91	-3	1620	2019-11-27 21:13:31.767092+03
10178	20	-1	830	2019-11-27 21:17:35.440611+03
10179	44	-2	500	2019-11-27 21:18:09.906561+03
10180	42	-1	1790	2019-11-27 21:34:23.309153+03
10181	48	-1	640	2019-11-27 21:53:35.095267+03
10182	81	-1	1620	2019-11-27 22:02:26.798637+03
10183	90	35	1052	2019-11-27 22:22:41.470451+03
10184	95	-1	480	2019-11-27 22:41:56.350917+03
10185	81	-2	1620	2019-11-27 23:48:30.916694+03
10186	26	-1	390	2019-11-28 00:15:59.530566+03
10187	64	-2	970	2019-11-28 00:32:23.291495+03
10188	47	-2	1480	2019-11-28 00:55:46.571857+03
10189	4	-2	1420	2019-11-28 00:55:49.126127+03
10190	53	-2	3120	2019-11-28 01:05:38.855196+03
10191	6	-1	980	2019-11-28 01:28:08.404564+03
10192	39	-1	910	2019-11-28 01:43:37.64936+03
10193	23	25	2059	2019-11-28 01:44:37.879704+03
10194	28	-1	1860	2019-11-28 01:48:05.576396+03
10195	49	-2	970	2019-11-28 02:02:58.865585+03
10196	27	-2	880	2019-11-28 02:11:21.169478+03
10197	77	-1	640	2019-11-28 02:40:59.241353+03
10198	81	-1	1620	2019-11-28 03:21:39.073161+03
10199	40	-2	1430	2019-11-28 04:05:02.832702+03
10200	95	-1	480	2019-11-28 04:13:48.893719+03
10201	27	-1	880	2019-11-28 04:16:05.573687+03
10202	67	-1	350	2019-11-28 04:39:36.711108+03
10203	45	-1	1590	2019-11-28 04:48:05.383215+03
10204	79	-1	550	2019-11-28 04:49:24.18971+03
10205	59	-1	1030	2019-11-28 05:02:14.849674+03
10206	30	-1	1140	2019-11-28 05:17:35.835775+03
10207	45	-1	1590	2019-11-28 05:26:57.378684+03
10208	73	-1	960	2019-11-28 05:27:49.907211+03
10209	30	-1	1140	2019-11-28 05:38:08.967823+03
10210	23	-1	4390	2019-11-28 06:07:33.642634+03
10211	93	-2	1620	2019-11-28 06:07:34.462704+03
10212	60	-1	2700	2019-11-28 06:17:57.634555+03
10213	14	-1	1350	2019-11-28 06:24:42.688979+03
10214	95	-1	480	2019-11-28 06:59:04.559597+03
10215	27	-2	880	2019-11-28 07:17:15.320262+03
10216	39	-2	910	2019-11-28 07:43:36.47587+03
10217	3	-1	660	2019-11-28 07:44:06.269068+03
10218	4	-2	1420	2019-11-28 08:01:54.570401+03
10219	22	-2	1070	2019-11-28 08:04:07.335235+03
10220	8	-1	1920	2019-11-28 08:23:48.144363+03
10221	77	-1	640	2019-11-28 08:40:53.220997+03
10222	10	-2	2080	2019-11-28 08:54:16.36698+03
10223	86	-1	910	2019-11-28 09:07:39.999546+03
10224	89	-1	1420	2019-11-28 09:11:29.027756+03
10225	56	-1	2460	2019-11-28 09:28:38.647594+03
10226	26	-1	390	2019-11-28 09:45:40.215354+03
10227	52	-1	1090	2019-11-28 10:12:50.844919+03
10228	81	-2	1620	2019-11-28 10:19:35.600769+03
10229	84	-1	2700	2019-11-28 10:20:02.232332+03
10230	83	-1	1230	2019-11-28 10:20:56.647454+03
10231	13	-1	460	2019-11-28 10:35:45.628946+03
10232	47	-1	1480	2019-11-28 10:43:12.52603+03
10233	47	-1	1480	2019-11-28 11:34:51.440107+03
10234	89	-1	1420	2019-11-28 11:42:26.047808+03
10235	4	-1	1420	2019-11-28 12:22:44.534157+03
10236	39	-2	910	2019-11-28 12:33:26.486284+03
10237	96	32	632	2019-11-28 12:38:59.734524+03
10238	22	34	587	2019-11-28 13:30:02.77819+03
10239	76	-2	1070	2019-11-28 13:38:09.618046+03
10240	63	-1	1780	2019-11-28 13:38:48.939784+03
10241	21	-1	960	2019-11-28 13:40:00.176908+03
10242	6	-1	980	2019-11-28 14:45:02.852707+03
10243	61	-1	1510	2019-11-28 14:46:36.180583+03
10244	52	-1	1090	2019-11-28 14:57:49.121703+03
10245	67	-1	350	2019-11-28 15:05:20.471149+03
10246	94	-1	1230	2019-11-28 15:38:13.282182+03
10247	42	-2	1790	2019-11-28 16:14:53.323114+03
10248	14	-1	1350	2019-11-28 17:15:51.100149+03
10249	65	-1	490	2019-11-28 17:27:29.737434+03
10250	22	-1	1070	2019-11-28 17:52:53.681137+03
10251	84	-1	2700	2019-11-28 18:02:48.149153+03
10252	6	-1	980	2019-11-28 18:08:42.198042+03
10253	11	-1	830	2019-11-28 18:19:56.149229+03
10254	50	-1	1140	2019-11-28 18:21:57.937218+03
10255	95	-1	480	2019-11-28 18:26:47.977784+03
10256	23	-1	4390	2019-11-28 18:42:35.74924+03
10257	95	28	266	2019-11-28 18:49:58.612804+03
10258	40	-1	1430	2019-11-28 18:58:14.783638+03
10259	46	-2	1270	2019-11-28 19:00:04.215964+03
10260	10	-1	2080	2019-11-28 19:07:41.779138+03
10261	22	-1	1070	2019-11-28 19:33:13.831341+03
10262	47	-1	1480	2019-11-28 19:47:59.427609+03
10263	51	-1	1310	2019-11-28 19:56:29.466207+03
10264	39	-1	910	2019-11-28 20:12:09.47373+03
10265	55	-2	3480	2019-11-28 20:19:41.659404+03
10266	21	-1	960	2019-11-28 20:32:24.161221+03
10267	69	-1	1100	2019-11-28 20:41:30.20244+03
10268	48	-1	640	2019-11-28 20:50:52.063945+03
10269	39	-2	910	2019-11-28 21:08:17.813157+03
10270	70	26	345	2019-11-28 21:20:36.063608+03
10271	88	-1	1270	2019-11-28 21:51:20.120794+03
10272	4	-1	1420	2019-11-28 22:27:41.079207+03
10273	47	-1	1480	2019-11-28 22:57:36.951843+03
10274	57	-1	1900	2019-11-28 23:00:46.178422+03
10275	5	-1	1620	2019-11-28 23:06:29.150816+03
10276	31	-1	1190	2019-11-28 23:12:09.573572+03
10277	92	-1	630	2019-11-28 23:23:12.724023+03
10278	32	-1	710	2019-11-28 23:24:32.026157+03
10279	10	-1	2080	2019-11-28 23:56:49.348859+03
10280	36	-2	630	2019-11-29 00:12:51.287506+03
10281	2	-1	470	2019-11-29 00:20:44.57071+03
10282	88	-2	1270	2019-11-29 01:05:49.140506+03
10283	69	-1	1100	2019-11-29 01:46:39.332309+03
10284	71	-2	1030	2019-11-29 02:01:03.582787+03
10285	62	-1	1220	2019-11-29 02:40:01.207038+03
10286	44	-2	500	2019-11-29 03:10:55.609503+03
10287	4	-1	1420	2019-11-29 03:27:59.135595+03
10288	62	-1	1220	2019-11-29 03:32:05.805564+03
10289	67	-1	350	2019-11-29 03:40:01.664817+03
10290	6	-1	980	2019-11-29 03:40:37.027481+03
10291	74	-1	1010	2019-11-29 03:43:50.039744+03
10292	86	-2	910	2019-11-29 03:53:22.352098+03
10293	54	-2	3470	2019-11-29 04:17:23.009775+03
10294	22	-1	1070	2019-11-29 04:28:05.303301+03
10295	35	-1	670	2019-11-29 04:28:33.654872+03
10296	45	-1	1590	2019-11-29 04:48:05.231199+03
10297	86	-1	910	2019-11-29 04:53:32.097216+03
10298	30	-1	1140	2019-11-29 05:25:17.302277+03
10299	38	-1	1100	2019-11-29 05:33:53.773147+03
10300	7	-2	810	2019-11-29 05:57:02.414782+03
10301	74	-2	1010	2019-11-29 05:57:53.869416+03
10302	34	-1	1550	2019-11-29 06:49:56.150367+03
10303	23	-1	4390	2019-11-29 06:59:26.470969+03
10304	43	-1	380	2019-11-29 07:20:38.354451+03
10305	30	-1	1140	2019-11-29 07:30:19.287426+03
10306	83	-2	1230	2019-11-29 07:34:12.252515+03
10307	14	-1	1350	2019-11-29 07:59:09.019716+03
10308	29	-1	1940	2019-11-29 07:59:43.739283+03
10309	69	-1	1100	2019-11-29 08:26:38.725548+03
10310	1	-1	640	2019-11-29 08:41:23.781305+03
10311	17	-2	1500	2019-11-29 08:52:07.319271+03
10312	41	-1	830	2019-11-29 09:25:34.340198+03
10313	91	-1	1620	2019-11-29 09:34:10.258977+03
10314	20	-1	830	2019-11-29 10:03:28.090655+03
10315	53	-1	3120	2019-11-29 10:05:14.697424+03
10316	93	-1	1620	2019-11-29 10:13:25.323503+03
10317	1	-1	640	2019-11-29 10:52:57.293408+03
10318	31	-1	1190	2019-11-29 10:58:11.166942+03
10319	68	-1	490	2019-11-29 11:27:27.378815+03
10320	13	-1	460	2019-11-29 11:33:49.772878+03
10321	5	-1	1620	2019-11-29 11:50:25.944875+03
10322	93	-2	1620	2019-11-29 12:03:28.710244+03
10323	13	-1	460	2019-11-29 12:38:03.016176+03
10324	33	-1	900	2019-11-29 12:54:28.631245+03
10325	73	26	564	2019-11-29 13:01:36.415641+03
10326	51	-2	1310	2019-11-29 13:20:11.078497+03
10327	80	-1	1120	2019-11-29 13:39:17.107308+03
10328	87	-1	2320	2019-11-29 13:49:46.139351+03
10329	3	-1	660	2019-11-29 14:06:40.738619+03
10330	87	-1	2320	2019-11-29 14:54:48.822192+03
10331	26	-2	390	2019-11-29 15:02:57.099863+03
10332	79	-2	550	2019-11-29 15:10:40.517965+03
10333	68	-2	490	2019-11-29 15:17:53.998792+03
10334	12	-1	1650	2019-11-29 15:32:47.944929+03
10335	88	-1	1270	2019-11-29 15:47:47.522445+03
10336	40	-1	1430	2019-11-29 15:53:11.534981+03
10337	59	-1	1030	2019-11-29 16:02:48.069768+03
10338	27	-1	880	2019-11-29 16:22:01.861948+03
10339	44	-3	500	2019-11-29 16:22:44.109409+03
10340	28	-1	1860	2019-11-29 16:30:56.825596+03
10341	93	-1	1620	2019-11-29 16:53:52.124925+03
10342	83	-1	1230	2019-11-29 17:23:18.700968+03
10343	83	-1	1230	2019-11-29 17:33:00.899674+03
10344	47	-1	1480	2019-11-29 18:05:55.186295+03
10345	22	-2	1070	2019-11-29 18:08:20.485427+03
10346	55	-1	3480	2019-11-29 18:20:29.535459+03
10347	7	-1	810	2019-11-29 18:41:46.289009+03
10348	74	-1	1010	2019-11-29 20:03:02.651545+03
10349	3	-1	660	2019-11-29 20:21:52.43276+03
10350	26	-1	390	2019-11-29 20:55:39.382087+03
10351	69	-1	1100	2019-11-29 21:52:02.55025+03
10352	13	41	216	2019-11-29 21:54:02.079602+03
10353	30	-1	1140	2019-11-29 22:16:59.188215+03
10354	36	-1	630	2019-11-29 22:17:19.02237+03
10355	95	-2	480	2019-11-29 23:33:37.670536+03
10356	49	-2	970	2019-11-29 23:41:59.822763+03
10357	52	-1	1090	2019-11-29 23:52:46.927605+03
10358	86	-1	910	2019-11-29 23:59:42.850064+03
10359	43	-1	380	2019-11-30 00:04:11.584793+03
10360	32	-1	710	2019-11-30 00:04:55.343466+03
10361	47	-1	1480	2019-11-30 00:30:38.416466+03
10362	22	-1	1070	2019-11-30 00:40:01.294017+03
10363	87	-1	2320	2019-11-30 00:48:57.175062+03
10364	26	-1	390	2019-11-30 01:11:37.54746+03
10365	57	-1	1900	2019-11-30 01:25:55.242876+03
10366	91	-1	1620	2019-11-30 01:29:11.06536+03
10367	18	-2	910	2019-11-30 01:52:52.410671+03
10368	20	-1	830	2019-11-30 02:19:05.398557+03
10369	47	-1	1480	2019-11-30 02:33:45.869796+03
10370	74	-1	1010	2019-11-30 02:47:01.510265+03
10371	14	-1	1350	2019-11-30 03:07:32.20504+03
10372	18	-2	910	2019-11-30 03:08:50.396795+03
10373	3	-1	660	2019-11-30 03:12:17.854663+03
10374	91	-1	1620	2019-11-30 03:31:39.168116+03
10375	29	-1	1940	2019-11-30 03:39:31.214107+03
10376	1	-1	640	2019-11-30 03:46:58.151743+03
10377	30	-1	1140	2019-11-30 03:47:32.227659+03
10378	17	-1	1500	2019-11-30 04:16:40.779006+03
10379	21	-1	960	2019-11-30 04:59:09.524394+03
10380	14	-2	1350	2019-11-30 05:06:46.016052+03
10381	93	-1	1620	2019-11-30 05:09:43.552813+03
10382	90	-1	1780	2019-11-30 05:09:55.295377+03
10383	75	-1	830	2019-11-30 05:41:44.735079+03
10384	20	-2	830	2019-11-30 05:43:05.370597+03
10385	69	-2	1100	2019-11-30 05:51:45.01457+03
10386	8	-3	1920	2019-11-30 06:50:19.738842+03
10387	60	-1	2700	2019-11-30 07:04:38.910688+03
10388	40	-1	1430	2019-11-30 07:05:12.220258+03
10389	47	-1	1480	2019-11-30 07:33:33.15917+03
10390	18	-1	910	2019-11-30 07:39:51.63487+03
10391	78	-1	900	2019-11-30 08:10:02.59544+03
10392	55	-2	3480	2019-11-30 08:28:47.03171+03
10393	22	-1	1070	2019-11-30 08:34:03.878459+03
10394	64	-1	970	2019-11-30 08:40:22.257982+03
10395	69	-1	1100	2019-11-30 09:15:05.748005+03
10396	36	-1	630	2019-11-30 09:21:04.048449+03
10397	32	-1	710	2019-11-30 09:23:34.726008+03
10398	75	-1	830	2019-11-30 09:43:10.42675+03
10399	45	-1	1590	2019-11-30 10:12:19.960278+03
10400	47	-1	1480	2019-11-30 10:25:43.2388+03
10401	63	-1	1780	2019-11-30 10:26:34.375635+03
10402	88	-1	1270	2019-11-30 10:31:06.509557+03
10403	35	-1	670	2019-11-30 11:26:05.090624+03
10404	71	-1	1030	2019-11-30 11:33:24.741422+03
10405	13	-1	460	2019-11-30 11:59:24.791235+03
10406	40	-2	1430	2019-11-30 12:10:36.550173+03
10407	6	-1	980	2019-11-30 12:41:51.998694+03
10408	75	-1	830	2019-11-30 13:27:25.91601+03
10409	19	-1	1220	2019-11-30 13:31:56.446116+03
10410	90	-1	1780	2019-11-30 13:56:47.755599+03
10411	4	-1	1420	2019-11-30 14:17:20.600779+03
10412	43	-1	380	2019-11-30 14:18:52.642003+03
10413	88	-1	1270	2019-11-30 14:26:38.509895+03
10414	22	-1	1070	2019-11-30 14:43:09.52649+03
10415	84	-1	2700	2019-11-30 14:55:41.636816+03
10416	65	-1	490	2019-11-30 15:05:10.594476+03
10417	60	-1	2700	2019-11-30 15:12:40.316592+03
10418	86	-1	910	2019-11-30 15:16:51.575288+03
10419	56	25	1444	2019-11-30 15:38:38.822106+03
10420	12	-1	1650	2019-11-30 15:50:29.992371+03
10421	49	-1	970	2019-11-30 16:39:22.337301+03
10422	50	-1	1140	2019-11-30 17:07:29.996682+03
10423	63	-1	1780	2019-11-30 17:08:51.899284+03
10424	81	-1	1620	2019-11-30 17:11:09.659136+03
10425	96	-1	1570	2019-11-30 18:03:41.467829+03
10426	83	-1	1230	2019-11-30 18:04:46.837813+03
10427	77	-1	640	2019-11-30 18:05:49.867286+03
10428	39	-1	910	2019-11-30 18:08:46.662204+03
10429	86	-2	910	2019-11-30 18:10:53.111379+03
10430	79	-1	550	2019-11-30 18:40:11.16624+03
10431	19	-1	1220	2019-11-30 18:46:34.35086+03
10432	95	-1	480	2019-11-30 18:48:47.35601+03
10433	55	-1	3480	2019-11-30 19:05:52.10289+03
10434	8	-1	1920	2019-11-30 19:14:42.54572+03
10435	19	-1	1220	2019-11-30 19:33:24.002961+03
10436	93	-1	1620	2019-11-30 19:34:40.589425+03
10437	80	-1	1120	2019-11-30 19:39:12.876515+03
10438	61	-2	1510	2019-11-30 20:01:00.251931+03
10439	4	-1	1420	2019-11-30 20:06:11.401319+03
10440	29	-1	1940	2019-11-30 20:23:12.713107+03
10441	38	-1	1100	2019-11-30 20:25:57.489609+03
10442	43	-1	380	2019-11-30 21:06:26.32893+03
10443	10	-1	2080	2019-11-30 21:14:35.356734+03
10444	70	-1	760	2019-11-30 21:16:15.66214+03
10445	68	-1	490	2019-11-30 21:44:19.718125+03
10446	40	-1	1430	2019-11-30 22:00:16.598174+03
10447	49	-1	970	2019-11-30 22:06:10.118093+03
10448	65	-1	490	2019-11-30 22:10:29.079146+03
10449	15	-2	2830	2019-11-30 22:11:52.938975+03
10450	83	-1	1230	2019-11-30 22:37:28.194656+03
10451	91	-1	1620	2019-11-30 23:27:58.227955+03
10452	26	-1	390	2019-11-30 23:29:25.353557+03
10453	55	-1	3480	2019-11-30 23:33:50.939553+03
10454	56	-2	2460	2019-12-01 00:00:51.119245+03
10455	47	-1	1480	2019-12-01 00:31:19.350582+03
10456	85	23	416	2019-12-01 00:45:26.56456+03
10457	88	-1	1270	2019-12-01 00:50:59.226018+03
10458	48	-2	640	2019-12-01 00:59:21.551356+03
10459	29	-2	1940	2019-12-01 01:17:42.903767+03
10460	33	-2	900	2019-12-01 01:36:34.142628+03
10461	51	-2	1310	2019-12-01 02:20:04.693958+03
10462	59	23	557	2019-12-01 02:20:56.640438+03
10463	14	-1	1350	2019-12-01 02:37:21.685615+03
10464	67	-2	350	2019-12-01 03:10:59.703789+03
10465	82	-1	560	2019-12-01 03:14:53.837976+03
10466	10	-1	2080	2019-12-01 03:42:30.046799+03
10467	24	-1	950	2019-12-01 04:08:32.411628+03
10468	63	-1	1780	2019-12-01 04:15:00.909937+03
10469	52	-1	1090	2019-12-01 04:26:20.636765+03
10470	89	-1	1420	2019-12-01 04:36:23.366459+03
10471	9	-1	2090	2019-12-01 05:07:41.713292+03
10472	27	-1	880	2019-12-01 05:08:47.126491+03
10473	96	-2	1570	2019-12-01 05:11:46.25411+03
10474	56	-1	2460	2019-12-01 05:28:21.786541+03
10475	49	-2	970	2019-12-01 05:45:28.593025+03
10476	29	-1	1940	2019-12-01 05:45:34.859751+03
10477	56	-1	2460	2019-12-01 06:04:50.618443+03
10478	44	21	222	2019-12-01 06:09:51.972826+03
10479	19	-1	1220	2019-12-01 06:39:38.017263+03
10480	47	-1	1480	2019-12-01 06:43:02.616535+03
10481	64	-1	970	2019-12-01 07:10:36.813477+03
10482	95	-1	480	2019-12-01 07:16:10.544425+03
10483	63	-1	1780	2019-12-01 07:16:13.838853+03
10484	46	-1	1270	2019-12-01 07:16:28.97789+03
10485	70	-1	760	2019-12-01 07:23:33.769629+03
10486	4	-1	1420	2019-12-01 07:25:03.289827+03
10487	20	-1	830	2019-12-01 07:30:17.388081+03
10488	92	-1	630	2019-12-01 07:52:01.749848+03
10489	41	-1	830	2019-12-01 08:01:14.755951+03
10490	32	-1	710	2019-12-01 08:26:07.432417+03
10491	82	-1	560	2019-12-01 08:51:42.238407+03
10492	36	-1	630	2019-12-01 09:03:54.231563+03
10493	81	-1	1620	2019-12-01 09:51:13.97105+03
10494	82	-1	560	2019-12-01 10:00:03.204295+03
10495	39	-2	910	2019-12-01 10:16:06.518264+03
10496	81	-1	1620	2019-12-01 10:32:48.409493+03
10497	57	-1	1900	2019-12-01 10:39:43.499986+03
10498	76	-2	1070	2019-12-01 10:47:58.911765+03
10499	53	-1	3120	2019-12-01 10:52:41.219587+03
10500	77	-1	640	2019-12-01 10:58:30.745853+03
10501	93	-1	1620	2019-12-01 11:30:04.981364+03
10502	18	-2	910	2019-12-01 11:32:57.369599+03
10503	33	-1	900	2019-12-01 11:33:34.997502+03
10504	52	-1	1090	2019-12-01 11:36:25.512299+03
10505	25	-2	1100	2019-12-01 12:02:30.088632+03
10506	7	-2	810	2019-12-01 12:06:08.482503+03
10507	27	-1	880	2019-12-01 12:06:49.85846+03
10508	41	-1	830	2019-12-01 12:10:47.360133+03
10509	86	-1	910	2019-12-01 12:23:39.187262+03
10510	3	-2	660	2019-12-01 12:57:39.614109+03
10511	95	-1	480	2019-12-01 13:09:38.769505+03
10512	22	-1	1070	2019-12-01 13:30:48.542057+03
10513	29	-1	1940	2019-12-01 14:08:39.929413+03
10514	38	-1	1100	2019-12-01 14:29:55.025386+03
10515	75	-1	830	2019-12-01 14:34:46.020428+03
10516	59	-1	1030	2019-12-01 14:54:12.188465+03
10517	94	20	649	2019-12-01 15:06:18.102235+03
10518	44	-2	500	2019-12-01 15:10:11.043948+03
10519	34	-1	1550	2019-12-01 15:11:06.336037+03
10520	95	-1	480	2019-12-01 15:24:44.729147+03
10521	38	-1	1100	2019-12-01 15:24:57.097522+03
10522	2	-1	470	2019-12-01 15:57:42.491543+03
10523	49	-1	970	2019-12-01 16:32:44.135678+03
10524	57	-3	1900	2019-12-01 16:33:48.531713+03
10525	33	-1	900	2019-12-01 17:19:31.038117+03
10526	17	-1	1500	2019-12-01 17:51:42.269602+03
10527	69	19	546	2019-12-01 18:00:38.101425+03
10528	95	-1	480	2019-12-01 18:42:15.575546+03
10529	9	-1	2090	2019-12-01 18:51:31.247646+03
10530	36	-1	630	2019-12-01 19:53:28.553654+03
10531	8	-2	1920	2019-12-01 20:12:42.33168+03
10532	69	-1	1100	2019-12-01 20:23:11.534832+03
10533	18	-1	910	2019-12-01 20:42:59.814062+03
10534	75	-1	830	2019-12-01 20:57:24.785844+03
10535	21	-1	960	2019-12-01 21:08:19.764295+03
10536	10	-2	2080	2019-12-01 21:14:53.243723+03
10537	18	-1	910	2019-12-01 21:24:44.497184+03
10538	18	-1	910	2019-12-01 21:36:10.350189+03
10539	2	-1	470	2019-12-01 21:37:40.11752+03
10540	61	-1	1510	2019-12-01 21:39:46.679161+03
10541	44	-1	500	2019-12-01 22:03:37.469304+03
10542	41	-2	830	2019-12-01 22:12:37.99017+03
10543	75	-1	830	2019-12-01 22:14:20.844827+03
10544	22	-1	1070	2019-12-01 22:42:13.188525+03
10545	4	52	643	2019-12-01 22:44:28.747238+03
10546	73	-1	960	2019-12-01 23:00:25.926378+03
10547	46	-2	1270	2019-12-01 23:10:35.849943+03
10548	49	-1	970	2019-12-01 23:20:08.754009+03
10549	45	-1	1590	2019-12-01 23:23:08.85519+03
10550	60	-2	2700	2019-12-01 23:32:57.911209+03
10551	74	-1	1010	2019-12-01 23:38:17.324902+03
10552	92	-2	630	2019-12-01 23:49:05.822733+03
10553	75	-1	830	2019-12-01 23:55:32.693743+03
10554	64	-1	970	2019-12-02 00:26:00.619839+03
10555	88	-2	1270	2019-12-02 01:17:32.498754+03
10556	8	-1	1920	2019-12-02 01:42:47.190161+03
10557	84	-2	2700	2019-12-02 01:54:29.659086+03
10558	39	-1	910	2019-12-02 02:08:53.192872+03
10559	69	-1	1100	2019-12-02 02:11:05.580891+03
10560	96	-1	1570	2019-12-02 02:11:40.496997+03
10561	33	-2	900	2019-12-02 03:22:23.347704+03
10562	42	24	725	2019-12-02 03:22:41.776969+03
10563	28	-1	1860	2019-12-02 04:06:15.636206+03
10564	39	-1	910	2019-12-02 04:44:51.613624+03
10565	38	-2	1100	2019-12-02 05:47:45.035272+03
10566	47	-1	1480	2019-12-02 06:15:58.557626+03
10567	17	30	836	2019-12-02 06:29:27.312677+03
10568	46	-1	1270	2019-12-02 06:40:49.891762+03
10569	83	-2	1230	2019-12-02 07:02:05.877617+03
10570	57	-1	1900	2019-12-02 07:32:14.802657+03
10571	58	-2	2830	2019-12-02 07:35:55.022776+03
10572	8	-2	1920	2019-12-02 08:42:53.019328+03
10573	89	-1	1420	2019-12-02 08:48:57.643138+03
10574	36	30	323	2019-12-02 08:49:04.658981+03
10575	83	-1	1230	2019-12-02 09:13:25.952368+03
10576	88	-1	1270	2019-12-02 09:44:40.177978+03
10577	58	-2	2830	2019-12-02 10:22:38.407264+03
10578	35	-2	670	2019-12-02 10:26:00.883755+03
10579	38	-1	1100	2019-12-02 10:27:54.248811+03
10580	96	-2	1570	2019-12-02 10:30:17.787359+03
10581	22	-2	1070	2019-12-02 10:36:08.559514+03
10582	24	-1	950	2019-12-02 11:13:09.054066+03
10583	95	-2	480	2019-12-02 11:14:10.835824+03
10584	70	-1	760	2019-12-02 11:16:31.392708+03
10585	30	-1	1140	2019-12-02 11:34:41.789323+03
10586	5	-1	1620	2019-12-02 11:35:53.766844+03
10587	1	-1	640	2019-12-02 11:53:26.417958+03
10588	48	-2	640	2019-12-02 12:02:46.393255+03
10589	69	-1	1100	2019-12-02 12:06:42.080969+03
10590	86	-1	910	2019-12-02 12:34:58.369228+03
10591	23	-1	4390	2019-12-02 12:50:06.054789+03
10592	12	-2	1650	2019-12-02 13:11:31.863795+03
10593	5	-1	1620	2019-12-02 13:22:07.480089+03
10594	41	-1	830	2019-12-02 13:37:36.50994+03
10595	16	-1	1380	2019-12-02 13:50:26.306481+03
10596	94	-1	1230	2019-12-02 13:51:51.084586+03
10597	76	-1	1070	2019-12-02 14:08:36.326781+03
10598	13	-1	460	2019-12-02 14:22:13.774712+03
10599	91	-1	1620	2019-12-02 15:28:11.072458+03
10600	10	-1	2080	2019-12-02 15:28:58.988779+03
10601	38	-2	1100	2019-12-02 15:55:41.454611+03
10602	8	-1	1920	2019-12-02 16:00:39.017766+03
10603	39	-2	910	2019-12-02 16:49:09.32851+03
10604	80	-1	1120	2019-12-02 17:07:48.803908+03
10605	52	-1	1090	2019-12-02 17:23:18.092923+03
10606	60	-1	2700	2019-12-02 17:39:44.342651+03
10607	57	-1	1900	2019-12-02 18:05:59.095822+03
10608	93	-1	1620	2019-12-02 18:06:17.783228+03
10609	33	-1	900	2019-12-02 18:08:42.569521+03
10610	4	-2	1420	2019-12-02 18:13:46.165047+03
10611	31	-1	1190	2019-12-02 18:16:12.974905+03
10612	64	-1	970	2019-12-02 18:17:21.919416+03
10613	6	-1	980	2019-12-02 18:32:43.298832+03
10614	74	-1	1010	2019-12-02 18:34:11.106642+03
10615	8	-1	1920	2019-12-02 18:45:04.316187+03
10616	76	32	549	2019-12-02 18:49:25.375405+03
10617	50	-1	1140	2019-12-02 18:50:02.886982+03
10618	84	-1	2700	2019-12-02 18:59:17.657901+03
10619	53	-2	3120	2019-12-02 19:00:08.241189+03
10620	64	-1	970	2019-12-02 19:03:51.270738+03
10621	12	-1	1650	2019-12-02 19:07:15.829979+03
10622	34	-3	1550	2019-12-02 19:20:27.721038+03
10623	71	-1	1030	2019-12-02 19:25:12.193187+03
10624	74	-1	1010	2019-12-02 19:26:30.40922+03
10625	76	-1	1070	2019-12-02 19:45:44.286314+03
10626	41	-2	830	2019-12-02 20:16:32.61834+03
10627	77	-2	640	2019-12-02 20:23:44.355736+03
10628	29	-2	1940	2019-12-02 20:53:03.146083+03
10629	32	-1	710	2019-12-02 21:06:18.98825+03
10630	39	-1	910	2019-12-02 21:07:40.58392+03
10631	62	-1	1220	2019-12-02 21:11:52.015822+03
10632	67	-2	350	2019-12-02 21:22:25.257201+03
10633	9	-1	2090	2019-12-02 21:30:30.728567+03
10634	87	-1	2320	2019-12-02 21:38:35.860639+03
10635	75	-1	830	2019-12-02 21:40:02.181992+03
10636	87	-1	2320	2019-12-02 21:41:36.65726+03
10637	90	-2	1780	2019-12-02 21:56:49.215623+03
10638	4	-1	1420	2019-12-02 21:57:02.663671+03
10639	85	-1	730	2019-12-02 22:01:14.266585+03
10640	75	-2	830	2019-12-02 22:17:32.217943+03
10641	76	-1	1070	2019-12-02 22:26:41.999049+03
10642	73	-1	960	2019-12-02 22:27:59.130582+03
10643	83	-1	1230	2019-12-02 22:36:42.405496+03
10644	76	-1	1070	2019-12-02 22:43:36.999303+03
10645	86	-1	910	2019-12-02 22:45:52.151682+03
10646	57	35	1065	2019-12-02 22:59:41.688666+03
10647	85	-2	730	2019-12-02 23:04:28.822897+03
10648	15	-1	2830	2019-12-02 23:34:05.052768+03
10649	85	-1	730	2019-12-02 23:40:19.99874+03
10650	15	-1	2830	2019-12-02 23:46:05.238547+03
10651	63	-1	1780	2019-12-03 00:07:03.72454+03
10652	90	-1	1780	2019-12-03 01:07:01.661733+03
10653	42	-1	1790	2019-12-03 01:08:01.533006+03
10654	3	-2	660	2019-12-03 01:11:32.269694+03
10655	59	-1	1030	2019-12-03 01:13:23.662451+03
10656	52	-1	1090	2019-12-03 01:23:41.743281+03
10657	11	-1	830	2019-12-03 01:29:30.39761+03
10658	20	-2	830	2019-12-03 01:30:59.40037+03
10659	6	-2	980	2019-12-03 01:56:29.780727+03
10660	85	-1	730	2019-12-03 02:07:35.55598+03
10661	52	-1	1090	2019-12-03 02:09:29.47392+03
10662	71	-1	1030	2019-12-03 02:46:11.453753+03
10663	96	-2	1570	2019-12-03 02:49:15.767391+03
10664	32	38	318	2019-12-03 03:02:22.389672+03
10665	36	-1	630	2019-12-03 03:19:50.339738+03
10666	12	-2	1650	2019-12-03 03:35:28.776769+03
10667	11	-2	830	2019-12-03 03:41:25.10397+03
10668	28	-1	1860	2019-12-03 04:26:01.391633+03
10669	29	-1	1940	2019-12-03 04:36:42.87223+03
10670	11	-1	830	2019-12-03 04:50:28.787426+03
10671	20	-1	830	2019-12-03 04:59:46.077983+03
10672	82	-1	560	2019-12-03 05:33:54.052004+03
10673	84	-1	2700	2019-12-03 05:42:59.582058+03
10674	74	-1	1010	2019-12-03 05:59:32.076929+03
10675	12	-1	1650	2019-12-03 06:27:48.446886+03
10676	73	-1	960	2019-12-03 07:12:14.956206+03
10677	49	-2	970	2019-12-03 07:12:52.631883+03
10678	53	-1	3120	2019-12-03 07:14:25.813475+03
10679	6	-1	980	2019-12-03 07:15:14.008469+03
10680	42	-1	1790	2019-12-03 07:24:46.297251+03
10681	79	-1	550	2019-12-03 07:36:44.480422+03
10682	79	22	254	2019-12-03 07:48:41.400541+03
10683	19	-1	1220	2019-12-03 07:51:42.508922+03
10684	92	-1	630	2019-12-03 07:51:46.114417+03
10685	53	-1	3120	2019-12-03 08:18:53.4948+03
10686	76	-1	1070	2019-12-03 08:43:16.84707+03
10687	75	32	396	2019-12-03 08:58:28.96476+03
10688	4	-1	1420	2019-12-03 08:58:35.545071+03
10689	16	-2	1380	2019-12-03 09:12:37.028939+03
10690	14	-2	1350	2019-12-03 09:27:00.962962+03
10691	88	-1	1270	2019-12-03 09:32:26.815134+03
10692	23	-1	4390	2019-12-03 09:46:45.741748+03
10693	54	-1	3470	2019-12-03 09:56:53.725992+03
10694	79	-1	550	2019-12-03 10:34:20.473794+03
10695	49	-2	970	2019-12-03 10:45:56.461645+03
10696	34	-1	1550	2019-12-03 10:53:30.014061+03
10697	81	-1	1620	2019-12-03 11:45:00.04558+03
10698	28	-1	1860	2019-12-03 11:59:16.98215+03
10699	13	-1	460	2019-12-03 12:00:07.906929+03
10700	46	-1	1270	2019-12-03 12:05:41.58076+03
10701	14	-1	1350	2019-12-03 12:17:06.525858+03
10702	69	-1	1100	2019-12-03 12:30:07.209453+03
10703	90	-1	1780	2019-12-03 12:57:54.137138+03
10704	74	-1	1010	2019-12-03 13:30:33.106734+03
10705	4	-1	1420	2019-12-03 13:34:41.193222+03
10706	27	-1	880	2019-12-03 14:20:07.716005+03
10707	17	-1	1500	2019-12-03 14:34:11.484115+03
10708	22	-1	1070	2019-12-03 14:50:10.167956+03
10709	6	-1	980	2019-12-03 14:53:34.197318+03
10710	7	-1	810	2019-12-03 15:34:19.293984+03
10711	77	-1	640	2019-12-03 15:42:41.235102+03
10712	27	-1	880	2019-12-03 15:59:35.207471+03
10713	88	19	667	2019-12-03 17:04:58.610932+03
10714	61	-1	1510	2019-12-03 17:13:21.301059+03
10715	8	-1	1920	2019-12-03 17:24:53.399921+03
10716	65	-2	490	2019-12-03 17:32:35.074832+03
10717	36	-1	630	2019-12-03 17:32:49.735567+03
10718	56	-1	2460	2019-12-03 17:40:21.290317+03
10719	71	-1	1030	2019-12-03 17:47:08.83174+03
10720	48	-1	640	2019-12-03 17:48:14.569775+03
10721	23	-2	4390	2019-12-03 18:02:28.492939+03
10722	63	-1	1780	2019-12-03 18:04:46.4557+03
10723	64	-1	970	2019-12-03 18:32:07.308648+03
10724	80	-2	1120	2019-12-03 19:01:23.776193+03
10725	1	-1	640	2019-12-03 19:07:26.132145+03
10726	19	-1	1220	2019-12-03 19:11:51.191064+03
10727	51	-1	1310	2019-12-03 19:27:23.97941+03
10728	14	-1	1350	2019-12-03 19:42:17.515289+03
10729	85	-1	730	2019-12-03 20:06:58.885301+03
10730	67	-1	350	2019-12-03 20:17:48.025467+03
10731	66	-1	690	2019-12-03 20:51:00.152934+03
10732	20	-1	830	2019-12-03 20:56:10.923491+03
10733	46	41	521	2019-12-03 21:06:57.570598+03
10734	34	-1	1550	2019-12-03 21:08:08.102581+03
10735	26	-1	390	2019-12-03 21:15:24.960231+03
10736	31	-1	1190	2019-12-03 21:16:58.584471+03
10737	26	-1	390	2019-12-03 21:34:22.045653+03
10738	32	-1	710	2019-12-03 22:10:54.449135+03
10739	59	-1	1030	2019-12-03 22:30:08.698042+03
10740	75	-1	830	2019-12-03 22:39:11.87897+03
10741	12	-1	1650	2019-12-03 22:57:50.929943+03
10742	51	-2	1310	2019-12-03 23:00:09.558933+03
10743	4	-1	1420	2019-12-03 23:10:08.104563+03
10744	47	-2	1480	2019-12-03 23:18:04.174883+03
10745	70	-2	760	2019-12-03 23:36:59.052427+03
10746	93	-1	1620	2019-12-04 00:05:59.602369+03
10747	77	-1	640	2019-12-04 00:27:36.524958+03
10748	85	-1	730	2019-12-04 00:54:47.522335+03
10749	93	-1	1620	2019-12-04 01:03:11.502691+03
10750	34	-1	1550	2019-12-04 01:10:15.520351+03
10751	32	-1	710	2019-12-04 01:24:12.158299+03
10752	83	-1	1230	2019-12-04 01:34:20.138749+03
10753	8	-1	1920	2019-12-04 01:46:58.759207+03
10754	46	-1	1270	2019-12-04 01:58:58.766501+03
10755	37	-1	1290	2019-12-04 02:01:47.913467+03
10756	66	-1	690	2019-12-04 02:14:07.223342+03
10757	95	-1	480	2019-12-04 02:32:05.526563+03
10758	10	27	1012	2019-12-04 02:54:05.281817+03
10759	23	-1	4390	2019-12-04 03:00:44.071568+03
10760	27	-1	880	2019-12-04 03:04:07.92081+03
10761	53	-1	3120	2019-12-04 03:12:01.086143+03
10762	70	-1	760	2019-12-04 03:42:44.338187+03
10763	70	-1	760	2019-12-04 03:53:50.274061+03
10764	44	-2	500	2019-12-04 04:04:39.052507+03
10765	22	-1	1070	2019-12-04 04:16:57.720038+03
10766	22	-1	1070	2019-12-04 04:22:50.587905+03
10767	39	-1	910	2019-12-04 04:55:03.078858+03
10768	3	-1	660	2019-12-04 05:03:37.261257+03
10769	33	-1	900	2019-12-04 05:15:21.893974+03
10770	86	-1	910	2019-12-04 05:37:04.159765+03
10771	82	-2	560	2019-12-04 05:59:51.006696+03
10772	6	31	434	2019-12-04 06:05:59.298169+03
10773	22	-1	1070	2019-12-04 06:14:00.795824+03
10774	69	-1	1100	2019-12-04 06:18:41.16454+03
10775	13	-1	460	2019-12-04 06:27:34.196112+03
10776	40	-1	1430	2019-12-04 06:29:21.841162+03
10777	38	-1	1100	2019-12-04 06:39:11.429768+03
10778	68	-1	490	2019-12-04 07:02:44.092215+03
10779	11	-1	830	2019-12-04 07:05:03.378876+03
10780	68	-1	490	2019-12-04 07:27:35.217045+03
10781	32	-1	710	2019-12-04 07:42:49.675514+03
10782	36	-1	630	2019-12-04 07:59:14.051718+03
10783	5	-1	1620	2019-12-04 08:01:37.890587+03
10784	93	-1	1620	2019-12-04 08:25:20.193427+03
10785	36	-1	630	2019-12-04 08:58:21.220862+03
10786	29	-1	1940	2019-12-04 09:05:58.915972+03
10787	19	-1	1220	2019-12-04 09:14:03.861705+03
10788	19	-1	1220	2019-12-04 09:25:25.441523+03
10789	55	-1	3480	2019-12-04 10:24:09.962519+03
10790	50	24	630	2019-12-04 10:28:03.154012+03
10791	88	-1	1270	2019-12-04 10:30:16.58819+03
10792	60	-1	2700	2019-12-04 10:35:31.614037+03
10793	8	-1	1920	2019-12-04 10:52:46.897394+03
10794	26	-1	390	2019-12-04 10:56:56.180685+03
10795	28	-2	1860	2019-12-04 11:06:30.270075+03
10796	60	-2	2700	2019-12-04 11:20:26.276014+03
10797	12	-1	1650	2019-12-04 11:24:34.323272+03
10798	14	-1	1350	2019-12-04 11:28:59.241762+03
10799	25	-1	1100	2019-12-04 12:23:04.903121+03
10800	35	-1	670	2019-12-04 12:52:56.384189+03
10801	86	-1	910	2019-12-04 13:26:08.738416+03
10802	43	-2	380	2019-12-04 13:55:31.060721+03
10803	57	-1	1900	2019-12-04 14:21:32.159933+03
10804	32	-1	710	2019-12-04 14:42:08.206369+03
10805	67	-2	350	2019-12-04 14:57:30.122618+03
10806	10	-1	2080	2019-12-04 15:16:14.859561+03
10807	84	-2	2700	2019-12-04 15:20:10.814303+03
10808	4	-2	1420	2019-12-04 15:39:53.388715+03
10809	46	-1	1270	2019-12-04 15:49:02.862416+03
10810	5	-1	1620	2019-12-04 15:53:25.165407+03
10811	79	-2	550	2019-12-04 15:54:23.835713+03
10812	44	-1	500	2019-12-04 16:05:39.321642+03
10813	87	-1	2320	2019-12-04 16:24:47.687545+03
10814	56	-1	2460	2019-12-04 16:26:35.864607+03
10815	69	-1	1100	2019-12-04 16:26:38.027679+03
10816	64	-1	970	2019-12-04 16:30:19.486001+03
10817	9	-1	2090	2019-12-04 16:45:11.298816+03
10818	87	-1	2320	2019-12-04 16:55:28.414987+03
10819	44	-2	500	2019-12-04 17:17:52.880907+03
10820	83	-1	1230	2019-12-04 17:20:06.447138+03
10821	90	-2	1780	2019-12-04 17:29:04.613015+03
10822	71	-1	1030	2019-12-04 17:59:10.862955+03
10823	74	-1	1010	2019-12-04 18:11:36.066303+03
10824	7	-1	810	2019-12-04 18:53:22.687154+03
10825	60	-1	2700	2019-12-04 19:06:04.240925+03
10826	23	-1	4390	2019-12-04 19:08:19.865403+03
10827	20	-1	830	2019-12-04 19:32:59.07597+03
10828	80	-2	1120	2019-12-04 19:35:49.526718+03
10829	87	-1	2320	2019-12-04 20:14:25.959585+03
10830	31	-1	1190	2019-12-04 20:26:31.259707+03
10831	9	-1	2090	2019-12-04 20:51:52.490374+03
10832	33	-1	900	2019-12-04 20:52:15.671617+03
10833	12	52	736	2019-12-04 20:55:51.356558+03
10834	3	-1	660	2019-12-04 21:06:14.306814+03
10835	26	-1	390	2019-12-04 21:07:21.195532+03
10836	89	-1	1420	2019-12-04 21:24:04.76728+03
10837	60	-1	2700	2019-12-04 21:28:02.745885+03
10838	41	-1	830	2019-12-04 21:58:25.775458+03
10839	2	-1	470	2019-12-04 22:01:34.737364+03
10840	52	-1	1090	2019-12-04 22:24:33.934286+03
10841	87	-1	2320	2019-12-04 22:39:47.703058+03
10842	79	-1	550	2019-12-04 23:06:12.346959+03
10843	78	-1	900	2019-12-04 23:11:00.025404+03
10844	55	-2	3480	2019-12-04 23:24:54.289737+03
10845	57	-1	1900	2019-12-04 23:32:02.339345+03
10846	57	-1	1900	2019-12-04 23:37:23.196397+03
10847	84	29	1290	2019-12-05 00:03:20.017067+03
10848	61	-1	1510	2019-12-05 00:05:08.4989+03
10849	21	-1	960	2019-12-05 00:08:49.656053+03
10850	45	-2	1590	2019-12-05 00:09:33.547216+03
10851	35	-1	670	2019-12-05 00:25:51.723485+03
10852	81	-1	1620	2019-12-05 00:30:47.342222+03
10853	5	-1	1620	2019-12-05 00:49:05.704781+03
10854	34	-1	1550	2019-12-05 01:16:04.885913+03
10855	33	-1	900	2019-12-05 01:24:52.258744+03
10856	35	-1	670	2019-12-05 01:25:37.223435+03
10857	31	-2	1190	2019-12-05 01:49:34.212354+03
10858	71	-1	1030	2019-12-05 02:02:14.70065+03
10859	18	-1	910	2019-12-05 02:02:49.215572+03
10860	31	-1	1190	2019-12-05 02:11:48.346947+03
10861	68	-2	490	2019-12-05 02:12:08.326712+03
10862	19	31	535	2019-12-05 02:21:01.016234+03
10863	80	-1	1120	2019-12-05 02:21:23.082128+03
10864	94	-1	1230	2019-12-05 02:28:02.277702+03
10865	83	-1	1230	2019-12-05 02:35:22.109265+03
10866	76	-1	1070	2019-12-05 02:38:19.461166+03
10867	64	-2	970	2019-12-05 02:41:06.570823+03
10868	49	-1	970	2019-12-05 03:38:36.608677+03
10869	79	-1	550	2019-12-05 04:14:33.750249+03
10870	23	-1	4390	2019-12-05 04:18:38.205758+03
10871	91	-1	1620	2019-12-05 04:47:02.79754+03
10872	6	-1	980	2019-12-05 05:09:10.218187+03
10873	83	-2	1230	2019-12-05 05:25:07.499646+03
10874	13	-2	460	2019-12-05 05:39:18.471579+03
10875	25	-1	1100	2019-12-05 05:55:08.200604+03
10876	60	-1	2700	2019-12-05 06:01:46.857946+03
10877	51	-2	1310	2019-12-05 06:24:02.999395+03
10878	10	-1	2080	2019-12-05 06:27:09.325256+03
10879	13	-1	460	2019-12-05 06:36:46.779653+03
10880	89	-1	1420	2019-12-05 06:38:15.269037+03
10881	79	-1	550	2019-12-05 06:39:17.074643+03
10882	42	-1	1790	2019-12-05 07:04:59.891586+03
10883	34	-1	1550	2019-12-05 07:05:26.251174+03
10884	73	-1	960	2019-12-05 07:09:56.040595+03
10885	8	29	804	2019-12-05 07:24:30.540107+03
10886	40	-1	1430	2019-12-05 07:29:51.205527+03
10887	30	-1	1140	2019-12-05 07:37:34.095379+03
10888	19	-1	1220	2019-12-05 07:47:38.196002+03
10889	59	-2	1030	2019-12-05 08:04:03.207059+03
10890	77	-1	640	2019-12-05 08:55:53.538031+03
10891	24	-1	950	2019-12-05 08:58:15.913549+03
10892	95	-1	480	2019-12-05 09:14:22.113653+03
10893	7	-1	810	2019-12-05 09:18:07.277992+03
10894	73	-1	960	2019-12-05 09:40:39.507002+03
10895	42	-1	1790	2019-12-05 09:43:52.544668+03
10896	65	-1	490	2019-12-05 10:03:03.236174+03
10897	93	-1	1620	2019-12-05 10:07:08.48775+03
10898	64	-1	970	2019-12-05 10:41:37.736433+03
10899	54	-1	3470	2019-12-05 10:42:21.827228+03
10900	64	-1	970	2019-12-05 11:20:10.268504+03
10901	14	-1	1350	2019-12-05 11:27:25.585849+03
10902	6	-1	980	2019-12-05 11:35:29.131086+03
10903	47	-2	1480	2019-12-05 11:37:32.689896+03
10904	10	-1	2080	2019-12-05 12:44:40.92837+03
10905	69	-1	1100	2019-12-05 13:20:06.149877+03
10906	33	-1	900	2019-12-05 13:42:03.321863+03
10907	33	-1	900	2019-12-05 13:57:57.040025+03
10908	25	-1	1100	2019-12-05 14:16:31.344866+03
10909	71	-1	1030	2019-12-05 14:29:49.800256+03
10910	70	-1	760	2019-12-05 14:40:58.943828+03
10911	56	-1	2460	2019-12-05 14:48:20.778149+03
10912	83	-1	1230	2019-12-05 15:39:03.170707+03
10913	47	-1	1480	2019-12-05 15:39:05.115586+03
10914	49	-1	970	2019-12-05 16:16:59.13279+03
10915	37	-1	1290	2019-12-05 16:19:40.073718+03
10916	20	-1	830	2019-12-05 16:42:11.478825+03
10917	20	-1	830	2019-12-05 16:56:09.770811+03
10918	57	-1	1900	2019-12-05 16:56:21.189366+03
10919	33	-2	900	2019-12-05 16:59:04.540725+03
10920	7	-1	810	2019-12-05 17:22:16.556566+03
10921	60	-1	2700	2019-12-05 17:31:13.540627+03
10922	55	-1	3480	2019-12-05 17:41:59.32382+03
10923	27	-1	880	2019-12-05 17:48:54.454183+03
10924	84	-2	2700	2019-12-05 18:12:06.166187+03
10925	36	-1	630	2019-12-05 18:34:57.544226+03
10926	88	-1	1270	2019-12-05 18:35:47.422023+03
10927	96	-2	1570	2019-12-05 18:45:05.846747+03
10928	70	-1	760	2019-12-05 19:02:11.452102+03
10929	84	-1	2700	2019-12-05 19:05:41.294662+03
10930	63	33	1043	2019-12-05 19:06:43.775402+03
10931	41	-1	830	2019-12-05 19:09:05.21372+03
10932	42	-1	1790	2019-12-05 19:15:40.910638+03
10933	51	-1	1310	2019-12-05 19:35:36.980863+03
10934	90	-1	1780	2019-12-05 19:40:52.055779+03
10935	49	-1	970	2019-12-05 19:42:51.964358+03
10936	32	-1	710	2019-12-05 19:46:44.246479+03
10937	27	-1	880	2019-12-05 19:52:42.64069+03
10938	49	-1	970	2019-12-05 20:05:11.823613+03
10939	96	-1	1570	2019-12-05 20:18:16.92603+03
10940	19	-1	1220	2019-12-05 21:06:40.468586+03
10941	56	-2	2460	2019-12-05 21:21:36.935128+03
10942	29	-1	1940	2019-12-05 21:37:04.323203+03
10943	84	-1	2700	2019-12-05 22:05:53.588519+03
10944	56	-1	2460	2019-12-05 22:18:12.032991+03
10945	49	-1	970	2019-12-05 22:19:06.057214+03
10946	80	26	547	2019-12-05 22:47:38.146547+03
10947	94	-2	1230	2019-12-05 22:55:37.713552+03
10948	40	-1	1430	2019-12-05 23:05:32.130953+03
10949	60	27	1405	2019-12-05 23:05:36.056982+03
10950	63	-1	1780	2019-12-05 23:25:47.994726+03
10951	35	-2	670	2019-12-05 23:38:13.574397+03
10952	61	-1	1510	2019-12-05 23:41:14.3262+03
10953	2	-1	470	2019-12-06 00:13:18.386926+03
10954	13	-2	460	2019-12-06 00:18:25.924549+03
10955	87	-1	2320	2019-12-06 00:40:20.394154+03
10956	89	-1	1420	2019-12-06 00:50:19.638502+03
10957	7	-1	810	2019-12-06 01:00:55.247378+03
10958	52	-1	1090	2019-12-06 01:06:43.056099+03
10959	76	-1	1070	2019-12-06 01:08:54.71056+03
10960	27	-1	880	2019-12-06 01:54:40.8625+03
10961	44	-1	500	2019-12-06 02:52:03.374424+03
10962	69	-1	1100	2019-12-06 02:52:27.392337+03
10963	34	-1	1550	2019-12-06 02:59:01.017089+03
10964	81	-1	1620	2019-12-06 03:17:02.938708+03
10965	19	-1	1220	2019-12-06 03:28:39.42127+03
10966	57	-1	1900	2019-12-06 03:56:16.329964+03
10967	88	-2	1270	2019-12-06 04:20:04.436446+03
10968	23	-1	4390	2019-12-06 04:23:31.667638+03
10969	9	-1	2090	2019-12-06 04:26:29.174171+03
10970	8	-2	1920	2019-12-06 04:34:35.299796+03
10971	4	-2	1420	2019-12-06 04:38:04.046767+03
10972	59	-2	1030	2019-12-06 04:48:32.853848+03
10973	14	-2	1350	2019-12-06 05:11:15.517296+03
10974	56	-2	2460	2019-12-06 05:42:22.773734+03
10975	28	-1	1860	2019-12-06 05:47:08.323303+03
10976	32	-2	710	2019-12-06 05:56:47.70142+03
10977	3	-1	660	2019-12-06 06:12:35.604657+03
10978	45	-1	1590	2019-12-06 06:55:41.312309+03
10979	67	-1	350	2019-12-06 07:11:18.042793+03
10980	87	-1	2320	2019-12-06 07:54:39.033179+03
10981	77	-1	640	2019-12-06 08:22:24.458764+03
10982	76	-2	1070	2019-12-06 08:58:37.690917+03
10983	37	-2	1290	2019-12-06 09:00:09.170671+03
10984	33	-1	900	2019-12-06 09:07:05.405201+03
10985	84	-1	2700	2019-12-06 09:12:26.65674+03
10986	27	-1	880	2019-12-06 09:55:56.085952+03
10987	77	-1	640	2019-12-06 10:00:11.361162+03
10988	61	-1	1510	2019-12-06 10:01:25.82258+03
10989	20	-1	830	2019-12-06 10:14:20.805182+03
10990	5	-1	1620	2019-12-06 10:29:48.964963+03
10991	28	-1	1860	2019-12-06 10:33:04.236363+03
10992	40	-1	1430	2019-12-06 10:36:06.515001+03
10993	60	-1	2700	2019-12-06 10:50:39.126998+03
10994	89	-1	1420	2019-12-06 10:57:06.520207+03
10995	63	-1	1780	2019-12-06 11:51:32.099372+03
10996	12	-1	1650	2019-12-06 12:26:38.455946+03
10997	92	-1	630	2019-12-06 12:28:15.814648+03
10998	39	-1	910	2019-12-06 12:39:52.476509+03
10999	15	-1	2830	2019-12-06 12:47:11.157056+03
11000	57	-1	1900	2019-12-06 12:54:32.350286+03
11001	24	-1	950	2019-12-06 13:00:03.376013+03
11002	69	-1	1100	2019-12-06 13:36:35.327546+03
11003	35	-2	670	2019-12-06 13:38:47.479966+03
11004	11	-1	830	2019-12-06 13:50:52.854434+03
11005	6	-1	980	2019-12-06 14:01:38.821988+03
11006	46	-1	1270	2019-12-06 14:14:46.915419+03
11007	20	-1	830	2019-12-06 14:25:37.682769+03
11008	12	-1	1650	2019-12-06 14:43:15.111095+03
11009	17	-1	1500	2019-12-06 14:43:30.073368+03
11010	56	-1	2460	2019-12-06 14:43:57.594047+03
11011	41	-1	830	2019-12-06 14:50:01.282062+03
11012	93	-1	1620	2019-12-06 14:57:02.205121+03
11013	46	-1	1270	2019-12-06 15:00:56.242116+03
11014	30	-1	1140	2019-12-06 15:12:11.49836+03
11015	18	-1	910	2019-12-06 15:20:11.327205+03
11016	36	-1	630	2019-12-06 15:21:16.599856+03
11017	72	-1	620	2019-12-06 15:31:14.091288+03
11018	4	-1	1420	2019-12-06 15:47:37.575886+03
11019	12	-1	1650	2019-12-06 16:00:33.587257+03
11020	67	-2	350	2019-12-06 16:21:13.464991+03
11021	44	-2	500	2019-12-06 16:25:14.328036+03
11022	68	-1	490	2019-12-06 16:32:56.532206+03
11023	20	-1	830	2019-12-06 16:38:15.726411+03
11024	12	-1	1650	2019-12-06 17:14:33.510303+03
11025	6	-1	980	2019-12-06 17:22:26.2349+03
11026	74	-2	1010	2019-12-06 17:28:22.513851+03
11027	84	-1	2700	2019-12-06 17:32:32.045199+03
11028	82	-1	560	2019-12-06 17:37:38.660395+03
11029	76	-1	1070	2019-12-06 17:48:37.132769+03
11030	5	-1	1620	2019-12-06 17:54:10.383469+03
11031	96	-1	1570	2019-12-06 18:24:21.828415+03
11032	93	-1	1620	2019-12-06 18:57:13.548614+03
11033	12	-2	1650	2019-12-06 19:00:30.593213+03
11034	74	-1	1010	2019-12-06 19:19:53.109171+03
11035	57	-1	1900	2019-12-06 19:22:44.315195+03
11036	65	-1	490	2019-12-06 19:45:40.257039+03
11037	84	-1	2700	2019-12-06 19:48:59.872736+03
11038	4	-1	1420	2019-12-06 19:57:01.349446+03
11039	64	-1	970	2019-12-06 20:05:53.221455+03
11040	87	-1	2320	2019-12-06 20:21:59.511264+03
11041	32	-1	710	2019-12-06 20:24:28.509564+03
11042	19	-1	1220	2019-12-06 20:32:43.850859+03
11043	39	-1	910	2019-12-06 20:59:05.129208+03
11044	33	-1	900	2019-12-06 21:20:43.410229+03
11045	3	-1	660	2019-12-06 21:28:58.04942+03
11046	29	-1	1940	2019-12-06 21:43:10.305851+03
11047	94	-1	1230	2019-12-06 22:08:08.644119+03
11048	23	-1	4390	2019-12-06 22:08:40.659459+03
11049	52	-1	1090	2019-12-06 22:17:23.601051+03
11050	53	-1	3120	2019-12-06 22:25:20.246151+03
11051	50	-2	1140	2019-12-06 22:52:28.43726+03
11052	61	-1	1510	2019-12-06 23:03:03.091977+03
11053	96	-1	1570	2019-12-06 23:35:06.312165+03
11054	45	-1	1590	2019-12-06 23:42:44.661926+03
11055	37	33	589	2019-12-06 23:44:37.0403+03
11056	62	-2	1220	2019-12-06 23:49:22.234505+03
11057	73	-3	960	2019-12-07 00:19:37.462797+03
11058	43	-1	380	2019-12-07 00:47:41.527852+03
11059	53	-1	3120	2019-12-07 01:38:37.412023+03
11060	6	-1	980	2019-12-07 02:08:20.526645+03
11061	94	-2	1230	2019-12-07 02:42:41.677538+03
11062	93	-1	1620	2019-12-07 03:06:51.273185+03
11063	49	-1	970	2019-12-07 03:41:22.044211+03
11064	36	-1	630	2019-12-07 03:47:48.188787+03
11065	34	-1	1550	2019-12-07 03:49:02.172409+03
11066	71	-2	1030	2019-12-07 03:49:05.703633+03
11067	12	-2	1650	2019-12-07 04:04:42.415139+03
11068	10	-1	2080	2019-12-07 04:15:31.435048+03
11069	81	-1	1620	2019-12-07 04:35:59.775754+03
11070	30	-2	1140	2019-12-07 04:40:22.46448+03
11071	46	-1	1270	2019-12-07 04:56:59.051946+03
11072	49	-1	970	2019-12-07 05:06:33.773878+03
11073	17	-2	1500	2019-12-07 05:52:21.214796+03
11074	71	-1	1030	2019-12-07 06:03:02.788825+03
11075	38	-1	1100	2019-12-07 06:26:29.832066+03
11076	19	-1	1220	2019-12-07 06:31:18.459799+03
11077	34	-2	1550	2019-12-07 06:35:53.886431+03
11078	77	-1	640	2019-12-07 07:06:17.758378+03
11079	41	-1	830	2019-12-07 07:15:58.610091+03
11080	75	-1	830	2019-12-07 07:21:21.523121+03
11081	58	-2	2830	2019-12-07 07:26:40.147467+03
11082	95	-1	480	2019-12-07 07:44:24.002503+03
11083	46	-2	1270	2019-12-07 07:57:32.94083+03
11084	49	-1	970	2019-12-07 09:15:04.563158+03
11085	13	-1	460	2019-12-07 09:53:10.622357+03
11086	62	-2	1220	2019-12-07 10:20:52.107778+03
11087	87	-1	2320	2019-12-07 10:29:23.040172+03
11088	33	-1	900	2019-12-07 10:46:24.555778+03
11089	96	-1	1570	2019-12-07 11:03:06.064673+03
11090	56	-1	2460	2019-12-07 11:06:44.529661+03
11091	47	-1	1480	2019-12-07 11:19:27.209511+03
11092	92	-2	630	2019-12-07 11:39:05.10011+03
11093	19	-1	1220	2019-12-07 11:44:24.938877+03
11094	86	27	445	2019-12-07 11:49:32.177371+03
11095	18	-1	910	2019-12-07 11:51:12.546052+03
11096	55	-2	3480	2019-12-07 11:55:33.879018+03
11097	57	-1	1900	2019-12-07 12:03:11.342924+03
11098	19	-2	1220	2019-12-07 12:27:06.627427+03
11099	19	-2	1220	2019-12-07 12:46:23.36481+03
11100	34	-1	1550	2019-12-07 12:57:12.696171+03
11101	19	-1	1220	2019-12-07 13:18:49.049518+03
11102	74	-1	1010	2019-12-07 13:43:45.650605+03
11103	22	-1	1070	2019-12-07 14:13:33.380697+03
11104	22	-1	1070	2019-12-07 14:15:30.337883+03
11105	38	-1	1100	2019-12-07 14:21:20.156474+03
11106	33	-1	900	2019-12-07 14:38:58.885399+03
11107	31	-1	1190	2019-12-07 15:03:11.185287+03
11108	86	-1	910	2019-12-07 15:07:36.477874+03
11109	96	-1	1570	2019-12-07 15:11:56.014926+03
11110	59	-2	1030	2019-12-07 15:24:14.941799+03
11111	19	-1	1220	2019-12-07 15:27:07.871654+03
11112	93	-1	1620	2019-12-07 15:48:46.683511+03
11113	3	-1	660	2019-12-07 15:53:52.317157+03
11114	6	-1	980	2019-12-07 16:19:26.088709+03
11115	59	-1	1030	2019-12-07 16:37:25.694576+03
11116	71	-1	1030	2019-12-07 17:05:45.755534+03
11117	53	-1	3120	2019-12-07 17:06:37.92881+03
11118	9	-1	2090	2019-12-07 17:16:15.423219+03
11119	31	-1	1190	2019-12-07 17:45:01.028355+03
11120	42	-1	1790	2019-12-07 17:47:15.209443+03
11121	12	-1	1650	2019-12-07 18:00:06.581134+03
11122	89	-2	1420	2019-12-07 18:00:24.680313+03
11123	17	-1	1500	2019-12-07 18:18:11.892226+03
11124	53	-1	3120	2019-12-07 18:26:37.948327+03
11125	63	-1	1780	2019-12-07 18:27:21.315033+03
11126	11	-1	830	2019-12-07 18:33:00.012963+03
11127	35	-1	670	2019-12-07 18:49:14.520172+03
11128	38	-1	1100	2019-12-07 18:59:45.687962+03
11129	52	-1	1090	2019-12-07 19:03:36.834268+03
11130	52	31	638	2019-12-07 19:23:54.903865+03
11131	73	-1	960	2019-12-07 19:42:41.821598+03
11132	19	-1	1220	2019-12-07 19:54:15.301829+03
11133	35	-1	670	2019-12-07 20:26:29.212907+03
11134	46	-1	1270	2019-12-07 20:38:52.141433+03
11135	60	-1	2700	2019-12-07 20:54:01.23754+03
11136	6	-1	980	2019-12-07 20:55:12.406585+03
11137	41	-1	830	2019-12-07 21:34:05.821886+03
11138	39	-1	910	2019-12-07 21:37:06.503797+03
11139	53	-1	3120	2019-12-07 21:45:22.859649+03
11140	47	-1	1480	2019-12-07 22:00:15.936781+03
11141	37	-1	1290	2019-12-07 22:24:38.369486+03
11142	45	-1	1590	2019-12-07 22:40:35.888271+03
11143	67	-1	350	2019-12-07 23:22:38.007598+03
11144	49	-1	970	2019-12-07 23:45:16.522644+03
11145	71	-1	1030	2019-12-08 00:03:13.682755+03
11146	36	-1	630	2019-12-08 00:17:45.685927+03
11147	95	-1	480	2019-12-08 00:27:46.204204+03
11148	57	-1	1900	2019-12-08 00:38:14.222899+03
11149	28	-2	1860	2019-12-08 01:19:50.076251+03
11150	28	-1	1860	2019-12-08 01:21:41.416162+03
11151	88	-2	1270	2019-12-08 01:25:11.145049+03
11152	96	-1	1570	2019-12-08 01:30:14.414327+03
11153	41	-2	830	2019-12-08 01:41:51.744693+03
11154	1	-1	640	2019-12-08 02:27:41.452046+03
11155	37	-1	1290	2019-12-08 02:59:33.365206+03
11156	18	-1	910	2019-12-08 03:39:57.122337+03
11157	12	-1	1650	2019-12-08 04:14:28.251051+03
11158	95	-1	480	2019-12-08 04:26:47.572768+03
11159	73	-1	960	2019-12-08 04:44:12.172322+03
11160	30	-2	1140	2019-12-08 04:48:24.41586+03
11161	25	-1	1100	2019-12-08 05:02:58.269361+03
11162	82	-1	560	2019-12-08 05:12:07.93176+03
11163	16	-1	1380	2019-12-08 05:38:02.250739+03
11164	11	-2	830	2019-12-08 05:50:47.350697+03
11165	24	-3	950	2019-12-08 05:54:22.48432+03
11166	45	-2	1590	2019-12-08 05:56:15.452649+03
11167	60	-1	2700	2019-12-08 05:57:19.226807+03
11168	89	-1	1420	2019-12-08 06:08:14.657662+03
11169	6	-1	980	2019-12-08 06:20:13.434588+03
11170	19	-1	1220	2019-12-08 06:21:29.086558+03
11171	20	-2	830	2019-12-08 07:06:28.181307+03
11172	17	-2	1500	2019-12-08 07:11:00.871436+03
11173	83	-1	1230	2019-12-08 07:19:52.917507+03
11174	86	-1	910	2019-12-08 07:30:38.432209+03
11175	44	-1	500	2019-12-08 07:42:45.43162+03
11176	52	-2	1090	2019-12-08 07:43:26.347127+03
11177	62	-2	1220	2019-12-08 07:44:26.68649+03
11178	55	-1	3480	2019-12-08 08:22:13.681443+03
11179	94	-1	1230	2019-12-08 08:30:07.262251+03
11180	18	-1	910	2019-12-08 08:33:01.525673+03
11181	83	-2	1230	2019-12-08 08:35:10.116702+03
11182	76	-1	1070	2019-12-08 09:08:57.899274+03
11183	6	-1	980	2019-12-08 09:32:16.617962+03
11184	87	-1	2320	2019-12-08 09:34:12.863463+03
11185	46	-1	1270	2019-12-08 09:39:43.607637+03
11186	42	-2	1790	2019-12-08 10:10:05.113653+03
11187	31	-2	1190	2019-12-08 10:25:18.816096+03
11188	47	-1	1480	2019-12-08 10:52:58.970103+03
11189	48	-1	640	2019-12-08 11:29:43.696731+03
11190	19	-1	1220	2019-12-08 12:04:17.284202+03
11191	22	-1	1070	2019-12-08 12:05:25.694253+03
11192	54	-2	3470	2019-12-08 12:23:38.760253+03
11193	88	-1	1270	2019-12-08 12:33:45.799928+03
11194	88	-1	1270	2019-12-08 12:38:34.632078+03
11195	96	-1	1570	2019-12-08 12:39:51.289186+03
11196	81	-1	1620	2019-12-08 13:03:53.4681+03
11197	59	-1	1030	2019-12-08 13:05:58.529881+03
11198	6	-1	980	2019-12-08 13:11:20.134716+03
11199	67	-2	350	2019-12-08 13:19:54.758226+03
11200	61	-2	1510	2019-12-08 13:20:35.105807+03
11201	96	-3	1570	2019-12-08 13:25:48.829429+03
11202	17	-2	1500	2019-12-08 13:52:24.095551+03
11203	57	-1	1900	2019-12-08 13:53:46.285307+03
11204	9	-1	2090	2019-12-08 13:55:33.974291+03
11205	84	-1	2700	2019-12-08 14:32:58.385498+03
11206	33	-2	900	2019-12-08 14:56:24.890963+03
11207	77	-1	640	2019-12-08 15:02:47.089817+03
11208	20	-1	830	2019-12-08 15:12:30.739002+03
11209	59	-1	1030	2019-12-08 15:46:26.810721+03
11210	67	-1	350	2019-12-08 16:03:11.889145+03
11211	32	-2	710	2019-12-08 16:08:12.456556+03
11212	23	-1	4390	2019-12-08 16:28:56.695708+03
11213	41	-1	830	2019-12-08 16:32:31.107944+03
11214	69	-1	1100	2019-12-08 16:48:15.556679+03
11215	76	-1	1070	2019-12-08 17:13:41.085664+03
11216	39	-1	910	2019-12-08 17:15:08.588555+03
11217	7	-1	810	2019-12-08 17:17:33.847846+03
11218	44	-1	500	2019-12-08 17:37:39.672564+03
11219	48	-1	640	2019-12-08 17:43:48.647934+03
11220	33	-2	900	2019-12-08 17:45:05.711265+03
11221	19	-2	1220	2019-12-08 17:45:25.760007+03
11222	92	-2	630	2019-12-08 17:47:28.211166+03
11223	5	-1	1620	2019-12-08 17:48:23.526599+03
11224	20	-1	830	2019-12-08 17:49:13.669562+03
11225	89	-1	1420	2019-12-08 17:50:42.25537+03
11226	89	-1	1420	2019-12-08 18:55:50.324658+03
11227	50	-1	1140	2019-12-08 19:38:52.728262+03
11228	72	13	270	2019-12-08 19:45:32.769621+03
11229	74	-1	1010	2019-12-08 19:51:42.505488+03
11230	89	-1	1420	2019-12-08 19:51:49.945346+03
11231	25	-1	1100	2019-12-08 20:02:01.171126+03
11232	47	-1	1480	2019-12-08 20:37:02.25391+03
11233	77	-1	640	2019-12-08 20:37:05.105811+03
11234	75	-1	830	2019-12-08 20:58:11.620526+03
11235	67	29	143	2019-12-08 21:38:05.376703+03
11236	18	-1	910	2019-12-08 22:05:43.074417+03
11237	47	-2	1480	2019-12-08 22:24:14.016468+03
11238	2	-1	470	2019-12-08 22:30:06.081872+03
11239	90	-1	1780	2019-12-08 22:55:13.862936+03
11240	39	-1	910	2019-12-08 23:35:00.639214+03
11241	84	-3	2700	2019-12-08 23:40:14.843251+03
11242	14	-1	1350	2019-12-08 23:52:38.55971+03
11243	60	-1	2700	2019-12-08 23:57:35.357781+03
11244	87	-1	2320	2019-12-09 00:05:53.482587+03
11245	48	-1	640	2019-12-09 00:34:50.462394+03
11246	91	-1	1620	2019-12-09 01:08:21.137667+03
11247	45	-2	1590	2019-12-09 01:13:19.580762+03
11248	90	-1	1780	2019-12-09 01:31:07.728108+03
11249	66	-1	690	2019-12-09 02:09:03.162763+03
11250	77	-1	640	2019-12-09 02:16:23.020752+03
11251	33	29	367	2019-12-09 02:34:15.500428+03
11252	7	-1	810	2019-12-09 02:35:43.74128+03
11253	39	25	471	2019-12-09 03:12:06.413655+03
11254	96	-1	1570	2019-12-09 03:24:42.849569+03
11255	88	-2	1270	2019-12-09 03:25:58.496804+03
11256	25	-1	1100	2019-12-09 04:03:31.437002+03
11257	9	-1	2090	2019-12-09 04:06:57.044213+03
11258	77	-1	640	2019-12-09 04:18:38.842028+03
11259	15	-1	2830	2019-12-09 04:26:36.722277+03
11260	13	-1	460	2019-12-09 04:31:53.56825+03
11261	51	-2	1310	2019-12-09 04:42:18.038215+03
11262	41	-1	830	2019-12-09 04:44:35.749062+03
11263	47	-1	1480	2019-12-09 05:05:33.722981+03
11264	82	-1	560	2019-12-09 05:38:57.437564+03
11265	3	-1	660	2019-12-09 05:45:00.772753+03
11266	69	-1	1100	2019-12-09 05:57:05.534967+03
11267	14	-1	1350	2019-12-09 06:22:45.728085+03
11268	95	-1	480	2019-12-09 06:29:07.059365+03
11269	33	-1	900	2019-12-09 06:30:02.080441+03
11270	17	-1	1500	2019-12-09 06:31:35.155895+03
11271	39	-1	910	2019-12-09 06:40:59.267744+03
11272	19	-1	1220	2019-12-09 06:41:51.940277+03
11273	78	-1	900	2019-12-09 06:47:26.691589+03
11274	55	-1	3480	2019-12-09 06:49:25.886675+03
11275	38	-2	1100	2019-12-09 06:56:47.665483+03
11276	13	-1	460	2019-12-09 07:07:07.762533+03
11277	58	-1	2830	2019-12-09 07:24:09.758722+03
11278	86	-1	910	2019-12-09 07:39:03.667712+03
11279	4	-1	1420	2019-12-09 07:50:46.395686+03
11280	28	-1	1860	2019-12-09 07:55:57.116197+03
11281	55	-2	3480	2019-12-09 07:58:13.633191+03
11282	33	-2	900	2019-12-09 08:01:26.503976+03
11283	17	-1	1500	2019-12-09 08:28:26.407703+03
11284	33	-1	900	2019-12-09 08:28:45.822464+03
11285	57	-1	1900	2019-12-09 08:51:31.660624+03
11286	47	-2	1480	2019-12-09 09:14:27.497018+03
11287	92	-1	630	2019-12-09 09:23:14.84933+03
11288	43	-2	380	2019-12-09 09:48:28.008622+03
11289	42	-1	1790	2019-12-09 09:51:05.643495+03
11290	11	-1	830	2019-12-09 09:53:52.34982+03
11291	95	-1	480	2019-12-09 09:58:53.902961+03
11292	34	-1	1550	2019-12-09 10:01:42.270082+03
11293	39	-2	910	2019-12-09 10:16:32.975977+03
11294	61	25	707	2019-12-09 10:40:21.609144+03
11295	58	-1	2830	2019-12-09 10:56:56.281522+03
11296	76	-1	1070	2019-12-09 11:18:07.938637+03
11297	86	-1	910	2019-12-09 12:06:10.488766+03
11298	91	-1	1620	2019-12-09 12:08:00.372871+03
11299	34	-1	1550	2019-12-09 12:15:52.185782+03
11300	72	-2	620	2019-12-09 12:23:49.385923+03
11301	1	-1	640	2019-12-09 12:53:34.878663+03
11302	73	-1	960	2019-12-09 13:19:26.132628+03
11303	75	-1	830	2019-12-09 13:27:16.930844+03
11304	8	-1	1920	2019-12-09 13:42:03.851135+03
11305	45	-1	1590	2019-12-09 13:44:33.050185+03
11306	30	-2	1140	2019-12-09 14:13:36.112858+03
11307	88	-1	1270	2019-12-09 14:48:36.008797+03
11308	17	-1	1500	2019-12-09 14:50:36.951315+03
11309	46	-1	1270	2019-12-09 14:59:06.612571+03
11310	70	-1	760	2019-12-09 15:17:10.81132+03
11311	42	-1	1790	2019-12-09 16:15:43.271393+03
11312	3	-1	660	2019-12-09 16:23:56.62122+03
11313	91	-1	1620	2019-12-09 16:32:09.652362+03
11314	7	-1	810	2019-12-09 16:34:57.232715+03
11315	16	-1	1380	2019-12-09 16:53:26.912071+03
11316	75	-1	830	2019-12-09 17:11:23.065897+03
11317	86	-1	910	2019-12-09 17:28:27.828744+03
11318	75	-1	830	2019-12-09 17:57:52.559755+03
11319	13	-2	460	2019-12-09 18:02:50.24835+03
11320	96	-1	1570	2019-12-09 18:12:16.265054+03
11321	22	-1	1070	2019-12-09 18:17:46.096559+03
11322	71	-1	1030	2019-12-09 18:42:14.021914+03
11323	49	-1	970	2019-12-09 19:54:56.029223+03
11324	39	-2	910	2019-12-09 20:14:46.956186+03
11325	27	-1	880	2019-12-09 20:26:05.272676+03
11326	84	-1	2700	2019-12-09 20:27:56.547346+03
11327	83	-1	1230	2019-12-09 20:59:54.517242+03
11328	11	24	415	2019-12-09 21:18:37.558658+03
11329	11	-1	830	2019-12-09 21:21:21.641865+03
11330	81	-1	1620	2019-12-09 21:25:16.183747+03
11331	81	-1	1620	2019-12-09 21:32:46.365946+03
11332	77	-1	640	2019-12-09 21:56:10.029784+03
11333	95	-1	480	2019-12-09 22:26:56.501214+03
11334	67	-1	350	2019-12-09 22:40:56.040304+03
11335	68	-2	490	2019-12-09 22:54:30.908569+03
11336	65	-1	490	2019-12-09 23:09:45.334969+03
11337	64	-1	970	2019-12-09 23:12:16.988486+03
11338	90	-1	1780	2019-12-09 23:25:08.866492+03
11339	41	-1	830	2019-12-09 23:25:54.337093+03
11340	37	-1	1290	2019-12-09 23:30:20.665352+03
11341	5	-1	1620	2019-12-09 23:36:06.127213+03
11342	78	-2	900	2019-12-10 00:15:03.204395+03
11343	58	-1	2830	2019-12-10 00:19:19.689497+03
11344	80	-1	1120	2019-12-10 00:25:15.735675+03
11345	43	-1	380	2019-12-10 00:37:15.065291+03
11346	76	-1	1070	2019-12-10 00:42:18.314573+03
11347	6	-1	980	2019-12-10 01:23:44.419248+03
11348	61	-2	1510	2019-12-10 01:48:42.547448+03
11349	94	-1	1230	2019-12-10 02:07:10.309454+03
11350	39	-1	910	2019-12-10 02:52:34.567478+03
11351	39	-2	910	2019-12-10 03:09:44.091862+03
11352	61	-1	1510	2019-12-10 03:23:45.853283+03
11353	29	-1	1940	2019-12-10 03:31:04.438264+03
11354	32	-1	710	2019-12-10 03:58:22.053249+03
11355	31	-1	1190	2019-12-10 04:01:40.804331+03
11356	49	-1	970	2019-12-10 04:12:15.70175+03
11357	38	-1	1100	2019-12-10 05:33:07.863471+03
11358	55	-1	3480	2019-12-10 05:34:11.362756+03
11359	76	-1	1070	2019-12-10 05:45:45.227446+03
11360	31	-1	1190	2019-12-10 06:18:05.31016+03
11361	6	-1	980	2019-12-10 06:21:50.213187+03
11362	29	-1	1940	2019-12-10 06:53:01.137295+03
11363	56	-1	2460	2019-12-10 07:04:58.628318+03
11364	1	-1	640	2019-12-10 07:05:10.682501+03
11365	14	-1	1350	2019-12-10 07:13:48.491096+03
11366	36	-1	630	2019-12-10 07:13:56.641802+03
11367	49	-1	970	2019-12-10 07:32:23.640376+03
11368	31	-2	1190	2019-12-10 07:34:39.237627+03
11369	8	-1	1920	2019-12-10 08:11:50.897785+03
11370	75	-1	830	2019-12-10 08:38:27.424253+03
11371	71	-3	1030	2019-12-10 09:00:18.342905+03
11372	60	-1	2700	2019-12-10 09:26:35.150437+03
11373	61	-1	1510	2019-12-10 09:38:36.283752+03
11374	4	-1	1420	2019-12-10 09:57:28.727107+03
11375	93	-1	1620	2019-12-10 10:05:16.950505+03
11376	78	-1	900	2019-12-10 10:10:52.103378+03
11377	28	-2	1860	2019-12-10 10:36:52.656734+03
11378	54	-1	3470	2019-12-10 10:47:15.492308+03
11379	56	-1	2460	2019-12-10 10:51:40.398435+03
11380	35	39	361	2019-12-10 11:33:17.377466+03
11381	49	-1	970	2019-12-10 11:34:27.938318+03
11382	60	-1	2700	2019-12-10 11:34:31.909714+03
11383	38	-1	1100	2019-12-10 11:47:36.850542+03
11384	95	-1	480	2019-12-10 12:15:45.453854+03
11385	58	25	1255	2019-12-10 12:30:06.876959+03
11386	54	-1	3470	2019-12-10 12:33:14.796267+03
11387	30	-1	1140	2019-12-10 12:37:40.673739+03
11388	96	-1	1570	2019-12-10 12:56:30.087546+03
11389	79	-1	550	2019-12-10 13:04:08.101215+03
11390	66	-1	690	2019-12-10 13:05:06.725163+03
11391	55	-1	3480	2019-12-10 13:15:21.93255+03
11392	22	-1	1070	2019-12-10 13:17:31.568612+03
11393	64	-1	970	2019-12-10 14:08:03.355377+03
11394	76	-1	1070	2019-12-10 14:27:44.633281+03
11395	89	-1	1420	2019-12-10 14:44:06.757378+03
11396	25	-1	1100	2019-12-10 14:55:49.180884+03
11397	15	-1	2830	2019-12-10 14:58:50.043169+03
11398	86	-2	910	2019-12-10 15:26:21.378562+03
11399	68	-1	490	2019-12-10 15:28:44.001787+03
11400	76	-2	1070	2019-12-10 15:38:17.46863+03
11401	86	-1	910	2019-12-10 15:39:03.938469+03
11402	56	-1	2460	2019-12-10 16:02:57.294778+03
11403	43	-1	380	2019-12-10 16:06:32.470633+03
11404	54	26	1768	2019-12-10 16:36:46.785197+03
11405	87	-1	2320	2019-12-10 16:56:30.796583+03
11406	71	-1	1030	2019-12-10 17:09:29.252406+03
11407	30	-1	1140	2019-12-10 17:10:33.668432+03
11408	34	-2	1550	2019-12-10 17:54:30.607225+03
11409	84	-1	2700	2019-12-10 18:04:00.220581+03
11410	57	-2	1900	2019-12-10 18:19:51.167985+03
11411	14	-2	1350	2019-12-10 18:31:47.987045+03
11412	48	22	355	2019-12-10 18:49:00.679704+03
11413	64	-2	970	2019-12-10 19:12:07.165343+03
11414	83	-1	1230	2019-12-10 19:18:52.924796+03
11415	24	20	482	2019-12-10 19:34:00.736091+03
11416	86	-1	910	2019-12-10 19:42:32.839048+03
11417	60	-1	2700	2019-12-10 19:51:45.11296+03
11418	58	-1	2830	2019-12-10 19:54:45.0056+03
11419	84	-1	2700	2019-12-10 20:11:49.049688+03
11420	33	-2	900	2019-12-10 20:17:26.903231+03
11421	96	-1	1570	2019-12-10 20:22:55.978718+03
11422	18	-2	910	2019-12-10 20:37:31.496223+03
11423	71	-1	1030	2019-12-10 20:45:08.241775+03
11424	24	-1	950	2019-12-10 21:05:15.774493+03
11425	13	-1	460	2019-12-10 22:01:17.98799+03
11426	81	-1	1620	2019-12-10 22:10:48.79672+03
11427	55	-1	3480	2019-12-10 22:13:29.689387+03
11428	1	-1	640	2019-12-10 22:54:32.363413+03
11429	87	-1	2320	2019-12-10 23:03:16.158734+03
11430	88	-1	1270	2019-12-10 23:07:50.389529+03
11431	51	-1	1310	2019-12-10 23:32:31.646519+03
11432	46	-2	1270	2019-12-10 23:52:06.650205+03
11433	48	-1	640	2019-12-11 00:20:57.252144+03
11434	31	-1	1190	2019-12-11 00:45:56.694453+03
11435	76	-2	1070	2019-12-11 00:49:01.493012+03
11436	32	-1	710	2019-12-11 00:59:00.611355+03
11437	95	-1	480	2019-12-11 01:11:50.240745+03
11438	46	-1	1270	2019-12-11 01:26:49.494504+03
11439	4	-1	1420	2019-12-11 01:33:47.607705+03
11440	83	-1	1230	2019-12-11 01:41:55.547184+03
11441	6	-1	980	2019-12-11 01:58:56.3435+03
11442	19	-1	1220	2019-12-11 02:50:05.042632+03
11443	69	-1	1100	2019-12-11 02:54:35.613566+03
11444	17	-1	1500	2019-12-11 03:15:11.917643+03
11445	9	-2	2090	2019-12-11 03:16:36.765024+03
11446	88	-1	1270	2019-12-11 03:16:58.943398+03
11447	42	-1	1790	2019-12-11 03:26:37.113145+03
11448	52	-1	1090	2019-12-11 04:21:47.903743+03
11449	95	-1	480	2019-12-11 04:51:18.184307+03
11450	58	-1	2830	2019-12-11 04:54:03.505771+03
11451	43	-1	380	2019-12-11 05:05:18.444452+03
11452	69	-1	1100	2019-12-11 05:18:31.551217+03
11453	89	32	637	2019-12-11 05:21:22.49929+03
11454	77	-1	640	2019-12-11 05:41:18.41879+03
11455	19	-1	1220	2019-12-11 06:52:11.172299+03
11456	85	-1	730	2019-12-11 06:56:26.952016+03
11457	68	-1	490	2019-12-11 07:03:48.540022+03
11458	34	-1	1550	2019-12-11 07:47:03.388234+03
11459	22	-1	1070	2019-12-11 08:01:54.626198+03
11460	33	-1	900	2019-12-11 08:05:40.561255+03
11461	16	-1	1380	2019-12-11 08:07:12.772725+03
11462	69	-1	1100	2019-12-11 08:09:12.163669+03
11463	79	-1	550	2019-12-11 08:17:25.700922+03
11464	21	-1	960	2019-12-11 08:41:40.248028+03
11465	42	-1	1790	2019-12-11 08:47:58.43743+03
11466	56	-1	2460	2019-12-11 08:48:11.171597+03
11467	2	-2	470	2019-12-11 08:56:29.804215+03
11468	14	-1	1350	2019-12-11 09:27:05.487967+03
11469	76	-2	1070	2019-12-11 09:39:59.478849+03
11470	39	-1	910	2019-12-11 09:47:09.844186+03
11471	52	-1	1090	2019-12-11 10:03:25.955817+03
11472	32	-1	710	2019-12-11 10:11:07.8726+03
11473	55	-1	3480	2019-12-11 10:23:19.564736+03
11474	55	-1	3480	2019-12-11 10:47:44.013393+03
11475	87	-1	2320	2019-12-11 11:05:08.084173+03
11476	2	-1	470	2019-12-11 11:15:12.244555+03
11477	21	-2	960	2019-12-11 11:24:31.92372+03
11478	41	-1	830	2019-12-11 11:28:39.288524+03
11479	96	-1	1570	2019-12-11 11:40:26.248127+03
11480	31	-2	1190	2019-12-11 11:58:43.608624+03
11481	19	-1	1220	2019-12-11 12:01:16.294837+03
11482	89	-1	1420	2019-12-11 12:05:58.881433+03
11483	30	-1	1140	2019-12-11 12:20:15.581191+03
11484	73	-2	960	2019-12-11 12:22:56.856952+03
11485	6	-1	980	2019-12-11 12:30:31.917114+03
11486	55	-1	3480	2019-12-11 12:31:31.777851+03
11487	51	-1	1310	2019-12-11 12:31:45.765321+03
11488	63	-2	1780	2019-12-11 12:45:58.872226+03
11489	49	-2	970	2019-12-11 12:58:00.733911+03
11490	46	-1	1270	2019-12-11 13:04:21.158387+03
11491	77	-1	640	2019-12-11 13:28:19.954848+03
11492	64	-1	970	2019-12-11 13:43:22.1235+03
11493	85	-1	730	2019-12-11 13:59:21.38356+03
11494	79	-1	550	2019-12-11 14:02:19.843848+03
11495	12	-2	1650	2019-12-11 14:04:34.720116+03
11496	76	-2	1070	2019-12-11 14:06:45.595057+03
11497	51	-1	1310	2019-12-11 14:08:36.830187+03
11498	36	-1	630	2019-12-11 15:16:38.663996+03
11499	12	-1	1650	2019-12-11 16:41:57.051538+03
11500	36	-1	630	2019-12-11 17:43:55.908876+03
11501	29	-1	1940	2019-12-11 17:54:19.662515+03
11502	31	-1	1190	2019-12-11 17:57:57.369017+03
11503	54	-2	3470	2019-12-11 18:06:39.925091+03
11504	32	-1	710	2019-12-11 18:27:04.744939+03
11505	90	-1	1780	2019-12-11 18:53:38.037144+03
11506	33	-1	900	2019-12-11 18:57:59.843468+03
11507	38	-1	1100	2019-12-11 19:24:21.345928+03
11508	95	-1	480	2019-12-11 19:38:42.233886+03
11509	10	-1	2080	2019-12-11 19:56:49.609102+03
11510	79	-1	550	2019-12-11 20:06:33.185781+03
11511	77	-1	640	2019-12-11 20:36:47.303512+03
11512	71	-1	1030	2019-12-11 21:52:06.397427+03
11513	94	-1	1230	2019-12-11 21:53:26.278911+03
11514	44	-2	500	2019-12-11 22:37:17.914115+03
11515	13	-2	460	2019-12-11 22:44:02.21944+03
11516	37	-1	1290	2019-12-11 22:49:20.657746+03
11517	85	-2	730	2019-12-11 23:03:05.035113+03
11518	87	-1	2320	2019-12-11 23:11:23.15739+03
11519	8	-1	1920	2019-12-11 23:15:43.285608+03
11520	1	-1	640	2019-12-11 23:44:12.876324+03
11521	59	-1	1030	2019-12-11 23:49:02.554541+03
11522	51	-1	1310	2019-12-11 23:49:46.702721+03
11523	75	-1	830	2019-12-12 00:06:09.733115+03
11524	77	-1	640	2019-12-12 00:45:22.712727+03
11525	6	-1	980	2019-12-12 00:54:12.518617+03
11526	80	-1	1120	2019-12-12 01:09:09.255377+03
11527	12	-2	1650	2019-12-12 01:55:45.072366+03
11528	21	-2	960	2019-12-12 02:26:47.522593+03
11529	40	-2	1430	2019-12-12 02:38:54.530051+03
11530	22	-1	1070	2019-12-12 03:13:54.402331+03
11531	39	-2	910	2019-12-12 03:14:35.446168+03
11532	71	-1	1030	2019-12-12 03:23:52.899095+03
11533	76	-1	1070	2019-12-12 04:02:37.141187+03
11534	55	-1	3480	2019-12-12 04:11:46.009459+03
11535	46	-1	1270	2019-12-12 04:22:17.451778+03
11536	49	-1	970	2019-12-12 04:50:04.273126+03
11537	23	-2	4390	2019-12-12 05:51:02.747955+03
11538	33	-1	900	2019-12-12 05:56:01.252359+03
11539	85	-1	730	2019-12-12 05:59:48.390916+03
11540	70	-1	760	2019-12-12 05:59:53.262341+03
11541	7	-1	810	2019-12-12 06:45:48.244471+03
11542	42	-2	1790	2019-12-12 07:09:59.867579+03
11543	43	-2	380	2019-12-12 07:25:49.969778+03
11544	6	-1	980	2019-12-12 07:45:38.127965+03
11545	78	-1	900	2019-12-12 07:46:52.939345+03
11546	56	-1	2460	2019-12-12 08:05:05.133527+03
11547	73	-1	960	2019-12-12 08:21:15.445893+03
11548	30	-1	1140	2019-12-12 08:25:46.631088+03
11549	68	-1	490	2019-12-12 08:35:00.53498+03
11550	37	-1	1290	2019-12-12 08:42:43.825322+03
11551	28	-1	1860	2019-12-12 08:56:27.765824+03
11552	36	-2	630	2019-12-12 08:58:25.674089+03
11553	27	-1	880	2019-12-12 09:01:44.947513+03
11554	3	-1	660	2019-12-12 09:18:23.766606+03
11555	96	-1	1570	2019-12-12 10:04:55.634561+03
11556	30	-1	1140	2019-12-12 10:13:35.297552+03
11557	80	-1	1120	2019-12-12 10:24:28.869624+03
11558	10	-1	2080	2019-12-12 10:31:29.029187+03
11559	1	-1	640	2019-12-12 10:37:14.179089+03
11560	94	-1	1230	2019-12-12 10:44:01.201661+03
11561	61	-1	1510	2019-12-12 11:03:59.476321+03
11562	36	-1	630	2019-12-12 11:16:42.059609+03
11563	10	-1	2080	2019-12-12 11:19:37.692385+03
11564	19	-2	1220	2019-12-12 11:24:12.745475+03
11565	55	-3	3480	2019-12-12 11:45:25.765309+03
11566	47	-1	1480	2019-12-12 12:11:33.757485+03
11567	71	-1	1030	2019-12-12 12:13:41.491143+03
11568	6	-1	980	2019-12-12 12:27:01.492374+03
11569	35	-2	670	2019-12-12 12:51:07.362141+03
11570	15	-1	2830	2019-12-12 12:53:31.386615+03
11571	23	-1	4390	2019-12-12 12:55:41.834505+03
11572	11	-1	830	2019-12-12 13:02:41.328651+03
11573	7	27	371	2019-12-12 13:59:43.234714+03
11574	6	-1	980	2019-12-12 14:14:04.561862+03
11575	37	-2	1290	2019-12-12 14:29:10.104783+03
11576	86	-1	910	2019-12-12 14:42:38.47466+03
11577	33	-1	900	2019-12-12 14:43:37.558357+03
11578	10	-1	2080	2019-12-12 15:21:39.82594+03
11579	23	-1	4390	2019-12-12 15:26:40.867624+03
11580	47	41	825	2019-12-12 16:10:07.09681+03
11581	96	-1	1570	2019-12-12 16:18:01.494324+03
11582	52	-1	1090	2019-12-12 16:53:19.260453+03
11583	79	-1	550	2019-12-12 16:57:39.286826+03
11584	18	-1	910	2019-12-12 17:28:36.407838+03
11585	42	-2	1790	2019-12-12 17:38:33.997952+03
11586	48	-1	640	2019-12-12 17:42:19.918217+03
11587	2	-1	470	2019-12-12 17:45:27.254023+03
11588	35	-1	670	2019-12-12 17:49:02.384278+03
11589	2	-1	470	2019-12-12 18:37:19.533624+03
11590	56	-1	2460	2019-12-12 18:46:27.230778+03
11591	17	-1	1500	2019-12-12 19:35:23.299906+03
11592	66	-1	690	2019-12-12 19:51:01.478146+03
11593	58	-1	2830	2019-12-12 19:59:11.315936+03
11594	35	-2	670	2019-12-12 20:46:03.51156+03
11595	49	-1	970	2019-12-12 20:58:16.661426+03
11596	16	-1	1380	2019-12-12 21:01:28.756696+03
11597	34	-2	1550	2019-12-12 21:19:49.877455+03
11598	49	-1	970	2019-12-12 21:41:36.205251+03
11599	92	-2	630	2019-12-12 21:49:12.616625+03
11600	61	-1	1510	2019-12-12 21:56:03.204568+03
11601	30	-1	1140	2019-12-12 21:59:42.231647+03
11602	89	-1	1420	2019-12-12 22:18:46.283371+03
11603	73	-1	960	2019-12-12 22:26:37.208293+03
11604	30	-1	1140	2019-12-12 22:39:48.391973+03
11605	64	-1	970	2019-12-12 22:52:49.825739+03
11606	15	-2	2830	2019-12-13 00:01:51.644061+03
11607	14	-1	1350	2019-12-13 00:17:33.918656+03
11608	63	-1	1780	2019-12-13 00:46:06.207614+03
11609	63	-1	1780	2019-12-13 01:56:36.965758+03
11610	46	-1	1270	2019-12-13 02:01:10.597678+03
11611	58	-1	2830	2019-12-13 02:05:51.69724+03
11612	23	-1	4390	2019-12-13 02:12:29.397068+03
11613	73	-1	960	2019-12-13 03:20:16.347937+03
11614	10	-2	2080	2019-12-13 04:11:44.523375+03
11615	79	-1	550	2019-12-13 04:25:28.651479+03
11616	37	-1	1290	2019-12-13 04:34:51.86838+03
11617	92	-2	630	2019-12-13 04:38:44.562823+03
11618	93	-1	1620	2019-12-13 04:39:39.255487+03
11619	68	-1	490	2019-12-13 04:39:55.66634+03
11620	17	-1	1500	2019-12-13 04:48:04.58026+03
11621	46	-1	1270	2019-12-13 04:53:33.385577+03
11622	88	-1	1270	2019-12-13 05:04:46.863657+03
11623	96	-1	1570	2019-12-13 05:26:07.83688+03
11624	51	-1	1310	2019-12-13 05:41:33.361388+03
11625	56	-2	2460	2019-12-13 05:42:49.128344+03
11626	5	-2	1620	2019-12-13 05:58:17.792047+03
11627	9	-1	2090	2019-12-13 06:16:45.208155+03
11628	17	-1	1500	2019-12-13 06:24:16.854719+03
11629	44	-1	500	2019-12-13 07:02:49.229581+03
11630	95	-1	480	2019-12-13 07:06:50.118751+03
11631	58	-1	2830	2019-12-13 07:19:24.090146+03
11632	65	-2	490	2019-12-13 07:29:35.242737+03
11633	12	-2	1650	2019-12-13 07:38:18.50233+03
11634	13	-1	460	2019-12-13 07:38:34.380923+03
11635	27	-1	880	2019-12-13 07:52:28.430466+03
11636	11	-1	830	2019-12-13 08:15:40.021069+03
11637	6	-1	980	2019-12-13 08:27:48.970829+03
11638	78	-1	900	2019-12-13 08:39:41.304708+03
11639	70	-1	760	2019-12-13 09:02:55.713643+03
11640	74	-1	1010	2019-12-13 09:22:17.597762+03
11641	35	-1	670	2019-12-13 09:48:36.605034+03
11642	13	-1	460	2019-12-13 09:55:42.070035+03
11643	27	25	369	2019-12-13 10:30:31.038167+03
11644	77	-1	640	2019-12-13 10:39:04.698566+03
11645	4	-1	1420	2019-12-13 11:02:50.442233+03
11646	10	-2	2080	2019-12-13 11:11:32.22729+03
11647	49	-1	970	2019-12-13 11:19:48.176143+03
11648	18	-1	910	2019-12-13 11:23:22.67158+03
11649	34	-1	1550	2019-12-13 12:24:13.980365+03
11650	78	-1	900	2019-12-13 12:30:04.624838+03
11651	49	-1	970	2019-12-13 13:02:47.812189+03
11652	2	-1	470	2019-12-13 13:06:55.869211+03
11653	10	-2	2080	2019-12-13 13:27:35.882203+03
11654	30	-1	1140	2019-12-13 14:25:18.831062+03
11655	12	-2	1650	2019-12-13 14:28:45.553639+03
11656	73	-1	960	2019-12-13 14:34:57.671391+03
11657	86	-1	910	2019-12-13 15:04:07.392708+03
11658	93	-1	1620	2019-12-13 15:28:39.122964+03
11659	85	-1	730	2019-12-13 15:30:29.162815+03
11660	58	-2	2830	2019-12-13 15:53:08.072362+03
11661	17	-2	1500	2019-12-13 16:14:46.889943+03
11662	47	-1	1480	2019-12-13 16:24:09.652754+03
11663	42	-1	1790	2019-12-13 16:25:04.67101+03
11664	96	-1	1570	2019-12-13 16:26:55.639401+03
11665	47	-2	1480	2019-12-13 16:37:23.681777+03
11666	39	-1	910	2019-12-13 16:38:06.973703+03
11667	3	-1	660	2019-12-13 17:31:17.987654+03
11668	7	-2	810	2019-12-13 17:47:25.711841+03
11669	56	-1	2460	2019-12-13 17:48:33.055359+03
11670	52	-1	1090	2019-12-13 17:58:30.788461+03
11671	5	-1	1620	2019-12-13 18:16:34.959307+03
11672	14	-1	1350	2019-12-13 19:24:25.563304+03
11673	9	-2	2090	2019-12-13 19:49:47.691883+03
11674	82	-1	560	2019-12-13 20:04:54.66923+03
11675	37	-1	1290	2019-12-13 20:09:45.529551+03
11676	5	-1	1620	2019-12-13 20:21:19.642066+03
11677	33	-1	900	2019-12-13 20:22:26.891883+03
11678	8	-2	1920	2019-12-13 20:27:24.993072+03
11679	61	-1	1510	2019-12-13 20:41:40.500512+03
11680	27	-3	880	2019-12-13 20:43:48.996603+03
11681	19	-1	1220	2019-12-13 20:47:21.83794+03
11682	12	-1	1650	2019-12-13 20:53:59.295624+03
11683	42	-1	1790	2019-12-13 21:05:43.163929+03
11684	6	-1	980	2019-12-13 21:24:13.851998+03
11685	95	-2	480	2019-12-13 21:35:42.863008+03
11686	58	-1	2830	2019-12-13 21:36:47.740142+03
11687	93	-1	1620	2019-12-13 21:37:13.046788+03
11688	53	-2	3120	2019-12-13 21:43:01.558993+03
11689	10	-1	2080	2019-12-13 21:43:30.084422+03
11690	36	-1	630	2019-12-13 21:44:25.547804+03
11691	47	-1	1480	2019-12-13 21:46:23.589274+03
11692	7	-1	810	2019-12-13 22:05:44.909853+03
11693	22	-1	1070	2019-12-13 22:13:23.430134+03
11694	19	-1	1220	2019-12-13 22:21:04.889314+03
11695	27	-1	880	2019-12-13 23:15:43.27916+03
11696	11	-2	830	2019-12-13 23:56:08.780487+03
11697	5	-1	1620	2019-12-14 00:03:31.843736+03
11698	69	-1	1100	2019-12-14 00:55:48.669442+03
11699	12	-1	1650	2019-12-14 01:27:51.064202+03
11700	26	-2	390	2019-12-14 01:32:34.436693+03
11701	54	-3	3470	2019-12-14 01:33:27.217727+03
11702	73	-1	960	2019-12-14 01:33:39.741861+03
11703	88	-1	1270	2019-12-14 01:41:30.028466+03
11704	61	-1	1510	2019-12-14 01:50:45.151116+03
11705	37	-1	1290	2019-12-14 02:15:26.789348+03
11706	21	-1	960	2019-12-14 02:35:09.572083+03
11707	53	-2	3120	2019-12-14 02:44:59.021786+03
11708	68	-1	490	2019-12-14 03:08:27.257356+03
11709	30	27	478	2019-12-14 03:11:19.464591+03
11710	95	-1	480	2019-12-14 03:11:21.606127+03
11711	29	-1	1940	2019-12-14 03:16:08.130817+03
11712	39	-1	910	2019-12-14 03:32:37.058448+03
11713	37	-1	1290	2019-12-14 03:47:16.974687+03
11714	83	-1	1230	2019-12-14 03:48:15.002283+03
11715	43	19	190	2019-12-14 03:51:17.05103+03
11716	19	-1	1220	2019-12-14 03:57:27.771464+03
11717	4	-2	1420	2019-12-14 04:01:25.098927+03
11718	64	-1	970	2019-12-14 04:07:53.078458+03
11719	20	-2	830	2019-12-14 04:13:19.863427+03
11720	67	-2	350	2019-12-14 04:30:36.436681+03
11721	56	-1	2460	2019-12-14 04:34:58.937601+03
11722	71	32	551	2019-12-14 04:35:33.56239+03
11723	27	-1	880	2019-12-14 04:36:16.710507+03
11724	75	-2	830	2019-12-14 04:48:22.672755+03
11725	13	-1	460	2019-12-14 04:48:54.379083+03
11726	21	-3	960	2019-12-14 05:01:26.697648+03
11727	69	-1	1100	2019-12-14 05:23:59.432765+03
11728	4	-1	1420	2019-12-14 05:34:04.325762+03
11729	14	-1	1350	2019-12-14 05:41:19.599939+03
11730	88	-2	1270	2019-12-14 05:47:34.082628+03
11731	79	-1	550	2019-12-14 05:57:22.16555+03
11732	46	-2	1270	2019-12-14 05:57:33.658682+03
11733	67	-2	350	2019-12-14 05:59:08.352821+03
11734	14	47	738	2019-12-14 06:13:42.409724+03
11735	5	-1	1620	2019-12-14 06:15:09.471361+03
11736	65	-1	490	2019-12-14 06:18:48.587244+03
11737	12	-1	1650	2019-12-14 06:36:45.202875+03
11738	71	-1	1030	2019-12-14 06:37:34.585745+03
11739	37	-2	1290	2019-12-14 06:54:23.282372+03
11740	84	-1	2700	2019-12-14 07:11:26.092593+03
11741	95	-1	480	2019-12-14 07:16:21.883987+03
11742	4	-2	1420	2019-12-14 07:54:12.918588+03
11743	14	-2	1350	2019-12-14 08:11:09.338177+03
11744	31	-1	1190	2019-12-14 09:13:08.405297+03
11745	69	-1	1100	2019-12-14 09:16:46.879844+03
11746	75	-1	830	2019-12-14 09:41:16.726585+03
11747	6	-1	980	2019-12-14 09:47:07.710208+03
11748	9	-1	2090	2019-12-14 09:49:27.736968+03
11749	4	-1	1420	2019-12-14 10:06:09.08726+03
11750	28	-1	1860	2019-12-14 10:12:37.465845+03
11751	1	-1	640	2019-12-14 10:21:44.975086+03
11752	77	-1	640	2019-12-14 10:40:22.663534+03
11753	62	-2	1220	2019-12-14 11:04:32.117553+03
11754	32	-1	710	2019-12-14 11:09:29.601634+03
11755	49	32	460	2019-12-14 11:14:33.979584+03
11756	88	-2	1270	2019-12-14 11:16:11.907571+03
11757	37	-1	1290	2019-12-14 11:20:13.371594+03
11758	77	-1	640	2019-12-14 11:25:11.990207+03
11759	81	-1	1620	2019-12-14 11:35:09.698716+03
11760	25	-1	1100	2019-12-14 12:20:46.174083+03
11761	87	-1	2320	2019-12-14 12:36:51.439679+03
11762	38	-1	1100	2019-12-14 12:52:35.713992+03
11763	96	-1	1570	2019-12-14 13:32:32.468051+03
11764	74	-2	1010	2019-12-14 14:23:21.874619+03
11765	30	-1	1140	2019-12-14 14:26:57.519042+03
11766	14	-1	1350	2019-12-14 15:01:08.046365+03
11767	33	-1	900	2019-12-14 15:14:46.508079+03
11768	12	-1	1650	2019-12-14 15:21:16.911525+03
11769	13	-1	460	2019-12-14 15:37:13.955324+03
11770	42	-2	1790	2019-12-14 15:38:24.223452+03
11771	12	-1	1650	2019-12-14 15:40:28.768083+03
11772	63	-1	1780	2019-12-14 15:57:56.587721+03
11773	27	-1	880	2019-12-14 16:58:01.013791+03
11774	30	-1	1140	2019-12-14 17:00:31.013775+03
11775	63	-2	1780	2019-12-14 17:08:09.798849+03
11776	78	-1	900	2019-12-14 17:29:36.310513+03
11777	18	-1	910	2019-12-14 17:33:07.549925+03
11778	30	-1	1140	2019-12-14 18:21:41.578069+03
11779	22	-1	1070	2019-12-14 18:36:48.782048+03
11780	94	-1	1230	2019-12-14 18:38:22.529211+03
11781	73	-1	960	2019-12-14 19:19:05.409183+03
11782	69	-1	1100	2019-12-14 19:55:41.811959+03
11783	61	-1	1510	2019-12-14 20:01:25.412589+03
11784	75	-1	830	2019-12-14 20:27:01.525411+03
11785	33	-2	900	2019-12-14 20:31:40.44699+03
11786	65	14	198	2019-12-14 20:41:00.412418+03
11787	32	-1	710	2019-12-14 21:10:57.468019+03
11788	30	-1	1140	2019-12-14 21:48:23.859922+03
11789	91	-1	1620	2019-12-14 22:27:26.505959+03
11790	63	-2	1780	2019-12-14 22:49:21.992974+03
11791	93	-1	1620	2019-12-14 22:55:43.850496+03
11792	69	25	516	2019-12-14 23:02:44.162112+03
11793	30	-1	1140	2019-12-14 23:12:46.719393+03
11794	58	-1	2830	2019-12-14 23:24:18.048949+03
11795	31	-1	1190	2019-12-14 23:30:55.13118+03
11796	30	-1	1140	2019-12-14 23:37:23.713573+03
11797	48	-1	640	2019-12-14 23:39:36.495323+03
11798	23	-2	4390	2019-12-14 23:43:04.580555+03
11799	83	-1	1230	2019-12-14 23:49:59.693557+03
11800	96	-1	1570	2019-12-15 00:03:05.853455+03
11801	71	-1	1030	2019-12-15 00:03:48.937001+03
11802	9	-1	2090	2019-12-15 00:40:24.512114+03
11803	33	-1	900	2019-12-15 00:52:50.520048+03
11804	76	-1	1070	2019-12-15 01:15:10.821161+03
11805	96	-1	1570	2019-12-15 01:27:58.413984+03
11806	14	-1	1350	2019-12-15 01:36:51.276631+03
11807	16	-1	1380	2019-12-15 01:43:11.869682+03
11808	36	-1	630	2019-12-15 01:45:45.979329+03
11809	91	-1	1620	2019-12-15 01:56:48.853212+03
11810	49	-1	970	2019-12-15 02:01:12.427047+03
11811	88	22	574	2019-12-15 02:04:36.456763+03
11812	45	-1	1590	2019-12-15 02:07:06.844957+03
11813	85	-1	730	2019-12-15 02:15:41.809474+03
11814	36	-2	630	2019-12-15 02:23:51.496694+03
11815	93	-3	1620	2019-12-15 02:26:23.190219+03
11816	39	-2	910	2019-12-15 02:40:19.176675+03
11817	78	21	427	2019-12-15 03:35:57.755071+03
11818	59	-1	1030	2019-12-15 03:37:38.910322+03
11819	30	-1	1140	2019-12-15 03:51:03.469183+03
11820	11	-1	830	2019-12-15 04:00:20.666088+03
11821	61	-1	1510	2019-12-15 04:13:10.016763+03
11822	23	-1	4390	2019-12-15 04:28:32.940659+03
11823	5	-2	1620	2019-12-15 04:46:51.884725+03
11824	72	-3	620	2019-12-15 05:10:14.678601+03
11825	90	-1	1780	2019-12-15 05:58:38.597137+03
11826	56	-1	2460	2019-12-15 06:02:10.196106+03
11827	51	27	573	2019-12-15 06:05:23.701983+03
11828	46	-1	1270	2019-12-15 06:06:53.276046+03
11829	33	-1	900	2019-12-15 06:23:31.105644+03
11830	13	-1	460	2019-12-15 06:27:59.440629+03
11831	59	-1	1030	2019-12-15 06:56:04.432824+03
11832	29	-2	1940	2019-12-15 07:05:41.143924+03
11833	75	-1	830	2019-12-15 07:11:14.055416+03
11834	21	-1	960	2019-12-15 07:54:34.474764+03
11835	49	-2	970	2019-12-15 08:18:53.714103+03
11836	76	-2	1070	2019-12-15 08:42:22.840394+03
11837	37	-1	1290	2019-12-15 08:44:43.54405+03
11838	44	-1	500	2019-12-15 08:51:22.402644+03
11839	70	-1	760	2019-12-15 08:53:42.592139+03
11840	49	-1	970	2019-12-15 08:59:26.659666+03
11841	41	-1	830	2019-12-15 09:01:07.513365+03
11842	41	19	461	2019-12-15 09:15:46.62686+03
11843	70	-1	760	2019-12-15 09:39:56.506417+03
11844	35	-2	670	2019-12-15 09:41:16.693263+03
11845	48	-1	640	2019-12-15 10:37:40.767131+03
11846	15	24	1224	2019-12-15 10:54:58.89179+03
11847	60	-1	2700	2019-12-15 11:00:23.596378+03
11848	83	-1	1230	2019-12-15 11:15:23.525654+03
11849	41	-1	830	2019-12-15 11:29:01.506331+03
11850	11	-1	830	2019-12-15 11:50:15.725421+03
11851	70	-1	760	2019-12-15 11:52:08.786008+03
11852	56	33	1103	2019-12-15 11:57:12.848819+03
11853	13	-1	460	2019-12-15 12:06:00.045907+03
11854	4	-1	1420	2019-12-15 12:10:10.068354+03
11855	96	25	639	2019-12-15 12:10:45.384615+03
11856	95	-1	480	2019-12-15 13:22:33.469981+03
11857	92	-1	630	2019-12-15 13:27:16.87153+03
11858	56	-1	2460	2019-12-15 13:56:55.738081+03
11859	12	-1	1650	2019-12-15 14:02:51.379097+03
11860	56	-1	2460	2019-12-15 14:26:01.488988+03
11861	72	-2	620	2019-12-15 14:39:52.340893+03
11862	78	-1	900	2019-12-15 15:19:46.072533+03
11863	2	-1	470	2019-12-15 16:17:55.57537+03
11864	55	33	1870	2019-12-15 17:06:41.350524+03
11865	40	-2	1430	2019-12-15 17:19:53.887878+03
11866	49	-1	970	2019-12-15 17:27:13.859698+03
11867	13	-2	460	2019-12-15 17:38:52.264292+03
11868	68	-2	490	2019-12-15 17:42:43.706571+03
11869	81	24	742	2019-12-15 17:43:51.897795+03
11870	82	-2	560	2019-12-15 18:03:07.505575+03
11871	94	-1	1230	2019-12-15 18:03:13.205786+03
11872	53	-1	3120	2019-12-15 18:36:45.138287+03
11873	47	-1	1480	2019-12-15 18:46:46.422392+03
11874	44	-1	500	2019-12-15 19:11:29.382827+03
11875	19	-1	1220	2019-12-15 19:26:04.277358+03
11876	6	-1	980	2019-12-15 19:29:15.790458+03
11877	78	-2	900	2019-12-15 19:54:39.884896+03
11878	20	-1	830	2019-12-15 19:59:30.931974+03
11879	45	-1	1590	2019-12-15 20:03:10.94589+03
11880	94	-2	1230	2019-12-15 20:28:35.844432+03
11881	58	-1	2830	2019-12-15 20:31:11.422893+03
11882	46	-1	1270	2019-12-15 20:36:07.881493+03
11883	31	-1	1190	2019-12-15 20:52:44.122742+03
11884	67	-2	350	2019-12-15 21:13:52.324728+03
11885	54	-1	3470	2019-12-15 21:49:46.448563+03
11886	7	-1	810	2019-12-15 22:01:18.964516+03
11887	80	-1	1120	2019-12-15 22:24:15.240063+03
11888	30	-2	1140	2019-12-15 22:48:03.076371+03
11889	55	-1	3480	2019-12-15 23:14:49.156474+03
11890	82	-1	560	2019-12-15 23:22:27.467204+03
11891	64	-1	970	2019-12-15 23:24:52.366894+03
11892	53	-2	3120	2019-12-15 23:30:55.975575+03
11893	96	-2	1570	2019-12-15 23:57:21.831745+03
11894	67	-1	350	2019-12-16 00:35:53.141976+03
11895	39	-1	910	2019-12-16 00:49:25.507388+03
11896	87	-1	2320	2019-12-16 01:20:07.850632+03
11897	91	-1	1620	2019-12-16 01:53:23.068574+03
11898	61	-1	1510	2019-12-16 02:02:28.771293+03
11899	91	-1	1620	2019-12-16 02:13:44.333681+03
11900	50	-1	1140	2019-12-16 02:31:17.24078+03
11901	56	-1	2460	2019-12-16 02:44:55.96285+03
11902	21	24	425	2019-12-16 02:44:56.99644+03
11903	16	-1	1380	2019-12-16 03:23:25.565177+03
11904	86	-1	910	2019-12-16 03:24:58.929056+03
11905	61	-1	1510	2019-12-16 03:46:35.036304+03
11906	39	-1	910	2019-12-16 04:13:58.337678+03
11907	45	-1	1590	2019-12-16 04:17:59.124201+03
11908	46	-1	1270	2019-12-16 05:31:51.063579+03
11909	70	-1	760	2019-12-16 05:50:58.082302+03
11910	6	-2	980	2019-12-16 05:51:00.448269+03
11911	25	18	545	2019-12-16 07:07:30.317522+03
11912	5	-1	1620	2019-12-16 07:11:33.522567+03
11913	93	-1	1620	2019-12-16 07:24:52.864309+03
11914	89	-2	1420	2019-12-16 08:21:31.637509+03
11915	34	-1	1550	2019-12-16 08:24:02.671029+03
11916	61	-1	1510	2019-12-16 08:32:47.415423+03
11917	42	-2	1790	2019-12-16 08:44:11.424662+03
11918	40	-1	1430	2019-12-16 09:10:39.829713+03
11919	11	-1	830	2019-12-16 09:17:21.257884+03
11920	87	-1	2320	2019-12-16 09:36:01.085996+03
11921	78	-1	900	2019-12-16 10:27:55.185368+03
11922	32	-2	710	2019-12-16 11:00:23.904551+03
11923	58	-2	2830	2019-12-16 11:13:51.077779+03
11924	35	-1	670	2019-12-16 12:19:02.983616+03
11925	59	-2	1030	2019-12-16 12:28:09.000329+03
11926	12	-2	1650	2019-12-16 12:32:56.955841+03
11927	2	-1	470	2019-12-16 12:51:21.238742+03
11928	41	-1	830	2019-12-16 13:03:16.177362+03
11929	20	-1	830	2019-12-16 13:16:00.835297+03
11930	50	-1	1140	2019-12-16 14:02:16.946052+03
11931	81	-1	1620	2019-12-16 14:15:50.730936+03
11932	77	-1	640	2019-12-16 14:18:31.047401+03
11933	43	-1	380	2019-12-16 14:23:45.038762+03
11934	88	-1	1270	2019-12-16 14:46:24.898583+03
11935	29	-2	1940	2019-12-16 15:00:35.604626+03
11936	34	-2	1550	2019-12-16 15:10:09.726208+03
11937	8	-1	1920	2019-12-16 15:28:42.876467+03
11938	1	-1	640	2019-12-16 15:29:14.048037+03
11939	46	-1	1270	2019-12-16 16:05:04.875189+03
11940	78	-2	900	2019-12-16 16:10:44.603095+03
11941	46	-1	1270	2019-12-16 16:13:05.845773+03
11942	10	-1	2080	2019-12-16 16:17:19.879338+03
11943	22	-1	1070	2019-12-16 16:40:30.958614+03
11944	7	-1	810	2019-12-16 17:47:01.425958+03
11945	74	-1	1010	2019-12-16 18:23:23.414207+03
11946	17	-1	1500	2019-12-16 18:38:43.1204+03
11947	39	-1	910	2019-12-16 18:50:32.604065+03
11948	88	-1	1270	2019-12-16 18:51:32.57795+03
11949	46	-1	1270	2019-12-16 18:52:53.554981+03
11950	82	-1	560	2019-12-16 18:57:26.315659+03
11951	29	-1	1940	2019-12-16 19:04:22.564133+03
11952	27	-2	880	2019-12-16 20:03:42.911587+03
11953	48	-2	640	2019-12-16 20:17:39.316641+03
11954	60	-1	2700	2019-12-16 20:54:50.304035+03
11955	39	-1	910	2019-12-16 21:15:40.376691+03
11956	78	-1	900	2019-12-16 21:16:41.195821+03
11957	94	-1	1230	2019-12-16 21:17:36.777505+03
11958	75	-1	830	2019-12-16 21:24:37.56493+03
11959	58	-1	2830	2019-12-16 21:34:11.312086+03
11960	72	-2	620	2019-12-16 21:34:13.994176+03
11961	75	-1	830	2019-12-16 21:48:15.111717+03
11962	91	-1	1620	2019-12-16 22:12:16.608813+03
11963	87	-1	2320	2019-12-16 22:14:26.581979+03
11964	20	-1	830	2019-12-16 22:17:18.09875+03
11965	63	-2	1780	2019-12-16 22:25:10.888063+03
11966	45	30	894	2019-12-16 22:33:07.430394+03
11967	89	-1	1420	2019-12-16 22:35:33.383309+03
11968	38	-2	1100	2019-12-16 23:25:57.397572+03
11969	87	-1	2320	2019-12-16 23:27:06.326002+03
11970	4	-1	1420	2019-12-16 23:35:45.368329+03
11971	21	-2	960	2019-12-16 23:38:15.210128+03
11972	36	-1	630	2019-12-17 00:19:14.142621+03
11973	82	-1	560	2019-12-17 00:29:11.008911+03
11974	23	-1	4390	2019-12-17 01:02:45.528459+03
11975	28	-1	1860	2019-12-17 01:38:51.673868+03
11976	29	-2	1940	2019-12-17 01:45:25.945631+03
11977	26	-2	390	2019-12-17 02:00:21.072584+03
11978	59	-1	1030	2019-12-17 02:08:46.532408+03
11979	67	-2	350	2019-12-17 03:53:20.966128+03
11980	24	-2	950	2019-12-17 04:27:28.366261+03
11981	15	-1	2830	2019-12-17 04:32:40.323232+03
11982	30	-1	1140	2019-12-17 04:44:53.84032+03
11983	47	-1	1480	2019-12-17 04:49:39.317397+03
11984	27	-2	880	2019-12-17 05:06:23.9706+03
11985	70	-1	760	2019-12-17 05:07:16.2791+03
11986	60	-2	2700	2019-12-17 05:08:43.409689+03
11987	33	-2	900	2019-12-17 05:30:25.311174+03
11988	86	-1	910	2019-12-17 05:31:41.820316+03
11989	37	-1	1290	2019-12-17 06:00:08.792356+03
11990	8	-1	1920	2019-12-17 06:03:36.641602+03
11991	23	-1	4390	2019-12-17 06:06:48.502998+03
11992	45	-1	1590	2019-12-17 06:14:35.721841+03
11993	49	-2	970	2019-12-17 06:23:38.910687+03
11994	34	-1	1550	2019-12-17 06:33:31.151492+03
11995	7	-1	810	2019-12-17 06:36:22.368341+03
11996	69	-2	1100	2019-12-17 06:49:31.767584+03
11997	94	-1	1230	2019-12-17 07:08:09.91098+03
11998	22	-1	1070	2019-12-17 07:18:14.380203+03
11999	37	-1	1290	2019-12-17 07:57:43.440137+03
12000	37	-1	1290	2019-12-17 08:30:27.897971+03
12001	46	-1	1270	2019-12-17 08:42:29.938985+03
12002	55	-1	3480	2019-12-17 08:47:03.58038+03
12003	52	-1	1090	2019-12-17 09:06:36.944528+03
12004	33	-1	900	2019-12-17 09:17:21.722316+03
12005	77	-2	640	2019-12-17 09:23:19.841342+03
12006	47	-1	1480	2019-12-17 09:35:11.653203+03
12007	36	-1	630	2019-12-17 09:55:08.235788+03
12008	89	-2	1420	2019-12-17 10:29:13.861907+03
12009	40	-1	1430	2019-12-17 10:39:31.610792+03
12010	76	-2	1070	2019-12-17 10:40:47.170993+03
12011	71	-1	1030	2019-12-17 10:43:22.600154+03
12012	60	-1	2700	2019-12-17 10:51:43.804252+03
12013	70	-1	760	2019-12-17 10:54:19.017374+03
12014	86	-1	910	2019-12-17 10:59:52.712047+03
12015	7	-1	810	2019-12-17 11:07:24.077206+03
12016	14	-1	1350	2019-12-17 11:16:24.734888+03
12017	49	-1	970	2019-12-17 11:49:53.53836+03
12018	62	-1	1220	2019-12-17 12:01:57.219166+03
12019	48	-1	640	2019-12-17 12:15:15.377438+03
12020	4	-1	1420	2019-12-17 12:19:19.815273+03
12021	8	-1	1920	2019-12-17 12:34:07.378755+03
12022	45	-1	1590	2019-12-17 12:36:27.988264+03
12023	76	-1	1070	2019-12-17 12:38:06.145181+03
12024	86	-1	910	2019-12-17 12:52:44.560502+03
12025	14	-1	1350	2019-12-17 13:00:25.732819+03
12026	90	-1	1780	2019-12-17 13:04:57.903076+03
12027	63	-1	1780	2019-12-17 13:13:04.116928+03
12028	78	-1	900	2019-12-17 13:20:26.932533+03
12029	37	-2	1290	2019-12-17 13:34:45.724507+03
12030	71	-1	1030	2019-12-17 13:38:36.481748+03
12031	1	-1	640	2019-12-17 13:52:33.007981+03
12032	51	-2	1310	2019-12-17 14:08:14.537041+03
12033	14	-1	1350	2019-12-17 14:25:39.593277+03
12034	11	-1	830	2019-12-17 14:27:51.269891+03
12035	10	-1	2080	2019-12-17 14:29:09.294539+03
12036	93	-2	1620	2019-12-17 14:37:16.418378+03
12037	13	-2	460	2019-12-17 15:05:47.424805+03
12038	32	-1	710	2019-12-17 15:54:52.470222+03
12039	55	-1	3480	2019-12-17 16:14:36.831308+03
12040	80	-1	1120	2019-12-17 16:44:51.765825+03
12041	42	-1	1790	2019-12-17 16:55:19.731583+03
12042	56	-1	2460	2019-12-17 16:58:42.236729+03
12043	92	-2	630	2019-12-17 17:55:32.580534+03
12044	11	-1	830	2019-12-17 18:08:39.530997+03
12045	94	-1	1230	2019-12-17 18:38:25.716566+03
12046	79	-1	550	2019-12-17 18:48:07.213607+03
12047	37	-1	1290	2019-12-17 18:51:04.985492+03
12048	20	-1	830	2019-12-17 19:21:52.045435+03
12049	48	-2	640	2019-12-17 19:24:07.963375+03
12050	90	-1	1780	2019-12-17 19:29:57.322637+03
12051	84	-1	2700	2019-12-17 20:00:59.791307+03
12052	34	-1	1550	2019-12-17 20:17:52.713402+03
12053	20	34	335	2019-12-17 20:27:18.135481+03
12054	17	-1	1500	2019-12-17 20:28:02.727645+03
12055	33	-1	900	2019-12-17 20:42:34.108263+03
12056	12	-2	1650	2019-12-17 20:47:13.047123+03
12057	21	-1	960	2019-12-17 21:06:15.008107+03
12058	93	18	743	2019-12-17 21:43:33.012937+03
12059	51	-1	1310	2019-12-17 22:04:47.543069+03
12060	71	-1	1030	2019-12-17 22:09:06.109551+03
12061	34	-1	1550	2019-12-17 22:45:02.171822+03
12062	27	-1	880	2019-12-17 22:58:13.597917+03
12063	35	-1	670	2019-12-17 23:05:11.758059+03
12064	19	-1	1220	2019-12-17 23:41:42.304283+03
12065	46	-1	1270	2019-12-17 23:56:06.936345+03
12066	29	-1	1940	2019-12-17 23:56:16.800362+03
12067	86	-1	910	2019-12-18 00:17:53.589661+03
12068	93	-1	1620	2019-12-18 00:57:49.04595+03
12069	7	-1	810	2019-12-18 01:07:02.400265+03
12070	7	-1	810	2019-12-18 01:10:19.562285+03
12071	26	-1	390	2019-12-18 01:14:56.022486+03
12072	4	-1	1420	2019-12-18 01:25:39.973521+03
12073	7	-1	810	2019-12-18 01:27:35.406554+03
12074	75	-1	830	2019-12-18 01:38:20.938802+03
12075	88	-1	1270	2019-12-18 01:57:08.484719+03
12076	51	-1	1310	2019-12-18 02:05:40.120376+03
12077	29	-1	1940	2019-12-18 02:05:59.217912+03
12078	64	-1	970	2019-12-18 02:12:29.564013+03
12079	23	-1	4390	2019-12-18 02:21:28.769424+03
12080	60	-2	2700	2019-12-18 02:29:37.215231+03
12081	20	-1	830	2019-12-18 03:03:44.195572+03
12082	27	-1	880	2019-12-18 03:16:15.705017+03
12083	40	-2	1430	2019-12-18 03:36:56.584882+03
12084	18	-2	910	2019-12-18 03:51:42.213139+03
12085	88	-1	1270	2019-12-18 04:26:08.557683+03
12086	78	-1	900	2019-12-18 05:27:11.396382+03
12087	30	-1	1140	2019-12-18 05:28:14.427704+03
12088	37	-1	1290	2019-12-18 05:44:02.23804+03
12089	12	-1	1650	2019-12-18 05:45:10.576535+03
12090	83	-2	1230	2019-12-18 05:50:45.681876+03
12091	50	-1	1140	2019-12-18 05:57:25.91918+03
12092	14	-2	1350	2019-12-18 06:23:43.842664+03
12093	45	-1	1590	2019-12-18 06:31:55.938093+03
12094	88	-2	1270	2019-12-18 06:35:10.16939+03
12095	43	-1	380	2019-12-18 06:41:09.980284+03
12096	47	-1	1480	2019-12-18 06:53:04.155416+03
12097	23	21	2463	2019-12-18 06:54:49.764003+03
12098	75	-1	830	2019-12-18 07:08:58.222098+03
12099	14	-1	1350	2019-12-18 07:16:03.645316+03
12100	35	-1	670	2019-12-18 07:45:07.457944+03
12101	41	-1	830	2019-12-18 07:56:47.79519+03
12102	57	-2	1900	2019-12-18 07:59:32.466484+03
12103	21	-1	960	2019-12-18 08:35:17.621796+03
12104	82	-1	560	2019-12-18 08:42:23.02616+03
12105	60	-1	2700	2019-12-18 09:16:06.710199+03
12106	61	-1	1510	2019-12-18 09:47:00.806921+03
12107	46	-1	1270	2019-12-18 10:03:48.400451+03
12108	30	-1	1140	2019-12-18 10:13:41.065873+03
12109	79	-1	550	2019-12-18 10:23:01.747131+03
12110	52	-1	1090	2019-12-18 10:23:19.136416+03
12111	64	-1	970	2019-12-18 11:15:23.875448+03
12112	13	-1	460	2019-12-18 11:15:58.811631+03
12113	4	-1	1420	2019-12-18 11:23:54.971081+03
12114	67	-1	350	2019-12-18 11:48:03.618307+03
12115	30	-1	1140	2019-12-18 11:48:43.31342+03
12116	18	-1	910	2019-12-18 12:30:29.967467+03
12117	15	-2	2830	2019-12-18 12:32:07.983395+03
12118	19	-1	1220	2019-12-18 12:36:13.155623+03
12119	54	-1	3470	2019-12-18 12:43:51.850901+03
12120	51	-1	1310	2019-12-18 12:47:57.021096+03
12121	41	-1	830	2019-12-18 12:57:17.53433+03
12122	96	-1	1570	2019-12-18 13:42:34.440079+03
12123	4	-2	1420	2019-12-18 14:06:39.512271+03
12124	39	-1	910	2019-12-18 14:58:04.378276+03
12125	92	-1	630	2019-12-18 15:03:03.82666+03
12126	5	-1	1620	2019-12-18 15:24:39.397541+03
12127	14	-1	1350	2019-12-18 16:00:50.238811+03
12128	26	-1	390	2019-12-18 16:04:02.866951+03
12129	64	29	562	2019-12-18 16:09:17.175228+03
12130	28	-1	1860	2019-12-18 16:12:58.523389+03
12131	4	-1	1420	2019-12-18 16:28:33.234434+03
12132	15	-1	2830	2019-12-18 16:41:17.103246+03
12133	74	-1	1010	2019-12-18 17:02:30.867349+03
12134	57	-1	1900	2019-12-18 17:22:34.722384+03
12135	50	-1	1140	2019-12-18 17:30:56.816797+03
12136	2	-1	470	2019-12-18 18:19:53.622971+03
12137	28	-1	1860	2019-12-18 18:31:36.746059+03
12138	42	-2	1790	2019-12-18 18:35:21.20163+03
12139	19	-1	1220	2019-12-18 19:06:34.811617+03
12140	67	-1	350	2019-12-18 20:08:23.928283+03
12141	24	-2	950	2019-12-18 20:15:17.381139+03
12142	48	-1	640	2019-12-18 20:21:33.060912+03
12143	75	-2	830	2019-12-18 20:42:35.409046+03
12144	69	-1	1100	2019-12-18 20:49:30.14319+03
12145	37	-1	1290	2019-12-18 21:10:43.962023+03
12146	87	-1	2320	2019-12-18 21:11:28.422161+03
12147	3	-1	660	2019-12-18 21:15:01.700246+03
12148	13	-1	460	2019-12-18 21:18:14.950733+03
12149	21	-1	960	2019-12-18 21:36:02.767902+03
12150	81	-1	1620	2019-12-18 21:42:55.135972+03
12151	34	23	728	2019-12-18 21:46:10.634671+03
12152	70	-2	760	2019-12-18 21:53:17.91492+03
12153	94	-2	1230	2019-12-18 22:24:19.159548+03
12154	63	-2	1780	2019-12-18 22:41:26.891364+03
12155	46	-1	1270	2019-12-18 22:58:16.492512+03
12156	26	29	185	2019-12-18 23:02:58.25272+03
12157	6	-1	980	2019-12-18 23:32:10.281233+03
12158	9	-1	2090	2019-12-18 23:37:37.83539+03
12159	46	-1	1270	2019-12-18 23:44:38.360919+03
12160	43	-2	380	2019-12-18 23:45:19.178746+03
12161	64	-2	970	2019-12-18 23:50:56.770369+03
12162	36	-1	630	2019-12-18 23:52:55.042038+03
12163	29	-1	1940	2019-12-19 00:21:00.048335+03
12164	15	-1	2830	2019-12-19 00:49:39.995255+03
12165	60	-1	2700	2019-12-19 01:57:21.671472+03
12166	78	-2	900	2019-12-19 02:41:10.803744+03
12167	50	-1	1140	2019-12-19 02:48:07.407137+03
12168	96	-1	1570	2019-12-19 02:51:06.289465+03
12169	92	25	251	2019-12-19 03:02:53.134122+03
12170	60	-1	2700	2019-12-19 03:11:22.064561+03
12171	58	-1	2830	2019-12-19 03:12:09.756531+03
12172	93	-1	1620	2019-12-19 03:31:48.206694+03
12173	35	-1	670	2019-12-19 03:59:02.181918+03
12174	15	-1	2830	2019-12-19 04:34:36.400107+03
12175	53	29	1827	2019-12-19 04:42:35.34191+03
12176	14	-1	1350	2019-12-19 04:45:24.224092+03
12177	83	-1	1230	2019-12-19 04:54:03.721924+03
12178	29	38	994	2019-12-19 05:04:07.748274+03
12179	50	-1	1140	2019-12-19 05:09:58.040793+03
12180	92	-1	630	2019-12-19 05:14:06.465862+03
12181	12	-1	1650	2019-12-19 05:22:18.059242+03
12182	89	-2	1420	2019-12-19 05:43:53.769407+03
12183	9	-1	2090	2019-12-19 05:45:52.507542+03
12184	75	-2	830	2019-12-19 05:55:32.036707+03
12185	24	-2	950	2019-12-19 06:02:06.959568+03
12186	81	-2	1620	2019-12-19 06:05:21.740506+03
12187	17	-1	1500	2019-12-19 06:21:15.347951+03
12188	45	-1	1590	2019-12-19 06:25:32.795139+03
12189	71	-1	1030	2019-12-19 06:39:33.697916+03
12190	50	-1	1140	2019-12-19 06:50:14.495997+03
12191	55	-1	3480	2019-12-19 07:24:41.533354+03
12192	40	-1	1430	2019-12-19 07:45:28.687301+03
12193	27	-1	880	2019-12-19 08:02:05.413864+03
12194	13	-1	460	2019-12-19 08:15:23.465239+03
12195	47	-1	1480	2019-12-19 08:34:28.53604+03
12196	57	-1	1900	2019-12-19 08:50:00.744962+03
12197	71	-1	1030	2019-12-19 08:53:52.402361+03
12198	93	-1	1620	2019-12-19 09:02:53.935131+03
12199	12	-2	1650	2019-12-19 09:06:29.212758+03
12200	24	-1	950	2019-12-19 09:43:53.677346+03
12201	26	-1	390	2019-12-19 09:50:37.896043+03
12202	46	-1	1270	2019-12-19 09:52:14.282922+03
12203	11	-2	830	2019-12-19 10:05:05.472389+03
12204	10	-1	2080	2019-12-19 10:29:36.941041+03
12205	65	-1	490	2019-12-19 10:46:03.213654+03
12206	61	-1	1510	2019-12-19 11:53:29.574601+03
12207	37	-1	1290	2019-12-19 12:59:11.821992+03
12208	54	-1	3470	2019-12-19 13:19:33.295203+03
12209	23	-1	4390	2019-12-19 13:31:21.144169+03
12210	32	-1	710	2019-12-19 13:31:38.761293+03
12211	73	-1	960	2019-12-19 13:36:08.54027+03
12212	50	-1	1140	2019-12-19 13:47:17.772459+03
12213	76	-1	1070	2019-12-19 13:49:02.453356+03
12214	66	-1	690	2019-12-19 14:04:53.897816+03
12215	63	-1	1780	2019-12-19 14:35:36.322322+03
12216	12	-1	1650	2019-12-19 15:38:10.526497+03
12217	76	-1	1070	2019-12-19 15:50:56.66884+03
12218	85	-1	730	2019-12-19 15:57:36.453489+03
12219	28	-1	1860	2019-12-19 16:11:36.842674+03
12220	76	-2	1070	2019-12-19 16:25:46.395002+03
12221	75	-1	830	2019-12-19 16:32:07.110942+03
12222	7	-2	810	2019-12-19 16:56:02.459013+03
12223	93	-1	1620	2019-12-19 17:00:15.333301+03
12224	90	-1	1780	2019-12-19 17:03:26.211475+03
12225	28	-1	1860	2019-12-19 17:22:51.303786+03
12226	70	-1	760	2019-12-19 17:50:17.026711+03
12227	26	-2	390	2019-12-19 18:06:08.917051+03
12228	83	-2	1230	2019-12-19 19:08:54.904368+03
12229	44	-1	500	2019-12-19 19:32:15.528473+03
12230	89	-2	1420	2019-12-19 19:40:05.850994+03
12231	29	-1	1940	2019-12-19 19:54:57.917926+03
12232	77	-1	640	2019-12-19 19:56:20.623531+03
12233	31	-2	1190	2019-12-19 20:07:51.807464+03
12234	76	39	559	2019-12-19 20:10:58.59146+03
12235	11	-1	830	2019-12-19 20:34:03.20988+03
12236	8	-2	1920	2019-12-19 20:42:33.109847+03
12237	86	-1	910	2019-12-19 21:05:19.600917+03
12238	47	-2	1480	2019-12-19 21:38:16.714828+03
12239	82	-1	560	2019-12-19 21:56:45.884367+03
12240	24	-1	950	2019-12-19 22:17:14.416925+03
12241	42	34	933	2019-12-19 22:26:48.009647+03
12242	14	-1	1350	2019-12-19 22:32:04.207156+03
12243	44	-1	500	2019-12-19 22:48:46.189735+03
12244	24	-1	950	2019-12-19 22:48:53.156626+03
12245	39	-1	910	2019-12-19 23:25:08.602611+03
12246	23	-1	4390	2019-12-19 23:59:03.837073+03
12247	49	-2	970	2019-12-20 00:06:11.641194+03
12248	57	-1	1900	2019-12-20 00:58:36.204705+03
12249	9	-1	2090	2019-12-20 01:00:26.046271+03
12250	13	-1	460	2019-12-20 01:02:27.743138+03
12251	12	-1	1650	2019-12-20 01:25:02.72997+03
12252	5	-1	1620	2019-12-20 01:26:02.756239+03
12253	17	-1	1500	2019-12-20 01:43:42.152276+03
12254	87	32	1174	2019-12-20 02:05:45.444149+03
12255	96	-1	1570	2019-12-20 02:09:50.442381+03
12256	61	-1	1510	2019-12-20 02:23:09.178324+03
12257	4	-2	1420	2019-12-20 02:35:22.342104+03
12258	40	-1	1430	2019-12-20 02:35:26.066554+03
12259	87	-2	2320	2019-12-20 02:37:51.96428+03
12260	20	-1	830	2019-12-20 02:40:48.938043+03
12261	4	-1	1420	2019-12-20 02:48:44.378694+03
12262	46	-1	1270	2019-12-20 02:54:01.90854+03
12263	45	-1	1590	2019-12-20 03:05:09.150528+03
12264	63	-1	1780	2019-12-20 03:17:12.236655+03
12265	73	-1	960	2019-12-20 03:25:52.245912+03
12266	4	-1	1420	2019-12-20 03:29:22.581881+03
12267	38	-1	1100	2019-12-20 03:31:46.91828+03
12268	83	-1	1230	2019-12-20 04:25:49.441704+03
12269	31	-1	1190	2019-12-20 04:52:33.18907+03
12270	33	-1	900	2019-12-20 05:53:32.235467+03
12271	72	-2	620	2019-12-20 05:54:27.263118+03
12272	56	-1	2460	2019-12-20 05:57:22.659208+03
12273	95	-1	480	2019-12-20 05:59:48.622958+03
12274	89	-2	1420	2019-12-20 06:00:38.726161+03
12275	23	-1	4390	2019-12-20 06:05:38.935397+03
12276	1	35	362	2019-12-20 06:08:02.848897+03
12277	8	-1	1920	2019-12-20 06:16:14.287937+03
12278	83	-1	1230	2019-12-20 06:23:24.578467+03
12279	87	-2	2320	2019-12-20 06:37:09.176833+03
12280	34	-1	1550	2019-12-20 06:52:47.357691+03
12281	30	-1	1140	2019-12-20 06:57:37.494703+03
12282	94	32	701	2019-12-20 07:42:57.945418+03
12283	20	-1	830	2019-12-20 08:01:13.948127+03
12284	64	-1	970	2019-12-20 08:05:20.094172+03
12285	13	-2	460	2019-12-20 08:20:46.55139+03
12286	33	-1	900	2019-12-20 08:23:59.971118+03
12287	88	-1	1270	2019-12-20 08:24:50.175698+03
12288	18	-2	910	2019-12-20 08:44:34.083941+03
12289	38	-1	1100	2019-12-20 09:23:23.95683+03
12290	39	-1	910	2019-12-20 10:02:50.399205+03
12291	38	-1	1100	2019-12-20 10:06:44.842447+03
12292	40	-1	1430	2019-12-20 10:15:51.530877+03
12293	63	-1	1780	2019-12-20 10:33:52.068225+03
12294	59	-1	1030	2019-12-20 10:40:35.818964+03
12295	35	-2	670	2019-12-20 11:10:05.592204+03
12296	5	-2	1620	2019-12-20 11:11:57.531995+03
12297	8	-1	1920	2019-12-20 11:24:34.742392+03
12298	92	-1	630	2019-12-20 11:35:33.175624+03
12299	47	-1	1480	2019-12-20 11:37:51.282058+03
12300	45	-1	1590	2019-12-20 11:41:13.747667+03
12301	34	-1	1550	2019-12-20 11:43:43.177451+03
12302	80	-1	1120	2019-12-20 11:46:27.595829+03
12303	88	-1	1270	2019-12-20 12:47:43.692467+03
12304	7	-1	810	2019-12-20 13:02:58.838366+03
12305	67	-1	350	2019-12-20 13:11:43.536771+03
12306	59	-1	1030	2019-12-20 13:23:37.255054+03
12307	83	40	597	2019-12-20 13:25:45.770876+03
12308	42	-1	1790	2019-12-20 13:30:21.039032+03
12309	90	-1	1780	2019-12-20 13:33:41.283002+03
12310	38	-2	1100	2019-12-20 13:41:47.36347+03
12311	6	-1	980	2019-12-20 13:55:57.570416+03
12312	54	-1	3470	2019-12-20 14:08:11.196111+03
12313	39	-1	910	2019-12-20 14:28:28.323476+03
12314	84	-1	2700	2019-12-20 14:49:21.914763+03
12315	77	-1	640	2019-12-20 14:58:58.133954+03
12316	30	-1	1140	2019-12-20 15:17:45.684474+03
12317	86	-2	910	2019-12-20 15:19:40.246253+03
12318	17	-1	1500	2019-12-20 15:29:54.088666+03
12319	67	-1	350	2019-12-20 16:00:52.671421+03
12320	78	-2	900	2019-12-20 16:30:42.328552+03
12321	95	-1	480	2019-12-20 16:31:28.075851+03
12322	61	-1	1510	2019-12-20 16:38:58.086812+03
12323	23	-1	4390	2019-12-20 17:30:42.953067+03
12324	55	-1	3480	2019-12-20 17:41:30.543872+03
12325	57	-2	1900	2019-12-20 17:50:36.825667+03
12326	81	-1	1620	2019-12-20 18:06:34.192419+03
12327	91	-1	1620	2019-12-20 18:07:26.557015+03
12328	96	-1	1570	2019-12-20 18:08:31.198709+03
12329	41	-1	830	2019-12-20 18:14:34.462011+03
12330	75	-1	830	2019-12-20 18:22:12.048546+03
12331	76	-1	1070	2019-12-20 18:22:14.023833+03
12332	38	-1	1100	2019-12-20 18:35:49.872218+03
12333	31	-2	1190	2019-12-20 18:59:49.980441+03
12334	75	-2	830	2019-12-20 19:02:06.048078+03
12335	37	-1	1290	2019-12-20 19:12:26.015025+03
12336	26	-1	390	2019-12-20 19:23:40.073705+03
12337	60	-2	2700	2019-12-20 19:28:41.140253+03
12338	49	-1	970	2019-12-20 19:33:39.744981+03
12339	38	-1	1100	2019-12-20 20:19:48.270072+03
12340	75	-2	830	2019-12-20 20:21:26.875448+03
12341	38	29	563	2019-12-20 20:37:59.708151+03
12342	78	-2	900	2019-12-20 21:01:13.708052+03
12343	7	-2	810	2019-12-20 21:27:09.956974+03
12344	33	-1	900	2019-12-20 21:53:53.549941+03
12345	66	-1	690	2019-12-20 22:03:11.040546+03
12346	22	-1	1070	2019-12-20 22:27:10.671111+03
12347	36	-1	630	2019-12-20 22:27:30.095143+03
12348	58	-2	2830	2019-12-20 22:35:25.887773+03
12349	4	-1	1420	2019-12-20 23:20:05.187685+03
12350	12	-1	1650	2019-12-21 01:02:02.238921+03
12351	41	-1	830	2019-12-21 01:17:32.092347+03
12352	10	-3	2080	2019-12-21 01:28:57.496812+03
12353	3	-2	660	2019-12-21 01:59:06.277219+03
12354	20	-2	830	2019-12-21 01:59:56.596234+03
12355	82	-2	560	2019-12-21 02:07:41.63025+03
12356	58	-2	2830	2019-12-21 02:11:42.978338+03
12357	53	-1	3120	2019-12-21 02:26:34.931007+03
12358	3	-1	660	2019-12-21 03:06:54.201435+03
12359	44	-1	500	2019-12-21 03:15:42.829148+03
12360	96	-1	1570	2019-12-21 03:39:53.413388+03
12361	49	-1	970	2019-12-21 04:32:39.141631+03
12362	28	-1	1860	2019-12-21 05:00:35.15713+03
12363	83	-1	1230	2019-12-21 05:03:24.328945+03
12364	17	-2	1500	2019-12-21 05:08:43.504943+03
12365	53	-2	3120	2019-12-21 05:21:15.300993+03
12366	76	-1	1070	2019-12-21 05:22:41.743596+03
12367	67	-1	350	2019-12-21 05:55:14.176923+03
12368	26	-1	390	2019-12-21 06:00:18.997533+03
12369	67	-2	350	2019-12-21 06:00:40.800487+03
12370	12	-1	1650	2019-12-21 06:02:38.951624+03
12371	71	-2	1030	2019-12-21 06:04:35.477295+03
12372	71	-1	1030	2019-12-21 06:14:48.591204+03
12373	43	-1	380	2019-12-21 06:27:09.006633+03
12374	40	24	839	2019-12-21 06:35:02.07656+03
12375	25	-1	1100	2019-12-21 06:43:06.270412+03
12376	7	-1	810	2019-12-21 07:13:53.084231+03
12377	14	-1	1350	2019-12-21 08:12:57.446966+03
12378	3	-2	660	2019-12-21 08:29:31.387129+03
12379	74	-1	1010	2019-12-21 09:01:14.350299+03
12380	29	-1	1940	2019-12-21 09:06:15.240844+03
12381	77	-1	640	2019-12-21 09:52:09.929735+03
12382	40	-1	1430	2019-12-21 10:08:11.516457+03
12383	6	-1	980	2019-12-21 10:18:14.258261+03
12384	19	28	601	2019-12-21 10:37:53.171183+03
12385	9	22	840	2019-12-21 10:42:50.073035+03
12386	53	-2	3120	2019-12-21 10:48:12.792441+03
12387	12	-1	1650	2019-12-21 10:48:23.141809+03
12388	67	-1	350	2019-12-21 10:56:11.846039+03
12389	47	-2	1480	2019-12-21 11:20:05.198167+03
12390	45	-1	1590	2019-12-21 11:24:49.216176+03
12391	60	-1	2700	2019-12-21 11:36:52.301903+03
12392	38	-1	1100	2019-12-21 11:45:12.323621+03
12393	56	-1	2460	2019-12-21 11:52:17.660427+03
12394	93	-1	1620	2019-12-21 11:52:45.420951+03
12395	86	-1	910	2019-12-21 12:37:07.963772+03
12396	75	-1	830	2019-12-21 12:48:57.351213+03
12397	23	-1	4390	2019-12-21 12:56:01.697413+03
12398	46	-1	1270	2019-12-21 13:21:34.857792+03
12399	13	-1	460	2019-12-21 13:45:38.925975+03
12400	22	-1	1070	2019-12-21 13:55:36.253538+03
12401	57	-1	1900	2019-12-21 14:11:37.004983+03
12402	76	-1	1070	2019-12-21 14:25:13.348201+03
12403	19	-1	1220	2019-12-21 14:28:09.865784+03
12404	44	27	249	2019-12-21 14:52:03.117777+03
12405	38	-1	1100	2019-12-21 14:55:09.901881+03
12406	91	-1	1620	2019-12-21 15:24:54.758656+03
12407	92	-1	630	2019-12-21 15:48:35.806724+03
12408	57	-1	1900	2019-12-21 15:49:25.105317+03
12409	55	-1	3480	2019-12-21 15:52:16.80834+03
12410	52	-1	1090	2019-12-21 16:01:02.407877+03
12411	94	-1	1230	2019-12-21 16:03:24.23846+03
12412	83	-1	1230	2019-12-21 16:04:16.833627+03
12413	78	-1	900	2019-12-21 16:29:34.850583+03
12414	57	-1	1900	2019-12-21 16:43:55.350373+03
12415	5	-1	1620	2019-12-21 16:51:09.865441+03
12416	96	-1	1570	2019-12-21 16:58:54.999577+03
12417	77	35	316	2019-12-21 17:12:30.878574+03
12418	36	-1	630	2019-12-21 17:31:02.72644+03
12419	63	-1	1780	2019-12-21 17:45:05.352183+03
12420	80	-2	1120	2019-12-21 17:47:34.661495+03
12421	91	-1	1620	2019-12-21 17:52:14.493377+03
12422	87	-1	2320	2019-12-21 18:11:35.672815+03
12423	96	-1	1570	2019-12-21 18:30:42.49613+03
12424	11	-2	830	2019-12-21 18:34:44.063733+03
12425	47	-1	1480	2019-12-21 18:44:01.444113+03
12426	13	-1	460	2019-12-21 18:57:22.879537+03
12427	32	-1	710	2019-12-21 19:26:34.990577+03
12428	1	-1	640	2019-12-21 19:27:31.666468+03
12429	14	-1	1350	2019-12-21 19:33:23.761599+03
12430	36	-1	630	2019-12-21 19:50:22.924594+03
12431	37	-2	1290	2019-12-21 20:06:19.311713+03
12432	69	-1	1100	2019-12-21 20:20:49.810413+03
12433	67	-1	350	2019-12-21 20:39:03.65308+03
12434	8	-1	1920	2019-12-21 22:29:00.712317+03
12435	44	-1	500	2019-12-21 22:39:09.379705+03
12436	68	-1	490	2019-12-21 22:51:29.485003+03
12437	77	-1	640	2019-12-21 23:31:24.222923+03
12438	24	-2	950	2019-12-21 23:35:05.232977+03
12439	61	-1	1510	2019-12-21 23:37:38.076088+03
12440	79	-1	550	2019-12-22 00:16:45.249613+03
12441	59	-1	1030	2019-12-22 00:34:53.158195+03
12442	7	-1	810	2019-12-22 00:44:42.951826+03
12443	89	-1	1420	2019-12-22 00:45:24.736435+03
12444	75	-1	830	2019-12-22 00:45:46.946323+03
12445	87	-1	2320	2019-12-22 02:00:39.503873+03
12446	52	-2	1090	2019-12-22 02:54:41.380506+03
12447	53	-1	3120	2019-12-22 03:22:33.724712+03
12448	54	-1	3470	2019-12-22 03:43:04.09546+03
12449	36	-1	630	2019-12-22 03:44:11.589017+03
12450	77	-3	640	2019-12-22 03:57:55.583533+03
12451	49	-1	970	2019-12-22 04:00:02.578322+03
12452	65	-1	490	2019-12-22 04:01:30.589413+03
12453	28	-1	1860	2019-12-22 05:38:15.983871+03
12454	37	-2	1290	2019-12-22 05:48:40.799134+03
12455	74	-1	1010	2019-12-22 05:51:19.886864+03
12456	47	-2	1480	2019-12-22 06:02:22.995638+03
12457	90	-1	1780	2019-12-22 06:08:49.601956+03
12458	94	-1	1230	2019-12-22 06:23:02.532258+03
12459	95	33	210	2019-12-22 06:42:27.641114+03
12460	19	-2	1220	2019-12-22 06:50:46.601986+03
12461	69	-2	1100	2019-12-22 06:54:16.028067+03
12462	81	-1	1620	2019-12-22 07:06:46.418911+03
12463	87	-1	2320	2019-12-22 07:14:08.40675+03
12464	67	-1	350	2019-12-22 07:16:03.965205+03
12465	9	-1	2090	2019-12-22 07:23:24.045437+03
12466	60	-1	2700	2019-12-22 07:26:08.62859+03
12467	47	-1	1480	2019-12-22 08:18:49.102302+03
12468	12	-1	1650	2019-12-22 08:39:17.744154+03
12469	66	-1	690	2019-12-22 08:58:43.713387+03
12470	28	17	843	2019-12-22 09:06:37.041519+03
12471	44	-1	500	2019-12-22 09:28:00.11625+03
12472	17	-1	1500	2019-12-22 09:28:44.108085+03
12473	35	-2	670	2019-12-22 09:34:47.787173+03
12474	8	-2	1920	2019-12-22 09:36:16.805294+03
12475	65	-1	490	2019-12-22 10:11:37.482489+03
12476	50	-1	1140	2019-12-22 10:16:51.294262+03
12477	24	-1	950	2019-12-22 11:09:30.955978+03
12478	46	-1	1270	2019-12-22 11:15:56.551907+03
12479	17	-1	1500	2019-12-22 11:27:19.53298+03
12480	91	-1	1620	2019-12-22 12:03:21.109587+03
12481	20	-1	830	2019-12-22 12:30:52.009454+03
12482	96	-1	1570	2019-12-22 12:49:50.489381+03
12483	41	-2	830	2019-12-22 13:43:49.058796+03
12484	91	30	740	2019-12-22 13:48:42.012722+03
12485	17	-1	1500	2019-12-22 14:46:31.250426+03
12486	33	-2	900	2019-12-22 15:18:23.172454+03
12487	22	-1	1070	2019-12-22 16:25:32.280573+03
12488	3	-2	660	2019-12-22 16:46:15.516938+03
12489	39	-1	910	2019-12-22 17:10:39.075525+03
12490	72	-1	620	2019-12-22 17:20:24.947268+03
12491	82	-1	560	2019-12-22 17:24:38.539601+03
12492	37	-1	1290	2019-12-22 17:24:45.572542+03
12493	54	-1	3470	2019-12-22 17:34:12.380293+03
12494	69	-1	1100	2019-12-22 18:49:10.116414+03
12495	33	-1	900	2019-12-22 18:50:08.040351+03
12496	79	-2	550	2019-12-22 19:11:58.659312+03
12497	43	-1	380	2019-12-22 19:51:09.575226+03
12498	54	-1	3470	2019-12-22 20:02:36.872397+03
12499	69	-1	1100	2019-12-22 20:33:36.821737+03
12500	95	-2	480	2019-12-22 20:37:28.962526+03
12501	71	-1	1030	2019-12-22 21:14:45.397665+03
12502	2	-1	470	2019-12-22 21:20:25.404184+03
12503	28	-1	1860	2019-12-22 21:27:22.075645+03
12504	67	-1	350	2019-12-22 21:41:22.171374+03
12505	72	-1	620	2019-12-22 22:11:47.776573+03
12506	28	-2	1860	2019-12-22 22:39:54.905896+03
12507	49	-2	970	2019-12-22 23:04:04.958164+03
12508	3	26	336	2019-12-22 23:17:50.702441+03
12509	68	22	281	2019-12-22 23:34:18.186757+03
12510	32	-1	710	2019-12-22 23:43:31.521448+03
12511	51	-1	1310	2019-12-22 23:46:49.33511+03
12512	60	-2	2700	2019-12-22 23:47:53.830846+03
12513	24	-1	950	2019-12-22 23:49:37.745233+03
12514	13	-1	460	2019-12-22 23:49:57.691905+03
12515	36	-1	630	2019-12-22 23:53:05.463989+03
12516	15	-1	2830	2019-12-23 00:09:10.581014+03
12517	12	-1	1650	2019-12-23 00:22:27.919188+03
12518	4	-1	1420	2019-12-23 00:35:33.275244+03
12519	49	-1	970	2019-12-23 01:29:20.388888+03
12520	59	-1	1030	2019-12-23 01:45:15.013581+03
12521	36	-1	630	2019-12-23 02:36:09.033038+03
12522	90	-1	1780	2019-12-23 02:37:04.026359+03
12523	10	-1	2080	2019-12-23 02:45:21.108977+03
12524	11	-1	830	2019-12-23 02:52:13.553645+03
12525	80	-1	1120	2019-12-23 02:53:20.612841+03
12526	80	-2	1120	2019-12-23 02:53:58.544885+03
12527	71	-1	1030	2019-12-23 03:04:35.671034+03
12528	20	-1	830	2019-12-23 03:11:26.04628+03
12529	41	-2	830	2019-12-23 03:19:27.68133+03
12530	74	22	473	2019-12-23 03:28:46.244383+03
12531	91	-2	1620	2019-12-23 03:34:07.591386+03
12532	92	-1	630	2019-12-23 03:48:37.37624+03
12533	3	-1	660	2019-12-23 04:37:57.065501+03
12534	75	-2	830	2019-12-23 05:05:19.35508+03
12535	71	-1	1030	2019-12-23 05:10:29.312249+03
12536	9	-1	2090	2019-12-23 05:46:28.981921+03
12537	44	-1	500	2019-12-23 05:57:35.138274+03
12538	77	-1	640	2019-12-23 05:59:42.687175+03
12539	35	-1	670	2019-12-23 05:59:59.515589+03
12540	37	-1	1290	2019-12-23 06:11:07.264252+03
12541	2	15	213	2019-12-23 06:14:55.175988+03
12542	28	-1	1860	2019-12-23 06:18:46.573715+03
12543	25	-1	1100	2019-12-23 06:18:54.780205+03
12544	43	-1	380	2019-12-23 06:20:01.223127+03
12545	87	-1	2320	2019-12-23 06:30:51.795354+03
12546	10	-1	2080	2019-12-23 06:45:31.833351+03
12547	86	-1	910	2019-12-23 07:39:36.716316+03
12548	67	-1	350	2019-12-23 07:40:01.997655+03
12549	49	-1	970	2019-12-23 07:56:32.318562+03
12550	48	-2	640	2019-12-23 08:13:50.486268+03
12551	13	-1	460	2019-12-23 08:14:14.143471+03
12552	87	-1	2320	2019-12-23 08:16:08.281464+03
12553	51	-2	1310	2019-12-23 08:35:23.840308+03
12554	37	-1	1290	2019-12-23 09:32:07.031296+03
12555	27	-1	880	2019-12-23 09:46:50.280442+03
12556	25	-1	1100	2019-12-23 09:56:32.723379+03
12557	91	-1	1620	2019-12-23 09:59:27.535911+03
12558	5	-1	1620	2019-12-23 10:45:24.146687+03
12559	2	-1	470	2019-12-23 11:12:00.237679+03
12560	35	-1	670	2019-12-23 11:29:40.195674+03
12561	14	-1	1350	2019-12-23 11:30:49.010606+03
12562	74	-1	1010	2019-12-23 12:04:08.761687+03
12563	57	-1	1900	2019-12-23 12:06:02.079689+03
12564	65	-1	490	2019-12-23 12:06:33.251061+03
12565	1	-1	640	2019-12-23 12:13:48.899316+03
12566	22	-1	1070	2019-12-23 12:15:58.479358+03
12567	9	-1	2090	2019-12-23 12:19:52.820376+03
12568	56	-1	2460	2019-12-23 12:28:46.563889+03
12569	28	-1	1860	2019-12-23 12:45:02.805497+03
12570	53	-1	3120	2019-12-23 12:50:06.359265+03
12571	36	-1	630	2019-12-23 12:55:25.688017+03
12572	80	-1	1120	2019-12-23 13:37:19.785543+03
12573	1	-1	640	2019-12-23 13:45:17.344047+03
12574	60	-1	2700	2019-12-23 13:51:54.362663+03
12575	11	-1	830	2019-12-23 14:22:09.483689+03
12576	64	-1	970	2019-12-23 14:32:21.981329+03
12577	81	-1	1620	2019-12-23 14:37:40.886472+03
12578	70	-1	760	2019-12-23 14:57:25.736423+03
12579	36	-1	630	2019-12-23 15:07:33.788686+03
12580	13	-2	460	2019-12-23 15:34:19.946254+03
12581	33	-1	900	2019-12-23 15:41:03.631852+03
12582	37	-1	1290	2019-12-23 16:14:49.747442+03
12583	81	-1	1620	2019-12-23 16:24:07.176797+03
12584	24	-2	950	2019-12-23 16:47:13.863202+03
12585	76	-1	1070	2019-12-23 18:02:47.781434+03
12586	78	-1	900	2019-12-23 19:05:22.697181+03
12587	93	-1	1620	2019-12-23 19:54:14.250964+03
12588	19	-1	1220	2019-12-23 20:07:29.497594+03
12589	83	-2	1230	2019-12-23 21:13:38.121525+03
12590	77	-1	640	2019-12-23 21:34:23.59614+03
12591	62	10	644	2019-12-23 21:38:16.292692+03
12592	52	-2	1090	2019-12-23 21:54:10.067631+03
12593	39	-1	910	2019-12-23 22:08:28.97924+03
12594	40	-2	1430	2019-12-23 22:10:23.973302+03
12595	31	25	561	2019-12-23 23:04:57.0727+03
12596	5	-1	1620	2019-12-23 23:10:19.350716+03
12597	92	-1	630	2019-12-23 23:11:44.045871+03
12598	56	-1	2460	2019-12-23 23:26:41.584337+03
12599	35	-1	670	2019-12-24 00:20:54.587075+03
12600	89	-1	1420	2019-12-24 00:22:51.520164+03
12601	13	-1	460	2019-12-24 00:29:41.942221+03
12602	85	-1	730	2019-12-24 00:30:51.952301+03
12603	93	-1	1620	2019-12-24 00:37:27.704788+03
12604	85	-1	730	2019-12-24 01:10:53.436372+03
12605	46	-1	1270	2019-12-24 02:05:03.136481+03
12606	18	-2	910	2019-12-24 02:22:58.575159+03
12607	42	-1	1790	2019-12-24 02:32:24.958214+03
12608	40	-1	1430	2019-12-24 02:35:30.647133+03
12609	68	-1	490	2019-12-24 02:39:31.863966+03
12610	61	-1	1510	2019-12-24 02:51:52.204715+03
12611	89	-1	1420	2019-12-24 03:00:31.861848+03
12612	3	-1	660	2019-12-24 03:06:41.735273+03
12613	93	-1	1620	2019-12-24 04:32:15.945331+03
12614	35	-2	670	2019-12-24 04:36:03.624114+03
12615	13	-1	460	2019-12-24 04:37:16.519742+03
12616	3	-1	660	2019-12-24 05:04:43.976457+03
12617	34	-1	1550	2019-12-24 05:11:19.760987+03
12618	37	25	524	2019-12-24 06:56:41.777778+03
12619	60	-1	2700	2019-12-24 07:06:32.030612+03
12620	50	-2	1140	2019-12-24 07:09:29.216816+03
12621	18	-1	910	2019-12-24 07:10:21.202485+03
12622	27	-2	880	2019-12-24 07:16:45.021787+03
12623	88	-1	1270	2019-12-24 07:22:26.636371+03
12624	3	-1	660	2019-12-24 07:23:39.336897+03
12625	54	-1	3470	2019-12-24 07:28:57.819842+03
12626	13	35	223	2019-12-24 07:49:02.397815+03
12627	48	-1	640	2019-12-24 08:03:56.193395+03
12628	11	-2	830	2019-12-24 08:24:38.795428+03
12629	20	-1	830	2019-12-24 08:35:35.873956+03
12630	85	-1	730	2019-12-24 08:41:06.85711+03
12631	86	-1	910	2019-12-24 08:46:59.289442+03
12632	14	-1	1350	2019-12-24 09:01:14.862928+03
12633	62	-1	1220	2019-12-24 09:14:39.183768+03
12634	38	-1	1100	2019-12-24 09:37:41.492193+03
12635	64	-1	970	2019-12-24 09:38:25.947366+03
12636	13	-2	460	2019-12-24 09:42:38.750641+03
12637	37	-1	1290	2019-12-24 09:43:36.994612+03
12638	66	-1	690	2019-12-24 09:56:35.883998+03
12639	44	-1	500	2019-12-24 10:10:03.066111+03
12640	19	-2	1220	2019-12-24 10:39:18.130496+03
12641	47	-1	1480	2019-12-24 10:52:39.562006+03
12642	40	-1	1430	2019-12-24 11:03:03.275604+03
12643	88	-1	1270	2019-12-24 11:06:30.184134+03
12644	81	-1	1620	2019-12-24 11:07:56.728516+03
12645	87	-1	2320	2019-12-24 11:37:35.006978+03
12646	13	-1	460	2019-12-24 11:45:50.55388+03
12647	94	-2	1230	2019-12-24 11:47:30.970124+03
12648	12	-2	1650	2019-12-24 12:06:45.084599+03
12649	87	-1	2320	2019-12-24 12:16:01.785277+03
12650	7	-1	810	2019-12-24 12:40:43.69542+03
12651	30	-1	1140	2019-12-24 12:47:51.78722+03
12652	9	-1	2090	2019-12-24 12:48:44.115995+03
12653	90	-1	1780	2019-12-24 13:11:34.16697+03
12654	78	-1	900	2019-12-24 13:17:50.97039+03
12655	77	-1	640	2019-12-24 13:31:26.029162+03
12656	74	-1	1010	2019-12-24 14:00:33.980167+03
12657	60	-1	2700	2019-12-24 14:01:19.391272+03
12658	13	-1	460	2019-12-24 14:30:14.469315+03
12659	19	-1	1220	2019-12-24 14:34:18.334134+03
12660	93	-1	1620	2019-12-24 14:48:43.718422+03
12661	93	-1	1620	2019-12-24 15:16:09.528698+03
12662	46	-2	1270	2019-12-24 15:27:44.512441+03
12663	11	-1	830	2019-12-24 15:33:35.267803+03
12664	60	-1	2700	2019-12-24 15:47:30.008119+03
12665	26	-2	390	2019-12-24 15:54:25.915806+03
12666	59	-1	1030	2019-12-24 15:59:03.23064+03
12667	24	-1	950	2019-12-24 16:13:45.727701+03
12668	88	-1	1270	2019-12-24 16:17:25.365744+03
12669	36	-1	630	2019-12-24 16:28:22.790479+03
12670	23	-1	4390	2019-12-24 16:28:46.671625+03
12671	85	-1	730	2019-12-24 16:48:06.534548+03
12672	21	-1	960	2019-12-24 16:54:28.256943+03
12673	52	-1	1090	2019-12-24 17:00:42.96526+03
12674	26	-1	390	2019-12-24 17:04:24.412356+03
12675	46	-2	1270	2019-12-24 17:14:02.890259+03
12676	63	-1	1780	2019-12-24 17:19:59.71204+03
12677	27	-2	880	2019-12-24 17:32:16.902359+03
12678	94	-2	1230	2019-12-24 17:46:31.703988+03
12679	7	-1	810	2019-12-24 18:31:37.025615+03
12680	54	-1	3470	2019-12-24 18:48:40.121479+03
12681	65	-1	490	2019-12-24 18:49:22.971279+03
12682	4	-2	1420	2019-12-24 19:54:40.511508+03
12683	21	-1	960	2019-12-24 20:13:33.938928+03
12684	35	-1	670	2019-12-24 20:14:23.127242+03
12685	6	-1	980	2019-12-24 20:20:12.182742+03
12686	13	-1	460	2019-12-24 20:22:18.695765+03
12687	87	-1	2320	2019-12-24 20:45:12.382609+03
12688	9	-1	2090	2019-12-24 20:50:28.912087+03
12689	28	-1	1860	2019-12-24 21:22:13.884388+03
12690	33	-1	900	2019-12-24 21:22:40.026759+03
12691	29	-1	1940	2019-12-24 21:43:19.006672+03
12692	21	-1	960	2019-12-24 22:11:17.306537+03
12693	46	-1	1270	2019-12-24 22:11:54.437654+03
12694	89	-1	1420	2019-12-24 22:24:17.638536+03
12695	64	-2	970	2019-12-24 22:43:51.298242+03
12696	24	-1	950	2019-12-24 22:48:47.698491+03
12697	5	-1	1620	2019-12-24 23:11:17.426999+03
12698	36	29	341	2019-12-24 23:17:40.527197+03
12699	22	-1	1070	2019-12-24 23:21:14.987978+03
12700	28	-1	1860	2019-12-24 23:38:55.673046+03
12701	21	-1	960	2019-12-24 23:41:10.461852+03
12702	54	-1	3470	2019-12-24 23:46:18.213715+03
12703	63	-1	1780	2019-12-25 00:05:09.744505+03
12704	43	-1	380	2019-12-25 00:13:56.04419+03
12705	48	-1	640	2019-12-25 00:43:29.977501+03
12706	36	-1	630	2019-12-25 00:45:07.491232+03
12707	51	-2	1310	2019-12-25 00:52:00.068376+03
12708	77	-1	640	2019-12-25 00:53:10.74594+03
12709	60	32	1295	2019-12-25 01:06:59.045392+03
12710	38	-1	1100	2019-12-25 01:17:21.696294+03
12711	41	-3	830	2019-12-25 01:30:09.263028+03
12712	28	-1	1860	2019-12-25 01:44:50.359508+03
12713	30	-1	1140	2019-12-25 01:55:11.378039+03
12714	20	-1	830	2019-12-25 02:07:18.317556+03
12715	58	-2	2830	2019-12-25 02:13:38.466808+03
12716	80	-1	1120	2019-12-25 02:21:48.536807+03
12717	3	-2	660	2019-12-25 02:40:12.552863+03
12718	47	-2	1480	2019-12-25 02:43:26.128923+03
12719	73	-1	960	2019-12-25 02:55:53.895243+03
12720	39	39	498	2019-12-25 03:08:23.609677+03
12721	48	-1	640	2019-12-25 03:09:16.634585+03
12722	47	-1	1480	2019-12-25 03:13:03.59164+03
12723	84	-1	2700	2019-12-25 03:19:35.381861+03
12724	22	-1	1070	2019-12-25 03:38:21.307313+03
12725	86	-1	910	2019-12-25 03:44:23.655982+03
12726	61	-1	1510	2019-12-25 04:06:15.637843+03
12727	64	-1	970	2019-12-25 04:42:54.718338+03
12728	90	-1	1780	2019-12-25 05:09:32.941923+03
12729	38	-1	1100	2019-12-25 05:41:16.810983+03
12730	78	-2	900	2019-12-25 07:12:11.590569+03
12731	41	-1	830	2019-12-25 07:42:32.588726+03
12732	56	-1	2460	2019-12-25 08:09:10.179753+03
12733	37	-1	1290	2019-12-25 08:11:32.307217+03
12734	14	-1	1350	2019-12-25 08:42:41.980461+03
12735	94	-1	1230	2019-12-25 08:43:10.281643+03
12736	90	-2	1780	2019-12-25 08:45:08.891505+03
12737	71	-1	1030	2019-12-25 09:29:28.025377+03
12738	95	-1	480	2019-12-25 09:52:50.662207+03
12739	77	-1	640	2019-12-25 10:17:46.533205+03
12740	89	-2	1420	2019-12-25 10:50:20.57704+03
12741	68	-1	490	2019-12-25 10:57:00.957324+03
12742	75	28	478	2019-12-25 10:57:11.874671+03
12743	40	-1	1430	2019-12-25 11:02:07.442495+03
12744	55	-2	3480	2019-12-25 11:12:11.260947+03
12745	87	-1	2320	2019-12-25 11:19:32.757389+03
12746	64	-1	970	2019-12-25 11:31:36.908801+03
12747	36	-1	630	2019-12-25 11:59:23.190247+03
12748	76	-1	1070	2019-12-25 12:38:47.583891+03
12749	24	-1	950	2019-12-25 12:39:08.859975+03
12750	10	-1	2080	2019-12-25 13:28:12.699519+03
12751	81	-1	1620	2019-12-25 13:39:22.728841+03
12752	77	-1	640	2019-12-25 13:41:07.1861+03
12753	63	-1	1780	2019-12-25 13:44:14.72354+03
12754	26	-1	390	2019-12-25 13:54:59.71545+03
12755	73	-1	960	2019-12-25 14:24:34.552535+03
12756	65	-2	490	2019-12-25 14:34:41.717218+03
12757	74	-1	1010	2019-12-25 14:58:44.780938+03
12758	37	-1	1290	2019-12-25 15:19:36.88393+03
12759	83	-2	1230	2019-12-25 15:22:45.71529+03
12760	30	-1	1140	2019-12-25 15:23:40.443666+03
12761	4	-1	1420	2019-12-25 15:40:24.437186+03
12762	78	24	460	2019-12-25 15:43:41.25901+03
12763	71	-1	1030	2019-12-25 15:59:34.122576+03
12764	60	-1	2700	2019-12-25 16:01:26.849391+03
12765	63	-1	1780	2019-12-25 16:57:45.575918+03
12766	32	-1	710	2019-12-25 16:59:09.220193+03
12767	61	-1	1510	2019-12-25 17:09:34.274135+03
12768	30	-2	1140	2019-12-25 17:14:21.089705+03
12769	95	-2	480	2019-12-25 17:38:17.39531+03
12770	57	-1	1900	2019-12-25 17:47:01.397789+03
12771	96	-1	1570	2019-12-25 18:07:27.953931+03
12772	35	-1	670	2019-12-25 18:13:11.477835+03
12773	74	-1	1010	2019-12-25 18:23:23.421978+03
12774	7	-1	810	2019-12-25 18:23:31.847281+03
12775	67	-1	350	2019-12-25 18:34:02.408178+03
12776	28	-1	1860	2019-12-25 18:34:29.263187+03
12777	57	-1	1900	2019-12-25 18:40:34.523554+03
12778	47	-1	1480	2019-12-25 18:51:37.210093+03
12779	3	-1	660	2019-12-25 18:59:59.383025+03
12780	14	-1	1350	2019-12-25 19:04:35.71547+03
12781	96	-1	1570	2019-12-25 19:26:04.822808+03
12782	50	-2	1140	2019-12-25 19:33:24.890643+03
12783	12	-1	1650	2019-12-25 20:06:10.386543+03
12784	63	-1	1780	2019-12-25 20:26:46.369454+03
12785	75	-2	830	2019-12-25 20:26:53.740204+03
12786	52	-1	1090	2019-12-25 20:30:49.379722+03
12787	74	-1	1010	2019-12-25 21:41:22.439666+03
12788	56	-1	2460	2019-12-25 21:55:38.271588+03
12789	22	-1	1070	2019-12-25 22:33:19.959338+03
12790	14	-1	1350	2019-12-25 22:37:32.887346+03
12791	24	-1	950	2019-12-25 23:07:52.963068+03
12792	56	-1	2460	2019-12-25 23:13:33.229821+03
12793	75	-1	830	2019-12-25 23:40:17.387087+03
12794	52	-1	1090	2019-12-25 23:58:08.849138+03
12795	72	10	362	2019-12-26 00:25:21.666663+03
12796	2	-1	470	2019-12-26 00:46:49.398049+03
12797	47	-1	1480	2019-12-26 00:47:49.849259+03
12798	22	27	624	2019-12-26 01:12:09.752344+03
12799	76	-1	1070	2019-12-26 01:23:40.447378+03
12800	74	-1	1010	2019-12-26 01:51:54.652796+03
12801	82	18	272	2019-12-26 02:08:09.507466+03
12802	84	-2	2700	2019-12-26 02:16:41.259867+03
12803	27	-1	880	2019-12-26 02:17:01.366548+03
12804	50	-1	1140	2019-12-26 02:30:27.831104+03
12805	58	-1	2830	2019-12-26 02:37:17.36896+03
12806	12	-1	1650	2019-12-26 02:49:09.101724+03
12807	58	-2	2830	2019-12-26 02:59:07.596813+03
12808	41	-1	830	2019-12-26 03:06:30.869594+03
12809	52	-1	1090	2019-12-26 04:01:20.838121+03
12810	61	-1	1510	2019-12-26 04:07:19.182404+03
12811	19	-1	1220	2019-12-26 04:27:00.597037+03
12812	14	-1	1350	2019-12-26 04:57:47.666875+03
12813	38	-1	1100	2019-12-26 04:58:37.455694+03
12814	17	-1	1500	2019-12-26 05:32:01.408082+03
12815	87	-2	2320	2019-12-26 05:38:27.305947+03
12816	34	-1	1550	2019-12-26 06:21:13.725936+03
12817	86	-1	910	2019-12-26 06:21:28.250081+03
12818	58	-1	2830	2019-12-26 07:12:40.023615+03
12819	49	-2	970	2019-12-26 07:18:28.445739+03
12820	70	-1	760	2019-12-26 07:34:15.242723+03
12821	57	-2	1900	2019-12-26 08:02:54.12165+03
12822	12	-1	1650	2019-12-26 08:25:15.25104+03
12823	8	-1	1920	2019-12-26 08:40:19.937894+03
12824	46	44	651	2019-12-26 08:44:20.928309+03
12825	11	-2	830	2019-12-26 08:47:21.163831+03
12826	90	-1	1780	2019-12-26 08:54:43.300086+03
12827	84	-2	2700	2019-12-26 09:19:36.513331+03
12828	37	-1	1290	2019-12-26 09:43:46.201169+03
12829	86	-1	910	2019-12-26 10:09:25.955064+03
12830	36	-1	630	2019-12-26 10:25:09.573716+03
12831	38	-1	1100	2019-12-26 10:27:59.995447+03
12832	59	34	501	2019-12-26 10:32:47.570288+03
12833	53	-1	3120	2019-12-26 11:05:27.700202+03
12834	35	-1	670	2019-12-26 11:11:27.828877+03
12835	60	-1	2700	2019-12-26 12:33:07.326711+03
12836	89	-1	1420	2019-12-26 12:44:13.054344+03
12837	19	-1	1220	2019-12-26 13:08:00.556966+03
12838	24	25	450	2019-12-26 13:16:59.283527+03
12839	70	-1	760	2019-12-26 13:29:33.382896+03
12840	47	-2	1480	2019-12-26 14:04:58.774023+03
12841	58	-1	2830	2019-12-26 14:12:39.097272+03
12842	26	-1	390	2019-12-26 14:36:22.393728+03
12843	73	-1	960	2019-12-26 15:29:31.327457+03
12844	80	-2	1120	2019-12-26 15:43:36.356942+03
12845	14	-1	1350	2019-12-26 15:50:14.980209+03
12846	61	-2	1510	2019-12-26 15:58:55.039783+03
12847	74	-2	1010	2019-12-26 16:16:24.733254+03
12848	77	-1	640	2019-12-26 16:53:28.686003+03
12849	67	-2	350	2019-12-26 16:54:33.616347+03
12850	62	-1	1220	2019-12-26 16:57:05.251443+03
12851	49	-2	970	2019-12-26 17:26:37.178565+03
12852	41	-1	830	2019-12-26 17:30:54.233596+03
12853	13	-1	460	2019-12-26 17:34:50.341739+03
12854	80	-1	1120	2019-12-26 18:05:41.415875+03
12855	76	-1	1070	2019-12-26 18:06:28.327869+03
12856	57	-1	1900	2019-12-26 18:08:05.779765+03
12857	10	-2	2080	2019-12-26 18:38:16.310431+03
12858	33	-1	900	2019-12-26 18:52:56.221514+03
12859	30	-1	1140	2019-12-26 18:54:17.512454+03
12860	49	-1	970	2019-12-26 18:56:51.144813+03
12861	2	-1	470	2019-12-26 19:47:16.270807+03
12862	37	-1	1290	2019-12-26 19:50:33.225517+03
12863	14	-1	1350	2019-12-26 19:51:40.975611+03
12864	83	-1	1230	2019-12-26 20:04:45.403463+03
12865	77	-2	640	2019-12-26 20:37:00.898129+03
12866	93	-1	1620	2019-12-26 21:04:31.192963+03
12867	89	-1	1420	2019-12-26 21:13:49.143806+03
12868	10	35	1165	2019-12-26 21:42:53.609985+03
12869	8	-1	1920	2019-12-26 21:44:16.082541+03
12870	28	-1	1860	2019-12-26 21:53:43.010961+03
12871	82	-1	560	2019-12-26 22:27:22.671368+03
12872	75	-2	830	2019-12-26 22:51:00.915582+03
12873	85	-1	730	2019-12-26 23:07:43.554098+03
12874	20	-1	830	2019-12-26 23:23:31.989211+03
12875	64	-1	970	2019-12-26 23:32:14.627421+03
12876	19	-2	1220	2019-12-26 23:40:42.536616+03
12877	77	-2	640	2019-12-26 23:53:56.813067+03
12878	45	-1	1590	2019-12-26 23:56:29.17625+03
12879	96	-1	1570	2019-12-27 00:02:03.692281+03
12880	52	-2	1090	2019-12-27 01:13:25.15047+03
12881	29	-2	1940	2019-12-27 01:16:49.117813+03
12882	10	-1	2080	2019-12-27 01:21:03.467783+03
12883	20	-1	830	2019-12-27 01:45:39.963417+03
12884	77	-1	640	2019-12-27 01:46:04.677074+03
12885	71	-1	1030	2019-12-27 01:49:45.012318+03
12886	6	-1	980	2019-12-27 01:51:23.515915+03
12887	19	-1	1220	2019-12-27 01:53:56.283383+03
12888	54	-2	3470	2019-12-27 02:06:02.803482+03
12889	46	-1	1270	2019-12-27 02:16:23.073423+03
12890	5	-1	1620	2019-12-27 03:06:10.411671+03
12891	17	29	715	2019-12-27 03:13:17.155586+03
12892	6	-1	980	2019-12-27 04:31:45.181651+03
12893	5	-1	1620	2019-12-27 04:33:37.038872+03
12894	89	-1	1420	2019-12-27 04:38:14.097475+03
12895	76	-1	1070	2019-12-27 05:29:59.101084+03
12896	54	-1	3470	2019-12-27 06:06:05.541434+03
12897	83	-1	1230	2019-12-27 06:06:54.990056+03
12898	25	-1	1100	2019-12-27 06:08:44.335406+03
12899	93	-2	1620	2019-12-27 06:29:37.888865+03
12900	57	-2	1900	2019-12-27 06:34:27.233508+03
12901	49	-1	970	2019-12-27 06:50:09.586239+03
12902	83	-1	1230	2019-12-27 07:03:14.572868+03
12903	9	-2	2090	2019-12-27 07:13:17.524604+03
12904	12	-1	1650	2019-12-27 07:29:09.288738+03
12905	63	-1	1780	2019-12-27 07:46:24.924516+03
12906	82	-1	560	2019-12-27 07:49:16.68498+03
12907	96	-1	1570	2019-12-27 07:54:00.561975+03
12908	18	-1	910	2019-12-27 08:06:03.088853+03
12909	1	-1	640	2019-12-27 08:21:55.08754+03
12910	55	-1	3480	2019-12-27 08:27:24.469892+03
12911	96	-1	1570	2019-12-27 08:33:24.345804+03
12912	55	-1	3480	2019-12-27 08:34:08.64451+03
12913	57	-1	1900	2019-12-27 08:39:12.584212+03
12914	29	-1	1940	2019-12-27 08:57:03.450568+03
12915	42	-1	1790	2019-12-27 08:57:19.640842+03
12916	6	-1	980	2019-12-27 09:03:11.40951+03
12917	20	-2	830	2019-12-27 09:08:32.957725+03
12918	71	-1	1030	2019-12-27 09:12:38.293628+03
12919	4	-1	1420	2019-12-27 09:16:12.866777+03
12920	77	-2	640	2019-12-27 09:29:05.005431+03
12921	46	-1	1270	2019-12-27 09:39:20.011384+03
12922	29	-1	1940	2019-12-27 10:04:30.297341+03
12923	89	-1	1420	2019-12-27 10:17:05.942756+03
12924	12	-2	1650	2019-12-27 10:31:56.577558+03
12925	39	-2	910	2019-12-27 10:39:58.37508+03
12926	50	-1	1140	2019-12-27 10:42:48.32226+03
12927	12	-2	1650	2019-12-27 10:54:32.546991+03
12928	57	-1	1900	2019-12-27 11:01:00.159936+03
12929	54	-1	3470	2019-12-27 11:27:57.914958+03
12930	71	-1	1030	2019-12-27 11:33:03.0847+03
12931	18	-2	910	2019-12-27 11:41:23.108865+03
12932	46	-1	1270	2019-12-27 11:56:01.795444+03
12933	66	-1	690	2019-12-27 12:13:47.592774+03
12934	56	-1	2460	2019-12-27 12:15:18.907635+03
12935	61	-1	1510	2019-12-27 12:22:21.958103+03
12936	10	-1	2080	2019-12-27 12:41:43.862894+03
12937	43	-1	380	2019-12-27 13:03:50.747434+03
12938	60	-1	2700	2019-12-27 13:09:54.670129+03
12939	24	-1	950	2019-12-27 13:13:31.210781+03
12940	92	-1	630	2019-12-27 13:33:16.976564+03
12941	71	-1	1030	2019-12-27 13:47:17.812929+03
12942	35	-2	670	2019-12-27 13:48:38.308249+03
12943	91	-1	1620	2019-12-27 14:00:07.222722+03
12944	30	-1	1140	2019-12-27 14:17:34.193463+03
12945	14	-1	1350	2019-12-27 14:53:03.618989+03
12946	77	-1	640	2019-12-27 14:53:09.432243+03
12947	11	-1	830	2019-12-27 14:58:12.254446+03
12948	76	-1	1070	2019-12-27 15:06:48.234764+03
12949	56	-1	2460	2019-12-27 15:16:16.204016+03
12950	89	-1	1420	2019-12-27 15:24:45.792832+03
12951	59	-1	1030	2019-12-27 16:04:09.573346+03
12952	1	-1	640	2019-12-27 16:06:22.456707+03
12953	7	-1	810	2019-12-27 16:11:52.046306+03
12954	14	-1	1350	2019-12-27 16:43:54.318033+03
12955	85	-1	730	2019-12-27 17:05:37.035021+03
12956	89	-1	1420	2019-12-27 17:16:20.883555+03
12957	85	-1	730	2019-12-27 17:19:20.937479+03
12958	3	-2	660	2019-12-27 17:26:12.457565+03
12959	22	-2	1070	2019-12-27 17:53:26.334545+03
12960	91	-1	1620	2019-12-27 18:08:48.764199+03
12961	13	-1	460	2019-12-27 18:11:25.056617+03
12962	87	-1	2320	2019-12-27 18:16:26.710793+03
12963	80	-1	1120	2019-12-27 18:32:36.561488+03
12964	52	-1	1090	2019-12-27 18:52:28.602381+03
12965	83	-3	1230	2019-12-27 19:23:43.467375+03
12966	8	-1	1920	2019-12-27 19:36:30.466299+03
12967	41	-1	830	2019-12-27 19:47:41.048773+03
12968	10	-1	2080	2019-12-27 19:54:31.717402+03
12969	47	-1	1480	2019-12-27 20:18:08.165292+03
12970	33	39	392	2019-12-27 20:51:55.198092+03
12971	55	-1	3480	2019-12-27 20:59:34.293252+03
12972	3	-1	660	2019-12-27 21:16:48.688414+03
12973	17	-1	1500	2019-12-27 21:17:22.172701+03
12974	48	-1	640	2019-12-27 21:19:28.534733+03
12975	84	-1	2700	2019-12-27 21:27:00.673252+03
12976	26	-1	390	2019-12-27 21:27:25.018064+03
12977	3	-1	660	2019-12-27 22:02:09.092986+03
12978	12	-2	1650	2019-12-27 22:18:09.288843+03
12979	79	-1	550	2019-12-27 22:22:37.271822+03
12980	18	-1	910	2019-12-27 22:31:19.549205+03
12981	27	-1	880	2019-12-27 22:41:23.369429+03
12982	32	-1	710	2019-12-27 23:13:57.144595+03
12983	36	-1	630	2019-12-28 00:00:37.607155+03
12984	63	-1	1780	2019-12-28 00:22:02.66353+03
12985	44	-1	500	2019-12-28 00:24:39.495113+03
12986	87	-2	2320	2019-12-28 00:38:32.908879+03
12987	59	-1	1030	2019-12-28 00:47:44.822716+03
12988	60	-1	2700	2019-12-28 01:25:38.025896+03
12989	17	-1	1500	2019-12-28 01:38:20.847683+03
12990	76	-1	1070	2019-12-28 02:01:51.76249+03
12991	31	-1	1190	2019-12-28 02:19:04.942693+03
12992	7	-1	810	2019-12-28 02:21:19.060919+03
12993	18	34	453	2019-12-28 02:30:12.318136+03
12994	47	-1	1480	2019-12-28 02:54:25.515584+03
12995	27	-1	880	2019-12-28 03:17:38.915999+03
12996	68	-1	490	2019-12-28 03:48:32.763192+03
12997	47	-1	1480	2019-12-28 04:29:56.601002+03
12998	28	-1	1860	2019-12-28 04:50:17.789454+03
12999	82	-1	560	2019-12-28 05:11:25.848378+03
13000	90	-1	1780	2019-12-28 05:29:57.809335+03
13001	58	30	1595	2019-12-28 05:40:17.258358+03
13002	56	-1	2460	2019-12-28 05:46:40.926316+03
13003	63	-1	1780	2019-12-28 05:57:56.307117+03
13004	20	-1	830	2019-12-28 06:00:48.490555+03
13005	40	-2	1430	2019-12-28 06:19:15.092742+03
13006	44	-2	500	2019-12-28 06:29:37.896095+03
13007	87	-1	2320	2019-12-28 06:29:55.905957+03
13008	39	-1	910	2019-12-28 06:58:15.552782+03
13009	51	-1	1310	2019-12-28 07:05:28.47652+03
13010	13	-2	460	2019-12-28 07:08:59.237074+03
13011	20	-1	830	2019-12-28 07:09:03.50906+03
13012	54	-1	3470	2019-12-28 07:16:40.005994+03
13013	12	37	776	2019-12-28 07:39:18.544475+03
13014	86	-1	910	2019-12-28 08:03:10.731012+03
13015	56	-2	2460	2019-12-28 08:34:03.529584+03
13016	83	-1	1230	2019-12-28 08:59:22.753522+03
13017	75	-1	830	2019-12-28 09:05:26.397127+03
13018	26	-1	390	2019-12-28 09:25:27.75754+03
13019	91	-1	1620	2019-12-28 09:39:34.013201+03
13020	47	-1	1480	2019-12-28 09:52:21.378936+03
13021	39	-1	910	2019-12-28 10:27:52.216786+03
13022	17	-2	1500	2019-12-28 10:30:10.993661+03
13023	13	-2	460	2019-12-28 10:34:02.464293+03
13024	90	-2	1780	2019-12-28 10:47:21.979927+03
13025	96	-1	1570	2019-12-28 11:18:20.53993+03
13026	88	-1	1270	2019-12-28 11:23:16.956963+03
13027	77	-1	640	2019-12-28 11:58:18.221039+03
13028	31	-1	1190	2019-12-28 12:08:19.353859+03
13029	47	-2	1480	2019-12-28 12:10:15.381938+03
13030	18	-1	910	2019-12-28 12:22:04.967905+03
13031	38	-2	1100	2019-12-28 12:23:47.950239+03
13032	82	-2	560	2019-12-28 12:31:13.724698+03
13033	86	-1	910	2019-12-28 12:31:43.268324+03
13034	68	-1	490	2019-12-28 12:45:48.358983+03
13035	38	-1	1100	2019-12-28 13:13:11.898297+03
13036	68	-1	490	2019-12-28 13:14:32.630329+03
13037	86	-1	910	2019-12-28 13:43:50.673502+03
13038	50	-1	1140	2019-12-28 13:52:20.838784+03
13039	35	-1	670	2019-12-28 14:16:58.463638+03
13040	64	-1	970	2019-12-28 14:28:04.578345+03
13041	94	-1	1230	2019-12-28 14:30:30.801658+03
13042	20	-1	830	2019-12-28 14:31:45.530577+03
13043	88	-1	1270	2019-12-28 14:44:47.91011+03
13044	42	-1	1790	2019-12-28 14:48:55.21557+03
13045	11	-1	830	2019-12-28 15:13:51.509642+03
13046	31	-2	1190	2019-12-28 15:19:12.234638+03
13047	41	-2	830	2019-12-28 15:21:30.510705+03
13048	2	-1	470	2019-12-28 15:42:30.773481+03
13049	4	-2	1420	2019-12-28 16:22:28.823375+03
13050	40	-1	1430	2019-12-28 16:25:54.099181+03
13051	88	-1	1270	2019-12-28 16:30:32.46807+03
13052	5	-1	1620	2019-12-28 16:41:41.020363+03
13053	28	-2	1860	2019-12-28 16:56:32.815245+03
13054	7	-1	810	2019-12-28 17:00:54.948324+03
13055	44	-1	500	2019-12-28 17:02:04.216889+03
13056	36	-1	630	2019-12-28 17:03:38.675549+03
13057	93	-2	1620	2019-12-28 17:40:07.695188+03
13058	92	-1	630	2019-12-28 17:47:52.568787+03
13059	66	13	388	2019-12-28 18:15:42.956205+03
13060	5	26	857	2019-12-28 18:31:03.68717+03
13061	60	-2	2700	2019-12-28 18:35:49.73422+03
13062	47	-1	1480	2019-12-28 18:36:40.589251+03
13063	43	-1	380	2019-12-28 18:46:53.350364+03
13064	92	-2	630	2019-12-28 18:54:33.706967+03
13065	77	-1	640	2019-12-28 18:56:07.670435+03
13066	47	-1	1480	2019-12-28 19:20:38.082396+03
13067	14	-1	1350	2019-12-28 19:34:38.837539+03
13068	10	-1	2080	2019-12-28 19:42:23.808457+03
13069	78	-1	900	2019-12-28 19:43:06.834078+03
13070	51	-1	1310	2019-12-28 19:56:29.405502+03
13071	64	-1	970	2019-12-28 20:11:40.650027+03
13072	94	-1	1230	2019-12-28 20:23:31.003292+03
13073	13	-1	460	2019-12-28 21:11:27.79391+03
13074	61	21	721	2019-12-28 21:14:00.020522+03
13075	31	-1	1190	2019-12-28 21:41:53.918887+03
13076	81	-1	1620	2019-12-28 21:48:12.301739+03
13077	26	-1	390	2019-12-28 22:36:42.744885+03
13078	15	-1	2830	2019-12-28 22:39:05.325367+03
13079	76	-1	1070	2019-12-28 22:41:44.131702+03
13080	22	-1	1070	2019-12-28 23:04:46.765291+03
13081	78	-1	900	2019-12-29 00:10:41.280778+03
13082	42	-1	1790	2019-12-29 00:20:11.126745+03
13083	71	-1	1030	2019-12-29 00:58:39.277911+03
13084	91	-1	1620	2019-12-29 01:03:19.682201+03
13085	49	-1	970	2019-12-29 01:40:55.125531+03
13086	87	-1	2320	2019-12-29 01:42:26.626072+03
13087	76	-2	1070	2019-12-29 01:56:32.660917+03
13088	35	-1	670	2019-12-29 02:10:35.450535+03
13089	57	-1	1900	2019-12-29 02:18:33.203049+03
13090	34	-1	1550	2019-12-29 02:27:35.422457+03
13091	39	-2	910	2019-12-29 02:40:13.964469+03
13092	23	-2	4390	2019-12-29 02:43:39.167279+03
13093	59	-1	1030	2019-12-29 02:54:51.742399+03
13094	17	-1	1500	2019-12-29 03:03:36.522481+03
13095	59	-1	1030	2019-12-29 04:03:33.170589+03
13096	29	-1	1940	2019-12-29 04:22:31.367857+03
13097	63	-1	1780	2019-12-29 04:43:59.115145+03
13098	93	-1	1620	2019-12-29 05:00:44.681852+03
13099	75	-2	830	2019-12-29 05:00:53.686468+03
13100	78	-3	900	2019-12-29 05:26:04.703518+03
13101	76	-1	1070	2019-12-29 05:32:42.315524+03
13102	22	-2	1070	2019-12-29 05:33:42.607658+03
13103	56	-2	2460	2019-12-29 05:45:31.408026+03
13104	34	-2	1550	2019-12-29 05:57:55.59584+03
13105	26	-2	390	2019-12-29 06:23:52.548809+03
13106	46	-2	1270	2019-12-29 07:59:50.733234+03
13107	91	-1	1620	2019-12-29 08:42:45.846973+03
13108	27	-1	880	2019-12-29 09:06:39.809175+03
13109	90	-1	1780	2019-12-29 09:29:29.220517+03
13110	79	-1	550	2019-12-29 09:34:35.260262+03
13111	34	-2	1550	2019-12-29 09:53:32.038379+03
13112	55	-1	3480	2019-12-29 09:56:40.735798+03
13113	39	-1	910	2019-12-29 10:07:51.811077+03
13114	21	-2	960	2019-12-29 10:31:02.518065+03
13115	47	-1	1480	2019-12-29 10:35:54.999693+03
13116	34	-1	1550	2019-12-29 10:54:09.897394+03
13117	36	-1	630	2019-12-29 10:59:51.730923+03
13118	89	-2	1420	2019-12-29 11:23:47.573891+03
13119	96	-1	1570	2019-12-29 12:29:57.12519+03
13120	69	-1	1100	2019-12-29 12:49:00.758217+03
13121	23	-1	4390	2019-12-29 13:28:36.213739+03
13122	3	-1	660	2019-12-29 13:41:19.360303+03
13123	8	-2	1920	2019-12-29 13:51:20.379952+03
13124	17	-1	1500	2019-12-29 13:52:17.76876+03
13125	88	-1	1270	2019-12-29 14:02:32.39298+03
13126	60	-1	2700	2019-12-29 14:03:17.530971+03
13127	65	-1	490	2019-12-29 14:19:45.188819+03
13128	8	-1	1920	2019-12-29 14:30:00.640072+03
13129	45	-1	1590	2019-12-29 15:03:04.308681+03
13130	89	-2	1420	2019-12-29 15:13:50.582137+03
13131	66	-1	690	2019-12-29 15:46:00.08802+03
13132	36	-1	630	2019-12-29 15:53:45.578557+03
13133	87	-1	2320	2019-12-29 15:56:10.829504+03
13134	29	-1	1940	2019-12-29 16:13:41.633529+03
13135	3	-1	660	2019-12-29 16:55:43.451608+03
13136	92	-1	630	2019-12-29 17:11:52.273865+03
13137	22	-1	1070	2019-12-29 17:13:31.963976+03
13138	84	-1	2700	2019-12-29 17:15:59.762418+03
13139	36	-1	630	2019-12-29 18:41:09.75063+03
13140	33	-1	900	2019-12-29 18:55:19.739189+03
13141	41	24	368	2019-12-29 19:02:51.504895+03
13142	20	-1	830	2019-12-29 19:14:17.567483+03
13143	9	-1	2090	2019-12-29 19:37:14.671811+03
13144	40	-1	1430	2019-12-29 19:44:13.772725+03
13145	86	24	384	2019-12-29 20:35:49.320995+03
13146	54	-1	3470	2019-12-29 21:06:13.696185+03
13147	25	-1	1100	2019-12-29 21:07:17.673728+03
13148	47	-1	1480	2019-12-29 21:21:41.148289+03
13149	56	-2	2460	2019-12-29 21:39:27.910801+03
13150	48	-1	640	2019-12-29 21:45:18.330442+03
13151	44	-1	500	2019-12-29 21:58:01.572179+03
13152	6	43	442	2019-12-29 22:20:38.13965+03
13153	16	-1	1380	2019-12-29 22:27:55.662852+03
13154	30	-1	1140	2019-12-29 22:29:31.284065+03
13155	65	-1	490	2019-12-29 22:55:17.446884+03
13156	71	-1	1030	2019-12-29 22:56:46.863218+03
13157	15	-2	2830	2019-12-29 23:16:47.362377+03
13158	63	-1	1780	2019-12-29 23:24:51.72342+03
13159	24	-2	950	2019-12-29 23:24:55.938872+03
13160	87	-1	2320	2019-12-29 23:34:51.383425+03
13161	27	-1	880	2019-12-29 23:47:44.632244+03
13162	32	-1	710	2019-12-29 23:53:22.785074+03
13163	58	-1	2830	2019-12-29 23:59:33.944224+03
13164	74	-1	1010	2019-12-30 00:15:55.909445+03
13165	46	-1	1270	2019-12-30 00:29:25.648969+03
13166	7	-1	810	2019-12-30 00:35:47.144793+03
13167	13	-1	460	2019-12-30 00:48:52.042385+03
13168	84	-1	2700	2019-12-30 01:17:04.30652+03
13169	74	-1	1010	2019-12-30 01:30:25.993133+03
13170	59	-1	1030	2019-12-30 01:35:04.690663+03
13171	22	-1	1070	2019-12-30 01:36:11.536019+03
13172	57	-1	1900	2019-12-30 01:45:10.728464+03
13173	82	-2	560	2019-12-30 02:24:01.493817+03
13174	55	-1	3480	2019-12-30 02:34:07.720635+03
13175	28	-1	1860	2019-12-30 02:47:20.308105+03
13176	38	-1	1100	2019-12-30 02:54:51.736848+03
13177	37	-1	1290	2019-12-30 03:06:34.775382+03
13178	83	-1	1230	2019-12-30 03:48:31.069325+03
13179	39	-2	910	2019-12-30 04:00:02.69686+03
13180	12	-1	1650	2019-12-30 04:04:43.151514+03
13181	79	-1	550	2019-12-30 04:42:04.135477+03
13182	10	-1	2080	2019-12-30 04:54:15.049019+03
13183	50	-1	1140	2019-12-30 05:40:20.224739+03
13184	4	-1	1420	2019-12-30 05:47:28.063595+03
13185	81	-1	1620	2019-12-30 05:49:38.172379+03
13186	19	-1	1220	2019-12-30 06:07:03.179884+03
13187	4	-1	1420	2019-12-30 06:10:32.91757+03
13188	83	-1	1230	2019-12-30 06:10:58.924884+03
13189	56	-1	2460	2019-12-30 06:30:10.162343+03
13190	18	-1	910	2019-12-30 06:50:53.791409+03
13191	56	-1	2460	2019-12-30 06:54:18.186235+03
13192	81	-1	1620	2019-12-30 07:03:27.366027+03
13193	75	-1	830	2019-12-30 07:15:47.061402+03
13194	86	-1	910	2019-12-30 07:23:04.415539+03
13195	45	-1	1590	2019-12-30 07:29:43.433728+03
13196	60	-1	2700	2019-12-30 07:36:38.722349+03
13197	89	-3	1420	2019-12-30 07:48:38.242042+03
13198	94	-1	1230	2019-12-30 07:51:10.326395+03
13199	55	-1	3480	2019-12-30 07:52:00.467605+03
13200	77	-2	640	2019-12-30 08:29:37.607441+03
13201	92	-1	630	2019-12-30 08:56:36.363297+03
13202	89	31	697	2019-12-30 09:08:15.504068+03
13203	46	-1	1270	2019-12-30 09:24:12.34114+03
13204	47	-1	1480	2019-12-30 09:37:23.729498+03
13205	69	-1	1100	2019-12-30 09:42:41.146548+03
13206	70	-1	760	2019-12-30 10:10:06.85925+03
13207	37	-1	1290	2019-12-30 10:14:47.267117+03
13208	80	-2	1120	2019-12-30 10:28:59.022307+03
13209	90	-1	1780	2019-12-30 10:48:30.203187+03
13210	63	-1	1780	2019-12-30 11:15:54.386001+03
13211	36	-1	630	2019-12-30 11:17:22.216661+03
13212	43	-1	380	2019-12-30 11:50:53.403966+03
13213	35	-1	670	2019-12-30 11:51:54.376964+03
13214	29	-1	1940	2019-12-30 12:35:13.005787+03
13215	67	-1	350	2019-12-30 12:37:25.983328+03
13216	21	-1	960	2019-12-30 12:51:01.606424+03
13217	21	-1	960	2019-12-30 12:56:16.383511+03
13218	77	-2	640	2019-12-30 13:05:39.233114+03
13219	21	-1	960	2019-12-30 13:31:28.637836+03
13220	4	-1	1420	2019-12-30 13:34:07.625481+03
13221	64	-1	970	2019-12-30 14:05:16.654182+03
13222	64	-1	970	2019-12-30 14:12:11.275007+03
13223	93	-1	1620	2019-12-30 14:13:38.996798+03
13224	71	-1	1030	2019-12-30 14:31:17.207963+03
13225	80	-1	1120	2019-12-30 14:40:13.210195+03
13226	70	-1	760	2019-12-30 14:48:05.409034+03
13227	95	-1	480	2019-12-30 15:15:40.798592+03
13228	43	-1	380	2019-12-30 15:19:15.742133+03
13229	84	-1	2700	2019-12-30 15:33:07.657656+03
13230	89	-1	1420	2019-12-30 15:37:18.42225+03
13231	87	-1	2320	2019-12-30 15:45:05.899664+03
13232	29	-2	1940	2019-12-30 15:45:20.58429+03
13233	80	-2	1120	2019-12-30 16:25:48.848055+03
13234	34	-1	1550	2019-12-30 16:33:17.840969+03
13235	7	-1	810	2019-12-30 16:34:43.74905+03
13236	18	-1	910	2019-12-30 16:48:03.648938+03
13237	35	-1	670	2019-12-30 17:12:35.181956+03
13238	58	-1	2830	2019-12-30 17:18:26.692272+03
13239	14	-1	1350	2019-12-30 17:26:26.203573+03
13240	55	-1	3480	2019-12-30 17:30:21.954021+03
13241	7	-1	810	2019-12-30 17:31:27.091304+03
13242	63	-1	1780	2019-12-30 18:09:56.279917+03
13243	43	-1	380	2019-12-30 18:11:29.964542+03
13244	53	-2	3120	2019-12-30 18:17:00.109291+03
13245	86	-1	910	2019-12-30 18:17:57.749696+03
13246	40	-2	1430	2019-12-30 18:20:35.674693+03
13247	61	-1	1510	2019-12-30 18:21:08.771295+03
13248	36	-1	630	2019-12-30 18:24:23.636181+03
13249	18	-1	910	2019-12-30 18:33:01.281451+03
13250	88	-2	1270	2019-12-30 18:34:58.626508+03
13251	40	-2	1430	2019-12-30 18:47:31.693274+03
13252	96	-2	1570	2019-12-30 18:52:12.772879+03
13253	71	-1	1030	2019-12-30 18:57:41.922719+03
13254	77	-1	640	2019-12-30 19:13:31.547091+03
13255	86	-1	910	2019-12-30 19:15:42.697522+03
13256	54	-1	3470	2019-12-30 19:16:17.214729+03
13257	82	-1	560	2019-12-30 19:28:06.512336+03
13258	49	-1	970	2019-12-30 19:44:03.219919+03
13259	39	-1	910	2019-12-30 19:47:10.862215+03
13260	62	-1	1220	2019-12-30 19:54:47.300864+03
13261	34	-1	1550	2019-12-30 20:12:42.219077+03
13262	38	-1	1100	2019-12-30 20:33:31.349823+03
13263	27	-1	880	2019-12-30 21:17:43.238332+03
13264	57	25	810	2019-12-30 21:19:53.621949+03
13265	6	-1	980	2019-12-30 21:59:53.419371+03
13266	1	-1	640	2019-12-30 22:13:28.414705+03
13267	41	-3	830	2019-12-30 22:43:07.404603+03
13268	13	-2	460	2019-12-30 23:53:24.49717+03
13269	91	-1	1620	2019-12-31 00:07:46.072751+03
13270	89	-1	1420	2019-12-31 00:19:04.169097+03
13271	52	-1	1090	2019-12-31 00:50:05.675954+03
13272	50	-1	1140	2019-12-31 01:07:42.657996+03
13273	74	-1	1010	2019-12-31 01:12:23.449214+03
13274	40	-1	1430	2019-12-31 01:35:17.87693+03
13275	88	-1	1270	2019-12-31 02:04:55.268325+03
13276	3	-1	660	2019-12-31 02:14:47.644338+03
13277	51	-2	1310	2019-12-31 03:02:49.873759+03
13278	1	-2	640	2019-12-31 03:30:17.935342+03
13279	35	-1	670	2019-12-31 03:37:29.904192+03
13280	56	-1	2460	2019-12-31 03:59:50.552622+03
13281	72	-1	620	2019-12-31 04:12:23.84885+03
13282	53	-1	3120	2019-12-31 04:48:26.429611+03
13283	47	-1	1480	2019-12-31 04:57:27.317319+03
13284	23	-1	4390	2019-12-31 05:03:06.362401+03
13285	52	-1	1090	2019-12-31 05:33:02.432497+03
13286	39	-1	910	2019-12-31 05:43:24.57878+03
13287	20	-1	830	2019-12-31 06:00:34.180079+03
13288	93	-1	1620	2019-12-31 06:18:03.056878+03
13289	50	-1	1140	2019-12-31 06:29:50.518116+03
13290	43	-1	380	2019-12-31 06:48:37.272112+03
13291	80	-1	1120	2019-12-31 07:07:02.861045+03
13292	57	-1	1900	2019-12-31 07:20:54.472807+03
13293	89	-1	1420	2019-12-31 08:09:31.377704+03
13294	5	-1	1620	2019-12-31 08:18:01.016949+03
13295	84	-1	2700	2019-12-31 08:36:13.480524+03
13296	96	-1	1570	2019-12-31 08:47:33.783176+03
13297	21	-2	960	2019-12-31 08:52:48.63502+03
13298	9	-1	2090	2019-12-31 09:29:27.732228+03
13299	83	-1	1230	2019-12-31 09:36:25.906051+03
13300	34	-2	1550	2019-12-31 09:41:19.005072+03
13301	21	-1	960	2019-12-31 09:55:20.069018+03
13302	24	-1	950	2019-12-31 10:30:27.634161+03
13303	26	-1	390	2019-12-31 11:19:56.967964+03
13304	64	-1	970	2019-12-31 11:38:58.436678+03
13305	88	-2	1270	2019-12-31 12:51:12.018688+03
13306	5	-1	1620	2019-12-31 13:04:26.528983+03
13307	87	-1	2320	2019-12-31 13:31:12.45978+03
13308	1	-1	640	2019-12-31 13:39:24.718269+03
13309	80	-1	1120	2019-12-31 13:39:49.493243+03
13310	34	-1	1550	2019-12-31 13:42:34.132607+03
13311	76	-2	1070	2019-12-31 13:46:56.034101+03
13312	49	-1	970	2019-12-31 13:48:50.341116+03
13313	14	-1	1350	2019-12-31 13:56:20.479325+03
13314	22	-2	1070	2019-12-31 14:00:47.318998+03
13315	95	-1	480	2019-12-31 14:04:16.364574+03
13316	34	-1	1550	2019-12-31 14:11:48.484281+03
13317	75	-1	830	2019-12-31 14:33:53.055767+03
13318	56	-1	2460	2019-12-31 14:37:16.306194+03
13319	38	-1	1100	2019-12-31 15:02:14.821033+03
13320	69	-1	1100	2019-12-31 15:08:53.019993+03
13321	91	-2	1620	2019-12-31 16:01:24.059601+03
13322	40	-1	1430	2019-12-31 16:02:41.745819+03
13323	55	-2	3480	2019-12-31 16:25:08.464806+03
13324	22	-1	1070	2019-12-31 16:27:08.296302+03
13325	65	-1	490	2019-12-31 17:31:21.746062+03
13326	37	-1	1290	2019-12-31 17:52:22.651508+03
13327	32	-1	710	2019-12-31 18:08:06.495997+03
13328	44	-1	500	2019-12-31 18:36:27.970446+03
13329	39	-1	910	2019-12-31 18:41:28.497776+03
13330	81	-1	1620	2019-12-31 18:42:28.078706+03
13331	12	-1	1650	2019-12-31 18:48:19.40306+03
13332	89	-1	1420	2019-12-31 19:07:45.874191+03
13333	78	-1	900	2019-12-31 19:30:54.208003+03
13334	13	-1	460	2019-12-31 19:32:24.993867+03
13335	69	-2	1100	2019-12-31 19:49:00.708052+03
13336	10	-1	2080	2019-12-31 19:52:06.728777+03
13337	47	-1	1480	2019-12-31 19:55:17.363207+03
13338	22	-1	1070	2019-12-31 20:14:01.952498+03
13339	77	-2	640	2019-12-31 20:20:32.54635+03
13340	91	-1	1620	2019-12-31 20:30:11.393796+03
13341	3	-1	660	2019-12-31 20:39:37.314762+03
13342	86	-1	910	2019-12-31 21:05:50.164411+03
13343	24	-1	950	2019-12-31 21:08:34.812289+03
13344	45	-1	1590	2019-12-31 21:51:19.791813+03
13345	48	-2	640	2019-12-31 22:09:12.257699+03
13346	12	-1	1650	2019-12-31 22:23:59.034837+03
13347	42	-1	1790	2019-12-31 22:34:55.40509+03
13348	78	-1	900	2019-12-31 23:14:18.561432+03
13349	23	-1	4390	2019-12-31 23:14:51.200769+03
13350	10	-1	2080	2019-12-31 23:17:05.43654+03
13351	43	-1	380	2019-12-31 23:34:22.054751+03
13352	89	-1	1420	2020-01-01 00:36:18.905774+03
13353	76	-3	1070	2020-01-01 00:47:14.108766+03
13354	17	-1	1500	2020-01-01 01:19:41.26041+03
13355	47	-1	1480	2020-01-01 01:34:15.289334+03
13356	64	-1	970	2020-01-01 01:56:52.390468+03
13357	91	-2	1620	2020-01-01 02:07:58.384576+03
13358	89	-2	1420	2020-01-01 02:37:11.961357+03
13359	76	-1	1070	2020-01-01 02:53:34.945264+03
13360	83	-1	1230	2020-01-01 03:13:54.25624+03
13361	50	-1	1140	2020-01-01 03:18:17.921466+03
13362	31	-1	1190	2020-01-01 03:28:25.375879+03
13363	77	-1	640	2020-01-01 05:21:32.097356+03
13364	90	-1	1780	2020-01-01 05:21:41.335172+03
13365	52	-1	1090	2020-01-01 05:25:22.179565+03
13366	15	-1	2830	2020-01-01 05:31:08.058451+03
13367	77	-1	640	2020-01-01 06:00:27.40622+03
13368	68	-1	490	2020-01-01 06:11:35.835833+03
13369	34	-1	1550	2020-01-01 06:17:57.988787+03
13370	8	-1	1920	2020-01-01 06:34:48.345376+03
13371	15	-1	2830	2020-01-01 06:53:02.72952+03
13372	31	-1	1190	2020-01-01 06:53:34.881644+03
13373	71	-1	1030	2020-01-01 07:08:05.759657+03
13374	50	-1	1140	2020-01-01 07:37:08.662801+03
13375	77	-1	640	2020-01-01 08:16:46.258781+03
13376	96	-1	1570	2020-01-01 08:31:53.092926+03
13377	35	-2	670	2020-01-01 08:46:39.836696+03
13378	51	-1	1310	2020-01-01 09:08:21.219986+03
13379	7	25	429	2020-01-01 09:30:05.418325+03
13380	48	-1	640	2020-01-01 10:30:21.383474+03
13381	90	-2	1780	2020-01-01 10:33:02.976123+03
13382	19	-2	1220	2020-01-01 11:21:56.481729+03
13383	95	-1	480	2020-01-01 11:32:50.37575+03
13384	52	-1	1090	2020-01-01 11:43:40.558385+03
13385	94	-1	1230	2020-01-01 12:07:18.306216+03
13386	29	-1	1940	2020-01-01 12:30:06.973661+03
13387	52	-1	1090	2020-01-01 12:30:20.964873+03
13388	42	-1	1790	2020-01-01 12:56:20.793847+03
13389	27	-1	880	2020-01-01 13:11:52.588033+03
13390	22	-1	1070	2020-01-01 13:15:36.256873+03
13391	22	-1	1070	2020-01-01 13:23:31.957968+03
13392	73	-1	960	2020-01-01 13:27:20.088519+03
13393	54	-1	3470	2020-01-01 13:33:56.425785+03
13394	71	-1	1030	2020-01-01 14:00:52.391066+03
13395	10	-1	2080	2020-01-01 14:00:59.773649+03
13396	57	-1	1900	2020-01-01 14:28:30.350284+03
13397	47	-1	1480	2020-01-01 15:23:53.576941+03
13398	52	-3	1090	2020-01-01 15:28:40.600085+03
13399	61	-1	1510	2020-01-01 15:30:05.937246+03
13400	57	-1	1900	2020-01-01 15:40:52.468547+03
13401	50	14	594	2020-01-01 15:43:55.1448+03
13402	17	-1	1500	2020-01-01 15:51:32.026119+03
13403	71	-1	1030	2020-01-01 15:55:13.833611+03
13404	19	-1	1220	2020-01-01 16:03:07.217425+03
13405	71	-1	1030	2020-01-01 16:09:17.637605+03
13406	58	-1	2830	2020-01-01 16:37:49.519681+03
13407	39	-1	910	2020-01-01 16:56:58.253214+03
13408	20	-1	830	2020-01-01 17:04:18.911452+03
13409	51	-1	1310	2020-01-01 17:05:51.083554+03
13410	19	-1	1220	2020-01-01 17:11:02.068103+03
13411	81	-1	1620	2020-01-01 17:17:55.353238+03
13412	30	-1	1140	2020-01-01 18:03:21.861752+03
13413	30	-1	1140	2020-01-01 18:07:50.997579+03
13414	18	-1	910	2020-01-01 18:54:51.293214+03
13415	42	-1	1790	2020-01-01 19:04:11.251215+03
13416	67	-1	350	2020-01-01 19:09:13.315065+03
13417	88	-1	1270	2020-01-01 19:09:36.640024+03
13418	39	-1	910	2020-01-01 19:12:47.79721+03
13419	34	-1	1550	2020-01-01 19:18:10.399588+03
13420	88	-1	1270	2020-01-01 19:51:49.884424+03
13421	32	-2	710	2020-01-01 20:13:30.931428+03
13422	22	-1	1070	2020-01-01 20:43:00.776232+03
13423	41	-1	830	2020-01-01 20:45:30.310389+03
13424	5	-1	1620	2020-01-01 20:51:11.361273+03
13425	26	-2	390	2020-01-01 21:11:26.035273+03
13426	4	-1	1420	2020-01-01 21:11:45.877889+03
13427	96	-2	1570	2020-01-01 21:22:56.551057+03
13428	66	-1	690	2020-01-01 21:25:48.978181+03
13429	19	-1	1220	2020-01-01 21:36:47.60588+03
13430	19	-1	1220	2020-01-01 21:43:22.006518+03
13431	31	-1	1190	2020-01-01 22:09:31.04072+03
13432	63	20	927	2020-01-01 22:22:28.647186+03
13433	6	-1	980	2020-01-01 22:23:09.350388+03
13434	6	-1	980	2020-01-01 22:34:52.721256+03
13435	76	-1	1070	2020-01-01 22:35:07.462084+03
13436	40	-1	1430	2020-01-01 22:39:59.29362+03
13437	17	-2	1500	2020-01-01 23:26:34.56479+03
13438	38	-1	1100	2020-01-01 23:28:14.071133+03
13439	46	-1	1270	2020-01-01 23:41:46.049803+03
13440	59	-1	1030	2020-01-01 23:42:18.531073+03
13441	22	-1	1070	2020-01-01 23:51:07.390638+03
13442	92	-1	630	2020-01-01 23:53:03.811581+03
13443	24	-1	950	2020-01-02 00:50:11.006186+03
13444	57	-2	1900	2020-01-02 01:02:50.396592+03
13445	31	-1	1190	2020-01-02 01:03:00.4549+03
13446	84	-1	2700	2020-01-02 01:05:25.294017+03
13447	73	-1	960	2020-01-02 01:11:03.025581+03
13448	78	-1	900	2020-01-02 01:12:50.344791+03
13449	90	-1	1780	2020-01-02 02:03:37.2902+03
13450	32	-1	710	2020-01-02 02:30:46.084101+03
13451	57	-1	1900	2020-01-02 02:46:36.43182+03
13452	68	-1	490	2020-01-02 02:52:18.347527+03
13453	78	-1	900	2020-01-02 03:01:07.2568+03
13454	29	-1	1940	2020-01-02 03:22:26.984165+03
13455	51	-1	1310	2020-01-02 03:50:47.423879+03
13456	70	31	447	2020-01-02 03:58:51.78007+03
13457	37	-1	1290	2020-01-02 04:49:51.606334+03
13458	33	-1	900	2020-01-02 04:55:16.556892+03
13459	34	-1	1550	2020-01-02 04:56:10.262334+03
13460	92	-1	630	2020-01-02 05:05:00.495032+03
13461	79	-1	550	2020-01-02 05:23:40.989125+03
13462	65	-1	490	2020-01-02 06:09:19.084094+03
13463	59	-1	1030	2020-01-02 06:23:41.571527+03
13464	33	-1	900	2020-01-02 06:32:59.241948+03
13465	95	-1	480	2020-01-02 06:46:19.45628+03
13466	13	-1	460	2020-01-02 06:54:32.995255+03
13467	72	-1	620	2020-01-02 07:09:02.133539+03
13468	26	-1	390	2020-01-02 07:09:41.851752+03
13469	20	-1	830	2020-01-02 07:56:12.656571+03
13470	48	-1	640	2020-01-02 08:10:40.537734+03
13471	96	-2	1570	2020-01-02 08:18:31.993369+03
13472	13	-1	460	2020-01-02 08:20:26.663693+03
13473	33	-1	900	2020-01-02 08:21:57.190911+03
13474	76	-1	1070	2020-01-02 08:43:27.38705+03
13475	40	-2	1430	2020-01-02 08:52:02.92547+03
13476	86	-2	910	2020-01-02 09:17:34.355664+03
13477	2	-1	470	2020-01-02 09:20:13.73166+03
13478	37	-2	1290	2020-01-02 10:25:43.727653+03
13479	85	-1	730	2020-01-02 10:30:46.155171+03
13480	38	-1	1100	2020-01-02 10:46:24.316872+03
13481	84	-1	2700	2020-01-02 10:56:54.820773+03
13482	25	-1	1100	2020-01-02 11:10:21.36596+03
13483	48	-1	640	2020-01-02 11:19:35.753817+03
13484	88	29	623	2020-01-02 11:46:26.698181+03
13485	62	-1	1220	2020-01-02 11:50:42.886342+03
13486	40	-1	1430	2020-01-02 11:52:04.36018+03
13487	70	-1	760	2020-01-02 12:20:10.679165+03
13488	82	-1	560	2020-01-02 12:23:29.979338+03
13489	64	-1	970	2020-01-02 12:54:02.885785+03
13490	71	-1	1030	2020-01-02 13:02:07.64521+03
13491	75	-1	830	2020-01-02 13:37:36.956978+03
13492	65	-1	490	2020-01-02 13:51:48.887689+03
13493	5	-2	1620	2020-01-02 14:32:56.957547+03
13494	20	-1	830	2020-01-02 14:33:21.688005+03
13495	12	-1	1650	2020-01-02 14:36:20.947868+03
13496	79	13	299	2020-01-02 15:08:22.040949+03
13497	91	-2	1620	2020-01-02 15:26:13.577158+03
13498	88	-1	1270	2020-01-02 15:28:35.739018+03
13499	79	-1	550	2020-01-02 15:40:17.086564+03
13500	85	30	375	2020-01-02 16:09:35.185029+03
13501	29	-2	1940	2020-01-02 16:10:01.219051+03
13502	2	-1	470	2020-01-02 16:15:37.696403+03
13503	5	-2	1620	2020-01-02 16:30:56.675105+03
13504	90	-1	1780	2020-01-02 16:40:54.509609+03
13505	3	-1	660	2020-01-02 16:57:01.115134+03
13506	49	-1	970	2020-01-02 17:09:46.926695+03
13507	50	-1	1140	2020-01-02 17:12:26.842566+03
13508	68	-1	490	2020-01-02 17:14:52.671778+03
13509	79	-2	550	2020-01-02 17:32:35.523699+03
13510	33	-1	900	2020-01-02 17:46:29.111541+03
13511	28	-1	1860	2020-01-02 18:23:47.194095+03
13512	77	-2	640	2020-01-02 18:25:48.22983+03
13513	36	-1	630	2020-01-02 18:48:45.327236+03
13514	76	-1	1070	2020-01-02 19:12:58.07858+03
13515	27	17	449	2020-01-02 19:47:06.407754+03
13516	71	-1	1030	2020-01-02 20:32:08.166912+03
13517	8	-1	1920	2020-01-02 20:52:39.266362+03
13518	76	-1	1070	2020-01-02 21:19:10.048643+03
13519	81	-2	1620	2020-01-02 21:30:06.365966+03
13520	34	-2	1550	2020-01-02 22:36:11.54079+03
13521	9	-1	2090	2020-01-02 22:46:16.109679+03
13522	23	-1	4390	2020-01-02 23:07:45.035415+03
13523	62	-2	1220	2020-01-02 23:13:05.386054+03
13524	20	-1	830	2020-01-02 23:29:44.572154+03
13525	43	-1	380	2020-01-02 23:29:53.536755+03
13526	12	-1	1650	2020-01-02 23:42:05.071603+03
13527	56	-1	2460	2020-01-02 23:51:59.73435+03
13528	74	-2	1010	2020-01-03 00:03:05.354069+03
13529	48	28	288	2020-01-03 00:24:06.332807+03
13530	81	-1	1620	2020-01-03 00:35:30.966376+03
13531	29	-2	1940	2020-01-03 00:37:27.804652+03
13532	28	-1	1860	2020-01-03 00:58:50.397238+03
13533	4	-1	1420	2020-01-03 00:59:50.283379+03
13534	95	-1	480	2020-01-03 01:16:12.005542+03
13535	10	-1	2080	2020-01-03 01:31:47.644524+03
13536	84	33	1599	2020-01-03 01:36:00.560363+03
13537	11	22	347	2020-01-03 01:49:23.518051+03
13538	14	-1	1350	2020-01-03 02:18:08.930722+03
13539	72	-1	620	2020-01-03 02:41:13.784398+03
13540	86	-1	910	2020-01-03 03:19:14.424904+03
13541	12	-2	1650	2020-01-03 04:19:20.348915+03
13542	3	-1	660	2020-01-03 04:25:14.124711+03
13543	1	-1	640	2020-01-03 04:51:03.177158+03
13544	3	-1	660	2020-01-03 05:00:58.453216+03
13545	35	-1	670	2020-01-03 05:46:07.334793+03
13546	56	-1	2460	2020-01-03 05:53:26.191726+03
13547	28	-1	1860	2020-01-03 06:02:59.644709+03
13548	67	-1	350	2020-01-03 06:13:26.842797+03
13549	84	-1	2700	2020-01-03 06:26:19.881609+03
13550	65	-2	490	2020-01-03 06:37:13.550783+03
13551	31	-2	1190	2020-01-03 06:57:32.258338+03
13552	2	-1	470	2020-01-03 07:10:26.082083+03
13553	92	-1	630	2020-01-03 07:24:31.882031+03
13554	95	-1	480	2020-01-03 07:24:56.538782+03
13555	42	-1	1790	2020-01-03 07:25:28.036873+03
13556	93	29	759	2020-01-03 08:06:09.982339+03
13557	93	-1	1620	2020-01-03 08:56:58.482016+03
13558	33	-1	900	2020-01-03 09:04:34.241175+03
13559	30	-2	1140	2020-01-03 09:07:44.882968+03
13560	46	-2	1270	2020-01-03 09:37:28.993553+03
13561	34	-1	1550	2020-01-03 09:42:56.607773+03
13562	26	-1	390	2020-01-03 10:00:42.087433+03
13563	33	-1	900	2020-01-03 10:10:47.859599+03
13564	56	-1	2460	2020-01-03 10:35:44.810022+03
13565	33	-1	900	2020-01-03 11:21:40.314262+03
13566	18	-2	910	2020-01-03 11:28:19.853594+03
13567	5	-2	1620	2020-01-03 11:35:10.170872+03
13568	96	22	740	2020-01-03 11:50:04.078197+03
13569	30	27	569	2020-01-03 12:08:21.46034+03
13570	30	-1	1140	2020-01-03 12:41:41.376947+03
13571	69	-2	1100	2020-01-03 12:49:44.56143+03
13572	25	-1	1100	2020-01-03 13:02:17.944915+03
13573	83	-1	1230	2020-01-03 13:37:23.687349+03
13574	21	-1	960	2020-01-03 13:52:01.327759+03
13575	42	-1	1790	2020-01-03 14:44:07.424015+03
13576	35	-1	670	2020-01-03 14:44:37.052595+03
13577	39	-1	910	2020-01-03 14:46:20.816807+03
13578	54	-1	3470	2020-01-03 14:53:06.994619+03
13579	64	-2	970	2020-01-03 15:06:06.100649+03
13580	49	-2	970	2020-01-03 15:11:12.196369+03
13581	16	7	779	2020-01-03 15:29:14.51835+03
13582	31	-1	1190	2020-01-03 15:31:35.197432+03
13583	34	-1	1550	2020-01-03 15:36:10.378655+03
13584	59	-1	1030	2020-01-03 15:47:37.277611+03
13585	24	-1	950	2020-01-03 16:01:43.918563+03
13586	75	-1	830	2020-01-03 16:09:32.499772+03
13587	12	-1	1650	2020-01-03 16:13:21.930554+03
13588	29	-1	1940	2020-01-03 16:50:22.034427+03
13589	94	-1	1230	2020-01-03 17:11:20.063841+03
13590	51	-1	1310	2020-01-03 17:38:19.607014+03
13591	13	-1	460	2020-01-03 17:47:15.217687+03
13592	42	-1	1790	2020-01-03 17:54:03.120059+03
13593	12	-1	1650	2020-01-03 17:55:03.968053+03
13594	47	41	818	2020-01-03 18:48:03.316819+03
13595	77	-1	640	2020-01-03 18:54:06.801194+03
13596	20	-1	830	2020-01-03 18:59:14.309224+03
13597	24	-1	950	2020-01-03 19:11:33.020531+03
13598	65	12	266	2020-01-03 19:20:29.351364+03
13599	15	-1	2830	2020-01-03 19:29:43.084178+03
13600	14	-1	1350	2020-01-03 19:31:52.419483+03
13601	32	-1	710	2020-01-03 19:56:13.71121+03
13602	26	-1	390	2020-01-03 19:56:27.379311+03
13603	31	-1	1190	2020-01-03 19:56:57.17679+03
13604	91	-2	1620	2020-01-03 20:06:20.954415+03
13605	29	-1	1940	2020-01-03 20:23:55.79473+03
13606	31	-1	1190	2020-01-03 22:00:25.753851+03
13607	65	-1	490	2020-01-03 22:23:37.883327+03
13608	11	-2	830	2020-01-03 22:31:05.196668+03
13609	18	-2	910	2020-01-03 22:55:20.659574+03
13610	69	-2	1100	2020-01-03 23:07:27.615709+03
13611	75	-1	830	2020-01-03 23:08:21.870933+03
13612	13	-1	460	2020-01-03 23:10:11.432218+03
13613	33	-1	900	2020-01-03 23:14:13.74984+03
13614	86	-1	910	2020-01-03 23:31:44.870646+03
13615	22	-1	1070	2020-01-03 23:49:12.676134+03
13616	51	-2	1310	2020-01-04 00:30:38.494748+03
13617	52	-1	1090	2020-01-04 00:39:35.012095+03
13618	85	-1	730	2020-01-04 00:50:14.436092+03
13619	54	-1	3470	2020-01-04 00:57:58.844375+03
13620	85	-1	730	2020-01-04 01:13:36.820854+03
13621	35	-1	670	2020-01-04 01:38:22.123754+03
13622	88	-1	1270	2020-01-04 01:38:23.632225+03
13623	88	-2	1270	2020-01-04 01:38:53.169676+03
13624	36	-1	630	2020-01-04 01:48:16.037017+03
13625	71	-2	1030	2020-01-04 01:58:18.094511+03
13626	18	-1	910	2020-01-04 02:14:51.741975+03
13627	12	-1	1650	2020-01-04 02:20:49.361584+03
13628	67	-1	350	2020-01-04 02:24:53.922224+03
13629	57	-1	1900	2020-01-04 02:50:09.209805+03
13630	69	-2	1100	2020-01-04 03:40:34.291311+03
13631	87	-1	2320	2020-01-04 03:56:49.72288+03
13632	94	-1	1230	2020-01-04 03:57:44.333952+03
13633	78	-1	900	2020-01-04 04:07:46.780316+03
13634	77	-1	640	2020-01-04 04:20:55.312683+03
13635	82	-1	560	2020-01-04 04:50:14.244414+03
13636	19	-1	1220	2020-01-04 05:08:15.150849+03
13637	61	-1	1510	2020-01-04 05:11:03.794535+03
13638	7	-1	810	2020-01-04 05:12:14.508306+03
13639	91	-1	1620	2020-01-04 05:31:57.347338+03
13640	18	-1	910	2020-01-04 06:26:22.603244+03
13641	53	-1	3120	2020-01-04 06:30:57.622533+03
13642	8	-2	1920	2020-01-04 06:49:48.909395+03
13643	32	-2	710	2020-01-04 07:01:04.185653+03
13644	46	-1	1270	2020-01-04 07:01:31.998496+03
13645	43	-1	380	2020-01-04 07:19:22.013632+03
13646	30	-1	1140	2020-01-04 07:41:59.117809+03
13647	17	-1	1500	2020-01-04 07:53:54.328329+03
13648	81	-3	1620	2020-01-04 08:17:28.78742+03
13649	84	-1	2700	2020-01-04 08:28:30.644461+03
13650	61	-1	1510	2020-01-04 08:38:08.487938+03
13651	29	-1	1940	2020-01-04 08:58:00.468513+03
13652	1	-1	640	2020-01-04 09:04:19.520691+03
13653	24	-1	950	2020-01-04 09:06:39.352905+03
13654	92	-2	630	2020-01-04 09:10:57.811893+03
13655	64	-1	970	2020-01-04 09:50:12.701357+03
13656	14	-1	1350	2020-01-04 10:18:39.799561+03
13657	40	-1	1430	2020-01-04 10:42:35.598312+03
13658	57	-1	1900	2020-01-04 11:05:37.520551+03
13659	7	-1	810	2020-01-04 11:13:49.180336+03
13660	2	-1	470	2020-01-04 11:16:58.689461+03
13661	67	32	149	2020-01-04 11:31:22.339626+03
13662	14	-1	1350	2020-01-04 11:34:38.823583+03
13663	42	-1	1790	2020-01-04 11:38:06.259672+03
13664	47	-1	1480	2020-01-04 11:43:12.213552+03
13665	74	-2	1010	2020-01-04 11:48:26.025314+03
13666	35	-1	670	2020-01-04 12:24:02.215492+03
13667	8	-1	1920	2020-01-04 12:30:33.060433+03
13668	66	-1	690	2020-01-04 13:02:12.76381+03
13669	29	-2	1940	2020-01-04 13:07:31.684924+03
13670	50	-1	1140	2020-01-04 13:27:32.653117+03
13671	34	29	730	2020-01-04 13:34:30.140747+03
13672	13	-1	460	2020-01-04 13:36:49.698554+03
13673	79	-1	550	2020-01-04 13:46:55.955224+03
13674	16	-1	1380	2020-01-04 13:52:12.310899+03
13675	2	-1	470	2020-01-04 14:10:23.816845+03
13676	45	-1	1590	2020-01-04 14:18:18.712232+03
13677	89	-1	1420	2020-01-04 14:34:55.623897+03
13678	14	-1	1350	2020-01-04 14:39:04.784803+03
13679	84	-1	2700	2020-01-04 14:54:08.353834+03
13680	16	-1	1380	2020-01-04 15:11:32.421091+03
13681	47	-2	1480	2020-01-04 15:14:53.70431+03
13682	7	-1	810	2020-01-04 15:18:12.81692+03
13683	64	-1	970	2020-01-04 15:48:41.52448+03
13684	2	-1	470	2020-01-04 15:53:24.342681+03
13685	37	-2	1290	2020-01-04 16:17:13.575699+03
13686	30	-1	1140	2020-01-04 16:46:06.296355+03
13687	58	-1	2830	2020-01-04 16:58:02.385404+03
13688	14	-1	1350	2020-01-04 17:12:09.063949+03
13689	35	-1	670	2020-01-04 17:17:39.480489+03
13690	71	-1	1030	2020-01-04 17:20:27.109214+03
13691	5	-1	1620	2020-01-04 17:22:31.666758+03
13692	13	-1	460	2020-01-04 17:28:42.214176+03
13693	17	-1	1500	2020-01-04 17:35:21.894928+03
13694	78	-2	900	2020-01-04 18:05:31.375033+03
13695	42	-2	1790	2020-01-04 18:46:15.671255+03
13696	71	26	442	2020-01-04 19:06:08.614791+03
13697	72	-1	620	2020-01-04 19:21:35.952698+03
13698	81	-1	1620	2020-01-04 19:23:44.219895+03
13699	19	-1	1220	2020-01-04 19:52:02.516046+03
13700	84	-1	2700	2020-01-04 20:04:55.454142+03
13701	82	-1	560	2020-01-04 20:26:27.339315+03
13702	94	-1	1230	2020-01-04 20:50:07.410989+03
13703	31	-1	1190	2020-01-04 21:25:09.609213+03
13704	11	-1	830	2020-01-04 21:34:39.236072+03
13705	40	-1	1430	2020-01-04 21:56:23.099954+03
13706	57	-2	1900	2020-01-04 22:17:08.984283+03
13707	65	-1	490	2020-01-04 22:20:02.717317+03
13708	31	-2	1190	2020-01-04 22:49:22.545917+03
13709	46	-1	1270	2020-01-04 22:51:26.190877+03
13710	87	-1	2320	2020-01-04 22:55:52.578885+03
13711	19	-1	1220	2020-01-04 23:10:40.858857+03
13712	11	-1	830	2020-01-04 23:39:08.402144+03
13713	81	-2	1620	2020-01-04 23:56:58.680612+03
13714	50	-2	1140	2020-01-05 00:09:03.528565+03
13715	60	-1	2700	2020-01-05 00:33:56.64642+03
13716	44	-1	500	2020-01-05 00:34:00.623819+03
13717	52	-1	1090	2020-01-05 00:51:23.119213+03
13718	64	-2	970	2020-01-05 00:53:28.751881+03
13719	42	-1	1790	2020-01-05 01:14:03.627587+03
13720	36	-1	630	2020-01-05 01:22:47.514617+03
13721	15	-1	2830	2020-01-05 01:23:10.395341+03
13722	86	-1	910	2020-01-05 01:51:28.126881+03
13723	7	-1	810	2020-01-05 02:15:01.053128+03
13724	64	-1	970	2020-01-05 02:32:08.425712+03
13725	10	-1	2080	2020-01-05 02:33:32.765317+03
13726	81	-1	1620	2020-01-05 02:33:48.946402+03
13727	57	-2	1900	2020-01-05 02:50:34.540793+03
13728	35	-1	670	2020-01-05 03:04:41.640235+03
13729	45	-2	1590	2020-01-05 03:23:10.941059+03
13730	5	-1	1620	2020-01-05 03:30:22.040424+03
13731	62	-1	1220	2020-01-05 03:30:22.870999+03
13732	16	-1	1380	2020-01-05 03:58:05.091024+03
13733	76	-1	1070	2020-01-05 04:20:46.134308+03
13734	40	-1	1430	2020-01-05 04:29:53.037472+03
13735	23	-2	4390	2020-01-05 04:40:30.400533+03
13736	30	-1	1140	2020-01-05 04:44:44.989013+03
13737	10	-1	2080	2020-01-05 04:49:22.546013+03
13738	71	-1	1030	2020-01-05 04:58:00.979251+03
13739	65	-1	490	2020-01-05 05:02:38.910653+03
13740	58	-1	2830	2020-01-05 05:03:12.248797+03
13741	15	-1	2830	2020-01-05 05:35:02.688012+03
13742	22	-1	1070	2020-01-05 05:37:08.656506+03
13743	2	-1	470	2020-01-05 05:51:09.198784+03
13744	12	-2	1650	2020-01-05 06:20:15.593422+03
13745	3	-1	660	2020-01-05 06:58:28.020908+03
13746	47	-1	1480	2020-01-05 07:11:21.991625+03
13747	40	30	785	2020-01-05 07:32:17.439502+03
13748	69	-1	1100	2020-01-05 07:35:48.041257+03
13749	62	-2	1220	2020-01-05 07:50:46.113869+03
13750	85	-1	730	2020-01-05 08:15:06.220384+03
13751	67	-2	350	2020-01-05 08:47:55.667309+03
13752	32	-1	710	2020-01-05 08:48:45.617966+03
13753	86	-1	910	2020-01-05 09:02:55.802012+03
13754	59	-1	1030	2020-01-05 09:49:08.838448+03
13755	60	-1	2700	2020-01-05 09:51:18.387279+03
13756	7	-2	810	2020-01-05 09:57:42.617374+03
13757	84	-1	2700	2020-01-05 10:24:47.778994+03
13758	80	-3	1120	2020-01-05 10:40:42.065194+03
13759	67	-1	350	2020-01-05 10:52:54.77595+03
13760	7	-1	810	2020-01-05 11:01:53.992112+03
13761	92	-1	630	2020-01-05 11:06:33.949853+03
13762	75	-2	830	2020-01-05 11:09:20.264817+03
13763	29	-1	1940	2020-01-05 11:20:44.60878+03
13764	77	33	377	2020-01-05 11:20:47.192537+03
13765	74	-1	1010	2020-01-05 11:24:59.705762+03
13766	3	-1	660	2020-01-05 11:37:42.636519+03
13767	56	-2	2460	2020-01-05 11:42:30.62207+03
13768	63	-1	1780	2020-01-05 12:00:37.340473+03
13769	75	-1	830	2020-01-05 12:20:54.841782+03
13770	67	-1	350	2020-01-05 13:01:37.370093+03
13771	12	-2	1650	2020-01-05 13:15:26.7509+03
13772	63	-1	1780	2020-01-05 13:18:02.995931+03
13773	46	-2	1270	2020-01-05 13:45:59.798699+03
13774	39	-1	910	2020-01-05 13:55:41.949342+03
13775	66	-1	690	2020-01-05 14:00:56.938241+03
13776	9	-1	2090	2020-01-05 14:18:33.468746+03
13777	67	-1	350	2020-01-05 14:18:50.345839+03
13778	3	-2	660	2020-01-05 14:23:18.556782+03
13779	68	-1	490	2020-01-05 14:38:58.408217+03
13780	6	-1	980	2020-01-05 14:51:36.858804+03
13781	5	-1	1620	2020-01-05 14:53:37.601427+03
13782	85	-1	730	2020-01-05 15:05:56.531652+03
13783	41	-1	830	2020-01-05 15:06:47.978929+03
13784	40	-1	1430	2020-01-05 15:40:14.702718+03
13785	96	-2	1570	2020-01-05 15:52:11.447296+03
13786	12	-1	1650	2020-01-05 16:08:46.473561+03
13787	19	-2	1220	2020-01-05 16:37:18.287938+03
13788	92	-1	630	2020-01-05 16:56:35.999565+03
13789	12	-1	1650	2020-01-05 17:11:46.683732+03
13790	41	-1	830	2020-01-05 17:23:56.732449+03
13791	20	-2	830	2020-01-05 18:02:56.582374+03
13792	35	34	341	2020-01-05 18:35:18.972633+03
13793	95	-1	480	2020-01-05 19:07:17.584995+03
13794	87	-1	2320	2020-01-05 19:08:40.554045+03
13795	75	-2	830	2020-01-05 19:36:48.864278+03
13796	7	-2	810	2020-01-05 19:36:56.740897+03
13797	73	24	487	2020-01-05 19:39:33.417837+03
13798	90	-1	1780	2020-01-05 20:13:09.729669+03
13799	22	-1	1070	2020-01-05 20:13:42.736199+03
13800	84	-1	2700	2020-01-05 20:33:45.135514+03
13801	54	-1	3470	2020-01-05 20:52:38.243198+03
13802	23	-2	4390	2020-01-05 21:07:32.174724+03
13803	96	-1	1570	2020-01-05 21:46:39.48203+03
13804	61	-1	1510	2020-01-05 22:55:13.983738+03
13805	48	-1	640	2020-01-05 23:04:45.430194+03
13806	6	-1	980	2020-01-05 23:08:45.359048+03
13807	12	-1	1650	2020-01-05 23:48:40.520898+03
13808	80	-1	1120	2020-01-06 00:24:37.976605+03
13809	71	-1	1030	2020-01-06 00:53:31.395492+03
13810	95	-1	480	2020-01-06 00:54:35.47026+03
13811	39	-1	910	2020-01-06 01:08:59.599449+03
13812	91	-1	1620	2020-01-06 01:27:26.497179+03
13813	74	-1	1010	2020-01-06 01:36:54.227614+03
13814	4	-1	1420	2020-01-06 01:57:56.564643+03
13815	6	-1	980	2020-01-06 02:09:51.915055+03
13816	21	-1	960	2020-01-06 02:11:37.14675+03
13817	14	-1	1350	2020-01-06 02:19:14.555984+03
13818	63	-1	1780	2020-01-06 02:21:53.398485+03
13819	5	-1	1620	2020-01-06 02:34:55.149993+03
13820	30	-1	1140	2020-01-06 03:00:50.458621+03
13821	14	-1	1350	2020-01-06 03:31:35.515436+03
13822	14	-2	1350	2020-01-06 03:39:34.067175+03
13823	39	-1	910	2020-01-06 04:25:37.497406+03
13824	70	-1	760	2020-01-06 04:27:54.702708+03
13825	5	-1	1620	2020-01-06 04:35:55.786937+03
13826	80	31	553	2020-01-06 04:53:25.225414+03
13827	63	-1	1780	2020-01-06 05:07:11.877279+03
13828	17	-1	1500	2020-01-06 05:13:31.926941+03
13829	47	-1	1480	2020-01-06 06:14:37.186852+03
13830	66	-1	690	2020-01-06 06:17:28.596787+03
13831	5	-1	1620	2020-01-06 06:20:13.089056+03
13832	39	-1	910	2020-01-06 06:39:41.627302+03
13833	69	-1	1100	2020-01-06 06:44:14.566983+03
13834	54	37	1858	2020-01-06 07:11:56.940419+03
13835	86	-1	910	2020-01-06 07:22:08.365925+03
13836	38	-1	1100	2020-01-06 07:32:05.247633+03
13837	17	-2	1500	2020-01-06 07:37:50.452418+03
13838	35	-1	670	2020-01-06 07:46:42.283233+03
13839	74	-1	1010	2020-01-06 07:48:06.969574+03
13840	35	-1	670	2020-01-06 08:01:24.5377+03
13841	49	-1	970	2020-01-06 08:04:05.50119+03
13842	6	-2	980	2020-01-06 08:05:42.703782+03
13843	81	22	707	2020-01-06 08:27:46.045854+03
13844	84	-1	2700	2020-01-06 08:51:24.735144+03
13845	3	-1	660	2020-01-06 08:57:01.970817+03
13846	72	-1	620	2020-01-06 09:27:33.350932+03
13847	31	-2	1190	2020-01-06 09:42:11.013301+03
13848	22	-1	1070	2020-01-06 09:44:11.862304+03
13849	24	-1	950	2020-01-06 10:27:39.857748+03
13850	31	-2	1190	2020-01-06 10:41:41.788715+03
13851	61	-1	1510	2020-01-06 10:42:52.741895+03
13852	43	-1	380	2020-01-06 10:48:30.770274+03
13853	81	-1	1620	2020-01-06 10:51:03.955092+03
13854	22	-1	1070	2020-01-06 11:02:17.379557+03
13855	30	-1	1140	2020-01-06 11:10:09.529417+03
13856	38	-1	1100	2020-01-06 11:11:48.442896+03
13857	65	-1	490	2020-01-06 11:13:22.085271+03
13858	55	-1	3480	2020-01-06 11:14:21.136481+03
13859	34	-1	1550	2020-01-06 11:17:25.797289+03
13860	40	-1	1430	2020-01-06 11:39:13.930707+03
13861	52	-1	1090	2020-01-06 12:18:13.229205+03
13862	85	-1	730	2020-01-06 12:46:27.897322+03
13863	10	-1	2080	2020-01-06 12:49:36.177807+03
13864	37	-1	1290	2020-01-06 13:15:02.96314+03
13865	96	-1	1570	2020-01-06 13:19:31.102113+03
13866	76	-1	1070	2020-01-06 13:23:36.244853+03
13867	59	-2	1030	2020-01-06 13:28:28.731587+03
13868	77	-2	640	2020-01-06 13:38:32.559458+03
13869	76	-1	1070	2020-01-06 14:10:58.345722+03
13870	4	-1	1420	2020-01-06 14:14:21.741299+03
13871	96	-2	1570	2020-01-06 14:14:44.443153+03
13872	76	-1	1070	2020-01-06 14:30:13.042372+03
13873	13	-1	460	2020-01-06 14:34:09.743703+03
13874	35	-1	670	2020-01-06 14:56:57.066454+03
13875	86	-2	910	2020-01-06 15:04:50.795232+03
13876	42	-2	1790	2020-01-06 15:14:26.502747+03
13877	4	-1	1420	2020-01-06 15:31:46.738387+03
13878	22	-2	1070	2020-01-06 15:32:13.790292+03
13879	71	-1	1030	2020-01-06 15:45:13.305237+03
13880	96	-1	1570	2020-01-06 16:01:27.122087+03
13881	56	-1	2460	2020-01-06 16:19:32.72733+03
13882	18	-1	910	2020-01-06 16:23:57.735479+03
13883	18	-1	910	2020-01-06 16:28:03.614901+03
13884	5	-1	1620	2020-01-06 16:41:40.405366+03
13885	51	-1	1310	2020-01-06 16:51:43.149295+03
13886	90	28	1059	2020-01-06 17:05:32.260254+03
13887	42	-1	1790	2020-01-06 17:15:20.63005+03
13888	64	-1	970	2020-01-06 17:36:56.308596+03
13889	39	-2	910	2020-01-06 17:45:53.644995+03
13890	44	-1	500	2020-01-06 18:00:05.29698+03
13891	22	-1	1070	2020-01-06 18:30:06.747111+03
13892	76	-1	1070	2020-01-06 18:50:20.512513+03
13893	96	-1	1570	2020-01-06 19:09:53.729724+03
13894	70	-1	760	2020-01-06 19:24:15.625005+03
13895	84	-1	2700	2020-01-06 19:58:10.775669+03
13896	86	-1	910	2020-01-06 20:42:40.075087+03
13897	56	-1	2460	2020-01-06 20:42:59.288718+03
13898	7	-1	810	2020-01-06 20:51:18.220058+03
13899	12	-1	1650	2020-01-06 21:03:33.347044+03
13900	42	-1	1790	2020-01-06 21:13:59.802847+03
13901	21	-1	960	2020-01-06 21:17:47.510583+03
13902	39	-3	910	2020-01-06 21:34:30.064519+03
13903	77	-2	640	2020-01-06 22:07:11.845027+03
13904	56	-1	2460	2020-01-06 22:15:23.045018+03
13905	80	-1	1120	2020-01-06 22:25:11.754597+03
13906	9	-1	2090	2020-01-06 22:34:37.772729+03
13907	81	-1	1620	2020-01-06 22:35:41.770822+03
13908	21	-1	960	2020-01-06 22:43:04.116725+03
13909	13	-2	460	2020-01-06 23:02:13.073823+03
13910	95	-2	480	2020-01-06 23:30:29.86327+03
13911	1	-1	640	2020-01-06 23:52:07.228039+03
13912	59	-1	1030	2020-01-06 23:58:42.759878+03
13913	17	-1	1500	2020-01-07 00:31:30.831367+03
13914	54	-1	3470	2020-01-07 00:40:21.117929+03
13915	51	-1	1310	2020-01-07 00:47:23.266535+03
13916	61	-1	1510	2020-01-07 00:54:08.249891+03
13917	87	-1	2320	2020-01-07 01:13:27.053839+03
13918	49	-1	970	2020-01-07 02:05:52.899395+03
13919	49	-1	970	2020-01-07 02:12:09.572444+03
13920	22	-1	1070	2020-01-07 02:43:14.311221+03
13921	28	25	788	2020-01-07 02:54:43.586051+03
13922	93	-1	1620	2020-01-07 02:54:49.115242+03
13923	18	-1	910	2020-01-07 03:00:22.508365+03
13924	85	-1	730	2020-01-07 03:07:32.410826+03
13925	38	-1	1100	2020-01-07 03:07:56.976362+03
13926	45	-1	1590	2020-01-07 03:19:58.641071+03
13927	60	-1	2700	2020-01-07 03:24:27.682243+03
13928	89	-1	1420	2020-01-07 03:37:36.779338+03
13929	90	-1	1780	2020-01-07 03:40:51.453609+03
13930	26	-2	390	2020-01-07 04:20:15.168494+03
13931	17	-1	1500	2020-01-07 04:25:55.149442+03
13932	86	-2	910	2020-01-07 04:32:07.974885+03
13933	17	-1	1500	2020-01-07 04:35:50.857322+03
13934	6	-1	980	2020-01-07 04:53:34.819359+03
13935	64	-1	970	2020-01-07 05:14:03.972738+03
13936	88	-2	1270	2020-01-07 05:25:24.925249+03
13937	14	-1	1350	2020-01-07 05:55:52.913409+03
13938	23	-2	4390	2020-01-07 06:19:14.365981+03
13939	30	-1	1140	2020-01-07 06:19:14.962752+03
13940	53	-2	3120	2020-01-07 06:20:31.494227+03
13941	29	-1	1940	2020-01-07 06:35:16.1377+03
13942	96	-2	1570	2020-01-07 06:43:06.05654+03
13943	71	-1	1030	2020-01-07 07:15:17.681588+03
13944	59	-1	1030	2020-01-07 07:48:37.945666+03
13945	77	-2	640	2020-01-07 07:56:06.798787+03
13946	59	-1	1030	2020-01-07 08:19:17.252436+03
13947	94	-1	1230	2020-01-07 08:26:00.264942+03
13948	84	-1	2700	2020-01-07 08:42:06.45092+03
13949	29	-1	1940	2020-01-07 09:17:31.686055+03
13950	51	-2	1310	2020-01-07 09:34:52.600897+03
13951	22	-1	1070	2020-01-07 09:39:22.86185+03
13952	37	-1	1290	2020-01-07 09:56:17.317096+03
13953	8	-1	1920	2020-01-07 10:35:01.40666+03
13954	30	-1	1140	2020-01-07 11:02:49.963228+03
13955	48	-3	640	2020-01-07 11:05:02.714752+03
13956	53	-1	3120	2020-01-07 11:35:59.016733+03
13957	42	-1	1790	2020-01-07 11:55:14.746343+03
13958	82	-1	560	2020-01-07 12:27:11.676096+03
13959	64	-1	970	2020-01-07 12:32:24.465149+03
13960	28	-1	1860	2020-01-07 12:48:56.845583+03
13961	54	-1	3470	2020-01-07 12:50:21.39086+03
13962	17	-2	1500	2020-01-07 13:21:25.635447+03
13963	1	-2	640	2020-01-07 13:33:26.332266+03
13964	42	-2	1790	2020-01-07 13:35:08.711087+03
13965	89	-1	1420	2020-01-07 14:14:56.919676+03
13966	35	-1	670	2020-01-07 14:37:59.338755+03
13967	24	-1	950	2020-01-07 14:43:00.167618+03
13968	77	-1	640	2020-01-07 15:59:41.270662+03
13969	52	29	615	2020-01-07 16:01:29.927227+03
13970	49	36	414	2020-01-07 16:05:25.631298+03
13971	82	-1	560	2020-01-07 16:08:43.34432+03
13972	58	-1	2830	2020-01-07 16:09:21.027311+03
13973	84	-1	2700	2020-01-07 16:16:09.883713+03
13974	63	-2	1780	2020-01-07 16:26:55.014421+03
13975	47	-2	1480	2020-01-07 16:27:22.616012+03
13976	46	-1	1270	2020-01-07 16:28:14.661992+03
13977	3	-1	660	2020-01-07 16:46:26.183175+03
13978	47	-1	1480	2020-01-07 17:02:32.327747+03
13979	17	-1	1500	2020-01-07 17:03:39.199858+03
13980	84	-3	2700	2020-01-07 17:24:13.71734+03
13981	91	-2	1620	2020-01-07 17:31:08.159572+03
13982	85	-1	730	2020-01-07 17:35:43.25217+03
13983	34	-1	1550	2020-01-07 18:19:19.987273+03
13984	62	-1	1220	2020-01-07 18:49:39.018789+03
13985	59	-1	1030	2020-01-07 18:55:25.088501+03
13986	28	-2	1860	2020-01-07 19:18:46.581919+03
13987	76	-2	1070	2020-01-07 20:49:12.955342+03
13988	75	-1	830	2020-01-07 21:28:00.092023+03
13989	76	-1	1070	2020-01-07 22:26:13.914121+03
13990	17	-2	1500	2020-01-07 22:58:25.588204+03
13991	87	-1	2320	2020-01-07 23:01:57.597161+03
13992	32	-1	710	2020-01-07 23:15:48.306292+03
13993	41	-1	830	2020-01-07 23:19:59.777339+03
13994	22	-1	1070	2020-01-07 23:22:01.568149+03
13995	86	-2	910	2020-01-07 23:43:10.918189+03
13996	80	-1	1120	2020-01-08 00:07:54.840648+03
13997	85	-2	730	2020-01-08 00:10:36.525426+03
13998	92	-1	630	2020-01-08 00:21:24.665146+03
13999	71	-1	1030	2020-01-08 00:49:34.059242+03
14000	88	-1	1270	2020-01-08 00:54:14.803249+03
14001	4	-1	1420	2020-01-08 01:04:08.399961+03
14002	96	-1	1570	2020-01-08 01:13:49.147373+03
14003	89	-1	1420	2020-01-08 01:31:57.718588+03
14004	47	-2	1480	2020-01-08 01:46:34.006967+03
14005	52	-1	1090	2020-01-08 02:12:47.26269+03
14006	18	-1	910	2020-01-08 02:18:56.603011+03
14007	33	-1	900	2020-01-08 02:23:55.546462+03
14008	36	-1	630	2020-01-08 02:33:03.163382+03
14009	34	-2	1550	2020-01-08 02:35:27.014833+03
14010	75	-1	830	2020-01-08 02:39:59.237183+03
14011	38	-1	1100	2020-01-08 03:13:42.364822+03
14012	51	-2	1310	2020-01-08 03:50:50.455758+03
14013	10	-1	2080	2020-01-08 03:54:03.48337+03
14014	70	-1	760	2020-01-08 04:03:57.349942+03
14015	91	-1	1620	2020-01-08 04:09:40.596148+03
14016	33	-1	900	2020-01-08 04:56:03.527307+03
14017	53	-1	3120	2020-01-08 05:14:50.608092+03
14018	60	-3	2700	2020-01-08 05:19:47.389368+03
14019	24	-1	950	2020-01-08 05:20:59.0529+03
14020	87	-1	2320	2020-01-08 05:25:22.760586+03
14021	89	-1	1420	2020-01-08 05:28:56.316366+03
14022	33	-1	900	2020-01-08 05:31:43.426957+03
14023	22	-1	1070	2020-01-08 05:32:11.482843+03
14024	7	-1	810	2020-01-08 05:44:18.981656+03
14025	22	44	510	2020-01-08 05:52:59.451956+03
14026	47	-1	1480	2020-01-08 06:01:45.768382+03
14027	1	-1	640	2020-01-08 06:10:01.282503+03
14028	13	-1	460	2020-01-08 06:12:54.536607+03
14029	32	-1	710	2020-01-08 06:29:27.748306+03
14030	10	-1	2080	2020-01-08 06:47:56.171903+03
14031	17	-1	1500	2020-01-08 07:05:36.406297+03
14032	18	-1	910	2020-01-08 07:18:08.067933+03
14033	13	-1	460	2020-01-08 07:18:20.088331+03
14034	87	-1	2320	2020-01-08 07:37:54.048551+03
14035	86	-1	910	2020-01-08 07:39:17.746677+03
14036	8	33	867	2020-01-08 07:43:02.668645+03
14037	46	-1	1270	2020-01-08 07:46:20.984027+03
14038	33	-1	900	2020-01-08 07:59:47.718232+03
14039	47	-1	1480	2020-01-08 08:01:14.641602+03
14040	19	-1	1220	2020-01-08 08:26:24.502548+03
14041	79	-1	550	2020-01-08 08:35:01.309709+03
14042	32	-1	710	2020-01-08 08:35:43.371732+03
14043	10	-3	2080	2020-01-08 09:19:09.281562+03
14044	64	-1	970	2020-01-08 09:35:36.467385+03
14045	78	-1	900	2020-01-08 09:50:17.545498+03
14046	33	-1	900	2020-01-08 10:02:00.454066+03
14047	57	-1	1900	2020-01-08 10:03:00.066228+03
14048	73	-1	960	2020-01-08 11:05:57.666332+03
14049	13	-1	460	2020-01-08 11:24:36.486235+03
14050	45	-1	1590	2020-01-08 11:32:38.500459+03
14051	76	-1	1070	2020-01-08 11:44:52.805339+03
14052	10	-1	2080	2020-01-08 11:58:40.073298+03
14053	67	-1	350	2020-01-08 12:04:27.163343+03
14054	58	-1	2830	2020-01-08 12:11:06.044944+03
14055	89	-1	1420	2020-01-08 12:32:53.257475+03
14056	35	-1	670	2020-01-08 12:47:12.92742+03
14057	6	-1	980	2020-01-08 13:08:04.050995+03
14058	44	-1	500	2020-01-08 13:14:33.754358+03
14059	42	-1	1790	2020-01-08 13:21:20.144593+03
14060	92	-1	630	2020-01-08 13:26:01.67806+03
14061	32	-1	710	2020-01-08 13:28:02.100787+03
14062	91	-1	1620	2020-01-08 14:10:06.270067+03
14063	68	-1	490	2020-01-08 14:12:57.09859+03
14064	29	-1	1940	2020-01-08 15:31:34.18395+03
14065	56	-1	2460	2020-01-08 15:55:58.699272+03
14066	49	-1	970	2020-01-08 16:00:37.886703+03
14067	6	-1	980	2020-01-08 16:04:19.303874+03
14068	37	-1	1290	2020-01-08 16:36:34.269764+03
14069	8	-1	1920	2020-01-08 16:59:27.66685+03
14070	42	-1	1790	2020-01-08 17:17:06.512509+03
14071	35	-2	670	2020-01-08 17:27:43.382593+03
14072	85	-1	730	2020-01-08 18:24:44.294522+03
14073	76	-2	1070	2020-01-08 18:45:44.461017+03
14074	68	-1	490	2020-01-08 18:56:45.320995+03
14075	43	-1	380	2020-01-08 19:21:09.673091+03
14076	32	40	415	2020-01-08 19:22:56.815645+03
14077	48	-1	640	2020-01-08 19:27:20.081306+03
14078	54	-1	3470	2020-01-08 19:28:12.441231+03
14079	19	-1	1220	2020-01-08 19:34:34.021333+03
14080	1	-1	640	2020-01-08 19:51:28.938998+03
14081	96	-1	1570	2020-01-08 20:02:43.033893+03
14082	56	-1	2460	2020-01-08 20:31:14.727798+03
14083	85	-1	730	2020-01-08 20:35:45.20053+03
14084	54	-1	3470	2020-01-08 20:37:00.915798+03
14085	53	-1	3120	2020-01-08 21:05:15.628808+03
14086	96	-1	1570	2020-01-08 21:05:44.34319+03
14087	76	-1	1070	2020-01-08 21:15:44.485379+03
14088	26	-1	390	2020-01-08 21:20:54.153124+03
14089	74	-2	1010	2020-01-08 21:59:02.013052+03
14090	68	-1	490	2020-01-08 22:44:25.449843+03
14091	20	-2	830	2020-01-08 22:49:54.133354+03
14092	77	-1	640	2020-01-08 23:13:17.419386+03
14093	82	-1	560	2020-01-08 23:14:09.403838+03
14094	93	-1	1620	2020-01-08 23:24:17.212676+03
14095	54	-1	3470	2020-01-08 23:50:56.903879+03
14096	82	-1	560	2020-01-08 23:53:54.9972+03
14097	42	-1	1790	2020-01-09 00:47:51.78409+03
14098	81	-1	1620	2020-01-09 00:52:58.530581+03
14099	40	-2	1430	2020-01-09 00:56:08.866831+03
14100	37	-1	1290	2020-01-09 00:56:53.416827+03
14101	91	-2	1620	2020-01-09 01:00:45.201318+03
14102	77	-1	640	2020-01-09 01:02:10.148468+03
14103	14	-2	1350	2020-01-09 01:04:54.516881+03
14104	37	-2	1290	2020-01-09 01:21:43.371625+03
14105	70	-1	760	2020-01-09 01:27:32.310345+03
14106	84	-1	2700	2020-01-09 01:31:46.820132+03
14107	6	-1	980	2020-01-09 02:06:24.066161+03
14108	21	-1	960	2020-01-09 02:09:30.811514+03
14109	67	-1	350	2020-01-09 02:13:35.93261+03
14110	61	-1	1510	2020-01-09 03:08:24.902755+03
14111	87	-1	2320	2020-01-09 03:09:41.52847+03
14112	73	-1	960	2020-01-09 03:21:36.112797+03
14113	53	-1	3120	2020-01-09 03:31:00.542097+03
14114	21	-1	960	2020-01-09 03:44:34.281372+03
14115	54	-1	3470	2020-01-09 03:51:44.424141+03
14116	1	-1	640	2020-01-09 04:01:43.50483+03
14117	70	-1	760	2020-01-09 05:05:12.156504+03
14118	75	-1	830	2020-01-09 05:22:53.419891+03
14119	14	-1	1350	2020-01-09 05:25:42.271378+03
14120	30	-1	1140	2020-01-09 06:03:37.050262+03
14121	43	21	201	2020-01-09 06:07:18.797379+03
14122	79	-1	550	2020-01-09 06:20:03.375287+03
14123	23	-1	4390	2020-01-09 06:39:42.549333+03
14124	70	-1	760	2020-01-09 06:48:45.271611+03
14125	53	-1	3120	2020-01-09 07:51:25.29236+03
14126	96	-1	1570	2020-01-09 08:00:51.897806+03
14127	5	-1	1620	2020-01-09 08:11:23.691331+03
14128	90	-1	1780	2020-01-09 08:26:07.394764+03
14129	10	-1	2080	2020-01-09 08:54:29.957934+03
14130	56	25	1139	2020-01-09 09:08:51.728544+03
14131	17	-1	1500	2020-01-09 09:19:57.8973+03
14132	39	-2	910	2020-01-09 09:57:19.207692+03
14133	96	-1	1570	2020-01-09 10:05:04.995049+03
14134	71	-1	1030	2020-01-09 10:06:39.210721+03
14135	4	-1	1420	2020-01-09 10:45:39.826239+03
14136	88	-2	1270	2020-01-09 11:34:32.7203+03
14137	32	-2	710	2020-01-09 11:52:07.609132+03
14138	49	-1	970	2020-01-09 12:42:08.60994+03
14139	78	-1	900	2020-01-09 12:56:15.681457+03
14140	6	-1	980	2020-01-09 12:59:52.542541+03
14141	13	-2	460	2020-01-09 13:14:17.998332+03
14142	73	-1	960	2020-01-09 13:18:54.677644+03
14143	31	-1	1190	2020-01-09 13:30:56.936224+03
14144	47	-2	1480	2020-01-09 13:41:30.212185+03
14145	84	-2	2700	2020-01-09 13:48:54.486903+03
14146	67	-1	350	2020-01-09 13:49:58.152301+03
14147	42	-1	1790	2020-01-09 14:28:30.436139+03
14148	93	-2	1620	2020-01-09 14:38:04.264655+03
14149	17	-1	1500	2020-01-09 14:56:42.68783+03
14150	53	-2	3120	2020-01-09 15:06:08.069993+03
14151	59	-1	1030	2020-01-09 15:35:19.579604+03
14152	38	-1	1100	2020-01-09 15:40:48.120569+03
14153	1	-1	640	2020-01-09 15:42:34.144166+03
14154	23	-1	4390	2020-01-09 16:12:41.859586+03
14155	21	-1	960	2020-01-09 16:26:16.360684+03
14156	30	-1	1140	2020-01-09 16:43:10.52641+03
14157	55	-1	3480	2020-01-09 17:25:44.871034+03
14158	85	-1	730	2020-01-09 17:29:28.373927+03
14159	28	-1	1860	2020-01-09 17:38:29.888274+03
14160	49	-2	970	2020-01-09 17:47:21.936626+03
14161	53	-1	3120	2020-01-09 17:48:11.063996+03
14162	63	-1	1780	2020-01-09 18:26:45.795974+03
14163	95	-1	480	2020-01-09 18:46:39.351266+03
14164	61	-1	1510	2020-01-09 19:04:33.561509+03
14165	10	-1	2080	2020-01-09 19:17:31.953971+03
14166	1	-1	640	2020-01-09 19:30:51.618377+03
14167	78	-1	900	2020-01-09 19:40:31.162565+03
14168	19	-1	1220	2020-01-09 20:08:09.096642+03
14169	27	-1	880	2020-01-09 20:09:14.602608+03
14170	46	-1	1270	2020-01-09 20:26:58.596339+03
14171	73	-1	960	2020-01-09 20:46:43.781063+03
14172	35	-1	670	2020-01-09 20:58:28.767465+03
14173	5	-2	1620	2020-01-09 21:12:54.777894+03
14174	71	-1	1030	2020-01-09 21:18:33.796488+03
14175	52	-1	1090	2020-01-09 21:21:11.140839+03
14176	87	29	1109	2020-01-09 21:28:04.896251+03
14177	67	-1	350	2020-01-09 21:29:13.535722+03
14178	78	-1	900	2020-01-09 21:44:28.044265+03
14179	55	-1	3480	2020-01-09 21:48:29.011786+03
14180	71	-1	1030	2020-01-09 22:40:33.83186+03
14181	57	-1	1900	2020-01-09 22:43:29.436338+03
14182	17	-1	1500	2020-01-09 22:53:49.831099+03
14183	63	-1	1780	2020-01-09 23:14:10.276413+03
14184	61	-1	1510	2020-01-09 23:17:27.892896+03
14185	84	-1	2700	2020-01-09 23:23:27.075204+03
14186	24	-1	950	2020-01-09 23:29:20.299816+03
14187	76	-1	1070	2020-01-09 23:51:05.961505+03
14188	31	-1	1190	2020-01-10 00:27:20.862447+03
14189	82	-1	560	2020-01-10 00:30:17.720774+03
14190	16	-1	1380	2020-01-10 01:02:14.089152+03
14191	14	-1	1350	2020-01-10 01:37:56.995844+03
14192	13	-1	460	2020-01-10 01:46:27.749753+03
14193	78	-1	900	2020-01-10 02:16:06.804437+03
14194	46	-1	1270	2020-01-10 02:34:08.45378+03
14195	67	-1	350	2020-01-10 02:51:48.652578+03
14196	31	-1	1190	2020-01-10 03:01:16.183719+03
14197	5	-1	1620	2020-01-10 03:01:53.40758+03
14198	70	-1	760	2020-01-10 03:19:41.746446+03
14199	36	-1	630	2020-01-10 03:32:16.064038+03
14200	40	-1	1430	2020-01-10 03:35:54.659729+03
14201	27	-1	880	2020-01-10 03:44:16.104392+03
14202	16	-1	1380	2020-01-10 04:02:05.478594+03
14203	58	-1	2830	2020-01-10 04:25:12.037413+03
14204	87	-1	2320	2020-01-10 04:43:04.47543+03
14205	47	-1	1480	2020-01-10 05:07:49.593067+03
14206	95	-1	480	2020-01-10 05:15:43.524288+03
14207	51	-1	1310	2020-01-10 05:22:51.504781+03
14208	13	-1	460	2020-01-10 05:39:07.052695+03
14209	85	-1	730	2020-01-10 06:04:06.275486+03
14210	75	-1	830	2020-01-10 06:04:21.232974+03
14211	35	-1	670	2020-01-10 06:08:40.667592+03
14212	48	-2	640	2020-01-10 06:32:10.141629+03
14213	46	-1	1270	2020-01-10 06:50:51.268441+03
14214	10	-1	2080	2020-01-10 06:54:40.630379+03
14215	6	-1	980	2020-01-10 07:20:56.069917+03
14216	49	-1	970	2020-01-10 07:49:47.824494+03
14217	89	-1	1420	2020-01-10 08:01:26.029517+03
14218	76	-2	1070	2020-01-10 08:30:46.610598+03
14219	24	-1	950	2020-01-10 08:44:56.715221+03
14220	12	-1	1650	2020-01-10 08:54:31.861719+03
14221	44	-1	500	2020-01-10 09:12:26.713661+03
14222	57	-1	1900	2020-01-10 09:37:45.403646+03
14223	4	28	604	2020-01-10 09:38:23.5516+03
14224	14	-1	1350	2020-01-10 10:37:21.482587+03
14225	17	-1	1500	2020-01-10 10:38:54.495007+03
14226	77	-1	640	2020-01-10 10:43:08.09585+03
14227	36	-1	630	2020-01-10 11:06:28.502746+03
14228	56	-1	2460	2020-01-10 11:28:42.268255+03
14229	64	-2	970	2020-01-10 11:33:35.811745+03
14230	45	-1	1590	2020-01-10 11:52:38.310416+03
14231	78	-1	900	2020-01-10 11:55:41.079386+03
14232	6	-3	980	2020-01-10 11:59:31.337406+03
14233	61	-1	1510	2020-01-10 12:03:49.313758+03
14234	12	-1	1650	2020-01-10 12:17:05.243611+03
14235	26	-2	390	2020-01-10 12:26:37.559538+03
14236	80	-1	1120	2020-01-10 12:29:49.62887+03
14237	24	-1	950	2020-01-10 12:32:08.175833+03
14238	79	-1	550	2020-01-10 12:32:28.200566+03
14239	42	-1	1790	2020-01-10 12:41:45.923188+03
14240	75	-1	830	2020-01-10 12:52:36.334738+03
14241	19	-2	1220	2020-01-10 13:35:16.620911+03
14242	30	-1	1140	2020-01-10 13:47:10.301242+03
14243	56	-1	2460	2020-01-10 13:53:20.552882+03
14244	25	-1	1100	2020-01-10 14:23:51.554733+03
14245	38	-2	1100	2020-01-10 14:23:54.272454+03
14246	13	-1	460	2020-01-10 14:43:54.261463+03
14247	35	-1	670	2020-01-10 14:48:32.343957+03
14248	59	-1	1030	2020-01-10 14:50:46.859712+03
14249	10	-1	2080	2020-01-10 14:59:27.465161+03
14250	30	-1	1140	2020-01-10 14:59:34.476602+03
14251	3	-2	660	2020-01-10 15:18:22.20032+03
14252	12	-1	1650	2020-01-10 15:51:51.092238+03
14253	28	-1	1860	2020-01-10 16:05:03.294987+03
14254	89	-1	1420	2020-01-10 16:12:36.447424+03
14255	45	-2	1590	2020-01-10 16:17:25.306445+03
14256	48	-1	640	2020-01-10 16:35:18.456919+03
14257	37	-1	1290	2020-01-10 16:38:25.520075+03
14258	46	-1	1270	2020-01-10 16:38:47.702493+03
14259	52	-1	1090	2020-01-10 16:54:19.022491+03
14260	4	-1	1420	2020-01-10 16:55:58.697892+03
14261	24	-2	950	2020-01-10 16:58:41.666488+03
14262	14	-1	1350	2020-01-10 17:39:17.607249+03
14263	13	-1	460	2020-01-10 18:01:45.180401+03
14264	10	-1	2080	2020-01-10 18:04:45.916863+03
14265	86	-1	910	2020-01-10 18:22:03.117406+03
14266	87	-1	2320	2020-01-10 18:32:54.92093+03
14267	12	-1	1650	2020-01-10 18:43:00.679984+03
14268	20	-1	830	2020-01-10 18:53:18.216782+03
14269	2	-2	470	2020-01-10 19:23:13.272025+03
14270	63	-2	1780	2020-01-10 19:33:32.844235+03
14271	53	-2	3120	2020-01-10 20:03:49.960662+03
14272	24	-1	950	2020-01-10 20:07:12.725686+03
14273	50	-1	1140	2020-01-10 20:30:27.966535+03
14274	69	-1	1100	2020-01-10 21:56:11.671396+03
14275	28	-1	1860	2020-01-10 22:28:02.61623+03
14276	21	23	450	2020-01-10 22:28:46.120462+03
14277	13	-1	460	2020-01-10 22:30:16.962619+03
14278	8	-1	1920	2020-01-10 22:56:52.552998+03
14279	31	-1	1190	2020-01-10 22:57:41.789031+03
14280	1	-1	640	2020-01-10 23:25:18.063432+03
14281	20	-1	830	2020-01-10 23:52:19.734222+03
14282	59	-1	1030	2020-01-10 23:54:58.360229+03
14283	82	-1	560	2020-01-11 00:14:45.393629+03
14284	88	-1	1270	2020-01-11 00:43:37.027211+03
14285	46	-1	1270	2020-01-11 01:42:57.028878+03
14286	35	-1	670	2020-01-11 01:54:03.829049+03
14287	77	-1	640	2020-01-11 02:04:10.193445+03
14288	74	-2	1010	2020-01-11 02:06:51.818862+03
14289	22	-2	1070	2020-01-11 02:35:38.538401+03
14290	8	-1	1920	2020-01-11 02:38:21.852619+03
14291	47	-1	1480	2020-01-11 02:49:18.114858+03
14292	80	-3	1120	2020-01-11 03:48:57.388848+03
14293	59	-1	1030	2020-01-11 04:06:20.323822+03
14294	5	-1	1620	2020-01-11 04:16:29.292271+03
14295	52	-1	1090	2020-01-11 04:25:47.433845+03
14296	43	-1	380	2020-01-11 04:51:26.522532+03
14297	61	-1	1510	2020-01-11 05:01:55.030319+03
14298	38	-2	1100	2020-01-11 05:07:43.59778+03
14299	22	-2	1070	2020-01-11 05:15:35.389935+03
14300	12	-2	1650	2020-01-11 05:37:03.43562+03
14301	37	-1	1290	2020-01-11 06:17:41.912094+03
14302	10	-1	2080	2020-01-11 06:20:02.249432+03
14303	64	24	524	2020-01-11 06:28:30.801021+03
14304	3	25	359	2020-01-11 06:29:47.676277+03
14305	46	-1	1270	2020-01-11 06:41:35.214866+03
14306	1	-1	640	2020-01-11 06:51:54.171656+03
14307	60	-1	2700	2020-01-11 07:46:24.150793+03
14308	86	-1	910	2020-01-11 09:06:26.278799+03
14309	93	-1	1620	2020-01-11 09:31:39.820549+03
14310	56	-1	2460	2020-01-11 09:49:12.296982+03
14311	73	-1	960	2020-01-11 10:42:58.412262+03
14312	94	-1	1230	2020-01-11 11:08:18.142906+03
14313	83	-1	1230	2020-01-11 11:23:14.341682+03
14314	71	-1	1030	2020-01-11 12:01:05.390951+03
14315	48	-1	640	2020-01-11 12:01:19.177613+03
14316	7	-1	810	2020-01-11 12:06:21.761303+03
14317	96	-1	1570	2020-01-11 12:16:11.146227+03
14318	59	-1	1030	2020-01-11 12:25:15.12312+03
14319	60	-1	2700	2020-01-11 12:34:02.159276+03
14320	8	-2	1920	2020-01-11 12:50:01.88398+03
14321	95	-1	480	2020-01-11 13:09:24.111711+03
14322	20	-1	830	2020-01-11 13:16:14.304694+03
14323	73	-2	960	2020-01-11 13:38:39.215269+03
14324	66	-2	690	2020-01-11 13:54:44.207115+03
14325	66	-1	690	2020-01-11 14:12:39.512376+03
14326	85	-1	730	2020-01-11 14:20:57.028487+03
14327	82	-1	560	2020-01-11 14:21:07.71342+03
14328	43	-2	380	2020-01-11 14:35:30.868718+03
14329	26	-1	390	2020-01-11 14:41:38.794234+03
14330	12	-1	1650	2020-01-11 14:46:14.349007+03
14331	48	-1	640	2020-01-11 15:11:43.37167+03
14332	42	-2	1790	2020-01-11 15:14:01.024682+03
14333	34	-1	1550	2020-01-11 15:26:23.191562+03
14334	1	-1	640	2020-01-11 15:27:44.710546+03
14335	71	-1	1030	2020-01-11 15:34:57.648584+03
14336	77	-1	640	2020-01-11 16:12:28.283983+03
14337	5	-1	1620	2020-01-11 16:31:05.701772+03
14338	20	-1	830	2020-01-11 16:32:12.321853+03
14339	64	-1	970	2020-01-11 16:52:57.223985+03
14340	44	-1	500	2020-01-11 17:34:34.698582+03
14341	55	-1	3480	2020-01-11 17:58:06.497134+03
14342	60	-1	2700	2020-01-11 18:00:38.01187+03
14343	26	-1	390	2020-01-11 19:08:08.398466+03
14344	90	-1	1780	2020-01-11 19:08:10.882224+03
14345	46	-1	1270	2020-01-11 19:12:24.269075+03
14346	13	25	248	2020-01-11 19:44:25.220339+03
14347	31	24	663	2020-01-11 19:46:52.111038+03
14348	30	-2	1140	2020-01-11 19:58:49.088112+03
14349	75	-1	830	2020-01-11 20:03:14.617017+03
14350	2	-1	470	2020-01-11 20:50:04.282373+03
14351	41	-1	830	2020-01-11 21:00:30.922436+03
14352	95	-1	480	2020-01-11 21:50:44.190139+03
14353	72	-2	620	2020-01-11 22:06:07.237787+03
14354	24	-1	950	2020-01-11 22:27:29.340362+03
14355	79	-2	550	2020-01-11 23:02:07.463124+03
14356	63	-1	1780	2020-01-11 23:06:18.385546+03
14357	94	-2	1230	2020-01-11 23:18:27.417145+03
14358	45	-1	1590	2020-01-11 23:33:55.517955+03
14359	59	-1	1030	2020-01-11 23:37:15.681679+03
14360	44	-1	500	2020-01-11 23:43:09.151881+03
14361	46	-2	1270	2020-01-11 23:50:53.314534+03
14362	71	-2	1030	2020-01-12 00:15:06.489585+03
14363	67	-2	350	2020-01-12 00:19:36.4002+03
14364	83	-1	1230	2020-01-12 00:35:35.443162+03
14365	20	-1	830	2020-01-12 01:14:44.755226+03
14366	33	-1	900	2020-01-12 01:39:01.235793+03
14367	47	-1	1480	2020-01-12 01:45:15.200749+03
14368	4	-1	1420	2020-01-12 01:53:46.602685+03
14369	77	-2	640	2020-01-12 02:07:07.220041+03
14370	24	-1	950	2020-01-12 02:45:25.394776+03
14371	87	-1	2320	2020-01-12 03:05:26.508886+03
14372	47	-2	1480	2020-01-12 03:08:19.059764+03
14373	83	-2	1230	2020-01-12 03:20:12.931423+03
14374	16	-1	1380	2020-01-12 03:29:13.843869+03
14375	26	-1	390	2020-01-12 03:29:38.453992+03
14376	70	-2	760	2020-01-12 04:24:18.930236+03
14377	66	-1	690	2020-01-12 05:17:34.600258+03
14378	91	-1	1620	2020-01-12 05:57:57.419927+03
14379	80	-1	1120	2020-01-12 06:05:25.759879+03
14380	29	-2	1940	2020-01-12 06:22:37.472051+03
14381	10	-2	2080	2020-01-12 06:24:40.552021+03
14382	93	-1	1620	2020-01-12 06:32:38.45555+03
14383	81	-1	1620	2020-01-12 06:37:22.225871+03
14384	63	-2	1780	2020-01-12 06:39:34.430921+03
14385	18	-1	910	2020-01-12 06:39:47.739438+03
14386	3	-1	660	2020-01-12 06:46:02.034239+03
14387	91	-1	1620	2020-01-12 07:04:35.291513+03
14388	12	-1	1650	2020-01-12 07:15:36.988094+03
14389	29	-1	1940	2020-01-12 07:16:55.816436+03
14390	75	-1	830	2020-01-12 07:57:11.11031+03
14391	83	-1	1230	2020-01-12 07:58:12.497474+03
14392	28	-1	1860	2020-01-12 08:12:20.976755+03
14393	14	-3	1350	2020-01-12 08:18:06.657453+03
14394	19	33	537	2020-01-12 08:28:03.731532+03
14395	70	-1	760	2020-01-12 08:35:10.810369+03
14396	95	-1	480	2020-01-12 09:05:41.197213+03
14397	57	-1	1900	2020-01-12 09:31:58.870812+03
14398	18	-1	910	2020-01-12 09:58:08.823097+03
14399	34	-1	1550	2020-01-12 10:17:41.809336+03
14400	78	-1	900	2020-01-12 10:27:34.604486+03
14401	4	-1	1420	2020-01-12 10:39:04.835777+03
14402	33	-1	900	2020-01-12 10:40:26.859591+03
14403	76	37	614	2020-01-12 11:18:50.61299+03
14404	3	-1	660	2020-01-12 11:40:33.210641+03
14405	17	-1	1500	2020-01-12 11:42:21.746606+03
14406	1	-1	640	2020-01-12 11:47:04.661354+03
14407	35	-1	670	2020-01-12 12:22:36.06876+03
14408	64	-1	970	2020-01-12 12:41:19.639299+03
14409	93	-2	1620	2020-01-12 13:13:59.032546+03
14410	87	-1	2320	2020-01-12 13:14:48.099522+03
14411	30	-1	1140	2020-01-12 13:16:47.631682+03
14412	40	-1	1430	2020-01-12 13:32:49.211149+03
14413	69	-1	1100	2020-01-12 13:44:14.108934+03
14414	33	-2	900	2020-01-12 13:45:52.423894+03
14415	48	-1	640	2020-01-12 13:53:14.821141+03
14416	60	-1	2700	2020-01-12 13:53:48.221376+03
14417	32	-1	710	2020-01-12 14:15:40.564688+03
14418	77	-1	640	2020-01-12 14:16:37.694332+03
14419	59	-1	1030	2020-01-12 14:20:12.666039+03
14420	71	-1	1030	2020-01-12 14:26:57.673743+03
14421	47	-1	1480	2020-01-12 15:13:12.434167+03
14422	69	-1	1100	2020-01-12 15:22:58.078444+03
14423	48	-2	640	2020-01-12 15:25:03.412511+03
14424	59	-1	1030	2020-01-12 15:42:54.589962+03
14425	88	-1	1270	2020-01-12 15:46:17.096628+03
14426	56	-1	2460	2020-01-12 15:48:40.21677+03
14427	21	-1	960	2020-01-12 15:49:00.543994+03
14428	32	-1	710	2020-01-12 16:05:24.9634+03
14429	80	-1	1120	2020-01-12 16:18:15.71359+03
14430	40	-2	1430	2020-01-12 16:49:50.682079+03
14431	96	-1	1570	2020-01-12 17:06:46.274329+03
14432	89	-1	1420	2020-01-12 17:24:25.519144+03
14433	83	-2	1230	2020-01-12 17:32:16.91647+03
14434	53	-2	3120	2020-01-12 18:05:43.825613+03
14435	87	-1	2320	2020-01-12 18:12:58.54686+03
14436	2	18	221	2020-01-12 18:47:38.230115+03
14437	76	-1	1070	2020-01-12 19:22:29.552589+03
14438	32	-1	710	2020-01-12 20:19:01.286763+03
14439	84	-3	2700	2020-01-12 20:46:30.876562+03
14440	22	-1	1070	2020-01-12 20:53:07.919246+03
14441	6	-1	980	2020-01-12 21:23:15.733029+03
14442	89	-1	1420	2020-01-12 22:01:49.603106+03
14443	24	-2	950	2020-01-12 22:08:05.498455+03
14444	47	-1	1480	2020-01-12 22:51:46.910077+03
14445	89	-1	1420	2020-01-12 23:03:36.781903+03
14446	59	-1	1030	2020-01-12 23:10:17.061022+03
14447	51	27	652	2020-01-12 23:16:39.713477+03
14448	23	-1	4390	2020-01-12 23:19:53.016619+03
14449	44	-1	500	2020-01-12 23:20:48.090722+03
14450	10	-1	2080	2020-01-12 23:29:23.390801+03
14451	45	-1	1590	2020-01-12 23:43:50.161521+03
14452	58	-1	2830	2020-01-13 00:02:14.995237+03
14453	30	-1	1140	2020-01-13 00:21:12.6644+03
14454	7	-1	810	2020-01-13 00:30:17.462161+03
14455	7	-2	810	2020-01-13 01:12:11.812305+03
14456	69	-1	1100	2020-01-13 01:21:16.559016+03
14457	30	-1	1140	2020-01-13 02:07:19.134027+03
14458	30	-2	1140	2020-01-13 02:09:35.813817+03
14459	56	-1	2460	2020-01-13 03:02:52.259602+03
14460	12	-1	1650	2020-01-13 03:03:52.534067+03
14461	38	-1	1100	2020-01-13 03:08:45.869665+03
14462	57	-1	1900	2020-01-13 03:19:11.561872+03
14463	19	-1	1220	2020-01-13 04:40:32.077772+03
14464	34	-1	1550	2020-01-13 04:48:23.872139+03
14465	31	-1	1190	2020-01-13 05:04:04.770487+03
14466	77	-1	640	2020-01-13 05:12:13.771999+03
14467	57	-1	1900	2020-01-13 05:13:19.492835+03
14468	71	-1	1030	2020-01-13 05:28:54.523651+03
14469	47	-1	1480	2020-01-13 05:45:07.470278+03
14470	23	-1	4390	2020-01-13 05:57:44.465089+03
14471	93	-1	1620	2020-01-13 05:58:51.170929+03
14472	12	-1	1650	2020-01-13 05:59:30.599675+03
14473	30	-2	1140	2020-01-13 06:34:00.657693+03
14474	67	-1	350	2020-01-13 06:35:36.739633+03
14475	53	-1	3120	2020-01-13 06:46:38.030118+03
14476	54	-1	3470	2020-01-13 06:57:10.832878+03
14477	20	-1	830	2020-01-13 06:58:44.663827+03
14478	39	-2	910	2020-01-13 06:59:28.829792+03
14479	40	-1	1430	2020-01-13 07:02:07.922204+03
14480	16	-1	1380	2020-01-13 07:19:36.662948+03
14481	44	-2	500	2020-01-13 07:29:08.708903+03
14482	53	-1	3120	2020-01-13 07:39:41.723774+03
14483	75	-1	830	2020-01-13 08:08:46.368584+03
14484	47	-1	1480	2020-01-13 08:19:39.041084+03
14485	20	33	387	2020-01-13 08:22:45.113572+03
14486	15	-1	2830	2020-01-13 09:24:20.591933+03
14487	51	-1	1310	2020-01-13 09:35:30.80752+03
14488	91	-1	1620	2020-01-13 09:42:13.012803+03
14489	52	-1	1090	2020-01-13 10:02:20.226072+03
14490	31	-2	1190	2020-01-13 10:02:50.152938+03
14491	4	-1	1420	2020-01-13 10:42:30.245598+03
14492	9	-1	2090	2020-01-13 11:23:13.613614+03
14493	89	-1	1420	2020-01-13 11:30:45.941769+03
14494	71	-1	1030	2020-01-13 11:52:16.08376+03
14495	64	-1	970	2020-01-13 12:00:45.925017+03
14496	55	-1	3480	2020-01-13 12:39:38.59538+03
14497	12	-1	1650	2020-01-13 12:43:06.823399+03
14498	39	-2	910	2020-01-13 12:52:12.959953+03
14499	75	-1	830	2020-01-13 13:04:23.707933+03
14500	23	30	2042	2020-01-13 13:11:11.407913+03
14501	22	-1	1070	2020-01-13 13:28:54.306423+03
14502	75	-1	830	2020-01-13 13:32:45.321815+03
14503	41	-1	830	2020-01-13 13:35:00.292752+03
14504	41	-1	830	2020-01-13 13:56:42.324841+03
14505	22	-1	1070	2020-01-13 14:02:43.259041+03
14506	35	-2	670	2020-01-13 14:07:01.408933+03
14507	80	-2	1120	2020-01-13 14:13:35.099685+03
14508	47	-1	1480	2020-01-13 15:04:32.872822+03
14509	5	-1	1620	2020-01-13 15:07:41.604042+03
14510	81	-2	1620	2020-01-13 15:38:47.908359+03
14511	94	-2	1230	2020-01-13 15:43:44.648303+03
14512	91	-1	1620	2020-01-13 15:55:44.137569+03
14513	7	-2	810	2020-01-13 16:00:57.239943+03
14514	30	-1	1140	2020-01-13 16:42:51.97418+03
14515	58	-1	2830	2020-01-13 16:46:27.967521+03
14516	38	-1	1100	2020-01-13 16:53:40.537852+03
14517	93	-1	1620	2020-01-13 17:01:44.948625+03
14518	44	-1	500	2020-01-13 17:10:30.129266+03
14519	75	-1	830	2020-01-13 17:25:01.862512+03
14520	47	-1	1480	2020-01-13 17:42:19.056879+03
14521	39	-1	910	2020-01-13 17:52:58.073008+03
14522	26	24	185	2020-01-13 17:55:45.336522+03
14523	35	-2	670	2020-01-13 18:01:52.128928+03
14524	77	-1	640	2020-01-13 18:13:00.379389+03
14525	6	-2	980	2020-01-13 18:23:03.812995+03
14526	17	-1	1500	2020-01-13 18:32:56.658842+03
14527	92	-1	630	2020-01-13 18:33:33.26538+03
14528	22	-1	1070	2020-01-13 18:56:35.077675+03
14529	94	-2	1230	2020-01-13 19:06:50.975373+03
14530	22	-2	1070	2020-01-13 19:21:21.340572+03
14531	82	21	321	2020-01-13 19:21:59.435142+03
14532	32	-2	710	2020-01-13 19:22:37.124062+03
14533	54	-1	3470	2020-01-13 19:49:20.928149+03
14534	1	-1	640	2020-01-13 19:49:43.248671+03
14535	95	-1	480	2020-01-13 19:58:17.716563+03
14536	15	-1	2830	2020-01-13 20:14:30.455655+03
14537	9	-1	2090	2020-01-13 20:17:52.014521+03
14538	6	-2	980	2020-01-13 20:44:19.819313+03
14539	36	-2	630	2020-01-13 20:54:03.17636+03
14540	20	-1	830	2020-01-13 21:03:14.403066+03
14541	23	-2	4390	2020-01-13 21:29:05.578251+03
14542	63	-3	1780	2020-01-13 21:35:06.606498+03
14543	22	-1	1070	2020-01-13 21:38:06.80847+03
14544	70	-1	760	2020-01-13 22:01:11.602753+03
14545	63	-2	1780	2020-01-13 22:15:39.48248+03
14546	12	-1	1650	2020-01-13 22:20:42.054255+03
14547	88	-1	1270	2020-01-13 22:39:42.870178+03
14548	24	-2	950	2020-01-13 22:50:22.945092+03
14549	10	-1	2080	2020-01-13 23:08:30.784709+03
14550	14	36	707	2020-01-13 23:16:42.594956+03
14551	22	-1	1070	2020-01-13 23:20:17.749271+03
14552	70	-1	760	2020-01-13 23:25:48.448423+03
14553	56	-1	2460	2020-01-13 23:28:34.294327+03
14554	49	-1	970	2020-01-13 23:57:42.733575+03
14555	69	-1	1100	2020-01-14 00:20:44.584557+03
14556	46	-1	1270	2020-01-14 00:28:28.885183+03
14557	56	-1	2460	2020-01-14 00:37:29.825296+03
14558	84	-1	2700	2020-01-14 01:14:18.778835+03
14559	79	-1	550	2020-01-14 01:26:00.861113+03
14560	41	-1	830	2020-01-14 01:51:09.752582+03
14561	9	-1	2090	2020-01-14 01:54:54.307619+03
14562	67	-1	350	2020-01-14 01:57:42.470361+03
14563	15	-1	2830	2020-01-14 02:02:02.881975+03
14564	85	-1	730	2020-01-14 02:18:58.945818+03
14565	71	-1	1030	2020-01-14 02:24:44.579134+03
14566	33	-1	900	2020-01-14 02:30:45.141106+03
14567	3	-1	660	2020-01-14 03:09:25.146757+03
14568	33	-1	900	2020-01-14 03:19:53.322838+03
14569	79	-1	550	2020-01-14 03:33:41.61446+03
14570	7	-1	810	2020-01-14 03:36:58.91504+03
14571	78	-1	900	2020-01-14 03:38:31.610389+03
14572	12	-1	1650	2020-01-14 03:43:58.920328+03
14573	34	-1	1550	2020-01-14 03:58:49.76344+03
14574	71	-1	1030	2020-01-14 04:03:49.575295+03
14575	59	-1	1030	2020-01-14 04:23:33.275867+03
14576	58	-1	2830	2020-01-14 04:28:56.728709+03
14577	75	27	371	2020-01-14 04:42:57.906585+03
14578	83	-1	1230	2020-01-14 05:04:43.76834+03
14579	34	-2	1550	2020-01-14 05:30:31.204483+03
14580	47	-2	1480	2020-01-14 05:36:41.25716+03
14581	84	-1	2700	2020-01-14 05:39:36.631171+03
14582	42	-1	1790	2020-01-14 05:39:44.777048+03
14583	43	-1	380	2020-01-14 05:50:07.222241+03
14584	37	-1	1290	2020-01-14 05:59:20.062512+03
14585	35	-1	670	2020-01-14 07:12:01.85387+03
14586	25	-1	1100	2020-01-14 07:15:19.176626+03
14587	35	-2	670	2020-01-14 08:01:10.160413+03
14588	9	-1	2090	2020-01-14 08:04:22.633647+03
14589	42	-1	1790	2020-01-14 08:09:31.444791+03
14590	77	-2	640	2020-01-14 08:24:29.619714+03
14591	29	-1	1940	2020-01-14 08:28:16.786802+03
14592	93	-1	1620	2020-01-14 08:49:39.551997+03
14593	61	-1	1510	2020-01-14 09:20:50.870708+03
14594	13	-1	460	2020-01-14 09:30:04.40978+03
14595	13	-1	460	2020-01-14 09:36:43.093501+03
14596	64	-1	970	2020-01-14 09:45:33.780736+03
14597	56	-1	2460	2020-01-14 10:01:59.604549+03
14598	29	-1	1940	2020-01-14 10:29:03.855643+03
14599	18	-1	910	2020-01-14 11:17:30.288389+03
14600	7	-1	810	2020-01-14 11:24:53.333772+03
14601	34	-1	1550	2020-01-14 11:37:08.063275+03
14602	45	-1	1590	2020-01-14 11:54:53.08259+03
14603	89	-1	1420	2020-01-14 12:00:14.276929+03
14604	48	-1	640	2020-01-14 12:32:53.340467+03
14605	23	-1	4390	2020-01-14 12:43:50.735071+03
14606	75	-1	830	2020-01-14 12:55:40.963114+03
14607	89	-1	1420	2020-01-14 12:57:56.901141+03
14608	51	-1	1310	2020-01-14 13:19:43.791238+03
14609	52	-2	1090	2020-01-14 13:20:30.813577+03
14610	59	-1	1030	2020-01-14 13:23:30.223707+03
14611	34	-3	1550	2020-01-14 13:29:44.302487+03
14612	34	-1	1550	2020-01-14 14:02:35.764303+03
14613	88	-1	1270	2020-01-14 14:20:08.134411+03
14614	66	-1	690	2020-01-14 14:47:46.108139+03
14615	46	-1	1270	2020-01-14 14:50:32.568401+03
14616	62	10	689	2020-01-14 15:18:38.302288+03
14617	78	-1	900	2020-01-14 15:19:59.703523+03
14618	22	-1	1070	2020-01-14 15:48:40.329353+03
14619	70	-2	760	2020-01-14 16:07:56.345582+03
14620	8	-1	1920	2020-01-14 16:18:49.583524+03
14621	10	-1	2080	2020-01-14 17:29:34.175269+03
14622	59	-1	1030	2020-01-14 17:47:22.00753+03
14623	42	-1	1790	2020-01-14 17:49:37.932333+03
14624	62	-1	1220	2020-01-14 17:52:02.16015+03
14625	67	-1	350	2020-01-14 17:56:00.616811+03
14626	18	-2	910	2020-01-14 18:13:59.052414+03
14627	9	-1	2090	2020-01-14 18:49:27.60292+03
14628	65	-1	490	2020-01-14 18:49:39.659335+03
14629	60	-2	2700	2020-01-14 19:12:58.227509+03
14630	47	-2	1480	2020-01-14 20:10:02.984193+03
14631	37	-1	1290	2020-01-14 20:25:34.001436+03
14632	90	-1	1780	2020-01-14 20:40:52.04458+03
14633	96	-1	1570	2020-01-14 20:57:50.424805+03
14634	96	-1	1570	2020-01-14 21:21:32.854428+03
14635	67	-1	350	2020-01-14 21:22:25.591247+03
14636	43	-1	380	2020-01-14 21:24:29.315719+03
14637	42	-1	1790	2020-01-14 21:44:34.1+03
14638	42	-1	1790	2020-01-14 21:54:35.695114+03
14639	31	-1	1190	2020-01-14 22:05:17.933387+03
14640	1	-1	640	2020-01-14 22:18:46.467274+03
14641	29	-1	1940	2020-01-14 22:19:03.142805+03
14642	26	-1	390	2020-01-14 22:27:57.249879+03
14643	20	-2	830	2020-01-14 22:45:26.743615+03
14644	12	-1	1650	2020-01-14 22:49:14.798018+03
14645	1	-1	640	2020-01-14 22:52:13.808313+03
14646	83	-2	1230	2020-01-14 23:11:42.308444+03
14647	87	-1	2320	2020-01-14 23:46:19.304986+03
14648	5	-1	1620	2020-01-15 00:25:02.432521+03
14649	8	-1	1920	2020-01-15 00:35:17.273301+03
14650	68	-1	490	2020-01-15 00:36:39.347019+03
14651	13	-1	460	2020-01-15 01:02:56.852695+03
14652	10	-1	2080	2020-01-15 01:23:25.536721+03
14653	90	-2	1780	2020-01-15 01:32:09.898928+03
14654	68	-1	490	2020-01-15 01:33:20.007822+03
14655	58	-2	2830	2020-01-15 01:44:13.822693+03
14656	1	-1	640	2020-01-15 01:45:12.195207+03
14657	2	-1	470	2020-01-15 01:45:50.255519+03
14658	21	-1	960	2020-01-15 01:52:45.831562+03
14659	70	-1	760	2020-01-15 01:54:06.044378+03
14660	40	-2	1430	2020-01-15 02:02:45.259583+03
14661	20	-1	830	2020-01-15 02:02:50.858751+03
14662	22	-1	1070	2020-01-15 02:10:34.131962+03
14663	61	-1	1510	2020-01-15 02:11:18.415985+03
14664	26	-1	390	2020-01-15 02:20:01.307591+03
14665	92	-1	630	2020-01-15 02:26:36.268472+03
14666	14	-1	1350	2020-01-15 02:29:58.787896+03
14667	26	-2	390	2020-01-15 02:30:14.961411+03
14668	24	-1	950	2020-01-15 02:59:34.859124+03
14669	89	-1	1420	2020-01-15 03:03:04.613316+03
14670	24	16	401	2020-01-15 03:04:50.525171+03
14671	60	-1	2700	2020-01-15 03:05:06.015435+03
14672	18	-1	910	2020-01-15 03:25:33.703054+03
14673	9	-1	2090	2020-01-15 03:29:11.545435+03
14674	75	-3	830	2020-01-15 04:17:05.124086+03
14675	49	-1	970	2020-01-15 04:19:10.106275+03
14676	20	-1	830	2020-01-15 04:43:04.216464+03
14677	13	-1	460	2020-01-15 04:50:54.99877+03
14678	15	-1	2830	2020-01-15 04:52:03.559521+03
14679	54	-1	3470	2020-01-15 05:09:23.133646+03
14680	34	-1	1550	2020-01-15 05:09:28.557322+03
14681	77	-2	640	2020-01-15 05:29:09.47584+03
14682	22	-1	1070	2020-01-15 05:49:53.772898+03
14683	55	-1	3480	2020-01-15 06:07:32.453083+03
14684	36	-1	630	2020-01-15 07:00:25.742339+03
14685	45	-1	1590	2020-01-15 07:03:52.393541+03
14686	42	23	865	2020-01-15 07:12:49.508315+03
14687	1	-1	640	2020-01-15 07:29:51.913474+03
14688	49	-1	970	2020-01-15 07:35:04.037163+03
14689	29	-1	1940	2020-01-15 07:36:51.324233+03
14690	59	-1	1030	2020-01-15 07:54:45.824292+03
14691	42	-2	1790	2020-01-15 08:23:20.581858+03
14692	83	-1	1230	2020-01-15 08:54:14.509316+03
14693	88	-1	1270	2020-01-15 09:01:28.595847+03
14694	87	-1	2320	2020-01-15 09:22:09.697573+03
14695	5	-2	1620	2020-01-15 09:25:22.295297+03
14696	87	-1	2320	2020-01-15 09:26:41.716049+03
14697	13	-1	460	2020-01-15 09:52:17.129833+03
14698	92	-1	630	2020-01-15 10:10:36.431744+03
14699	35	-1	670	2020-01-15 10:20:32.43676+03
14700	96	-1	1570	2020-01-15 10:25:13.393005+03
14701	2	-2	470	2020-01-15 10:42:52.023584+03
14702	13	-2	460	2020-01-15 11:03:32.701203+03
14703	27	-1	880	2020-01-15 11:07:01.902745+03
14704	4	-1	1420	2020-01-15 11:26:04.038024+03
14705	94	-1	1230	2020-01-15 12:17:05.867845+03
14706	30	-1	1140	2020-01-15 12:32:29.330151+03
14707	20	-1	830	2020-01-15 13:12:49.262733+03
14708	79	-1	550	2020-01-15 13:25:43.812434+03
14709	25	-1	1100	2020-01-15 13:28:48.198487+03
14710	63	-1	1780	2020-01-15 13:31:32.355924+03
14711	58	-1	2830	2020-01-15 13:37:53.03546+03
14712	24	-2	950	2020-01-15 14:20:22.185291+03
14713	90	-1	1780	2020-01-15 14:32:00.864942+03
14714	54	-3	3470	2020-01-15 14:40:54.396343+03
14715	56	-1	2460	2020-01-15 15:11:34.307207+03
14716	50	-1	1140	2020-01-15 15:25:02.394138+03
14717	69	27	579	2020-01-15 15:50:34.925443+03
14718	27	-1	880	2020-01-15 15:52:50.453998+03
14719	1	-1	640	2020-01-15 16:03:16.311631+03
14720	6	-1	980	2020-01-15 16:05:18.736154+03
14721	90	-2	1780	2020-01-15 16:11:12.641744+03
14722	32	-1	710	2020-01-15 16:12:16.075736+03
14723	37	-1	1290	2020-01-15 16:12:18.274147+03
14724	52	-1	1090	2020-01-15 16:25:19.460202+03
14725	76	-1	1070	2020-01-15 16:27:17.233345+03
14726	78	-2	900	2020-01-15 16:46:03.493266+03
14727	59	-1	1030	2020-01-15 17:23:27.338532+03
14728	59	-1	1030	2020-01-15 17:29:25.197706+03
14729	75	-2	830	2020-01-15 17:31:42.214015+03
14730	23	-1	4390	2020-01-15 17:37:39.559004+03
14731	89	-1	1420	2020-01-15 17:50:04.713541+03
14732	64	-2	970	2020-01-15 17:55:17.036066+03
14733	64	-1	970	2020-01-15 18:09:41.34422+03
14734	56	-1	2460	2020-01-15 18:22:29.060087+03
14735	81	-2	1620	2020-01-15 18:58:14.299965+03
14736	34	-2	1550	2020-01-15 19:17:19.316736+03
14737	84	-1	2700	2020-01-15 19:34:39.196371+03
14738	87	-2	2320	2020-01-15 19:48:28.450702+03
14739	10	-1	2080	2020-01-15 19:53:46.670079+03
14740	51	-1	1310	2020-01-15 19:54:26.530552+03
14741	42	-2	1790	2020-01-15 20:43:05.980101+03
14742	20	-1	830	2020-01-15 20:48:14.295975+03
14743	94	-2	1230	2020-01-15 20:48:30.280612+03
14744	54	-1	3470	2020-01-15 20:58:49.477748+03
14745	78	-1	900	2020-01-15 21:22:55.250371+03
14746	66	-2	690	2020-01-15 21:35:34.912467+03
14747	29	-1	1940	2020-01-15 21:40:48.448557+03
14748	12	-1	1650	2020-01-15 21:43:46.366373+03
14749	42	-1	1790	2020-01-15 21:51:22.246428+03
14750	90	-2	1780	2020-01-15 21:57:19.370249+03
14751	93	-2	1620	2020-01-15 22:22:41.595599+03
14752	15	-1	2830	2020-01-15 22:59:22.557631+03
14753	34	-2	1550	2020-01-15 23:10:12.092856+03
14754	11	-1	830	2020-01-15 23:14:30.242549+03
14755	40	-1	1430	2020-01-15 23:23:12.876458+03
14756	81	-1	1620	2020-01-15 23:23:56.910776+03
14757	1	-2	640	2020-01-15 23:24:58.239841+03
14758	34	-1	1550	2020-01-15 23:33:11.383068+03
14759	56	-1	2460	2020-01-15 23:43:32.009067+03
14760	61	-1	1510	2020-01-15 23:48:21.376482+03
14761	92	-1	630	2020-01-15 23:48:53.604235+03
14762	46	-1	1270	2020-01-15 23:55:23.242933+03
14763	64	-1	970	2020-01-16 00:04:29.112994+03
14764	55	-1	3480	2020-01-16 00:17:19.74071+03
14765	9	-1	2090	2020-01-16 00:18:59.916953+03
14766	20	-1	830	2020-01-16 00:20:29.475712+03
14767	10	-1	2080	2020-01-16 00:31:23.939103+03
14768	88	-1	1270	2020-01-16 00:55:15.321533+03
14769	46	-1	1270	2020-01-16 01:00:58.733309+03
14770	53	-1	3120	2020-01-16 01:31:05.576468+03
14771	49	-1	970	2020-01-16 01:48:47.334421+03
14772	93	-2	1620	2020-01-16 02:14:46.338439+03
14773	35	-2	670	2020-01-16 02:23:54.388101+03
14774	65	-2	490	2020-01-16 02:27:45.579784+03
14775	51	-1	1310	2020-01-16 02:28:43.586254+03
14776	87	-1	2320	2020-01-16 03:15:15.685398+03
14777	49	-2	970	2020-01-16 03:24:31.968658+03
14778	61	-2	1510	2020-01-16 03:32:06.409608+03
14779	51	-1	1310	2020-01-16 03:51:15.994429+03
14780	87	-1	2320	2020-01-16 03:55:25.012929+03
14781	53	-1	3120	2020-01-16 04:01:06.669855+03
14782	81	-1	1620	2020-01-16 04:11:18.166571+03
14783	32	-1	710	2020-01-16 04:12:31.593196+03
14784	36	-1	630	2020-01-16 04:12:34.406358+03
14785	49	-1	970	2020-01-16 04:20:10.616917+03
14786	48	-2	640	2020-01-16 04:23:28.724721+03
14787	22	-1	1070	2020-01-16 04:28:16.133616+03
14788	63	-1	1780	2020-01-16 04:34:11.141002+03
14789	85	-1	730	2020-01-16 04:38:35.97643+03
14790	90	-2	1780	2020-01-16 04:45:07.736994+03
14791	67	-2	350	2020-01-16 04:53:27.286843+03
14792	76	-1	1070	2020-01-16 04:53:54.074277+03
14793	74	-1	1010	2020-01-16 05:38:20.326331+03
14794	85	-2	730	2020-01-16 06:04:59.663498+03
14795	24	-1	950	2020-01-16 07:07:26.290233+03
14796	34	-1	1550	2020-01-16 07:14:07.247751+03
14797	46	-1	1270	2020-01-16 07:24:02.53967+03
14798	93	-1	1620	2020-01-16 08:06:24.94547+03
14799	40	-1	1430	2020-01-16 08:26:15.751986+03
14800	71	-1	1030	2020-01-16 08:33:08.20532+03
14801	57	-2	1900	2020-01-16 09:15:11.925507+03
14802	60	-2	2700	2020-01-16 09:20:21.147828+03
14803	26	-1	390	2020-01-16 09:25:43.15936+03
14804	58	-1	2830	2020-01-16 09:37:14.422248+03
14805	48	-1	640	2020-01-16 09:48:12.061297+03
14806	59	-1	1030	2020-01-16 09:50:10.222914+03
14807	4	-1	1420	2020-01-16 10:11:49.73005+03
14808	69	-1	1100	2020-01-16 10:19:55.178936+03
14809	10	-1	2080	2020-01-16 11:23:56.974714+03
14810	88	-2	1270	2020-01-16 11:27:58.837155+03
14811	39	-1	910	2020-01-16 11:56:42.010909+03
14812	57	-2	1900	2020-01-16 12:13:24.169699+03
14813	17	34	886	2020-01-16 12:25:50.272625+03
14814	55	-1	3480	2020-01-16 12:57:59.440795+03
14815	89	-1	1420	2020-01-16 12:58:08.493595+03
14816	70	-1	760	2020-01-16 13:01:55.004194+03
14817	24	-1	950	2020-01-16 13:51:27.496932+03
14818	48	-2	640	2020-01-16 14:11:47.331323+03
14819	20	-1	830	2020-01-16 14:19:21.077324+03
14820	93	-1	1620	2020-01-16 14:20:38.811883+03
14821	6	-1	980	2020-01-16 14:28:57.909502+03
14822	7	-2	810	2020-01-16 15:03:24.317351+03
14823	42	-1	1790	2020-01-16 15:10:35.277781+03
14824	65	-2	490	2020-01-16 15:13:44.903087+03
14825	6	-1	980	2020-01-16 16:09:59.203328+03
14826	70	-1	760	2020-01-16 16:14:29.292143+03
14827	56	-1	2460	2020-01-16 16:17:34.106052+03
14828	54	-2	3470	2020-01-16 16:42:25.994372+03
14829	42	-1	1790	2020-01-16 16:54:01.180407+03
14830	11	-1	830	2020-01-16 17:43:02.098376+03
14831	63	29	724	2020-01-16 18:11:41.780171+03
14832	33	-2	900	2020-01-16 18:24:37.362368+03
14833	57	-1	1900	2020-01-16 18:38:02.119292+03
14834	17	-1	1500	2020-01-16 19:04:42.901353+03
14835	63	-2	1780	2020-01-16 19:21:03.345718+03
14836	21	-1	960	2020-01-16 19:29:55.520149+03
14837	23	-1	4390	2020-01-16 20:01:44.279319+03
14838	86	-1	910	2020-01-16 20:18:08.035593+03
14839	86	-1	910	2020-01-16 20:21:19.40674+03
14840	32	-2	710	2020-01-16 20:22:36.183138+03
14841	7	-1	810	2020-01-16 20:23:00.840089+03
14842	54	-1	3470	2020-01-16 20:23:28.894659+03
14843	10	-1	2080	2020-01-16 21:10:24.394119+03
14844	38	-1	1100	2020-01-16 21:23:25.746806+03
14845	35	-2	670	2020-01-16 21:39:02.929351+03
14846	37	-1	1290	2020-01-16 21:43:42.278396+03
14847	93	-1	1620	2020-01-16 21:49:39.771046+03
14848	73	-1	960	2020-01-16 22:22:41.872+03
14849	44	-1	500	2020-01-16 22:55:50.201081+03
14850	86	-1	910	2020-01-16 23:17:38.133081+03
14851	85	-1	730	2020-01-16 23:51:40.53384+03
14852	62	-1	1220	2020-01-17 00:24:19.840425+03
14853	23	-1	4390	2020-01-17 00:55:22.854204+03
14854	17	-1	1500	2020-01-17 01:09:54.732504+03
14855	91	26	674	2020-01-17 01:39:59.010494+03
14856	59	-1	1030	2020-01-17 02:01:40.221402+03
14857	10	-1	2080	2020-01-17 02:05:48.960157+03
14858	28	-1	1860	2020-01-17 02:06:22.137306+03
14859	96	-1	1570	2020-01-17 02:20:51.313522+03
14860	30	-2	1140	2020-01-17 02:22:47.786756+03
14861	71	-1	1030	2020-01-17 02:35:55.142985+03
14862	48	-1	640	2020-01-17 02:36:26.287718+03
14863	57	-1	1900	2020-01-17 02:41:23.839359+03
14864	33	-1	900	2020-01-17 02:44:21.56717+03
14865	13	-1	460	2020-01-17 03:06:24.859603+03
14866	50	-1	1140	2020-01-17 03:09:00.947955+03
14867	29	-1	1940	2020-01-17 03:10:45.926122+03
14868	33	-1	900	2020-01-17 03:13:12.067887+03
14869	12	-1	1650	2020-01-17 03:17:09.101995+03
14870	78	17	473	2020-01-17 03:17:44.004405+03
14871	58	-1	2830	2020-01-17 03:42:11.950102+03
14872	21	-1	960	2020-01-17 03:42:34.88381+03
14873	30	-1	1140	2020-01-17 04:23:27.092389+03
14874	41	-1	830	2020-01-17 04:54:06.819691+03
14875	46	-1	1270	2020-01-17 05:09:33.36151+03
14876	41	-1	830	2020-01-17 05:19:05.195016+03
14877	43	-1	380	2020-01-17 05:47:55.128021+03
14878	91	-1	1620	2020-01-17 05:57:12.519852+03
14879	3	-1	660	2020-01-17 06:01:06.680823+03
14880	4	-1	1420	2020-01-17 06:14:07.388456+03
14881	83	-1	1230	2020-01-17 06:21:25.764863+03
14882	41	-1	830	2020-01-17 07:00:25.456296+03
14883	30	-1	1140	2020-01-17 07:16:18.085703+03
14884	70	-2	760	2020-01-17 07:35:38.527711+03
14885	52	-1	1090	2020-01-17 07:53:38.024146+03
14886	58	-1	2830	2020-01-17 07:54:11.197307+03
14887	3	-1	660	2020-01-17 08:04:34.882622+03
14888	93	-1	1620	2020-01-17 08:21:30.291865+03
14889	77	-1	640	2020-01-17 08:41:53.863472+03
14890	30	43	503	2020-01-17 08:47:40.382486+03
14891	12	-1	1650	2020-01-17 09:06:28.386597+03
14892	23	-1	4390	2020-01-17 09:07:26.597336+03
14893	33	-1	900	2020-01-17 09:14:53.731681+03
14894	47	-2	1480	2020-01-17 09:16:30.928871+03
14895	37	29	738	2020-01-17 10:27:26.440838+03
14896	39	-1	910	2020-01-17 10:40:47.346779+03
14897	57	-1	1900	2020-01-17 10:45:23.120675+03
14898	76	-1	1070	2020-01-17 10:49:28.953018+03
14899	25	-1	1100	2020-01-17 11:09:14.625874+03
14900	92	-1	630	2020-01-17 11:13:14.800966+03
14901	93	-1	1620	2020-01-17 11:23:45.375807+03
14902	24	-1	950	2020-01-17 11:41:13.38628+03
14903	71	-1	1030	2020-01-17 11:50:17.946743+03
14904	74	22	444	2020-01-17 12:29:34.673633+03
14905	21	-1	960	2020-01-17 12:34:41.802453+03
14906	3	-1	660	2020-01-17 12:35:02.37115+03
14907	6	-1	980	2020-01-17 12:48:08.397489+03
14908	36	-1	630	2020-01-17 13:07:44.969152+03
14909	76	-1	1070	2020-01-17 13:13:10.515321+03
14910	46	-1	1270	2020-01-17 13:39:21.407944+03
14911	82	-1	560	2020-01-17 13:40:32.602997+03
14912	84	-1	2700	2020-01-17 13:44:47.985843+03
14913	55	-2	3480	2020-01-17 13:58:40.299464+03
14914	59	-1	1030	2020-01-17 14:00:58.291229+03
14915	91	-1	1620	2020-01-17 14:06:39.852879+03
14916	94	-1	1230	2020-01-17 14:23:41.201735+03
14917	93	-1	1620	2020-01-17 14:24:16.207322+03
14918	55	-1	3480	2020-01-17 14:25:52.82377+03
14919	17	-1	1500	2020-01-17 14:26:14.954535+03
14920	42	-2	1790	2020-01-17 15:45:23.855925+03
14921	25	-1	1100	2020-01-17 15:56:26.648992+03
14922	94	-1	1230	2020-01-17 16:06:06.130213+03
14923	11	-1	830	2020-01-17 16:34:04.977882+03
14924	85	-1	730	2020-01-17 17:14:35.19703+03
14925	61	-1	1510	2020-01-17 17:18:32.493058+03
14926	47	-1	1480	2020-01-17 17:23:39.871352+03
14927	68	-2	490	2020-01-17 17:28:55.027898+03
14928	29	-1	1940	2020-01-17 17:34:36.064517+03
14929	48	-1	640	2020-01-17 17:36:44.867505+03
14930	94	-1	1230	2020-01-17 17:46:18.100526+03
14931	38	-1	1100	2020-01-17 18:06:20.25714+03
14932	12	-2	1650	2020-01-17 18:14:19.292482+03
14933	87	-1	2320	2020-01-17 18:18:28.768821+03
14934	20	-1	830	2020-01-17 18:18:36.367607+03
14935	70	-1	760	2020-01-17 18:54:22.994652+03
14936	59	-1	1030	2020-01-17 19:06:58.30604+03
14937	93	-1	1620	2020-01-17 19:07:06.14845+03
14938	43	-1	380	2020-01-17 19:22:55.105175+03
14939	61	-1	1510	2020-01-17 19:41:49.18624+03
14940	50	-1	1140	2020-01-17 19:48:59.385626+03
14941	6	-1	980	2020-01-17 19:51:20.263865+03
14942	11	-1	830	2020-01-17 19:56:14.716676+03
14943	76	-1	1070	2020-01-17 19:57:15.547057+03
14944	77	-1	640	2020-01-17 20:15:14.551394+03
14945	87	-2	2320	2020-01-17 20:18:34.531481+03
14946	76	-1	1070	2020-01-17 20:50:18.683835+03
14947	19	-2	1220	2020-01-17 20:51:50.035149+03
14948	40	-2	1430	2020-01-17 21:16:11.453643+03
14949	11	-1	830	2020-01-17 21:24:11.108714+03
14950	24	-2	950	2020-01-17 21:35:05.536382+03
14951	20	-1	830	2020-01-17 21:35:39.868938+03
14952	30	-1	1140	2020-01-17 21:39:39.196465+03
14953	32	-1	710	2020-01-17 21:43:40.921914+03
14954	14	-1	1350	2020-01-17 21:44:06.484874+03
14955	42	-1	1790	2020-01-17 21:59:18.466384+03
14956	37	-1	1290	2020-01-17 22:07:43.542727+03
14957	83	-1	1230	2020-01-17 22:11:55.057842+03
14958	59	25	612	2020-01-17 22:24:58.649794+03
14959	87	-1	2320	2020-01-17 23:27:33.338068+03
14960	92	30	355	2020-01-17 23:28:56.851027+03
14961	35	-1	670	2020-01-17 23:37:35.125084+03
14962	85	-1	730	2020-01-18 00:08:43.663313+03
14963	47	-1	1480	2020-01-18 00:12:28.266226+03
14964	95	-2	480	2020-01-18 01:09:33.009012+03
14965	21	-1	960	2020-01-18 01:34:25.432625+03
14966	35	-3	670	2020-01-18 01:57:55.742193+03
14967	70	-1	760	2020-01-18 02:00:29.589343+03
14968	80	-1	1120	2020-01-18 02:01:52.520877+03
14969	80	-1	1120	2020-01-18 02:21:49.260394+03
14970	28	-1	1860	2020-01-18 02:22:27.9252+03
14971	77	-2	640	2020-01-18 03:16:20.953977+03
14972	60	-1	2700	2020-01-18 03:17:56.261621+03
14973	19	-2	1220	2020-01-18 03:44:17.38073+03
14974	56	-1	2460	2020-01-18 03:44:59.876528+03
14975	37	-1	1290	2020-01-18 03:49:58.969325+03
14976	72	-1	620	2020-01-18 04:06:33.861462+03
14977	61	-2	1510	2020-01-18 04:14:14.325888+03
14978	21	-1	960	2020-01-18 04:16:06.576953+03
14979	77	-1	640	2020-01-18 04:32:53.026356+03
14980	42	-1	1790	2020-01-18 04:59:16.481541+03
14981	57	33	783	2020-01-18 05:25:13.356592+03
14982	76	-2	1070	2020-01-18 05:51:52.917745+03
14983	30	-1	1140	2020-01-18 05:52:28.217999+03
14984	48	-1	640	2020-01-18 05:56:40.60326+03
14985	46	-1	1270	2020-01-18 05:59:57.274915+03
14986	12	42	871	2020-01-18 06:05:29.304597+03
14987	66	-1	690	2020-01-18 06:20:18.299535+03
14988	29	-1	1940	2020-01-18 06:44:25.947455+03
14989	37	-1	1290	2020-01-18 06:47:12.099293+03
14990	12	-1	1650	2020-01-18 07:00:00.962798+03
14991	86	37	398	2020-01-18 07:26:26.317688+03
14992	10	-1	2080	2020-01-18 08:00:39.846118+03
14993	94	-1	1230	2020-01-18 08:11:12.053066+03
14994	33	-1	900	2020-01-18 09:09:55.075716+03
14995	76	-1	1070	2020-01-18 09:31:16.344134+03
14996	2	-1	470	2020-01-18 09:41:00.495102+03
14997	29	41	808	2020-01-18 09:59:06.844736+03
14998	80	-1	1120	2020-01-18 10:05:34.17124+03
14999	30	-1	1140	2020-01-18 10:17:40.909194+03
15000	93	-1	1620	2020-01-18 10:45:48.305383+03
15001	29	-1	1940	2020-01-18 10:50:35.54835+03
15002	73	-1	960	2020-01-18 10:52:13.551363+03
15003	58	-1	2830	2020-01-18 11:03:58.734505+03
15004	38	-2	1100	2020-01-18 11:05:41.87817+03
15005	55	-1	3480	2020-01-18 11:06:51.033994+03
15006	56	-1	2460	2020-01-18 11:19:51.920808+03
15007	14	-1	1350	2020-01-18 11:31:19.149639+03
15008	84	-1	2700	2020-01-18 12:19:22.34083+03
15009	2	-1	470	2020-01-18 13:01:12.695173+03
15010	88	-1	1270	2020-01-18 13:23:06.13575+03
15011	47	-1	1480	2020-01-18 13:24:06.751134+03
15012	45	-1	1590	2020-01-18 13:36:05.552335+03
15013	20	-1	830	2020-01-18 13:40:42.556559+03
15014	2	-2	470	2020-01-18 14:02:16.950542+03
15015	56	-1	2460	2020-01-18 14:13:40.490954+03
15016	40	-3	1430	2020-01-18 14:24:52.830012+03
15017	6	-2	980	2020-01-18 14:32:12.662365+03
15018	88	-2	1270	2020-01-18 14:46:18.636642+03
15019	10	31	1139	2020-01-18 14:59:00.032899+03
15020	45	-1	1590	2020-01-18 15:29:49.295644+03
15021	78	-1	900	2020-01-18 15:34:21.767694+03
15022	58	-1	2830	2020-01-18 15:54:08.093285+03
15023	80	-1	1120	2020-01-18 16:18:41.810108+03
15024	7	-1	810	2020-01-18 16:23:33.604015+03
15025	47	-1	1480	2020-01-18 16:27:49.816505+03
15026	47	-2	1480	2020-01-18 16:35:27.791172+03
15027	78	-1	900	2020-01-18 16:41:36.297768+03
15028	12	-1	1650	2020-01-18 16:43:41.342517+03
15029	61	23	726	2020-01-18 17:03:34.616653+03
15030	32	-1	710	2020-01-18 17:10:08.544268+03
15031	39	-1	910	2020-01-18 17:13:49.315602+03
15032	69	-2	1100	2020-01-18 17:31:32.086805+03
15033	9	-1	2090	2020-01-18 18:02:39.72661+03
15034	61	-1	1510	2020-01-18 18:22:22.414105+03
15035	37	-1	1290	2020-01-18 19:20:08.432883+03
15036	88	-1	1270	2020-01-18 19:36:17.210012+03
15037	4	-1	1420	2020-01-18 19:38:54.466518+03
15038	52	-2	1090	2020-01-18 19:50:25.141582+03
15039	35	-1	670	2020-01-18 19:54:21.033629+03
15040	68	-1	490	2020-01-18 20:15:07.873976+03
15041	75	-1	830	2020-01-18 20:17:13.358854+03
15042	75	-2	830	2020-01-18 20:19:39.208464+03
15043	17	-2	1500	2020-01-18 20:38:48.724744+03
15044	93	-1	1620	2020-01-18 20:39:41.537502+03
15045	35	-1	670	2020-01-18 20:53:50.890417+03
15046	87	-2	2320	2020-01-18 21:13:41.891811+03
15047	10	-1	2080	2020-01-18 21:46:32.498322+03
15048	1	-1	640	2020-01-18 21:47:27.448059+03
15049	2	-1	470	2020-01-18 21:52:42.294295+03
15050	75	-1	830	2020-01-18 21:57:44.408018+03
15051	29	-1	1940	2020-01-18 22:02:24.191264+03
15052	53	26	1695	2020-01-18 22:04:04.916726+03
15053	5	32	939	2020-01-18 22:26:47.793695+03
15054	14	-1	1350	2020-01-18 22:28:13.912884+03
15055	5	-1	1620	2020-01-18 22:32:58.356193+03
15056	61	-2	1510	2020-01-18 22:55:06.199076+03
15057	68	-1	490	2020-01-18 22:56:20.400292+03
15058	77	-2	640	2020-01-18 23:36:23.4096+03
15059	81	-1	1620	2020-01-18 23:52:37.22256+03
15060	88	-1	1270	2020-01-19 00:12:00.435656+03
15061	15	-2	2830	2020-01-19 01:03:03.615903+03
15062	46	-2	1270	2020-01-19 01:54:04.720401+03
15063	69	-1	1100	2020-01-19 02:17:26.813872+03
15064	73	-1	960	2020-01-19 02:23:48.790314+03
15065	59	-2	1030	2020-01-19 02:25:21.09175+03
15066	30	-1	1140	2020-01-19 02:31:22.267019+03
15067	10	-1	2080	2020-01-19 02:34:15.869752+03
15068	51	-1	1310	2020-01-19 02:35:10.516698+03
15069	64	-1	970	2020-01-19 02:51:14.838678+03
15070	94	-2	1230	2020-01-19 03:16:24.560076+03
15071	42	-1	1790	2020-01-19 03:29:10.380357+03
15072	75	-1	830	2020-01-19 03:56:11.933527+03
15073	18	-1	910	2020-01-19 04:02:22.547982+03
15074	64	-1	970	2020-01-19 04:05:23.238562+03
15075	52	-1	1090	2020-01-19 04:11:31.385754+03
15076	51	-1	1310	2020-01-19 04:23:47.500806+03
15077	6	-1	980	2020-01-19 04:24:17.868054+03
15078	84	-1	2700	2020-01-19 04:39:54.232073+03
15079	65	-1	490	2020-01-19 05:00:00.605005+03
15080	4	-1	1420	2020-01-19 05:21:24.479894+03
15081	77	-1	640	2020-01-19 05:36:12.790409+03
15082	93	-2	1620	2020-01-19 05:55:51.637401+03
15083	50	-1	1140	2020-01-19 06:05:01.898474+03
15084	92	-1	630	2020-01-19 06:25:31.153602+03
15085	86	-1	910	2020-01-19 06:36:48.729559+03
15086	43	-1	380	2020-01-19 06:49:40.812923+03
15087	46	-1	1270	2020-01-19 06:52:33.458783+03
15088	55	-1	3480	2020-01-19 06:55:02.114995+03
15089	92	-1	630	2020-01-19 07:10:06.058353+03
15090	84	-1	2700	2020-01-19 07:11:32.789245+03
15091	22	-3	1070	2020-01-19 07:28:59.98496+03
15092	8	-1	1920	2020-01-19 07:41:08.039905+03
15093	17	-1	1500	2020-01-19 07:49:19.753211+03
15094	52	-1	1090	2020-01-19 08:13:45.061608+03
15095	19	-1	1220	2020-01-19 08:55:14.927078+03
15096	47	-1	1480	2020-01-19 09:07:28.663547+03
15097	47	-1	1480	2020-01-19 09:21:25.822736+03
15098	47	-1	1480	2020-01-19 09:30:48.906916+03
15099	42	-1	1790	2020-01-19 09:31:01.607637+03
15100	44	-1	500	2020-01-19 09:59:37.316856+03
15101	81	-1	1620	2020-01-19 10:16:47.652419+03
15102	19	-1	1220	2020-01-19 10:27:08.618758+03
15103	57	-2	1900	2020-01-19 10:33:29.673591+03
15104	74	-1	1010	2020-01-19 10:56:20.924948+03
15105	86	-1	910	2020-01-19 10:56:54.763873+03
15106	55	-1	3480	2020-01-19 11:02:13.076717+03
15107	83	-1	1230	2020-01-19 11:09:11.563482+03
15108	77	-1	640	2020-01-19 11:20:37.778148+03
15109	17	-1	1500	2020-01-19 11:25:11.705471+03
15110	22	-2	1070	2020-01-19 11:25:13.102538+03
15111	37	-2	1290	2020-01-19 11:35:16.559227+03
15112	74	-1	1010	2020-01-19 11:51:39.223694+03
15113	87	-1	2320	2020-01-19 12:07:07.446918+03
15114	93	-1	1620	2020-01-19 12:24:47.372812+03
15115	8	-1	1920	2020-01-19 12:57:31.336925+03
15116	10	-1	2080	2020-01-19 13:05:17.44691+03
15117	63	-1	1780	2020-01-19 13:10:16.966825+03
15118	12	-1	1650	2020-01-19 13:12:51.712475+03
15119	61	-1	1510	2020-01-19 13:21:50.71267+03
15120	54	-1	3470	2020-01-19 13:35:29.824519+03
15121	6	-1	980	2020-01-19 13:50:56.952002+03
15122	80	-1	1120	2020-01-19 13:57:56.144385+03
15123	57	-1	1900	2020-01-19 14:31:54.196328+03
15124	13	-1	460	2020-01-19 14:44:51.049025+03
15125	90	-1	1780	2020-01-19 14:51:10.293316+03
15126	65	-1	490	2020-01-19 15:16:37.482861+03
15127	78	-2	900	2020-01-19 15:18:15.000662+03
15128	68	-1	490	2020-01-19 15:23:35.50504+03
15129	84	-1	2700	2020-01-19 15:41:42.719928+03
15130	59	-2	1030	2020-01-19 15:46:43.971347+03
15131	28	-1	1860	2020-01-19 16:21:05.154856+03
15132	20	-1	830	2020-01-19 16:22:19.304498+03
15133	86	-1	910	2020-01-19 16:38:01.121534+03
15134	20	-2	830	2020-01-19 16:45:08.189386+03
15135	60	-1	2700	2020-01-19 16:45:42.101695+03
15136	48	-2	640	2020-01-19 16:54:25.749813+03
15137	17	-2	1500	2020-01-19 17:20:40.27416+03
15138	95	-1	480	2020-01-19 17:49:07.912318+03
15139	87	-1	2320	2020-01-19 17:55:47.595329+03
15140	28	-1	1860	2020-01-19 18:50:56.006387+03
15141	81	-1	1620	2020-01-19 18:56:00.166871+03
15142	59	-2	1030	2020-01-19 20:15:13.014233+03
15143	81	-2	1620	2020-01-19 20:16:55.754627+03
15144	10	-2	2080	2020-01-19 20:36:59.097309+03
15145	5	-1	1620	2020-01-19 20:38:07.358453+03
15146	72	-1	620	2020-01-19 22:24:48.626807+03
15147	26	-1	390	2020-01-19 22:32:59.182628+03
15148	88	-2	1270	2020-01-19 22:40:38.587023+03
15149	93	-1	1620	2020-01-19 23:06:53.031915+03
15150	58	-1	2830	2020-01-19 23:09:08.770184+03
15151	93	23	912	2020-01-19 23:25:06.500692+03
15152	30	-1	1140	2020-01-19 23:27:12.875581+03
15153	42	-1	1790	2020-01-19 23:33:17.917164+03
15154	42	-2	1790	2020-01-19 23:42:31.30323+03
15155	89	-1	1420	2020-01-19 23:54:12.927667+03
15156	23	-1	4390	2020-01-20 00:00:25.292054+03
15157	1	-1	640	2020-01-20 00:20:33.208846+03
15158	56	-1	2460	2020-01-20 00:25:20.903387+03
15159	26	-1	390	2020-01-20 00:41:54.769435+03
15160	89	-1	1420	2020-01-20 00:48:43.256017+03
15161	83	-1	1230	2020-01-20 01:14:58.224869+03
15162	49	-1	970	2020-01-20 01:31:35.944879+03
15163	15	-1	2830	2020-01-20 01:48:22.17925+03
15164	22	-1	1070	2020-01-20 02:02:01.676328+03
15165	81	-1	1620	2020-01-20 02:15:33.709919+03
15166	30	-1	1140	2020-01-20 02:43:04.742456+03
15167	37	-2	1290	2020-01-20 02:58:53.512789+03
15168	87	-1	2320	2020-01-20 03:16:40.247906+03
15169	84	-2	2700	2020-01-20 03:20:40.100143+03
15170	77	-1	640	2020-01-20 03:23:31.226912+03
15171	17	-1	1500	2020-01-20 03:48:37.798308+03
15172	3	-1	660	2020-01-20 03:55:05.809644+03
15173	60	-2	2700	2020-01-20 03:59:39.660954+03
15174	8	-1	1920	2020-01-20 04:11:31.945715+03
15175	75	-1	830	2020-01-20 04:14:09.134621+03
15176	73	-1	960	2020-01-20 04:37:35.196521+03
15177	36	-2	630	2020-01-20 04:40:59.775866+03
15178	45	-1	1590	2020-01-20 04:56:31.191844+03
15179	10	-1	2080	2020-01-20 05:33:52.753045+03
15180	9	-1	2090	2020-01-20 05:52:55.393331+03
15181	49	-2	970	2020-01-20 07:14:47.410351+03
15182	83	-1	1230	2020-01-20 07:37:07.608609+03
15183	47	-1	1480	2020-01-20 07:56:00.62325+03
15184	32	-1	710	2020-01-20 08:30:55.992153+03
15185	9	-1	2090	2020-01-20 08:34:31.263974+03
15186	53	-2	3120	2020-01-20 09:09:49.918671+03
15187	55	-1	3480	2020-01-20 09:56:09.724987+03
15188	22	-1	1070	2020-01-20 09:57:06.345435+03
15189	60	-2	2700	2020-01-20 10:20:03.851442+03
15190	1	-1	640	2020-01-20 10:22:41.54224+03
15191	11	-2	830	2020-01-20 10:26:57.793149+03
15192	77	-2	640	2020-01-20 10:52:52.118438+03
15193	86	-1	910	2020-01-20 11:02:27.745007+03
15194	51	-1	1310	2020-01-20 11:13:10.347412+03
15195	92	-1	630	2020-01-20 11:39:56.167266+03
15196	63	-1	1780	2020-01-20 12:09:49.37793+03
15197	49	-1	970	2020-01-20 12:42:53.592021+03
15198	60	-2	2700	2020-01-20 12:50:20.258344+03
15199	46	-1	1270	2020-01-20 12:51:37.279109+03
15200	67	-1	350	2020-01-20 13:01:57.987294+03
15201	7	-1	810	2020-01-20 13:19:51.665468+03
15202	6	-1	980	2020-01-20 13:37:25.469583+03
15203	17	-1	1500	2020-01-20 13:39:49.052657+03
15204	22	-2	1070	2020-01-20 14:01:58.648636+03
15205	22	-1	1070	2020-01-20 14:07:44.877637+03
15206	57	-1	1900	2020-01-20 14:31:07.49302+03
15207	27	-2	880	2020-01-20 14:40:15.764776+03
15208	20	-1	830	2020-01-20 14:46:46.252395+03
15209	22	-1	1070	2020-01-20 15:01:14.576984+03
15210	91	-1	1620	2020-01-20 15:03:11.807683+03
15211	15	-1	2830	2020-01-20 15:06:14.459199+03
15212	64	-1	970	2020-01-20 15:07:34.865322+03
15213	71	-1	1030	2020-01-20 16:07:59.436758+03
15214	42	-2	1790	2020-01-20 16:18:09.219643+03
15215	3	-1	660	2020-01-20 16:22:52.504327+03
15216	85	-1	730	2020-01-20 16:25:19.377258+03
15217	4	-1	1420	2020-01-20 17:18:35.009483+03
15218	93	-1	1620	2020-01-20 17:34:32.579843+03
15219	81	-1	1620	2020-01-20 17:38:53.12251+03
15220	36	-1	630	2020-01-20 17:49:20.480774+03
15221	73	-2	960	2020-01-20 17:53:35.985253+03
15222	56	-2	2460	2020-01-20 18:04:14.171645+03
15223	28	-1	1860	2020-01-20 18:14:47.079469+03
15224	42	-2	1790	2020-01-20 19:22:02.00331+03
15225	87	-1	2320	2020-01-20 19:39:43.913774+03
15226	9	18	928	2020-01-20 19:42:19.156808+03
15227	35	-1	670	2020-01-20 19:42:29.452838+03
15228	51	-1	1310	2020-01-20 19:51:11.35829+03
15229	45	-2	1590	2020-01-20 19:51:23.741706+03
15230	39	-2	910	2020-01-20 20:26:23.965181+03
15231	11	-1	830	2020-01-20 20:32:32.764766+03
15232	68	-1	490	2020-01-20 20:33:10.875098+03
15233	8	-1	1920	2020-01-20 20:40:18.36674+03
15234	47	44	872	2020-01-20 20:40:46.949456+03
15235	95	-3	480	2020-01-20 20:49:39.247959+03
15236	80	-1	1120	2020-01-20 20:56:54.694068+03
15237	49	-1	970	2020-01-20 21:15:38.350299+03
15238	3	-1	660	2020-01-20 21:56:51.265601+03
15239	77	37	353	2020-01-20 22:12:09.960844+03
15240	65	-1	490	2020-01-20 22:14:43.360239+03
15241	96	-1	1570	2020-01-20 22:34:43.466946+03
15242	17	-2	1500	2020-01-20 22:42:25.692497+03
15243	31	-2	1190	2020-01-20 23:28:29.676015+03
15244	32	-1	710	2020-01-20 23:34:06.789487+03
15245	63	-1	1780	2020-01-20 23:41:08.353706+03
15246	85	-1	730	2020-01-20 23:47:21.772052+03
15247	81	-1	1620	2020-01-20 23:49:18.71052+03
15248	33	-2	900	2020-01-21 00:00:56.434718+03
15249	54	-1	3470	2020-01-21 00:02:53.740502+03
15250	54	-1	3470	2020-01-21 00:14:06.615342+03
15251	9	-1	2090	2020-01-21 00:14:53.085659+03
15252	90	-2	1780	2020-01-21 00:19:43.461022+03
15253	3	-2	660	2020-01-21 00:37:34.522167+03
15254	31	-1	1190	2020-01-21 00:40:06.25556+03
15255	24	-1	950	2020-01-21 01:25:44.66244+03
15256	13	-1	460	2020-01-21 01:33:31.162435+03
15257	19	-2	1220	2020-01-21 01:51:47.497526+03
15258	93	-1	1620	2020-01-21 02:14:30.891448+03
15259	46	-1	1270	2020-01-21 02:51:58.625863+03
15260	19	-1	1220	2020-01-21 02:53:24.973547+03
15261	70	-1	760	2020-01-21 03:02:45.489118+03
15262	77	-1	640	2020-01-21 03:08:22.663709+03
15263	42	-1	1790	2020-01-21 03:09:38.746331+03
15264	17	-1	1500	2020-01-21 03:09:54.126584+03
15265	34	-1	1550	2020-01-21 03:09:58.488374+03
15266	25	-1	1100	2020-01-21 03:17:25.809343+03
15267	10	-1	2080	2020-01-21 05:21:19.697365+03
15268	74	-1	1010	2020-01-21 05:25:49.080076+03
15269	48	-2	640	2020-01-21 05:49:33.939883+03
15270	30	-1	1140	2020-01-21 06:17:20.906014+03
15271	78	-1	900	2020-01-21 06:19:16.67124+03
15272	12	-1	1650	2020-01-21 07:08:55.891707+03
15273	84	-2	2700	2020-01-21 07:15:29.893763+03
15274	59	-1	1030	2020-01-21 08:02:41.135135+03
15275	83	-1	1230	2020-01-21 08:15:18.025141+03
15276	44	-1	500	2020-01-21 08:43:25.3331+03
15277	36	-1	630	2020-01-21 09:00:04.161891+03
15278	14	-1	1350	2020-01-21 09:05:21.037522+03
15279	46	-1	1270	2020-01-21 09:06:22.198037+03
15280	47	-1	1480	2020-01-21 09:55:21.016148+03
15281	38	23	504	2020-01-21 10:48:52.1168+03
15282	46	-1	1270	2020-01-21 10:53:17.359618+03
15283	84	-1	2700	2020-01-21 11:05:56.416584+03
15284	18	-3	910	2020-01-21 11:06:45.55579+03
15285	59	-1	1030	2020-01-21 11:07:24.572288+03
15286	52	-2	1090	2020-01-21 12:43:10.356929+03
15287	40	-1	1430	2020-01-21 12:44:25.340197+03
15288	83	-1	1230	2020-01-21 13:02:44.325548+03
15289	12	-1	1650	2020-01-21 13:54:15.220952+03
15290	36	-1	630	2020-01-21 14:32:06.448896+03
15291	30	-2	1140	2020-01-21 14:33:22.112928+03
15292	62	-2	1220	2020-01-21 14:45:38.756793+03
15293	37	-1	1290	2020-01-21 14:48:41.402148+03
15294	59	-1	1030	2020-01-21 15:00:29.110008+03
15295	64	-2	970	2020-01-21 15:38:42.850077+03
15296	76	-1	1070	2020-01-21 16:10:19.03289+03
15297	85	-1	730	2020-01-21 16:34:33.376147+03
15298	49	-1	970	2020-01-21 16:48:36.375336+03
15299	35	-1	670	2020-01-21 17:07:46.473938+03
15300	88	-1	1270	2020-01-21 17:16:33.726577+03
15301	14	-1	1350	2020-01-21 17:32:35.818233+03
15302	22	-1	1070	2020-01-21 17:50:10.511129+03
15303	56	-1	2460	2020-01-21 17:56:43.208218+03
15304	50	-1	1140	2020-01-21 17:56:43.867259+03
15305	38	-1	1100	2020-01-21 18:06:33.881159+03
15306	51	-1	1310	2020-01-21 18:12:33.602693+03
15307	78	-1	900	2020-01-21 19:01:04.399207+03
15308	66	12	326	2020-01-21 19:40:23.07635+03
15309	29	-1	1940	2020-01-21 20:22:42.5218+03
15310	93	-2	1620	2020-01-21 20:36:30.81256+03
15311	1	-1	640	2020-01-21 20:37:53.835978+03
15312	7	-1	810	2020-01-21 20:39:44.392562+03
15313	4	-1	1420	2020-01-21 20:47:53.899171+03
15314	64	-1	970	2020-01-21 21:04:38.420245+03
15315	30	-1	1140	2020-01-21 21:28:11.943196+03
15316	58	-1	2830	2020-01-21 21:49:21.371137+03
15317	33	-2	900	2020-01-21 21:58:04.473416+03
15318	82	-1	560	2020-01-21 22:03:39.801951+03
15319	96	31	933	2020-01-21 22:17:00.899947+03
15320	22	-1	1070	2020-01-21 22:23:37.608962+03
15321	10	-1	2080	2020-01-21 22:25:52.749582+03
15322	53	-1	3120	2020-01-21 22:33:08.13215+03
15323	73	-1	960	2020-01-21 22:35:01.537407+03
15324	53	-1	3120	2020-01-21 22:42:23.027583+03
15325	38	-1	1100	2020-01-21 23:33:43.794205+03
15326	40	-1	1430	2020-01-21 23:54:48.458904+03
15327	91	-1	1620	2020-01-22 00:08:34.211321+03
15328	1	23	313	2020-01-22 00:16:10.28649+03
15329	67	-2	350	2020-01-22 00:22:01.108463+03
15330	18	-1	910	2020-01-22 01:04:45.982648+03
15331	47	-1	1480	2020-01-22 01:12:42.33187+03
15332	92	-2	630	2020-01-22 01:31:23.76705+03
15333	29	-2	1940	2020-01-22 02:04:40.375635+03
15334	78	-1	900	2020-01-22 02:08:36.939337+03
15335	28	-1	1860	2020-01-22 02:17:10.36172+03
15336	75	-1	830	2020-01-22 02:26:11.76939+03
15337	14	-1	1350	2020-01-22 02:33:45.418963+03
15338	95	-2	480	2020-01-22 02:49:32.308189+03
15339	40	-2	1430	2020-01-22 02:50:35.781041+03
15340	10	-1	2080	2020-01-22 03:08:15.12413+03
15341	24	-1	950	2020-01-22 03:14:08.922625+03
15342	30	-1	1140	2020-01-22 03:21:23.338009+03
15343	15	15	1406	2020-01-22 03:54:56.666315+03
15344	56	-1	2460	2020-01-22 05:14:56.332245+03
15345	29	-1	1940	2020-01-22 05:35:12.88594+03
15346	93	-1	1620	2020-01-22 05:40:23.420244+03
15347	47	-1	1480	2020-01-22 05:58:08.867165+03
15348	74	-1	1010	2020-01-22 06:16:46.781294+03
15349	48	-1	640	2020-01-22 06:23:10.795108+03
15350	46	-1	1270	2020-01-22 06:26:32.840424+03
15351	54	-1	3470	2020-01-22 07:22:45.001085+03
15352	51	-1	1310	2020-01-22 07:24:05.146555+03
15353	77	-1	640	2020-01-22 08:10:22.863061+03
15354	36	-1	630	2020-01-22 08:58:16.674247+03
15355	21	-1	960	2020-01-22 09:07:13.008688+03
15356	20	-1	830	2020-01-22 09:11:15.45834+03
15357	80	-2	1120	2020-01-22 09:18:46.763479+03
15358	84	32	1236	2020-01-22 09:38:47.985736+03
15359	50	-1	1140	2020-01-22 09:55:41.893604+03
15360	71	-1	1030	2020-01-22 10:23:52.590355+03
15361	16	-1	1380	2020-01-22 10:25:43.427519+03
15362	84	-2	2700	2020-01-22 10:33:06.246927+03
15363	38	-1	1100	2020-01-22 10:47:05.544281+03
15364	91	-1	1620	2020-01-22 11:08:50.533511+03
15365	28	-1	1860	2020-01-22 11:40:11.809677+03
15366	61	-1	1510	2020-01-22 11:46:46.366526+03
15367	35	-1	670	2020-01-22 12:06:11.946602+03
15368	47	-1	1480	2020-01-22 12:25:14.802919+03
15369	62	-2	1220	2020-01-22 12:25:52.239844+03
15370	39	-3	910	2020-01-22 13:24:15.689724+03
15371	32	-2	710	2020-01-22 13:40:40.858553+03
15372	25	-1	1100	2020-01-22 14:54:02.364631+03
15373	10	-1	2080	2020-01-22 15:10:07.185004+03
15374	59	-1	1030	2020-01-22 15:23:24.235616+03
15375	87	-1	2320	2020-01-22 16:43:54.808458+03
15376	89	-1	1420	2020-01-22 17:21:04.078344+03
15377	36	-1	630	2020-01-22 17:37:21.061642+03
15378	40	-1	1430	2020-01-22 17:38:10.217909+03
15379	49	-2	970	2020-01-22 18:07:45.660599+03
15380	89	-1	1420	2020-01-22 18:26:21.90419+03
15381	46	-2	1270	2020-01-22 18:27:42.131088+03
15382	30	-1	1140	2020-01-22 18:43:11.777514+03
15383	95	-1	480	2020-01-22 18:46:01.991958+03
15384	86	-3	910	2020-01-22 18:50:46.155374+03
15385	23	-1	4390	2020-01-22 19:51:02.998945+03
15386	29	-1	1940	2020-01-22 19:52:08.424823+03
15387	89	-1	1420	2020-01-22 20:05:23.574909+03
15388	85	-1	730	2020-01-22 20:30:17.550089+03
15389	46	-1	1270	2020-01-22 20:45:51.576017+03
15390	80	-1	1120	2020-01-22 21:27:35.376479+03
15391	90	-1	1780	2020-01-22 21:30:51.278602+03
15392	94	20	527	2020-01-22 21:41:25.729279+03
15393	95	-2	480	2020-01-22 21:53:22.764644+03
15394	76	-1	1070	2020-01-22 21:57:44.132895+03
15395	70	-2	760	2020-01-22 22:39:59.832093+03
15396	65	17	284	2020-01-22 23:00:40.252688+03
15397	27	-1	880	2020-01-22 23:06:31.079972+03
15398	11	-2	830	2020-01-22 23:17:30.425073+03
15399	8	-2	1920	2020-01-22 23:35:33.251685+03
15400	89	-1	1420	2020-01-22 23:39:10.709434+03
15401	56	-1	2460	2020-01-22 23:41:53.640964+03
15402	84	-1	2700	2020-01-22 23:56:11.645101+03
15403	81	-1	1620	2020-01-23 00:00:04.810627+03
15404	12	-2	1650	2020-01-23 00:08:20.325712+03
15405	23	-1	4390	2020-01-23 00:13:50.488635+03
15406	46	-1	1270	2020-01-23 00:14:04.236104+03
15407	50	-1	1140	2020-01-23 00:24:22.363832+03
15408	89	-1	1420	2020-01-23 00:30:50.794138+03
15409	31	-2	1190	2020-01-23 01:44:52.30157+03
15410	91	-1	1620	2020-01-23 01:48:09.024698+03
15411	84	-2	2700	2020-01-23 01:48:47.037748+03
15412	12	-1	1650	2020-01-23 02:09:22.962804+03
15413	13	-1	460	2020-01-23 02:11:00.549766+03
15414	38	-1	1100	2020-01-23 02:17:35.089281+03
15415	9	-1	2090	2020-01-23 02:30:44.026436+03
15416	77	-1	640	2020-01-23 03:13:57.21933+03
15417	96	-1	1570	2020-01-23 03:15:15.776544+03
15418	4	-2	1420	2020-01-23 03:53:07.519093+03
15419	27	-2	880	2020-01-23 04:00:52.032624+03
15420	53	-1	3120	2020-01-23 04:24:51.241642+03
15421	9	-1	2090	2020-01-23 04:31:36.288839+03
15422	39	25	368	2020-01-23 04:37:35.967773+03
15423	68	-1	490	2020-01-23 04:39:52.183515+03
15424	75	-1	830	2020-01-23 04:51:23.598145+03
15425	87	-1	2320	2020-01-23 05:04:23.86767+03
15426	22	-1	1070	2020-01-23 05:16:41.517414+03
15427	94	-1	1230	2020-01-23 05:27:01.182726+03
15428	49	-1	970	2020-01-23 05:35:03.921606+03
15429	51	-2	1310	2020-01-23 05:39:36.697192+03
15430	1	-1	640	2020-01-23 06:12:36.943777+03
15431	65	-2	490	2020-01-23 06:34:42.7491+03
15432	26	-1	390	2020-01-23 06:52:12.943605+03
15433	39	-1	910	2020-01-23 07:47:41.206812+03
15434	54	-1	3470	2020-01-23 08:12:54.293536+03
15435	87	-1	2320	2020-01-23 08:18:45.172663+03
15436	44	-1	500	2020-01-23 08:18:54.962839+03
15437	47	-1	1480	2020-01-23 08:28:12.805367+03
15438	28	-2	1860	2020-01-23 08:28:50.422977+03
15439	41	-1	830	2020-01-23 08:41:12.545649+03
15440	30	-1	1140	2020-01-23 09:03:37.142887+03
15441	48	-1	640	2020-01-23 09:19:42.498645+03
15442	20	-1	830	2020-01-23 09:37:19.664428+03
15443	87	-1	2320	2020-01-23 09:49:46.580455+03
15444	18	-2	910	2020-01-23 10:12:10.385688+03
15445	77	-1	640	2020-01-23 10:47:05.964342+03
15446	56	-1	2460	2020-01-23 10:52:41.387036+03
15447	14	-1	1350	2020-01-23 11:00:41.096332+03
15448	59	-1	1030	2020-01-23 11:10:35.279492+03
15449	20	-1	830	2020-01-23 11:19:39.134569+03
15450	20	-1	830	2020-01-23 11:26:47.40122+03
15451	10	-1	2080	2020-01-23 11:40:49.531226+03
15452	48	22	335	2020-01-23 11:47:24.687984+03
15453	12	-2	1650	2020-01-23 11:47:35.401463+03
15454	1	-1	640	2020-01-23 12:19:20.691131+03
15455	62	-1	1220	2020-01-23 12:19:47.84944+03
15456	93	-1	1620	2020-01-23 12:20:32.464892+03
15457	84	-1	2700	2020-01-23 12:21:16.332682+03
15458	6	-2	980	2020-01-23 12:55:37.736725+03
15459	40	-1	1430	2020-01-23 13:12:40.096611+03
15460	43	-1	380	2020-01-23 13:14:55.925903+03
15461	10	-1	2080	2020-01-23 13:15:36.881519+03
15462	15	-1	2830	2020-01-23 13:29:58.236866+03
15463	50	-1	1140	2020-01-23 13:36:08.976107+03
15464	13	-1	460	2020-01-23 13:38:19.749129+03
15465	12	-1	1650	2020-01-23 13:47:18.27074+03
15466	63	-1	1780	2020-01-23 13:49:19.42313+03
15467	52	-1	1090	2020-01-23 14:11:24.137214+03
15468	43	-1	380	2020-01-23 14:41:46.889008+03
15469	87	-1	2320	2020-01-23 14:43:42.599911+03
15470	36	-1	630	2020-01-23 14:49:53.385967+03
15471	57	-1	1900	2020-01-23 14:50:58.848061+03
15472	86	-1	910	2020-01-23 15:24:43.505501+03
15473	37	-2	1290	2020-01-23 15:26:03.405078+03
15474	4	-1	1420	2020-01-23 15:44:16.929732+03
15475	11	-1	830	2020-01-23 15:51:29.271159+03
15476	50	22	634	2020-01-23 15:52:27.39219+03
15477	25	-1	1100	2020-01-23 16:14:33.398102+03
15478	56	-1	2460	2020-01-23 16:22:37.139762+03
15479	68	28	206	2020-01-23 16:35:17.939844+03
15480	6	-1	980	2020-01-23 16:42:21.844326+03
15481	63	-1	1780	2020-01-23 16:58:24.754764+03
15482	21	-1	960	2020-01-23 17:00:16.257323+03
15483	12	-2	1650	2020-01-23 17:09:50.973545+03
15484	83	-1	1230	2020-01-23 17:13:25.101083+03
15485	43	-2	380	2020-01-23 17:22:21.147533+03
15486	19	-1	1220	2020-01-23 17:36:24.040527+03
15487	27	-1	880	2020-01-23 18:02:51.724797+03
15488	25	-1	1100	2020-01-23 18:04:39.826326+03
15489	76	-1	1070	2020-01-23 18:05:24.418733+03
15490	46	35	639	2020-01-23 18:20:38.913046+03
15491	76	-1	1070	2020-01-23 18:22:51.721927+03
15492	93	-1	1620	2020-01-23 18:52:14.927555+03
15493	12	-1	1650	2020-01-23 18:56:00.243821+03
15494	29	-1	1940	2020-01-23 19:22:39.280582+03
15495	14	-2	1350	2020-01-23 19:45:30.195562+03
15496	59	-1	1030	2020-01-23 19:48:21.99636+03
15497	62	-1	1220	2020-01-23 19:49:15.105104+03
15498	73	-1	960	2020-01-23 20:00:19.654822+03
15499	82	-1	560	2020-01-23 20:14:43.080124+03
15500	48	-1	640	2020-01-23 20:28:11.934058+03
15501	87	-2	2320	2020-01-23 20:30:26.071038+03
15502	49	-1	970	2020-01-23 20:34:46.054328+03
15503	56	-1	2460	2020-01-23 20:45:11.526773+03
15504	82	-1	560	2020-01-23 21:02:21.293182+03
15505	32	-2	710	2020-01-23 21:09:26.665241+03
15506	78	-2	900	2020-01-23 21:20:38.134217+03
15507	77	-1	640	2020-01-23 21:24:22.453205+03
15508	63	-1	1780	2020-01-23 21:35:27.52272+03
15509	14	-1	1350	2020-01-23 21:47:16.1289+03
15510	81	-1	1620	2020-01-23 22:51:45.808703+03
15511	74	-1	1010	2020-01-23 23:05:17.173273+03
15512	38	-2	1100	2020-01-23 23:20:57.322716+03
15513	64	-1	970	2020-01-23 23:27:17.293366+03
15514	21	-1	960	2020-01-23 23:31:55.830562+03
15515	40	-1	1430	2020-01-23 23:49:40.762305+03
15516	84	-1	2700	2020-01-23 23:59:36.223299+03
15517	24	-1	950	2020-01-24 00:04:12.753584+03
15518	20	-1	830	2020-01-24 00:15:29.438373+03
15519	60	-1	2700	2020-01-24 00:22:45.880829+03
15520	6	-1	980	2020-01-24 00:38:22.768138+03
15521	38	-1	1100	2020-01-24 00:39:20.951499+03
15522	77	-1	640	2020-01-24 00:42:10.112686+03
15523	42	-2	1790	2020-01-24 00:55:34.752063+03
15524	13	-1	460	2020-01-24 01:04:01.567674+03
15525	8	-1	1920	2020-01-24 01:06:06.757428+03
15526	32	-1	710	2020-01-24 01:06:56.064452+03
15527	21	-1	960	2020-01-24 01:17:37.310591+03
15528	53	-1	3120	2020-01-24 01:27:06.255735+03
15529	83	-1	1230	2020-01-24 01:40:31.21728+03
15530	94	-1	1230	2020-01-24 01:40:52.061379+03
15531	54	-2	3470	2020-01-24 01:42:45.176929+03
15532	47	-1	1480	2020-01-24 01:55:32.816941+03
15533	77	-1	640	2020-01-24 02:09:38.056045+03
15534	65	-1	490	2020-01-24 02:11:15.13299+03
15535	46	-2	1270	2020-01-24 02:28:17.90615+03
15536	19	-2	1220	2020-01-24 02:53:16.648472+03
15537	48	-1	640	2020-01-24 03:36:03.859425+03
15538	60	22	1154	2020-01-24 03:55:44.024214+03
15539	73	-1	960	2020-01-24 04:10:56.473517+03
15540	95	-1	480	2020-01-24 04:15:59.053281+03
15541	8	-1	1920	2020-01-24 04:28:57.324836+03
15542	85	-1	730	2020-01-24 04:44:47.435881+03
15543	13	-2	460	2020-01-24 05:50:22.904616+03
15544	63	-2	1780	2020-01-24 06:02:12.635015+03
15545	89	36	771	2020-01-24 06:16:18.682627+03
15546	4	-2	1420	2020-01-24 07:16:49.091348+03
15547	69	-1	1100	2020-01-24 07:22:41.34758+03
15548	30	-2	1140	2020-01-24 07:31:06.911338+03
15549	71	-1	1030	2020-01-24 07:41:42.884252+03
15550	19	-1	1220	2020-01-24 08:47:50.675565+03
15551	7	-1	810	2020-01-24 09:29:26.38901+03
15552	8	-1	1920	2020-01-24 09:29:51.127363+03
15553	2	-1	470	2020-01-24 10:27:47.62157+03
15554	17	-1	1500	2020-01-24 10:35:07.345974+03
15555	47	-1	1480	2020-01-24 10:44:50.094176+03
15556	29	-1	1940	2020-01-24 10:52:21.031788+03
15557	87	41	1251	2020-01-24 10:54:18.528691+03
15558	87	-1	2320	2020-01-24 10:59:19.869182+03
15559	60	-1	2700	2020-01-24 11:01:27.595789+03
15560	54	-1	3470	2020-01-24 11:03:07.716966+03
15561	10	-2	2080	2020-01-24 11:46:32.38405+03
15562	93	-1	1620	2020-01-24 12:11:28.807217+03
15563	39	-1	910	2020-01-24 12:26:52.388247+03
15564	70	-1	760	2020-01-24 12:41:37.801099+03
15565	52	-1	1090	2020-01-24 13:02:04.539978+03
15566	37	-1	1290	2020-01-24 13:34:12.680863+03
15567	14	-1	1350	2020-01-24 13:35:01.414308+03
15568	79	-1	550	2020-01-24 13:47:11.615398+03
15569	40	-1	1430	2020-01-24 14:09:23.347625+03
15570	51	-1	1310	2020-01-24 14:12:20.655347+03
15571	1	-1	640	2020-01-24 14:16:41.034063+03
15572	34	-2	1550	2020-01-24 14:44:56.52169+03
15573	91	-1	1620	2020-01-24 14:53:55.104951+03
15574	76	-1	1070	2020-01-24 14:57:03.431547+03
15575	62	-1	1220	2020-01-24 15:17:55.573023+03
15576	39	-1	910	2020-01-24 15:48:16.268312+03
15577	74	-1	1010	2020-01-24 16:29:51.321508+03
15578	16	12	782	2020-01-24 16:39:41.278853+03
15579	22	-1	1070	2020-01-24 16:45:20.330439+03
15580	2	-2	470	2020-01-24 16:48:53.150847+03
15581	47	-1	1480	2020-01-24 16:54:53.609269+03
15582	67	-1	350	2020-01-24 17:15:31.318238+03
15583	13	-1	460	2020-01-24 17:23:27.549019+03
15584	57	-2	1900	2020-01-24 17:43:07.036238+03
15585	34	-1	1550	2020-01-24 18:01:13.650758+03
15586	82	-1	560	2020-01-24 18:03:51.871909+03
15587	88	-1	1270	2020-01-24 18:07:50.768502+03
15588	33	-2	900	2020-01-24 18:08:23.588777+03
15589	91	-1	1620	2020-01-24 19:05:49.406375+03
15590	25	-1	1100	2020-01-24 19:11:02.962101+03
15591	50	-1	1140	2020-01-24 19:14:16.396418+03
15592	90	-1	1780	2020-01-24 19:34:01.870965+03
15593	73	-1	960	2020-01-24 20:27:17.952844+03
15594	32	-1	710	2020-01-24 20:43:42.128059+03
15595	88	-1	1270	2020-01-24 21:26:28.421104+03
15596	30	-1	1140	2020-01-24 21:31:56.516806+03
15597	30	-1	1140	2020-01-24 22:00:37.429235+03
15598	41	-1	830	2020-01-24 22:08:51.781429+03
15599	38	-2	1100	2020-01-24 22:11:30.248972+03
15600	10	-2	2080	2020-01-24 22:12:14.220223+03
15601	44	-1	500	2020-01-24 22:38:18.835386+03
15602	48	-2	640	2020-01-24 22:45:40.417508+03
15603	22	-1	1070	2020-01-24 22:53:21.723543+03
15604	52	-1	1090	2020-01-24 22:56:18.06031+03
15605	82	-2	560	2020-01-24 23:08:23.756237+03
15606	74	-1	1010	2020-01-24 23:36:35.331815+03
15607	47	-1	1480	2020-01-24 23:43:21.893205+03
15608	6	-1	980	2020-01-25 00:03:13.078187+03
15609	22	-1	1070	2020-01-25 00:33:28.371509+03
15610	31	-2	1190	2020-01-25 00:44:43.244509+03
15611	80	-1	1120	2020-01-25 01:07:39.350821+03
15612	36	22	277	2020-01-25 01:31:40.535102+03
15613	90	-1	1780	2020-01-25 02:08:24.90441+03
15614	79	14	275	2020-01-25 02:32:53.103343+03
15615	39	-2	910	2020-01-25 02:39:59.595702+03
15616	9	-2	2090	2020-01-25 02:45:04.871615+03
15617	83	-1	1230	2020-01-25 03:21:41.952453+03
15618	10	-1	2080	2020-01-25 03:56:17.109324+03
15619	83	-1	1230	2020-01-25 04:21:49.692817+03
15620	55	-1	3480	2020-01-25 04:47:21.131852+03
15621	38	-1	1100	2020-01-25 05:09:38.803967+03
15622	25	14	590	2020-01-25 05:11:50.914776+03
15623	17	-2	1500	2020-01-25 05:42:51.961975+03
15624	59	-1	1030	2020-01-25 05:53:53.107117+03
15625	13	-1	460	2020-01-25 06:05:07.027385+03
15626	54	-1	3470	2020-01-25 06:27:59.689062+03
15627	81	-1	1620	2020-01-25 06:44:31.082202+03
15628	19	-2	1220	2020-01-25 06:50:33.930293+03
15629	72	-1	620	2020-01-25 06:57:12.356652+03
15630	96	-1	1570	2020-01-25 07:14:22.076608+03
15631	12	-1	1650	2020-01-25 07:44:42.493133+03
15632	47	-1	1480	2020-01-25 07:58:35.233803+03
15633	39	-1	910	2020-01-25 08:09:42.533875+03
15634	87	-1	2320	2020-01-25 08:10:41.603207+03
15635	70	-1	760	2020-01-25 08:25:59.599792+03
15636	40	-1	1430	2020-01-25 08:58:05.021063+03
15637	12	-1	1650	2020-01-25 09:17:28.11974+03
15638	71	-1	1030	2020-01-25 09:19:10.507857+03
15639	94	-1	1230	2020-01-25 09:37:42.915125+03
15640	68	-2	490	2020-01-25 10:18:32.891943+03
15641	91	-1	1620	2020-01-25 10:24:06.513919+03
15642	96	-1	1570	2020-01-25 10:24:35.850972+03
15643	13	-1	460	2020-01-25 10:27:53.964488+03
15644	5	-2	1620	2020-01-25 11:39:28.707701+03
15645	22	-1	1070	2020-01-25 11:40:38.239327+03
15646	89	-1	1420	2020-01-25 11:57:01.491631+03
15647	86	-1	910	2020-01-25 12:13:38.065368+03
15648	30	-1	1140	2020-01-25 12:18:27.786495+03
15649	39	-1	910	2020-01-25 12:24:43.096439+03
15650	89	-1	1420	2020-01-25 12:27:01.325581+03
15651	80	-1	1120	2020-01-25 13:38:47.468443+03
15652	8	-1	1920	2020-01-25 14:43:58.442122+03
15653	24	-1	950	2020-01-25 14:51:43.966003+03
15654	11	-1	830	2020-01-25 15:18:37.706664+03
15655	27	-1	880	2020-01-25 15:27:36.106686+03
15656	4	-1	1420	2020-01-25 15:52:24.343035+03
15657	77	-1	640	2020-01-25 16:01:40.89587+03
15658	29	-1	1940	2020-01-25 16:15:51.489374+03
15659	12	-2	1650	2020-01-25 16:18:32.155496+03
15660	17	-1	1500	2020-01-25 16:40:22.306001+03
15661	33	-1	900	2020-01-25 17:12:00.846144+03
15662	36	-1	630	2020-01-25 17:25:45.384321+03
15663	51	-1	1310	2020-01-25 17:37:50.631351+03
15664	96	-1	1570	2020-01-25 17:47:49.032973+03
15665	53	-1	3120	2020-01-25 18:08:21.674152+03
15666	77	-1	640	2020-01-25 18:21:51.407525+03
15667	6	-1	980	2020-01-25 18:39:45.226179+03
15668	41	-1	830	2020-01-25 18:57:14.22618+03
15669	5	-1	1620	2020-01-25 19:58:44.67819+03
15670	71	-1	1030	2020-01-25 20:11:38.601537+03
15671	36	-1	630	2020-01-25 20:30:57.870958+03
15672	69	-1	1100	2020-01-25 20:44:39.03997+03
15673	39	-1	910	2020-01-25 20:48:06.072398+03
15674	47	-1	1480	2020-01-25 20:56:46.036475+03
15675	77	-1	640	2020-01-25 21:25:01.816418+03
15676	58	-1	2830	2020-01-25 21:34:58.705129+03
15677	28	-1	1860	2020-01-25 21:59:32.174486+03
15678	8	-1	1920	2020-01-25 22:00:47.741223+03
15679	69	-1	1100	2020-01-25 22:06:35.609487+03
15680	76	-1	1070	2020-01-25 22:10:25.367727+03
15681	40	-1	1430	2020-01-25 22:35:34.816613+03
15682	33	-1	900	2020-01-25 22:40:41.728698+03
15683	41	-1	830	2020-01-25 22:54:10.474499+03
15684	80	-1	1120	2020-01-25 22:54:30.486359+03
15685	41	-1	830	2020-01-25 23:13:01.452324+03
15686	12	-1	1650	2020-01-25 23:54:55.916801+03
15687	78	-1	900	2020-01-25 23:55:55.69732+03
15688	33	-1	900	2020-01-26 00:03:12.983633+03
15689	76	-1	1070	2020-01-26 00:13:24.553239+03
15690	5	-1	1620	2020-01-26 00:17:39.855714+03
15691	87	-2	2320	2020-01-26 00:52:00.180612+03
15692	42	34	728	2020-01-26 01:03:26.315802+03
15693	59	-1	1030	2020-01-26 01:08:47.740341+03
15694	91	-1	1620	2020-01-26 01:22:00.800071+03
15695	60	-1	2700	2020-01-26 02:17:10.435553+03
15696	84	-1	2700	2020-01-26 02:21:17.829001+03
15697	12	-1	1650	2020-01-26 02:32:22.326824+03
15698	58	-1	2830	2020-01-26 02:37:09.884318+03
15699	79	-1	550	2020-01-26 02:41:30.554603+03
15700	20	-1	830	2020-01-26 03:43:31.032004+03
15701	80	-2	1120	2020-01-26 03:58:36.41091+03
15702	49	-1	970	2020-01-26 04:02:58.5539+03
15703	27	-1	880	2020-01-26 04:12:56.783454+03
15704	96	-3	1570	2020-01-26 04:15:36.86116+03
15705	44	-1	500	2020-01-26 04:26:14.072016+03
15706	87	-1	2320	2020-01-26 04:54:13.526877+03
15707	13	-1	460	2020-01-26 05:14:56.746655+03
15708	13	-1	460	2020-01-26 05:29:55.31352+03
15709	3	-1	660	2020-01-26 05:35:13.808677+03
15710	56	41	1097	2020-01-26 05:40:36.163547+03
15711	16	-1	1380	2020-01-26 06:04:12.342135+03
15712	72	13	276	2020-01-26 06:08:07.115405+03
15713	26	-1	390	2020-01-26 06:22:18.065362+03
15714	4	-1	1420	2020-01-26 06:31:23.862921+03
15715	41	-1	830	2020-01-26 06:36:43.804294+03
15716	56	-1	2460	2020-01-26 07:10:07.142986+03
15717	51	-3	1310	2020-01-26 07:17:36.521305+03
15718	10	-1	2080	2020-01-26 07:22:53.989381+03
15719	21	-1	960	2020-01-26 07:48:20.452576+03
15720	69	-1	1100	2020-01-26 07:54:39.253495+03
15721	67	-1	350	2020-01-26 08:08:38.43468+03
15722	77	-1	640	2020-01-26 08:16:20.687851+03
15723	75	-1	830	2020-01-26 08:19:49.624183+03
15724	37	-1	1290	2020-01-26 09:27:39.616891+03
15725	45	-1	1590	2020-01-26 09:28:51.942447+03
15726	75	-1	830	2020-01-26 09:49:52.358474+03
15727	37	-1	1290	2020-01-26 09:53:21.574204+03
15728	1	-2	640	2020-01-26 09:54:33.642537+03
15729	33	-1	900	2020-01-26 10:14:16.986471+03
15730	35	-1	670	2020-01-26 10:16:33.670539+03
15731	6	-1	980	2020-01-26 10:19:52.362761+03
15732	96	-2	1570	2020-01-26 10:28:48.234133+03
15733	20	-1	830	2020-01-26 10:41:30.885595+03
15734	22	-1	1070	2020-01-26 11:44:55.628609+03
15735	63	-1	1780	2020-01-26 11:47:59.356718+03
15736	12	-1	1650	2020-01-26 12:12:49.433414+03
15737	33	-2	900	2020-01-26 12:20:06.836876+03
15738	27	-1	880	2020-01-26 12:35:39.943915+03
15739	38	-2	1100	2020-01-26 12:45:09.92516+03
15740	81	-1	1620	2020-01-26 12:52:03.170974+03
15741	50	-1	1140	2020-01-26 13:17:49.703941+03
15742	81	30	732	2020-01-26 13:20:16.455412+03
15743	31	-1	1190	2020-01-26 13:39:46.238924+03
15744	20	-1	830	2020-01-26 13:53:29.202387+03
15745	89	-1	1420	2020-01-26 14:19:51.48001+03
15746	30	-1	1140	2020-01-26 14:35:27.005317+03
15747	57	-1	1900	2020-01-26 14:40:31.84351+03
15748	22	-1	1070	2020-01-26 14:45:02.187742+03
15749	74	-2	1010	2020-01-26 15:01:49.420123+03
15750	92	-1	630	2020-01-26 15:13:55.780634+03
15751	83	39	514	2020-01-26 15:28:44.871074+03
15752	19	-1	1220	2020-01-26 15:38:50.752558+03
15753	56	-1	2460	2020-01-26 15:43:32.007903+03
15754	17	-1	1500	2020-01-26 15:47:45.000964+03
15755	70	-1	760	2020-01-26 15:56:56.129826+03
15756	78	-1	900	2020-01-26 15:57:49.309294+03
15757	29	-1	1940	2020-01-26 16:27:59.407532+03
15758	90	-1	1780	2020-01-26 16:29:39.266553+03
15759	32	-1	710	2020-01-26 16:43:36.336156+03
15760	55	28	1451	2020-01-26 16:52:48.713098+03
15761	42	-2	1790	2020-01-26 17:03:32.389074+03
15762	18	-1	910	2020-01-26 17:06:38.722521+03
15763	29	-1	1940	2020-01-26 17:14:48.569153+03
15764	23	-1	4390	2020-01-26 17:47:24.349787+03
15765	54	-1	3470	2020-01-26 17:53:27.79545+03
15766	38	-2	1100	2020-01-26 18:15:27.358511+03
15767	51	-1	1310	2020-01-26 18:37:46.610109+03
15768	91	-1	1620	2020-01-26 19:16:05.207665+03
15769	52	-1	1090	2020-01-26 19:23:43.843131+03
15770	52	-2	1090	2020-01-26 19:25:08.325425+03
15771	16	-1	1380	2020-01-26 19:31:56.049893+03
15772	80	-1	1120	2020-01-26 19:55:15.3107+03
15773	37	-1	1290	2020-01-26 20:59:29.473533+03
15774	15	-1	2830	2020-01-26 21:11:31.802687+03
15775	4	-1	1420	2020-01-26 22:28:31.220981+03
15776	1	-1	640	2020-01-26 22:33:37.838973+03
15777	77	-1	640	2020-01-26 22:41:51.41918+03
15778	20	-1	830	2020-01-26 22:51:16.764391+03
15779	8	-1	1920	2020-01-26 23:13:41.078881+03
15780	28	-1	1860	2020-01-26 23:19:04.503311+03
15781	53	-1	3120	2020-01-26 23:52:37.395869+03
15782	92	-2	630	2020-01-27 00:05:48.756949+03
15783	32	-2	710	2020-01-27 00:11:23.016138+03
15784	89	-1	1420	2020-01-27 00:26:32.320329+03
15785	47	-1	1480	2020-01-27 00:30:32.833705+03
15786	30	-1	1140	2020-01-27 00:43:33.494271+03
15787	79	-2	550	2020-01-27 00:46:57.998137+03
15788	73	-1	960	2020-01-27 00:47:35.432027+03
15789	86	-1	910	2020-01-27 01:03:48.460142+03
15790	4	-1	1420	2020-01-27 02:07:01.436057+03
15791	27	-1	880	2020-01-27 02:15:58.512171+03
15792	39	-1	910	2020-01-27 03:00:45.191805+03
15793	60	-2	2700	2020-01-27 03:08:14.222503+03
15794	56	-2	2460	2020-01-27 03:16:35.34459+03
15795	23	-1	4390	2020-01-27 03:16:41.781204+03
15796	49	-1	970	2020-01-27 03:17:16.678468+03
15797	49	-1	970	2020-01-27 03:38:06.718929+03
15798	96	-1	1570	2020-01-27 03:41:53.733883+03
15799	4	-1	1420	2020-01-27 03:47:27.470292+03
15800	30	-1	1140	2020-01-27 03:55:28.034083+03
15801	79	-1	550	2020-01-27 04:23:38.018101+03
15802	63	-1	1780	2020-01-27 04:36:54.671968+03
15803	4	-2	1420	2020-01-27 04:47:01.275187+03
15804	8	-2	1920	2020-01-27 05:03:30.403712+03
15805	50	-1	1140	2020-01-27 05:35:20.427298+03
15806	93	-1	1620	2020-01-27 05:57:56.727726+03
15807	77	-1	640	2020-01-27 06:25:44.941435+03
15808	34	-1	1550	2020-01-27 06:38:04.335971+03
15809	51	-1	1310	2020-01-27 06:38:28.458697+03
15810	55	-1	3480	2020-01-27 06:53:25.425062+03
15811	29	-1	1940	2020-01-27 07:47:30.812351+03
15812	31	-3	1190	2020-01-27 08:04:57.746265+03
15813	49	-1	970	2020-01-27 08:42:59.695514+03
15814	96	-1	1570	2020-01-27 09:10:01.798536+03
15815	61	-2	1510	2020-01-27 09:11:42.422111+03
15816	34	-1	1550	2020-01-27 09:33:32.207842+03
15817	26	-1	390	2020-01-27 09:40:45.042061+03
15818	32	-1	710	2020-01-27 09:41:11.490741+03
15819	27	-2	880	2020-01-27 09:46:23.462251+03
15820	25	-1	1100	2020-01-27 09:46:57.285431+03
15821	35	34	392	2020-01-27 10:33:26.4586+03
15822	73	-1	960	2020-01-27 10:33:36.260122+03
15823	22	-1	1070	2020-01-27 11:04:34.374339+03
15824	77	-1	640	2020-01-27 11:06:03.857216+03
15825	59	-1	1030	2020-01-27 11:11:21.886735+03
15826	87	-1	2320	2020-01-27 11:20:54.231669+03
15827	93	-1	1620	2020-01-27 11:34:03.50962+03
15828	21	-1	960	2020-01-27 11:34:12.217955+03
15829	6	-1	980	2020-01-27 11:41:05.825565+03
15830	21	-1	960	2020-01-27 12:11:52.24348+03
15831	56	-1	2460	2020-01-27 12:46:59.279067+03
15832	2	-1	470	2020-01-27 12:55:26.008559+03
15833	33	31	375	2020-01-27 13:45:47.46402+03
15834	48	-1	640	2020-01-27 13:46:25.860863+03
15835	42	-2	1790	2020-01-27 13:47:41.547364+03
15836	27	-1	880	2020-01-27 13:56:40.081847+03
15837	84	-1	2700	2020-01-27 14:09:47.639978+03
15838	1	-2	640	2020-01-27 14:12:13.431805+03
15839	55	-1	3480	2020-01-27 14:27:55.04176+03
15840	60	-1	2700	2020-01-27 14:28:56.434976+03
15841	54	-1	3470	2020-01-27 15:01:36.575393+03
15842	30	-1	1140	2020-01-27 15:06:01.704437+03
15843	34	-1	1550	2020-01-27 15:08:03.329282+03
15844	56	-1	2460	2020-01-27 15:57:12.287253+03
15845	75	-1	830	2020-01-27 16:00:47.660277+03
15846	92	-1	630	2020-01-27 16:12:01.660773+03
15847	56	-1	2460	2020-01-27 16:20:07.12058+03
15848	43	-1	380	2020-01-27 16:34:59.910848+03
15849	64	-1	970	2020-01-27 16:47:43.711093+03
15850	61	-2	1510	2020-01-27 16:53:46.626912+03
15851	8	-1	1920	2020-01-27 16:59:08.666725+03
15852	14	-1	1350	2020-01-27 17:28:18.419459+03
15853	49	-1	970	2020-01-27 17:55:57.745171+03
15854	17	-1	1500	2020-01-27 17:57:12.810571+03
15855	90	-1	1780	2020-01-27 18:18:46.494961+03
15856	34	29	695	2020-01-27 19:00:32.99587+03
15857	20	-1	830	2020-01-27 19:05:32.31564+03
15858	40	-2	1430	2020-01-27 19:21:44.117204+03
15859	24	-1	950	2020-01-27 19:24:52.751265+03
15860	91	-1	1620	2020-01-27 19:47:28.045315+03
15861	58	-2	2830	2020-01-27 19:58:05.841983+03
15862	53	-1	3120	2020-01-27 20:03:29.500303+03
15863	1	-2	640	2020-01-27 20:07:30.569542+03
15864	48	-1	640	2020-01-27 20:28:10.991051+03
15865	4	-1	1420	2020-01-27 20:32:08.189439+03
15866	50	-1	1140	2020-01-27 20:35:19.959529+03
15867	62	-1	1220	2020-01-27 20:41:00.766127+03
15868	38	-2	1100	2020-01-27 20:47:07.134074+03
15869	39	-1	910	2020-01-27 20:52:04.156771+03
15870	56	-1	2460	2020-01-27 21:08:25.967177+03
15871	44	-1	500	2020-01-27 21:27:37.926313+03
15872	84	-1	2700	2020-01-27 21:55:18.651804+03
15873	23	-1	4390	2020-01-27 22:00:48.400658+03
15874	92	-1	630	2020-01-27 22:03:06.764915+03
15875	3	-1	660	2020-01-27 22:21:42.609082+03
15876	58	-1	2830	2020-01-27 22:43:54.774326+03
15877	57	-1	1900	2020-01-27 22:46:59.647093+03
15878	13	-1	460	2020-01-27 22:54:34.363734+03
15879	27	24	406	2020-01-27 23:11:21.147947+03
15880	24	-1	950	2020-01-27 23:14:22.109731+03
15881	36	-1	630	2020-01-28 00:08:37.745757+03
15882	77	-1	640	2020-01-28 00:29:02.661678+03
15883	90	-1	1780	2020-01-28 00:56:17.89848+03
15884	96	-2	1570	2020-01-28 01:19:37.667396+03
15885	71	-1	1030	2020-01-28 01:50:34.020407+03
15886	43	-2	380	2020-01-28 01:58:15.345925+03
15887	38	-1	1100	2020-01-28 02:08:27.789963+03
15888	86	-2	910	2020-01-28 03:18:12.747939+03
15889	59	-1	1030	2020-01-28 03:28:15.723084+03
15890	89	-1	1420	2020-01-28 03:46:25.353396+03
15891	86	-1	910	2020-01-28 04:03:34.301403+03
15892	17	-1	1500	2020-01-28 04:23:46.962957+03
15893	29	-1	1940	2020-01-28 04:38:26.13156+03
15894	32	-1	710	2020-01-28 05:20:02.47056+03
15895	81	-1	1620	2020-01-28 05:25:43.784852+03
15896	43	-1	380	2020-01-28 05:41:16.118472+03
15897	57	-2	1900	2020-01-28 05:45:34.540869+03
15898	12	-1	1650	2020-01-28 06:30:39.006831+03
15899	94	-2	1230	2020-01-28 06:35:52.736164+03
15900	33	-1	900	2020-01-28 06:52:10.741169+03
15901	12	-1	1650	2020-01-28 06:57:31.318345+03
15902	5	-2	1620	2020-01-28 07:28:02.215701+03
15903	90	-1	1780	2020-01-28 08:07:57.013217+03
15904	69	-1	1100	2020-01-28 08:09:09.63137+03
15905	60	-1	2700	2020-01-28 08:34:10.988014+03
15906	52	-1	1090	2020-01-28 08:35:39.95501+03
15907	39	-1	910	2020-01-28 09:06:03.424247+03
15908	17	-1	1500	2020-01-28 09:06:04.480918+03
15909	60	-1	2700	2020-01-28 10:14:03.171755+03
15910	4	-2	1420	2020-01-28 10:18:10.005038+03
15911	86	-1	910	2020-01-28 10:28:30.761824+03
15912	15	-2	2830	2020-01-28 10:53:45.694338+03
15913	49	-1	970	2020-01-28 10:56:44.920863+03
15914	56	-1	2460	2020-01-28 11:06:36.937574+03
15915	67	-1	350	2020-01-28 11:06:50.291438+03
15916	37	-2	1290	2020-01-28 11:11:51.656135+03
15917	92	-1	630	2020-01-28 11:20:42.329873+03
15918	18	-2	910	2020-01-28 12:35:39.128922+03
15919	93	-1	1620	2020-01-28 12:42:05.350324+03
15920	30	-1	1140	2020-01-28 12:42:36.922799+03
15921	20	-1	830	2020-01-28 12:46:41.103191+03
15922	92	-1	630	2020-01-28 12:53:43.879035+03
15923	73	-1	960	2020-01-28 13:12:52.471948+03
15924	52	-1	1090	2020-01-28 13:22:35.339072+03
15925	37	-1	1290	2020-01-28 13:59:10.03609+03
15926	56	-1	2460	2020-01-28 14:15:21.869763+03
15927	29	-1	1940	2020-01-28 14:52:59.028981+03
15928	31	-1	1190	2020-01-28 15:03:54.044229+03
15929	74	-1	1010	2020-01-28 15:30:53.006581+03
15930	67	-1	350	2020-01-28 15:33:51.466005+03
15931	66	-1	690	2020-01-28 15:48:45.268409+03
15932	83	-1	1230	2020-01-28 15:50:50.929046+03
15933	14	-1	1350	2020-01-28 15:51:29.298014+03
15934	18	-1	910	2020-01-28 15:51:38.055096+03
15935	52	-1	1090	2020-01-28 15:52:48.331671+03
15936	28	-1	1860	2020-01-28 16:01:15.628648+03
15937	88	-1	1270	2020-01-28 16:05:12.57131+03
15938	21	-2	960	2020-01-28 16:08:33.252499+03
15939	6	-2	980	2020-01-28 16:19:08.244386+03
15940	90	-2	1780	2020-01-28 16:19:39.771203+03
15941	3	-1	660	2020-01-28 16:21:53.392378+03
15942	55	-2	3480	2020-01-28 16:26:37.404261+03
15943	4	-1	1420	2020-01-28 16:35:42.580004+03
15944	12	-1	1650	2020-01-28 16:53:19.698611+03
15945	13	-1	460	2020-01-28 17:06:45.615031+03
15946	31	-1	1190	2020-01-28 17:51:10.567575+03
15947	10	-2	2080	2020-01-28 18:24:00.985972+03
15948	22	-1	1070	2020-01-28 18:26:52.71864+03
15949	74	-1	1010	2020-01-28 18:38:31.672118+03
15950	32	-1	710	2020-01-28 18:44:23.401677+03
15951	79	-1	550	2020-01-28 18:53:26.946506+03
15952	23	-1	4390	2020-01-28 19:03:04.982956+03
15953	35	-1	670	2020-01-28 19:16:48.687812+03
15954	74	-1	1010	2020-01-28 19:23:21.698848+03
15955	67	-1	350	2020-01-28 19:27:04.27466+03
15956	50	-2	1140	2020-01-28 19:40:07.65483+03
15957	61	-1	1510	2020-01-28 19:44:42.222695+03
15958	40	-1	1430	2020-01-28 20:36:29.905894+03
15959	78	-2	900	2020-01-28 20:46:06.99519+03
15960	18	-1	910	2020-01-28 20:56:19.716291+03
15961	45	-1	1590	2020-01-28 21:46:23.98604+03
15962	31	-1	1190	2020-01-28 21:47:22.447143+03
15963	77	-1	640	2020-01-28 22:24:35.697738+03
15964	79	-1	550	2020-01-28 22:27:31.626157+03
15965	50	-1	1140	2020-01-28 22:38:20.094575+03
15966	39	-1	910	2020-01-28 23:22:12.490016+03
15967	79	-2	550	2020-01-28 23:42:06.736752+03
15968	88	-1	1270	2020-01-28 23:47:52.904016+03
15969	49	-1	970	2020-01-29 00:01:21.842828+03
15970	33	-1	900	2020-01-29 00:20:53.383459+03
15971	32	-1	710	2020-01-29 00:26:10.090232+03
15972	46	-1	1270	2020-01-29 00:42:17.15856+03
15973	21	-1	960	2020-01-29 00:43:37.231534+03
15974	78	-1	900	2020-01-29 01:04:07.682178+03
15975	4	-1	1420	2020-01-29 01:16:25.665642+03
15976	10	-2	2080	2020-01-29 01:21:28.819011+03
15977	59	-1	1030	2020-01-29 01:45:56.510794+03
15978	52	-2	1090	2020-01-29 02:22:06.421703+03
15979	8	-2	1920	2020-01-29 02:25:41.603456+03
15980	10	-1	2080	2020-01-29 02:53:22.223317+03
15981	17	-1	1500	2020-01-29 02:54:03.208913+03
15982	4	57	631	2020-01-29 03:07:22.657595+03
15983	38	-2	1100	2020-01-29 03:13:44.029519+03
15984	57	-1	1900	2020-01-29 03:49:39.279653+03
15985	67	-1	350	2020-01-29 03:52:07.996834+03
15986	64	-1	970	2020-01-29 03:56:11.182813+03
15987	69	-1	1100	2020-01-29 04:06:47.920604+03
15988	49	-1	970	2020-01-29 04:07:18.138398+03
15989	35	-1	670	2020-01-29 04:08:41.995986+03
15990	38	-1	1100	2020-01-29 04:14:56.466656+03
15991	64	-1	970	2020-01-29 04:18:24.287819+03
15992	69	-1	1100	2020-01-29 04:26:46.281318+03
15993	74	-1	1010	2020-01-29 04:36:43.007071+03
15994	33	-1	900	2020-01-29 05:13:21.396603+03
15995	59	-1	1030	2020-01-29 05:38:40.211974+03
15996	12	-1	1650	2020-01-29 05:56:32.83238+03
15997	32	-1	710	2020-01-29 06:02:50.02932+03
15998	59	-1	1030	2020-01-29 06:05:05.412009+03
15999	77	-1	640	2020-01-29 06:09:40.991183+03
16000	23	-2	4390	2020-01-29 06:15:31.893508+03
16001	76	-1	1070	2020-01-29 06:26:38.690649+03
16002	80	-1	1120	2020-01-29 07:08:03.696147+03
16003	33	-1	900	2020-01-29 07:27:07.810089+03
16004	89	-1	1420	2020-01-29 08:08:06.918081+03
16005	46	-1	1270	2020-01-29 08:11:00.717851+03
16006	38	-1	1100	2020-01-29 08:44:54.538141+03
16007	87	-2	2320	2020-01-29 08:47:24.774203+03
16008	18	32	478	2020-01-29 08:47:43.76265+03
16009	83	-1	1230	2020-01-29 09:13:54.365094+03
16010	32	-1	710	2020-01-29 09:16:32.499065+03
16011	77	-1	640	2020-01-29 09:19:55.839732+03
16012	31	-1	1190	2020-01-29 09:30:23.904291+03
16013	5	-2	1620	2020-01-29 09:43:47.593141+03
16014	67	-2	350	2020-01-29 09:50:10.32258+03
16015	12	-1	1650	2020-01-29 09:58:29.355275+03
16016	32	-1	710	2020-01-29 10:01:30.025074+03
16017	57	-1	1900	2020-01-29 10:10:22.554772+03
16018	27	-1	880	2020-01-29 10:10:55.901939+03
16019	12	-1	1650	2020-01-29 10:35:37.169987+03
16020	80	-1	1120	2020-01-29 10:54:36.834885+03
16021	3	-1	660	2020-01-29 11:18:12.849878+03
16022	92	-1	630	2020-01-29 12:15:19.842257+03
16023	61	-1	1510	2020-01-29 12:36:20.426221+03
16024	6	44	438	2020-01-29 12:43:45.001257+03
16025	20	-1	830	2020-01-29 12:53:43.041315+03
16026	58	-1	2830	2020-01-29 12:57:18.666606+03
16027	45	-1	1590	2020-01-29 13:17:00.764792+03
16028	70	-1	760	2020-01-29 13:22:53.505368+03
16029	88	29	681	2020-01-29 13:24:30.932359+03
16030	92	-1	630	2020-01-29 13:25:05.412933+03
16031	77	-1	640	2020-01-29 13:43:35.233089+03
16032	93	-2	1620	2020-01-29 13:57:55.967117+03
16033	11	-2	830	2020-01-29 15:07:09.498308+03
16034	75	-1	830	2020-01-29 15:30:13.481469+03
16035	41	-1	830	2020-01-29 16:11:34.127927+03
16036	38	-1	1100	2020-01-29 16:28:36.621965+03
16037	18	-2	910	2020-01-29 16:48:40.48035+03
16038	76	-1	1070	2020-01-29 17:03:06.614874+03
16039	77	-1	640	2020-01-29 17:15:01.308112+03
16040	67	-2	350	2020-01-29 17:17:45.486017+03
16041	49	-1	970	2020-01-29 17:40:37.823264+03
16042	75	-1	830	2020-01-29 17:42:05.291463+03
16043	71	45	488	2020-01-29 17:45:39.12332+03
16044	9	-1	2090	2020-01-29 18:05:15.652874+03
16045	96	-1	1570	2020-01-29 18:21:38.628233+03
16046	28	-1	1860	2020-01-29 18:22:59.407214+03
16047	68	-1	490	2020-01-29 18:33:12.585824+03
16048	56	-1	2460	2020-01-29 18:51:24.101443+03
16049	55	-1	3480	2020-01-29 19:06:15.907397+03
16050	14	-1	1350	2020-01-29 19:15:57.147141+03
16051	50	-1	1140	2020-01-29 19:18:08.010245+03
16052	86	-2	910	2020-01-29 19:40:07.592731+03
16053	14	-1	1350	2020-01-29 20:01:56.880166+03
16054	84	-1	2700	2020-01-29 20:09:19.852023+03
16055	17	-1	1500	2020-01-29 20:25:00.096843+03
16056	12	-1	1650	2020-01-29 20:29:03.526393+03
16057	91	-1	1620	2020-01-29 20:53:26.043557+03
16058	90	-1	1780	2020-01-29 20:54:40.111913+03
16059	79	-1	550	2020-01-29 21:20:32.446066+03
16060	39	-1	910	2020-01-29 21:30:43.784011+03
16061	88	-2	1270	2020-01-29 22:02:11.644549+03
16062	52	-1	1090	2020-01-29 22:29:58.23853+03
16063	35	-1	670	2020-01-29 22:45:29.370599+03
16064	18	-1	910	2020-01-29 23:10:19.633601+03
16065	57	-1	1900	2020-01-29 23:20:41.143056+03
16066	46	-1	1270	2020-01-29 23:23:28.242361+03
16067	35	-1	670	2020-01-29 23:29:08.454838+03
16068	46	-2	1270	2020-01-29 23:36:51.479158+03
16069	94	-2	1230	2020-01-29 23:39:42.135453+03
16070	43	-1	380	2020-01-29 23:48:01.167231+03
16071	67	-1	350	2020-01-30 00:03:18.556616+03
16072	57	-1	1900	2020-01-30 00:04:41.08634+03
16073	81	-1	1620	2020-01-30 00:10:27.390823+03
16074	40	26	585	2020-01-30 00:22:53.196983+03
16075	56	-1	2460	2020-01-30 00:24:11.232772+03
16076	26	-1	390	2020-01-30 00:33:57.59616+03
16077	6	-1	980	2020-01-30 00:37:49.787932+03
16078	27	-1	880	2020-01-30 00:58:49.056291+03
16079	46	-1	1270	2020-01-30 01:05:29.038526+03
16080	42	-1	1790	2020-01-30 02:19:28.067241+03
16081	94	-2	1230	2020-01-30 02:19:46.040438+03
16082	13	-1	460	2020-01-30 02:22:22.559465+03
16083	93	-2	1620	2020-01-30 02:24:39.295341+03
16084	36	-1	630	2020-01-30 02:51:57.505224+03
16085	32	-1	710	2020-01-30 02:56:02.719594+03
16086	35	-1	670	2020-01-30 03:03:34.447028+03
16087	21	-1	960	2020-01-30 03:30:04.219403+03
16088	58	-1	2830	2020-01-30 04:46:58.171535+03
16089	93	-1	1620	2020-01-30 05:41:23.130938+03
16090	30	-1	1140	2020-01-30 06:52:04.916916+03
16091	32	-1	710	2020-01-30 06:59:29.167021+03
16092	48	-1	640	2020-01-30 07:00:05.025591+03
16093	70	-2	760	2020-01-30 07:00:27.1061+03
16094	76	-2	1070	2020-01-30 07:12:19.764988+03
16095	52	-1	1090	2020-01-30 07:41:39.211889+03
16096	29	-1	1940	2020-01-30 07:57:55.266449+03
16097	32	-1	710	2020-01-30 08:16:07.567631+03
16098	80	-1	1120	2020-01-30 08:19:19.188443+03
16099	65	-1	490	2020-01-30 08:19:58.232205+03
16100	44	17	246	2020-01-30 08:44:54.119676+03
16101	79	-1	550	2020-01-30 09:09:13.612695+03
16102	64	-2	970	2020-01-30 09:33:04.783719+03
16103	87	-1	2320	2020-01-30 09:34:58.868392+03
16104	13	-2	460	2020-01-30 09:52:45.279838+03
16105	47	-1	1480	2020-01-30 09:58:01.139656+03
16106	96	-1	1570	2020-01-30 10:22:55.516851+03
16107	51	-2	1310	2020-01-30 10:23:26.09541+03
16108	8	-2	1920	2020-01-30 11:01:46.674311+03
16109	62	16	664	2020-01-30 11:26:21.067696+03
16110	6	-1	980	2020-01-30 11:41:13.428769+03
16111	83	-2	1230	2020-01-30 11:43:13.989761+03
16112	33	-2	900	2020-01-30 11:52:48.66073+03
16113	7	29	475	2020-01-30 12:40:50.420855+03
16114	95	24	266	2020-01-30 12:44:33.219159+03
16115	56	-1	2460	2020-01-30 12:53:39.058698+03
16116	56	-1	2460	2020-01-30 13:08:36.383335+03
16117	1	-1	640	2020-01-30 14:22:55.339132+03
16118	21	-1	960	2020-01-30 14:23:33.860383+03
16119	39	-1	910	2020-01-30 14:45:22.371865+03
16120	1	-1	640	2020-01-30 15:08:52.863104+03
16121	77	-1	640	2020-01-30 15:12:46.15267+03
16122	28	-1	1860	2020-01-30 15:16:26.633337+03
16123	84	-1	2700	2020-01-30 15:17:16.782086+03
16124	65	-1	490	2020-01-30 15:19:29.195278+03
16125	33	-1	900	2020-01-30 15:30:33.822169+03
16126	29	-1	1940	2020-01-30 15:54:31.666244+03
16127	3	-1	660	2020-01-30 16:26:34.596936+03
16128	6	-1	980	2020-01-30 16:40:42.652486+03
16129	39	-1	910	2020-01-30 16:59:58.35572+03
16130	27	-1	880	2020-01-30 17:32:34.737716+03
16131	26	-1	390	2020-01-30 17:55:00.447521+03
16132	30	-2	1140	2020-01-30 18:01:44.563996+03
16133	49	-1	970	2020-01-30 18:19:06.036259+03
16134	55	-1	3480	2020-01-30 19:09:47.829979+03
16135	55	-1	3480	2020-01-30 19:13:02.563023+03
16136	11	-1	830	2020-01-30 20:08:49.489886+03
16137	42	-2	1790	2020-01-30 20:10:21.570203+03
16138	24	-1	950	2020-01-30 20:44:11.215892+03
16139	76	-1	1070	2020-01-30 20:51:39.724719+03
16140	18	-1	910	2020-01-30 21:04:04.451627+03
16141	31	-1	1190	2020-01-30 21:52:33.463928+03
16142	22	-1	1070	2020-01-30 22:19:51.443601+03
16143	43	-1	380	2020-01-30 22:55:07.932364+03
16144	14	-1	1350	2020-01-30 23:30:59.182409+03
16145	63	-1	1780	2020-01-30 23:31:28.986552+03
16146	82	-1	560	2020-01-30 23:45:47.35781+03
16147	10	-1	2080	2020-01-30 23:52:02.419365+03
16148	81	-1	1620	2020-01-30 23:53:34.139356+03
16149	85	-1	730	2020-01-31 00:06:55.119748+03
16150	46	-1	1270	2020-01-31 00:19:15.318813+03
16151	34	-2	1550	2020-01-31 00:20:40.714435+03
16152	43	-1	380	2020-01-31 00:25:05.685091+03
16153	37	-1	1290	2020-01-31 00:33:49.471519+03
16154	86	-1	910	2020-01-31 00:39:41.047644+03
16155	60	-1	2700	2020-01-31 00:41:49.429659+03
16156	56	-1	2460	2020-01-31 00:55:36.95269+03
16157	13	37	228	2020-01-31 01:08:39.236529+03
16158	89	-1	1420	2020-01-31 01:17:35.719212+03
16159	49	-1	970	2020-01-31 01:25:33.693701+03
16160	22	-1	1070	2020-01-31 01:52:44.128471+03
16161	67	31	149	2020-01-31 01:57:24.465518+03
16162	26	-1	390	2020-01-31 02:18:58.788907+03
16163	20	-1	830	2020-01-31 02:22:54.060851+03
16164	64	-1	970	2020-01-31 02:47:15.830136+03
16165	69	-2	1100	2020-01-31 02:49:09.991163+03
16166	78	-1	900	2020-01-31 03:33:55.888848+03
16167	73	-1	960	2020-01-31 03:51:52.297234+03
16168	26	-2	390	2020-01-31 04:33:57.787417+03
16169	5	-1	1620	2020-01-31 04:41:10.773372+03
16170	7	-1	810	2020-01-31 04:42:18.904339+03
16171	21	-1	960	2020-01-31 04:47:30.438638+03
16172	63	-1	1780	2020-01-31 05:30:30.381251+03
16173	43	-1	380	2020-01-31 05:30:51.005743+03
16174	53	-1	3120	2020-01-31 06:08:36.957952+03
16175	24	-1	950	2020-01-31 06:15:49.050394+03
16176	70	27	348	2020-01-31 06:42:10.160039+03
16177	80	-2	1120	2020-01-31 07:08:38.985922+03
16178	52	22	505	2020-01-31 07:33:57.291552+03
16179	85	-2	730	2020-01-31 07:38:28.194699+03
16180	40	-1	1430	2020-01-31 07:41:43.078746+03
16181	14	-1	1350	2020-01-31 07:47:16.918575+03
16182	22	-1	1070	2020-01-31 07:58:00.514629+03
16183	24	22	498	2020-01-31 08:18:15.254038+03
16184	26	-1	390	2020-01-31 08:26:25.721913+03
16185	9	-1	2090	2020-01-31 09:04:07.348286+03
16186	2	-1	470	2020-01-31 09:09:07.420028+03
16187	20	-1	830	2020-01-31 09:13:23.984103+03
16188	43	-1	380	2020-01-31 09:16:16.620817+03
16189	61	-1	1510	2020-01-31 09:17:14.837618+03
16190	42	-2	1790	2020-01-31 09:38:50.886162+03
16191	61	-2	1510	2020-01-31 09:41:55.317714+03
16192	57	-1	1900	2020-01-31 09:51:09.792604+03
16193	33	-1	900	2020-01-31 10:14:12.839802+03
16194	45	22	828	2020-01-31 10:34:54.174965+03
16195	22	-2	1070	2020-01-31 10:50:23.721204+03
16196	68	-1	490	2020-01-31 11:24:23.576768+03
16197	4	-1	1420	2020-01-31 11:29:06.343824+03
16198	49	-1	970	2020-01-31 11:29:50.691046+03
16199	8	-2	1920	2020-01-31 11:34:41.592919+03
16200	32	-1	710	2020-01-31 12:08:50.747498+03
16201	2	-1	470	2020-01-31 12:14:45.584553+03
16202	15	-1	2830	2020-01-31 12:23:17.350702+03
16203	73	-1	960	2020-01-31 12:33:20.834734+03
16204	22	-1	1070	2020-01-31 12:37:39.461104+03
16205	46	-1	1270	2020-01-31 12:49:33.465773+03
16206	73	-1	960	2020-01-31 13:03:12.505194+03
16207	18	-1	910	2020-01-31 13:03:13.775894+03
16208	80	23	509	2020-01-31 14:00:22.612107+03
16209	30	-1	1140	2020-01-31 14:11:00.580903+03
16210	57	-1	1900	2020-01-31 14:34:08.967163+03
16211	63	-1	1780	2020-01-31 14:38:25.212486+03
16212	67	-2	350	2020-01-31 14:48:47.117272+03
16213	85	-1	730	2020-01-31 14:51:06.148434+03
16214	33	-1	900	2020-01-31 14:57:03.154641+03
16215	90	-1	1780	2020-01-31 15:12:08.119132+03
16216	57	-1	1900	2020-01-31 15:18:12.497452+03
16217	10	-2	2080	2020-01-31 15:29:32.826385+03
16218	6	-1	980	2020-01-31 15:41:38.016413+03
16219	34	-1	1550	2020-01-31 15:53:09.03947+03
16220	83	-1	1230	2020-01-31 16:02:22.341458+03
16221	52	-2	1090	2020-01-31 16:05:51.031616+03
16222	30	-1	1140	2020-01-31 16:07:10.521629+03
16223	47	-1	1480	2020-01-31 16:16:51.577188+03
16224	96	-1	1570	2020-01-31 16:23:34.014332+03
16225	75	-1	830	2020-01-31 16:40:15.956221+03
16226	26	-2	390	2020-01-31 16:54:27.744611+03
16227	33	-1	900	2020-01-31 16:56:30.0372+03
16228	7	-2	810	2020-01-31 17:11:17.264581+03
16229	39	-1	910	2020-01-31 17:54:09.654304+03
16230	6	-1	980	2020-01-31 18:12:34.314646+03
16231	46	-1	1270	2020-01-31 18:23:22.638319+03
16232	45	-1	1590	2020-01-31 18:27:43.038902+03
16233	12	-1	1650	2020-01-31 19:12:07.011022+03
16234	56	-1	2460	2020-01-31 19:13:39.294413+03
16235	85	22	384	2020-01-31 19:30:55.6428+03
16236	63	-1	1780	2020-01-31 19:32:51.154354+03
16237	71	-2	1030	2020-01-31 19:45:12.119559+03
16238	81	-2	1620	2020-01-31 19:45:34.49851+03
16239	62	-2	1220	2020-01-31 19:55:56.643643+03
16240	20	-2	830	2020-01-31 20:01:05.247619+03
16241	6	-1	980	2020-01-31 20:02:09.963335+03
16242	75	-2	830	2020-01-31 20:07:37.062594+03
16243	24	-1	950	2020-01-31 20:08:33.170812+03
16244	68	-1	490	2020-01-31 20:34:00.215023+03
16245	92	-2	630	2020-01-31 20:44:56.217492+03
16246	82	-1	560	2020-01-31 21:16:27.16788+03
16247	94	-1	1230	2020-01-31 21:24:55.978434+03
16248	96	-1	1570	2020-01-31 21:46:42.047463+03
16249	10	-1	2080	2020-01-31 21:49:49.436152+03
16250	73	26	530	2020-01-31 21:51:40.212979+03
16251	35	-1	670	2020-01-31 21:52:08.688697+03
16252	27	-1	880	2020-01-31 22:05:28.154149+03
16253	30	-2	1140	2020-01-31 22:32:29.351345+03
16254	85	-1	730	2020-01-31 22:37:01.833955+03
16255	73	-1	960	2020-01-31 22:49:06.595147+03
16256	82	-1	560	2020-01-31 22:59:30.847207+03
16257	60	-1	2700	2020-01-31 23:05:56.409497+03
16258	80	-1	1120	2020-01-31 23:10:12.730201+03
16259	63	-1	1780	2020-01-31 23:34:50.943441+03
16260	25	-1	1100	2020-01-31 23:43:22.680503+03
16261	74	-1	1010	2020-02-01 00:39:16.104742+03
16262	39	-2	910	2020-02-01 00:52:14.403265+03
16263	36	-1	630	2020-02-01 01:07:41.33673+03
16264	10	-1	2080	2020-02-01 01:13:14.02589+03
16265	20	-1	830	2020-02-01 02:02:14.738839+03
16266	52	-2	1090	2020-02-01 02:09:25.310273+03
16267	23	-1	4390	2020-02-01 02:26:14.462243+03
16268	39	-1	910	2020-02-01 02:35:13.387131+03
16269	52	-1	1090	2020-02-01 02:37:04.480679+03
16270	63	-1	1780	2020-02-01 02:43:09.194938+03
16271	79	-2	550	2020-02-01 02:58:21.493547+03
16272	49	-1	970	2020-02-01 03:01:14.261643+03
16273	16	-2	1380	2020-02-01 03:04:15.263488+03
16274	49	38	423	2020-02-01 03:09:57.699079+03
16275	3	-1	660	2020-02-01 03:39:40.557769+03
16276	87	-1	2320	2020-02-01 03:42:55.328018+03
16277	44	-1	500	2020-02-01 03:56:38.898461+03
16278	7	-2	810	2020-02-01 04:03:06.319203+03
16279	30	-1	1140	2020-02-01 04:06:05.644962+03
16280	55	-2	3480	2020-02-01 04:39:26.118697+03
16281	93	-1	1620	2020-02-01 04:46:59.373509+03
16282	94	-1	1230	2020-02-01 04:52:09.44893+03
16283	91	-1	1620	2020-02-01 05:26:37.458285+03
16284	94	-1	1230	2020-02-01 05:30:31.053541+03
16285	79	-1	550	2020-02-01 05:33:35.689612+03
16286	77	-1	640	2020-02-01 05:33:44.232529+03
16287	70	-1	760	2020-02-01 06:00:55.391855+03
16288	77	-2	640	2020-02-01 06:23:26.806999+03
16289	63	-1	1780	2020-02-01 06:25:22.492464+03
16290	49	-1	970	2020-02-01 06:29:45.18776+03
16291	3	-1	660	2020-02-01 06:31:52.433265+03
16292	75	-1	830	2020-02-01 06:46:35.137406+03
16293	59	-1	1030	2020-02-01 06:54:34.484492+03
16294	23	-1	4390	2020-02-01 07:05:19.20463+03
16295	82	-1	560	2020-02-01 07:28:11.975378+03
16296	69	-1	1100	2020-02-01 07:30:16.375714+03
16297	42	-2	1790	2020-02-01 09:30:31.792455+03
16298	72	-2	620	2020-02-01 09:31:01.301934+03
16299	72	-1	620	2020-02-01 09:36:00.045644+03
16300	77	-1	640	2020-02-01 09:44:05.375857+03
16301	69	-1	1100	2020-02-01 10:01:45.784511+03
16302	10	-1	2080	2020-02-01 11:17:24.687271+03
16303	52	-1	1090	2020-02-01 11:38:36.381828+03
16304	68	-1	490	2020-02-01 12:08:08.483102+03
16305	65	-1	490	2020-02-01 12:12:33.33052+03
16306	49	-2	970	2020-02-01 12:21:26.911172+03
16307	17	-1	1500	2020-02-01 12:26:29.317994+03
16308	79	-1	550	2020-02-01 12:50:15.598166+03
16309	72	-1	620	2020-02-01 12:51:46.937461+03
16310	50	-1	1140	2020-02-01 14:06:23.173612+03
16311	50	-1	1140	2020-02-01 14:15:28.665634+03
16312	63	-1	1780	2020-02-01 14:21:31.614643+03
16313	47	-1	1480	2020-02-01 14:36:22.24314+03
16314	26	-1	390	2020-02-01 14:42:41.239558+03
16315	10	-1	2080	2020-02-01 14:50:09.74338+03
16316	10	28	934	2020-02-01 15:12:49.698041+03
16317	29	-1	1940	2020-02-01 15:45:16.871193+03
16318	49	-1	970	2020-02-01 16:05:16.466647+03
16319	65	-2	490	2020-02-01 16:46:48.143238+03
16320	89	-2	1420	2020-02-01 17:21:50.632947+03
16321	80	-1	1120	2020-02-01 17:44:29.198896+03
16322	1	-2	640	2020-02-01 17:50:06.889506+03
16323	38	-1	1100	2020-02-01 17:58:33.66416+03
16324	38	26	555	2020-02-01 18:09:26.115525+03
16325	81	-1	1620	2020-02-01 18:14:45.303543+03
16326	1	-1	640	2020-02-01 19:09:42.604715+03
16327	12	-1	1650	2020-02-01 19:20:25.908255+03
16328	77	-1	640	2020-02-01 19:23:01.450251+03
16329	53	-2	3120	2020-02-01 20:15:36.509927+03
16330	47	-2	1480	2020-02-01 20:42:15.023262+03
16331	73	-1	960	2020-02-01 20:46:43.365632+03
16332	71	-1	1030	2020-02-01 21:01:20.479867+03
16333	47	-1	1480	2020-02-01 21:25:17.762821+03
16334	44	-1	500	2020-02-01 21:42:50.317652+03
16335	51	-1	1310	2020-02-01 22:09:57.202625+03
16336	18	-1	910	2020-02-01 22:19:27.315653+03
16337	8	-1	1920	2020-02-01 22:25:54.137477+03
16338	21	-2	960	2020-02-01 22:35:57.337286+03
16339	81	-1	1620	2020-02-01 23:12:11.49952+03
16340	14	-2	1350	2020-02-01 23:24:57.494024+03
16341	31	-1	1190	2020-02-01 23:29:54.322982+03
16342	87	-1	2320	2020-02-01 23:42:11.630602+03
16343	77	-1	640	2020-02-02 00:43:32.06504+03
16344	92	-2	630	2020-02-02 00:44:37.952701+03
16345	31	-2	1190	2020-02-02 00:46:52.541329+03
16346	23	-1	4390	2020-02-02 01:28:12.141522+03
16347	61	-1	1510	2020-02-02 01:52:59.73116+03
16348	91	-2	1620	2020-02-02 02:29:12.065844+03
16349	76	-1	1070	2020-02-02 02:31:47.75361+03
16350	38	-1	1100	2020-02-02 02:50:12.093546+03
16351	58	-2	2830	2020-02-02 02:55:33.279153+03
16352	36	-1	630	2020-02-02 03:02:31.177645+03
16353	87	-1	2320	2020-02-02 03:05:09.298203+03
16354	42	-2	1790	2020-02-02 03:05:44.956629+03
16355	75	-1	830	2020-02-02 03:06:39.165188+03
16356	42	-1	1790	2020-02-02 03:13:19.352177+03
16357	57	-2	1900	2020-02-02 03:34:55.496882+03
16358	38	-1	1100	2020-02-02 03:47:14.723467+03
16359	74	-1	1010	2020-02-02 03:56:30.064407+03
16360	81	-1	1620	2020-02-02 03:57:31.909948+03
16361	82	-1	560	2020-02-02 04:02:13.049199+03
16362	18	-1	910	2020-02-02 04:14:07.927128+03
16363	76	-1	1070	2020-02-02 04:30:27.56595+03
16364	76	-1	1070	2020-02-02 04:36:59.699199+03
16365	83	-1	1230	2020-02-02 04:46:32.035164+03
16366	2	-1	470	2020-02-02 04:58:04.841616+03
16367	33	-1	900	2020-02-02 05:04:12.750783+03
16368	58	21	1549	2020-02-02 05:28:17.022637+03
16369	34	-1	1550	2020-02-02 05:43:05.744361+03
16370	53	-1	3120	2020-02-02 05:55:27.752734+03
16371	9	-1	2090	2020-02-02 06:03:42.257008+03
16372	48	-1	640	2020-02-02 06:06:38.773833+03
16373	32	-2	710	2020-02-02 06:12:56.41428+03
16374	52	-3	1090	2020-02-02 06:36:59.423535+03
16375	57	-1	1900	2020-02-02 06:43:35.61777+03
16376	18	-1	910	2020-02-02 07:16:15.524891+03
16377	93	-1	1620	2020-02-02 07:33:38.118933+03
16378	17	-1	1500	2020-02-02 07:35:30.367333+03
16379	56	-1	2460	2020-02-02 07:37:31.532629+03
16380	33	-1	900	2020-02-02 07:38:54.59933+03
16381	69	-2	1100	2020-02-02 07:46:45.086031+03
16382	72	-1	620	2020-02-02 08:00:31.200503+03
16383	84	-1	2700	2020-02-02 08:11:41.296305+03
16384	76	-1	1070	2020-02-02 09:03:14.264519+03
16385	4	-1	1420	2020-02-02 09:28:07.612986+03
16386	7	-1	810	2020-02-02 10:10:58.574734+03
16387	39	-1	910	2020-02-02 10:21:48.60513+03
16388	30	-1	1140	2020-02-02 10:28:00.893815+03
16389	26	-2	390	2020-02-02 10:36:09.1397+03
16390	4	-1	1420	2020-02-02 10:46:44.117788+03
16391	94	-2	1230	2020-02-02 10:50:56.002252+03
16392	45	-1	1590	2020-02-02 10:52:20.186209+03
16393	65	-1	490	2020-02-02 11:21:40.296796+03
16394	55	-1	3480	2020-02-02 12:11:44.496606+03
16395	91	-1	1620	2020-02-02 14:01:54.527536+03
16396	33	-1	900	2020-02-02 14:23:04.40714+03
16397	86	-1	910	2020-02-02 14:29:30.214643+03
16398	18	-1	910	2020-02-02 15:01:24.227177+03
16399	26	-1	390	2020-02-02 15:01:52.649939+03
16400	66	-1	690	2020-02-02 15:05:38.943041+03
16401	70	-1	760	2020-02-02 15:29:53.09488+03
16402	83	-2	1230	2020-02-02 15:41:15.852114+03
16403	39	-1	910	2020-02-02 16:13:37.266954+03
16404	78	-1	900	2020-02-02 16:35:58.126349+03
16405	87	-1	2320	2020-02-02 16:48:52.60068+03
16406	45	-1	1590	2020-02-02 17:04:30.140756+03
16407	77	-1	640	2020-02-02 17:09:06.048203+03
16408	47	-1	1480	2020-02-02 17:14:48.136397+03
16409	32	-1	710	2020-02-02 18:15:12.063766+03
16410	35	-1	670	2020-02-02 18:22:41.149977+03
16411	91	-1	1620	2020-02-02 18:24:26.659672+03
16412	47	-1	1480	2020-02-02 18:36:25.750804+03
16413	7	-1	810	2020-02-02 18:37:00.252536+03
16414	20	-1	830	2020-02-02 18:39:42.371111+03
16415	61	-1	1510	2020-02-02 18:51:25.862972+03
16416	92	-1	630	2020-02-02 18:57:58.592955+03
16417	51	-1	1310	2020-02-02 19:03:08.588403+03
16418	19	-1	1220	2020-02-02 19:54:20.174957+03
16419	39	-1	910	2020-02-02 19:55:46.514736+03
16420	36	-1	630	2020-02-02 20:14:24.866703+03
16421	68	-1	490	2020-02-02 20:59:34.261328+03
16422	94	-1	1230	2020-02-02 21:13:00.56234+03
16423	49	-2	970	2020-02-02 21:18:38.398035+03
16424	7	-1	810	2020-02-02 21:36:31.91002+03
16425	96	-1	1570	2020-02-02 21:54:38.870416+03
16426	47	-2	1480	2020-02-02 22:08:19.674043+03
16427	88	-1	1270	2020-02-02 23:01:06.208939+03
16428	17	-1	1500	2020-02-02 23:05:25.324124+03
16429	88	-2	1270	2020-02-02 23:17:33.374148+03
16430	46	-1	1270	2020-02-02 23:33:20.673907+03
16431	36	-1	630	2020-02-02 23:51:03.737233+03
16432	25	-1	1100	2020-02-03 00:32:20.282795+03
16433	27	-1	880	2020-02-03 00:32:23.291156+03
16434	48	-1	640	2020-02-03 00:41:21.501634+03
16435	28	-2	1860	2020-02-03 01:33:30.331351+03
16436	48	-2	640	2020-02-03 01:47:23.82113+03
16437	14	-1	1350	2020-02-03 02:36:23.849906+03
16438	52	-1	1090	2020-02-03 02:39:47.844528+03
16439	17	-1	1500	2020-02-03 02:41:34.284528+03
16440	53	-1	3120	2020-02-03 02:44:32.534264+03
16441	19	-1	1220	2020-02-03 02:52:53.791899+03
16442	40	-1	1430	2020-02-03 03:02:55.728747+03
16443	19	-1	1220	2020-02-03 03:05:52.413712+03
16444	4	-1	1420	2020-02-03 03:24:22.542268+03
16445	33	-1	900	2020-02-03 03:52:17.96451+03
16446	77	-2	640	2020-02-03 04:20:43.606637+03
16447	79	22	301	2020-02-03 04:33:54.488315+03
16448	91	-1	1620	2020-02-03 04:37:51.205747+03
16449	50	-1	1140	2020-02-03 04:39:11.069448+03
16450	25	-1	1100	2020-02-03 04:41:48.301941+03
16451	83	-1	1230	2020-02-03 04:43:16.360999+03
16452	68	-2	490	2020-02-03 05:05:05.947554+03
16453	36	-1	630	2020-02-03 06:53:47.568471+03
16454	84	-1	2700	2020-02-03 07:06:22.413711+03
16455	96	-1	1570	2020-02-03 07:07:13.551644+03
16456	1	-2	640	2020-02-03 07:16:06.968636+03
16457	12	-2	1650	2020-02-03 07:18:40.083763+03
16458	20	31	337	2020-02-03 07:52:23.295691+03
16459	45	-1	1590	2020-02-03 07:58:37.835469+03
16460	47	-1	1480	2020-02-03 08:01:21.267837+03
16461	34	-2	1550	2020-02-03 08:26:32.786228+03
16462	63	-1	1780	2020-02-03 08:30:40.168515+03
16463	47	-1	1480	2020-02-03 09:12:53.312646+03
16464	85	-1	730	2020-02-03 10:34:44.88426+03
16465	35	-3	670	2020-02-03 11:10:50.209193+03
16466	22	35	531	2020-02-03 11:16:02.608898+03
16467	71	-1	1030	2020-02-03 11:32:18.423068+03
16468	5	-1	1620	2020-02-03 11:33:21.116779+03
16469	84	-2	2700	2020-02-03 11:39:38.649802+03
16470	87	-1	2320	2020-02-03 11:43:25.15283+03
16471	57	-1	1900	2020-02-03 11:51:35.435972+03
16472	18	-1	910	2020-02-03 12:03:08.425255+03
16473	77	-1	640	2020-02-03 12:23:46.575311+03
16474	23	-1	4390	2020-02-03 12:31:31.85265+03
16475	67	-1	350	2020-02-03 12:34:35.199451+03
16476	85	-1	730	2020-02-03 12:44:43.820918+03
16477	18	-1	910	2020-02-03 13:08:39.029257+03
16478	28	-2	1860	2020-02-03 13:10:18.477786+03
16479	21	-1	960	2020-02-03 13:27:11.401271+03
16480	13	-1	460	2020-02-03 13:42:16.204797+03
16481	8	-1	1920	2020-02-03 13:50:11.130238+03
16482	34	-1	1550	2020-02-03 14:18:37.690508+03
16483	70	-1	760	2020-02-03 15:07:57.642383+03
16484	73	-1	960	2020-02-03 15:25:16.136575+03
16485	14	-1	1350	2020-02-03 15:33:51.70229+03
16486	91	-1	1620	2020-02-03 15:46:59.722084+03
16487	89	-1	1420	2020-02-03 16:16:02.302889+03
16488	88	-2	1270	2020-02-03 16:16:55.321202+03
16489	70	-1	760	2020-02-03 16:31:34.563185+03
16490	59	-1	1030	2020-02-03 16:42:17.929367+03
16491	17	-1	1500	2020-02-03 16:59:31.387715+03
16492	41	-1	830	2020-02-03 17:31:39.158565+03
16493	96	-1	1570	2020-02-03 18:24:32.936738+03
16494	47	-1	1480	2020-02-03 18:31:59.416678+03
16495	67	-1	350	2020-02-03 18:50:50.9396+03
16496	22	-1	1070	2020-02-03 19:10:09.068716+03
16497	54	-2	3470	2020-02-03 19:11:57.544088+03
16498	42	-2	1790	2020-02-03 19:22:33.369534+03
16499	58	-1	2830	2020-02-03 19:31:31.300821+03
16500	54	-2	3470	2020-02-03 19:51:10.500683+03
16501	76	-1	1070	2020-02-03 20:36:47.621672+03
16502	12	-1	1650	2020-02-03 20:47:59.484234+03
16503	91	-1	1620	2020-02-03 21:12:51.895301+03
16504	24	-1	950	2020-02-03 21:16:50.959422+03
16505	30	-1	1140	2020-02-03 21:18:06.039568+03
16506	95	-1	480	2020-02-03 21:27:44.886035+03
16507	16	-2	1380	2020-02-03 21:37:38.43663+03
16508	90	-1	1780	2020-02-03 21:40:11.980399+03
16509	63	-1	1780	2020-02-03 22:19:58.404755+03
16510	4	-1	1420	2020-02-03 22:54:58.963467+03
16511	93	-1	1620	2020-02-03 23:31:57.044283+03
16512	30	-1	1140	2020-02-03 23:45:22.545196+03
16513	6	-1	980	2020-02-04 00:02:53.679347+03
16514	11	-1	830	2020-02-04 00:05:53.148969+03
16515	15	-1	2830	2020-02-04 00:31:58.293445+03
16516	23	-1	4390	2020-02-04 00:46:31.049847+03
16517	66	-1	690	2020-02-04 00:52:33.413117+03
16518	41	-1	830	2020-02-04 01:16:41.222321+03
16519	58	-2	2830	2020-02-04 01:20:41.542317+03
16520	64	-1	970	2020-02-04 01:21:10.361133+03
16521	44	-1	500	2020-02-04 01:26:16.821526+03
16522	3	-1	660	2020-02-04 01:50:30.25428+03
16523	71	-2	1030	2020-02-04 01:53:12.641853+03
16524	1	-2	640	2020-02-04 03:18:46.172394+03
16525	46	-2	1270	2020-02-04 03:19:07.164543+03
16526	29	-1	1940	2020-02-04 03:35:20.829949+03
16527	5	-1	1620	2020-02-04 03:54:30.879414+03
16528	36	-1	630	2020-02-04 04:17:51.071726+03
16529	74	-2	1010	2020-02-04 04:22:12.859734+03
16530	18	-1	910	2020-02-04 04:41:34.029702+03
16531	19	-1	1220	2020-02-04 05:10:10.817492+03
16532	1	-1	640	2020-02-04 05:40:36.762717+03
16533	64	-2	970	2020-02-04 06:01:43.620476+03
16534	25	-2	1100	2020-02-04 06:14:26.969593+03
16535	93	-2	1620	2020-02-04 06:20:38.546821+03
16536	34	-1	1550	2020-02-04 06:33:47.491827+03
16537	86	-1	910	2020-02-04 06:52:10.816495+03
16538	94	-2	1230	2020-02-04 07:10:07.009897+03
16539	7	-2	810	2020-02-04 07:20:57.852055+03
16540	70	-1	760	2020-02-04 08:12:13.811469+03
16541	55	-1	3480	2020-02-04 08:15:25.371516+03
16542	67	-1	350	2020-02-04 08:27:17.449859+03
16543	3	-1	660	2020-02-04 08:35:09.606739+03
16544	5	-2	1620	2020-02-04 08:47:44.498717+03
16545	51	-1	1310	2020-02-04 09:03:45.139825+03
16546	81	-1	1620	2020-02-04 09:06:57.405069+03
16547	84	-1	2700	2020-02-04 09:56:25.739649+03
16548	55	-1	3480	2020-02-04 10:09:27.148967+03
16549	90	30	968	2020-02-04 10:17:34.765053+03
16550	57	-2	1900	2020-02-04 10:26:35.272011+03
16551	76	-1	1070	2020-02-04 10:37:48.973107+03
16552	54	-1	3470	2020-02-04 11:10:40.33106+03
16553	14	-1	1350	2020-02-04 11:19:27.475915+03
16554	45	-1	1590	2020-02-04 11:19:29.088115+03
16555	72	-1	620	2020-02-04 11:25:14.618423+03
16556	81	-1	1620	2020-02-04 12:03:46.013835+03
16557	77	-1	640	2020-02-04 12:37:45.408361+03
16558	43	14	158	2020-02-04 13:27:06.296764+03
16559	69	-1	1100	2020-02-04 13:31:20.575329+03
16560	39	-1	910	2020-02-04 13:33:51.577977+03
16561	61	-2	1510	2020-02-04 14:13:02.38928+03
16562	34	-1	1550	2020-02-04 14:56:58.911528+03
16563	68	-1	490	2020-02-04 15:06:39.060542+03
16564	65	-1	490	2020-02-04 15:09:49.817208+03
16565	69	-1	1100	2020-02-04 15:24:19.638188+03
16566	88	-1	1270	2020-02-04 16:07:13.529121+03
16567	76	-1	1070	2020-02-04 16:07:14.643677+03
16568	54	-1	3470	2020-02-04 16:26:18.789952+03
16569	29	-1	1940	2020-02-04 16:35:12.492627+03
16570	45	-1	1590	2020-02-04 16:43:24.002724+03
16571	52	-1	1090	2020-02-04 16:43:37.776838+03
16572	62	-1	1220	2020-02-04 17:03:03.928699+03
16573	69	-1	1100	2020-02-04 17:06:27.228244+03
16574	53	-1	3120	2020-02-04 17:08:31.237272+03
16575	71	-1	1030	2020-02-04 17:21:26.343606+03
16576	63	-1	1780	2020-02-04 17:56:52.488584+03
16577	34	-1	1550	2020-02-04 18:09:44.63728+03
16578	30	-1	1140	2020-02-04 18:32:49.190694+03
16579	44	-1	500	2020-02-04 18:52:28.81441+03
16580	42	-1	1790	2020-02-04 19:01:21.191978+03
16581	56	-2	2460	2020-02-04 19:02:10.159609+03
16582	80	-1	1120	2020-02-04 19:07:01.055663+03
16583	60	-1	2700	2020-02-04 19:25:09.284332+03
16584	87	-1	2320	2020-02-04 19:30:21.87835+03
16585	76	-1	1070	2020-02-04 19:54:34.890663+03
16586	88	-1	1270	2020-02-04 19:59:26.796866+03
16587	93	-1	1620	2020-02-04 20:12:19.13213+03
16588	58	-1	2830	2020-02-04 20:15:25.944459+03
16589	33	-2	900	2020-02-04 20:19:30.306889+03
16590	25	-2	1100	2020-02-04 20:38:59.936391+03
16591	81	-2	1620	2020-02-04 21:05:20.831008+03
16592	87	-1	2320	2020-02-04 21:42:46.326709+03
16593	83	-1	1230	2020-02-04 21:51:59.615566+03
16594	66	-1	690	2020-02-04 22:22:03.806922+03
16595	10	-1	2080	2020-02-04 22:48:58.561843+03
16596	50	-2	1140	2020-02-04 22:49:12.426597+03
16597	21	23	498	2020-02-04 23:07:15.12653+03
16598	53	-1	3120	2020-02-05 00:06:32.686089+03
16599	86	-1	910	2020-02-05 00:21:15.60118+03
16600	16	-1	1380	2020-02-05 00:30:43.990613+03
16601	14	-1	1350	2020-02-05 00:50:47.392319+03
16602	6	-1	980	2020-02-05 01:36:12.496781+03
16603	46	-1	1270	2020-02-05 01:41:51.992867+03
16604	76	-1	1070	2020-02-05 01:45:59.575747+03
16605	89	-1	1420	2020-02-05 02:22:00.069898+03
16606	74	-1	1010	2020-02-05 02:40:06.798601+03
16607	65	-1	490	2020-02-05 02:51:36.54215+03
16608	37	-1	1290	2020-02-05 02:59:12.129706+03
16609	21	-1	960	2020-02-05 03:01:35.715918+03
16610	77	-1	640	2020-02-05 03:10:29.906393+03
16611	26	-1	390	2020-02-05 03:13:08.50306+03
16612	4	-2	1420	2020-02-05 03:15:55.655569+03
16613	59	-1	1030	2020-02-05 03:38:32.692918+03
16614	33	-1	900	2020-02-05 04:07:24.95793+03
16615	24	-1	950	2020-02-05 04:08:59.552232+03
16616	6	-1	980	2020-02-05 04:29:25.820977+03
16617	7	-1	810	2020-02-05 05:07:08.077058+03
16618	40	-1	1430	2020-02-05 05:27:59.597283+03
16619	58	-1	2830	2020-02-05 05:28:43.724861+03
16620	52	-1	1090	2020-02-05 05:40:35.772487+03
16621	38	-1	1100	2020-02-05 05:46:30.96219+03
16622	64	32	488	2020-02-05 05:56:57.560758+03
16623	39	-1	910	2020-02-05 06:16:35.521073+03
16624	47	-1	1480	2020-02-05 06:32:31.594068+03
16625	3	-1	660	2020-02-05 06:37:28.065198+03
16626	65	-1	490	2020-02-05 06:52:21.948008+03
16627	77	-1	640	2020-02-05 07:07:49.780946+03
16628	45	-1	1590	2020-02-05 07:13:31.072913+03
16629	37	-1	1290	2020-02-05 07:14:23.855068+03
16630	87	-1	2320	2020-02-05 07:26:15.230648+03
16631	81	-1	1620	2020-02-05 07:40:44.462066+03
16632	10	-2	2080	2020-02-05 08:05:59.277739+03
16633	24	-1	950	2020-02-05 08:14:53.54724+03
16634	33	-1	900	2020-02-05 08:19:55.613992+03
16635	31	19	648	2020-02-05 08:40:49.873069+03
16636	8	-1	1920	2020-02-05 08:43:32.016709+03
16637	52	-1	1090	2020-02-05 08:59:01.306503+03
16638	22	-1	1070	2020-02-05 09:03:12.38447+03
16639	77	-1	640	2020-02-05 09:14:44.476505+03
16640	45	-1	1590	2020-02-05 09:38:01.049278+03
16641	85	-1	730	2020-02-05 09:42:45.279945+03
16642	13	-1	460	2020-02-05 09:45:40.407195+03
16643	74	-1	1010	2020-02-05 10:02:15.820953+03
16644	76	-1	1070	2020-02-05 10:16:33.301145+03
16645	60	-2	2700	2020-02-05 10:18:17.609495+03
16646	67	-1	350	2020-02-05 10:30:27.044495+03
16647	5	-2	1620	2020-02-05 10:36:06.638686+03
16648	47	-1	1480	2020-02-05 10:55:53.634266+03
16649	37	-1	1290	2020-02-05 11:01:00.342151+03
16650	82	-1	560	2020-02-05 11:13:58.560082+03
16651	22	-1	1070	2020-02-05 12:26:09.42688+03
16652	12	-1	1650	2020-02-05 12:34:25.250192+03
16653	60	-1	2700	2020-02-05 13:08:39.26383+03
16654	50	-1	1140	2020-02-05 13:26:06.537734+03
16655	3	-1	660	2020-02-05 14:01:21.400793+03
16656	64	-1	970	2020-02-05 14:04:29.48035+03
16657	56	-1	2460	2020-02-05 14:24:20.888925+03
16658	49	-1	970	2020-02-05 14:27:44.82587+03
16659	96	-2	1570	2020-02-05 14:36:12.88822+03
16660	19	-2	1220	2020-02-05 15:13:37.034787+03
16661	96	-1	1570	2020-02-05 15:24:02.192184+03
16662	77	-1	640	2020-02-05 15:34:24.976001+03
16663	41	28	489	2020-02-05 15:50:37.132158+03
16664	9	-1	2090	2020-02-05 15:54:45.645077+03
16665	59	-1	1030	2020-02-05 16:22:26.61991+03
16666	51	-1	1310	2020-02-05 16:23:24.803803+03
16667	19	-2	1220	2020-02-05 16:36:50.073097+03
16668	92	-1	630	2020-02-05 17:10:04.079211+03
16669	13	-1	460	2020-02-05 17:17:41.964907+03
16670	10	-1	2080	2020-02-05 17:56:03.193445+03
16671	55	-2	3480	2020-02-05 17:59:06.248554+03
16672	7	-1	810	2020-02-05 18:03:23.312016+03
16673	47	-1	1480	2020-02-05 18:03:58.539059+03
16674	69	-1	1100	2020-02-05 18:08:53.319467+03
16675	47	-1	1480	2020-02-05 19:11:39.339278+03
16676	66	-1	690	2020-02-05 19:11:53.782196+03
16677	77	41	281	2020-02-05 19:22:24.062196+03
16678	54	-1	3470	2020-02-05 19:27:49.033077+03
16679	83	-2	1230	2020-02-05 19:28:28.837949+03
16680	14	-1	1350	2020-02-05 19:31:35.44242+03
16681	94	-1	1230	2020-02-05 19:37:42.180422+03
16682	45	-1	1590	2020-02-05 19:42:23.877362+03
16683	12	-2	1650	2020-02-05 19:54:14.871326+03
16684	18	-1	910	2020-02-05 19:56:03.451529+03
16685	86	-1	910	2020-02-05 20:52:27.189472+03
16686	5	-2	1620	2020-02-05 20:58:14.303256+03
16687	91	-1	1620	2020-02-05 21:03:54.017267+03
16688	20	-2	830	2020-02-05 21:10:20.227892+03
16689	12	-1	1650	2020-02-05 22:43:20.798533+03
16690	8	-1	1920	2020-02-05 22:59:34.561408+03
16691	56	-1	2460	2020-02-05 23:27:17.671557+03
16692	87	-2	2320	2020-02-05 23:43:01.191169+03
16693	30	-1	1140	2020-02-05 23:47:53.116136+03
16694	54	-1	3470	2020-02-05 23:55:52.975916+03
16695	26	-1	390	2020-02-06 00:41:18.239675+03
16696	2	-2	470	2020-02-06 01:34:53.858743+03
16697	27	-1	880	2020-02-06 02:51:10.999186+03
16698	22	-1	1070	2020-02-06 03:24:47.933741+03
16699	44	-1	500	2020-02-06 03:28:54.898995+03
16700	96	-2	1570	2020-02-06 03:43:15.845038+03
16701	86	-2	910	2020-02-06 04:10:51.332613+03
16702	39	-1	910	2020-02-06 04:11:09.76551+03
16703	14	-1	1350	2020-02-06 04:12:02.71616+03
16704	79	-1	550	2020-02-06 04:38:33.45397+03
16705	8	-1	1920	2020-02-06 05:02:46.874062+03
16706	80	-1	1120	2020-02-06 05:31:38.353356+03
16707	38	-1	1100	2020-02-06 05:37:27.8904+03
16708	14	-1	1350	2020-02-06 06:00:45.580952+03
16709	86	-1	910	2020-02-06 06:52:51.566337+03
16710	66	-1	690	2020-02-06 07:01:05.889875+03
16711	35	-1	670	2020-02-06 07:09:40.687121+03
16712	75	-2	830	2020-02-06 07:12:48.598143+03
16713	55	-1	3480	2020-02-06 07:13:47.332606+03
16714	42	-2	1790	2020-02-06 08:23:54.291218+03
16715	14	-1	1350	2020-02-06 08:28:39.133108+03
16716	32	-1	710	2020-02-06 08:54:55.577468+03
16717	62	-1	1220	2020-02-06 08:56:13.180954+03
16718	20	-1	830	2020-02-06 08:56:59.362877+03
16719	68	-3	490	2020-02-06 09:34:46.713383+03
16720	39	22	530	2020-02-06 10:21:59.913509+03
16721	49	-1	970	2020-02-06 10:36:15.337399+03
16722	8	39	770	2020-02-06 11:32:36.27158+03
16723	50	-1	1140	2020-02-06 12:03:43.18298+03
16724	17	-1	1500	2020-02-06 12:20:21.454768+03
16725	6	-1	980	2020-02-06 12:29:21.59407+03
16726	61	-1	1510	2020-02-06 12:33:23.456491+03
16727	20	-1	830	2020-02-06 12:42:17.635719+03
16728	77	-1	640	2020-02-06 12:51:11.05493+03
16729	45	-1	1590	2020-02-06 12:51:59.550239+03
16730	89	-1	1420	2020-02-06 13:02:27.215286+03
16731	77	-2	640	2020-02-06 13:15:20.210128+03
16732	23	-1	4390	2020-02-06 13:37:32.136087+03
16733	83	-1	1230	2020-02-06 13:38:27.005067+03
16734	18	-1	910	2020-02-06 14:15:43.742149+03
16735	80	-1	1120	2020-02-06 14:35:15.210957+03
16736	19	-1	1220	2020-02-06 14:42:57.2079+03
16737	81	-1	1620	2020-02-06 15:01:46.14795+03
16738	18	-1	910	2020-02-06 15:08:02.805725+03
16739	18	-1	910	2020-02-06 15:29:52.59264+03
16740	39	-1	910	2020-02-06 15:32:09.732143+03
16741	30	-1	1140	2020-02-06 15:33:51.017667+03
16742	52	-2	1090	2020-02-06 16:09:17.46375+03
16743	96	-1	1570	2020-02-06 16:49:55.221276+03
16744	42	-2	1790	2020-02-06 16:50:04.877515+03
16745	23	-1	4390	2020-02-06 17:02:37.042039+03
16746	65	-1	490	2020-02-06 17:11:21.072292+03
16747	13	-1	460	2020-02-06 17:39:04.503618+03
16748	87	-1	2320	2020-02-06 18:12:31.049929+03
16749	93	-1	1620	2020-02-06 18:48:01.313632+03
16750	56	-1	2460	2020-02-06 19:08:43.02263+03
16751	10	-1	2080	2020-02-06 19:25:02.298321+03
16752	18	-1	910	2020-02-06 19:28:36.648967+03
16753	74	-1	1010	2020-02-06 19:39:08.161855+03
16754	5	-1	1620	2020-02-06 20:14:31.158306+03
16755	90	-1	1780	2020-02-06 20:50:54.342213+03
16756	75	-1	830	2020-02-06 20:58:18.654139+03
16757	22	-1	1070	2020-02-06 20:59:49.482485+03
16758	11	-2	830	2020-02-06 21:36:07.626574+03
16759	55	-1	3480	2020-02-06 22:11:31.259121+03
16760	17	-1	1500	2020-02-06 22:14:23.428922+03
16761	4	-1	1420	2020-02-06 22:20:05.920121+03
16762	14	-1	1350	2020-02-06 22:21:26.28002+03
16763	91	-1	1620	2020-02-06 23:24:01.192573+03
16764	33	-2	900	2020-02-06 23:29:07.338041+03
16765	57	-2	1900	2020-02-06 23:29:20.9427+03
16766	58	-1	2830	2020-02-07 00:03:51.327417+03
16767	50	-2	1140	2020-02-07 00:44:10.467181+03
16768	88	-1	1270	2020-02-07 00:44:11.819424+03
16769	3	-1	660	2020-02-07 00:47:30.206682+03
16770	96	-1	1570	2020-02-07 01:25:27.964271+03
16771	69	-1	1100	2020-02-07 01:36:10.57934+03
16772	88	-1	1270	2020-02-07 01:47:42.762952+03
16773	41	-2	830	2020-02-07 01:49:08.164211+03
16774	78	-1	900	2020-02-07 02:14:15.085464+03
16775	90	-1	1780	2020-02-07 02:46:22.376263+03
16776	83	-1	1230	2020-02-07 03:00:11.59793+03
16777	92	-1	630	2020-02-07 03:06:29.59822+03
16778	89	-1	1420	2020-02-07 03:10:58.853057+03
16779	36	-2	630	2020-02-07 03:19:42.177809+03
16780	47	-1	1480	2020-02-07 03:26:20.988099+03
16781	69	-1	1100	2020-02-07 03:39:58.675085+03
16782	46	-1	1270	2020-02-07 03:51:18.092644+03
16783	58	-1	2830	2020-02-07 04:40:23.499652+03
16784	96	-2	1570	2020-02-07 04:47:03.940162+03
16785	19	-1	1220	2020-02-07 05:34:36.232338+03
16786	93	30	790	2020-02-07 05:50:08.198642+03
16787	33	-2	900	2020-02-07 05:54:47.890125+03
16788	29	-2	1940	2020-02-07 05:55:00.995227+03
16789	49	-1	970	2020-02-07 06:35:22.081072+03
16790	38	-1	1100	2020-02-07 06:39:22.793851+03
16791	32	-2	710	2020-02-07 06:40:54.808133+03
16792	59	-1	1030	2020-02-07 06:42:02.39317+03
16793	36	-2	630	2020-02-07 06:42:31.375652+03
16794	70	-1	760	2020-02-07 06:50:21.517253+03
16795	33	-2	900	2020-02-07 07:25:41.244526+03
16796	49	-2	970	2020-02-07 07:41:04.907956+03
16797	90	-2	1780	2020-02-07 07:42:50.413954+03
16798	53	-1	3120	2020-02-07 08:01:24.471425+03
16799	33	-1	900	2020-02-07 08:03:59.118976+03
16800	80	-1	1120	2020-02-07 08:24:22.797407+03
16801	76	-1	1070	2020-02-07 09:18:11.156371+03
16802	37	-1	1290	2020-02-07 09:26:46.573914+03
16803	70	-1	760	2020-02-07 09:47:21.835503+03
16804	34	-1	1550	2020-02-07 09:58:36.529715+03
16805	75	33	394	2020-02-07 10:01:02.059727+03
16806	82	-2	560	2020-02-07 10:04:48.251561+03
16807	23	-1	4390	2020-02-07 10:17:08.701694+03
16808	55	-2	3480	2020-02-07 10:19:34.715452+03
16809	35	-1	670	2020-02-07 10:25:20.422766+03
16810	8	-1	1920	2020-02-07 10:41:41.587486+03
16811	13	-2	460	2020-02-07 10:41:48.987281+03
16812	56	-1	2460	2020-02-07 10:47:40.645796+03
16813	94	-1	1230	2020-02-07 10:55:58.805259+03
16814	81	-2	1620	2020-02-07 10:58:37.429253+03
16815	96	-1	1570	2020-02-07 11:57:13.870187+03
16816	37	-1	1290	2020-02-07 12:00:06.647211+03
16817	95	-1	480	2020-02-07 12:02:27.548202+03
16818	93	-1	1620	2020-02-07 12:20:40.367724+03
16819	73	-2	960	2020-02-07 12:28:34.675167+03
16820	71	-2	1030	2020-02-07 12:35:45.61145+03
16821	96	35	647	2020-02-07 12:36:51.996668+03
16822	17	-1	1500	2020-02-07 12:38:25.918017+03
16823	57	-1	1900	2020-02-07 12:59:17.599424+03
16824	5	-1	1620	2020-02-07 13:23:01.323832+03
16825	3	-1	660	2020-02-07 13:23:21.42663+03
16826	39	-1	910	2020-02-07 13:37:22.532476+03
16827	78	20	506	2020-02-07 14:04:58.220369+03
16828	35	-2	670	2020-02-07 14:42:42.181246+03
16829	6	-1	980	2020-02-07 14:54:17.579091+03
16830	1	-1	640	2020-02-07 15:03:54.960468+03
16831	33	-2	900	2020-02-07 15:07:03.799044+03
16832	35	-3	670	2020-02-07 15:19:43.04038+03
16833	43	-2	380	2020-02-07 15:23:51.622873+03
16834	89	-1	1420	2020-02-07 15:41:54.466224+03
16835	87	-2	2320	2020-02-07 15:48:09.580863+03
16836	79	-1	550	2020-02-07 15:54:40.993275+03
16837	47	-1	1480	2020-02-07 16:33:04.382739+03
16838	2	-2	470	2020-02-07 16:33:33.70617+03
16839	59	-1	1030	2020-02-07 17:08:10.857043+03
16840	39	-1	910	2020-02-07 17:16:20.542912+03
16841	78	-1	900	2020-02-07 17:30:49.867735+03
16842	82	-1	560	2020-02-07 18:17:43.301502+03
16843	18	-1	910	2020-02-07 18:33:03.799385+03
16844	70	-1	760	2020-02-07 19:06:41.088803+03
16845	14	-2	1350	2020-02-07 19:10:43.928736+03
16846	39	-1	910	2020-02-07 19:23:50.540501+03
16847	63	-1	1780	2020-02-07 19:58:54.309244+03
16848	90	-1	1780	2020-02-07 19:59:52.379087+03
16849	9	-1	2090	2020-02-07 20:35:42.660849+03
16850	6	-2	980	2020-02-07 21:15:57.584787+03
16851	90	-1	1780	2020-02-07 21:29:15.705514+03
16852	75	-2	830	2020-02-07 21:51:05.953419+03
16853	86	-1	910	2020-02-07 21:53:51.558461+03
16854	24	-1	950	2020-02-07 22:01:17.110671+03
16855	21	-1	960	2020-02-07 22:03:22.484597+03
16856	83	-1	1230	2020-02-07 22:03:36.509128+03
16857	1	-1	640	2020-02-07 22:04:07.404281+03
16858	80	-1	1120	2020-02-07 22:15:10.130261+03
16859	27	-1	880	2020-02-07 23:10:19.556343+03
16860	87	-1	2320	2020-02-07 23:39:02.509554+03
16861	5	-1	1620	2020-02-08 00:09:55.712577+03
16862	84	-1	2700	2020-02-08 00:10:20.008691+03
16863	29	-1	1940	2020-02-08 00:28:57.740757+03
16864	56	-1	2460	2020-02-08 00:49:03.279629+03
16865	52	-1	1090	2020-02-08 00:52:23.572571+03
16866	59	30	424	2020-02-08 00:56:51.176391+03
16867	18	-1	910	2020-02-08 01:05:22.261003+03
16868	86	-1	910	2020-02-08 01:17:24.215223+03
16869	73	-1	960	2020-02-08 02:09:47.042307+03
16870	86	-3	910	2020-02-08 02:14:37.261276+03
16871	20	-1	830	2020-02-08 02:20:11.473419+03
16872	81	-2	1620	2020-02-08 02:31:48.722953+03
16873	32	28	310	2020-02-08 02:42:41.903019+03
16874	36	-1	630	2020-02-08 03:06:57.001589+03
16875	54	-2	3470	2020-02-08 03:08:12.772843+03
16876	84	-1	2700	2020-02-08 03:09:36.056811+03
16877	14	-1	1350	2020-02-08 03:09:49.192726+03
16878	40	-1	1430	2020-02-08 03:15:58.108727+03
16879	1	-1	640	2020-02-08 03:37:11.746489+03
16880	31	-2	1190	2020-02-08 03:47:37.819376+03
16881	46	-1	1270	2020-02-08 04:18:43.144151+03
16882	7	-2	810	2020-02-08 05:02:26.1286+03
16883	71	-2	1030	2020-02-08 05:05:12.222408+03
16884	22	-1	1070	2020-02-08 05:07:18.527503+03
16885	38	-1	1100	2020-02-08 05:08:43.10994+03
16886	35	-2	670	2020-02-08 05:26:01.608842+03
16887	84	-2	2700	2020-02-08 06:09:44.200924+03
16888	49	-1	970	2020-02-08 06:13:48.156649+03
16889	18	-1	910	2020-02-08 06:15:12.47321+03
16890	35	-1	670	2020-02-08 06:25:12.310816+03
16891	4	-1	1420	2020-02-08 07:07:01.503764+03
16892	39	-1	910	2020-02-08 07:12:43.726159+03
16893	33	-1	900	2020-02-08 07:27:04.217268+03
16894	12	-2	1650	2020-02-08 07:44:09.941797+03
16895	24	-1	950	2020-02-08 07:53:09.345793+03
16896	40	-2	1430	2020-02-08 08:10:07.105238+03
16897	74	-1	1010	2020-02-08 08:11:37.21218+03
16898	68	-1	490	2020-02-08 08:22:46.61555+03
16899	83	-1	1230	2020-02-08 08:37:32.681262+03
16900	77	-2	640	2020-02-08 09:54:32.795467+03
16901	46	-1	1270	2020-02-08 10:14:10.395609+03
16902	19	-1	1220	2020-02-08 10:17:01.177991+03
16903	14	-1	1350	2020-02-08 10:20:54.308601+03
16904	57	-2	1900	2020-02-08 10:26:12.951184+03
16905	37	-1	1290	2020-02-08 10:35:24.966654+03
16906	70	-2	760	2020-02-08 10:36:50.810272+03
16907	19	-1	1220	2020-02-08 10:36:51.762434+03
16908	26	19	174	2020-02-08 10:40:56.691988+03
16909	82	-1	560	2020-02-08 10:52:37.041859+03
16910	21	-1	960	2020-02-08 11:06:01.641023+03
16911	31	-1	1190	2020-02-08 11:13:01.408512+03
16912	11	18	400	2020-02-08 11:30:44.664504+03
16913	77	-1	640	2020-02-08 11:47:13.983922+03
16914	68	-1	490	2020-02-08 12:23:37.932327+03
16915	84	-1	2700	2020-02-08 12:44:54.300292+03
16916	81	-2	1620	2020-02-08 13:02:54.672157+03
16917	67	-1	350	2020-02-08 13:44:43.079261+03
16918	34	-1	1550	2020-02-08 13:45:55.478154+03
16919	56	-1	2460	2020-02-08 13:56:21.60952+03
16920	19	-1	1220	2020-02-08 14:12:53.046355+03
16921	18	-1	910	2020-02-08 14:24:40.609714+03
16922	69	-1	1100	2020-02-08 14:25:11.640812+03
16923	51	-1	1310	2020-02-08 14:45:56.953462+03
16924	73	-1	960	2020-02-08 14:57:05.487643+03
16925	89	-1	1420	2020-02-08 15:12:40.453946+03
16926	63	-1	1780	2020-02-08 15:30:50.014873+03
16927	47	-1	1480	2020-02-08 15:42:53.027092+03
16928	56	-1	2460	2020-02-08 15:44:53.429173+03
16929	86	-1	910	2020-02-08 16:04:01.45674+03
16930	5	-1	1620	2020-02-08 16:26:16.708003+03
16931	3	-1	660	2020-02-08 16:28:53.892919+03
16932	76	-1	1070	2020-02-08 16:49:08.767582+03
16933	22	-1	1070	2020-02-08 17:14:54.123715+03
16934	90	-1	1780	2020-02-08 17:23:15.55225+03
16935	40	-1	1430	2020-02-08 17:37:52.450901+03
16936	12	-2	1650	2020-02-08 17:49:16.668537+03
16937	65	-1	490	2020-02-08 18:40:28.187061+03
16938	89	-1	1420	2020-02-08 18:46:39.702484+03
16939	83	-1	1230	2020-02-08 19:29:25.60321+03
16940	22	-1	1070	2020-02-08 19:45:16.665457+03
16941	66	-1	690	2020-02-08 19:59:28.177958+03
16942	51	28	738	2020-02-08 20:04:15.521495+03
16943	46	-1	1270	2020-02-08 20:12:00.412448+03
16944	32	-2	710	2020-02-08 20:33:51.914692+03
16945	64	-1	970	2020-02-08 20:41:32.033628+03
16946	37	-1	1290	2020-02-08 21:19:41.741925+03
16947	48	-1	640	2020-02-08 21:29:25.751376+03
16948	30	-2	1140	2020-02-08 21:34:31.446902+03
16949	13	-1	460	2020-02-08 21:35:18.996911+03
16950	14	-1	1350	2020-02-08 21:47:02.388598+03
16951	84	-2	2700	2020-02-08 21:48:41.25129+03
16952	61	-1	1510	2020-02-08 22:00:22.977736+03
16953	23	-2	4390	2020-02-08 22:06:30.99805+03
16954	45	-1	1590	2020-02-08 22:17:53.929855+03
16955	77	-1	640	2020-02-08 22:28:42.682162+03
16956	92	-1	630	2020-02-08 22:56:42.174815+03
16957	5	-1	1620	2020-02-08 23:06:25.824956+03
16958	90	-1	1780	2020-02-08 23:17:54.579788+03
16959	60	-1	2700	2020-02-08 23:33:40.028485+03
16960	27	-1	880	2020-02-08 23:55:39.345465+03
16961	87	-1	2320	2020-02-08 23:57:14.357743+03
16962	26	-2	390	2020-02-09 00:00:01.035437+03
16963	22	-1	1070	2020-02-09 00:02:18.945802+03
16964	40	-2	1430	2020-02-09 00:03:47.441988+03
16965	25	-1	1100	2020-02-09 00:29:03.188398+03
16966	21	-3	960	2020-02-09 01:00:38.019437+03
16967	34	-1	1550	2020-02-09 01:24:25.8339+03
16968	28	15	1005	2020-02-09 02:13:04.304624+03
16969	29	-1	1940	2020-02-09 02:19:50.606542+03
16970	35	-1	670	2020-02-09 02:26:36.386602+03
16971	49	-1	970	2020-02-09 02:32:51.330072+03
16972	15	-1	2830	2020-02-09 02:44:40.875528+03
16973	53	-1	3120	2020-02-09 02:48:34.893784+03
16974	92	-1	630	2020-02-09 03:03:56.499277+03
16975	46	-1	1270	2020-02-09 03:15:06.194628+03
16976	35	-2	670	2020-02-09 03:30:52.577807+03
16977	50	-2	1140	2020-02-09 03:41:16.311393+03
16978	88	-1	1270	2020-02-09 03:56:16.46769+03
16979	72	-1	620	2020-02-09 04:16:13.239247+03
16980	86	-1	910	2020-02-09 04:22:30.171627+03
16981	18	-1	910	2020-02-09 04:33:38.803983+03
16982	7	-1	810	2020-02-09 04:38:30.930433+03
16983	33	-1	900	2020-02-09 04:57:23.253594+03
16984	14	-1	1350	2020-02-09 05:12:10.267112+03
16985	3	22	282	2020-02-09 05:25:32.964847+03
16986	85	-1	730	2020-02-09 05:34:09.590364+03
16987	91	-1	1620	2020-02-09 05:43:12.004262+03
16988	13	-1	460	2020-02-09 05:44:30.627425+03
16989	86	-1	910	2020-02-09 06:12:08.870816+03
16990	84	-3	2700	2020-02-09 06:21:32.466781+03
16991	37	-1	1290	2020-02-09 06:35:17.604211+03
16992	91	-1	1620	2020-02-09 07:12:03.521933+03
16993	67	-3	350	2020-02-09 07:20:01.622898+03
16994	63	-1	1780	2020-02-09 07:21:35.752016+03
16995	82	-1	560	2020-02-09 07:31:11.124971+03
16996	64	-2	970	2020-02-09 07:40:56.994479+03
16997	28	-1	1860	2020-02-09 08:40:13.672824+03
16998	34	-1	1550	2020-02-09 08:40:46.766321+03
16999	7	-1	810	2020-02-09 08:56:57.580501+03
17000	63	-1	1780	2020-02-09 09:01:13.603815+03
17001	14	30	634	2020-02-09 09:15:31.57289+03
17002	27	-1	880	2020-02-09 09:30:37.685316+03
17003	8	-1	1920	2020-02-09 09:31:06.295116+03
17004	54	31	1608	2020-02-09 09:37:00.168631+03
17005	29	-1	1940	2020-02-09 10:09:46.872736+03
17006	93	-1	1620	2020-02-09 10:25:46.178099+03
17007	68	-1	490	2020-02-09 10:56:00.016192+03
17008	71	-1	1030	2020-02-09 10:57:22.762142+03
17009	83	-1	1230	2020-02-09 10:58:45.556059+03
17010	96	-1	1570	2020-02-09 11:36:23.021954+03
17011	46	-2	1270	2020-02-09 11:41:25.00311+03
17012	15	-1	2830	2020-02-09 11:45:33.076979+03
17013	32	-1	710	2020-02-09 11:50:08.927216+03
17014	22	-1	1070	2020-02-09 11:54:29.264186+03
17015	74	-1	1010	2020-02-09 12:08:29.036346+03
17016	91	-1	1620	2020-02-09 12:28:46.240553+03
17017	18	-1	910	2020-02-09 12:52:12.921093+03
17018	18	-1	910	2020-02-09 13:07:59.742135+03
17019	6	-1	980	2020-02-09 13:18:43.440328+03
17020	9	-1	2090	2020-02-09 13:37:33.189189+03
17021	36	-1	630	2020-02-09 14:24:20.545067+03
17022	1	23	274	2020-02-09 14:44:06.061703+03
17023	3	-1	660	2020-02-09 15:14:26.490792+03
17024	2	16	239	2020-02-09 15:15:59.398152+03
17025	93	-1	1620	2020-02-09 15:18:28.383106+03
17026	7	-2	810	2020-02-09 15:54:47.141136+03
17027	36	-1	630	2020-02-09 15:55:17.656197+03
17028	3	-2	660	2020-02-09 16:14:28.242319+03
17029	46	-1	1270	2020-02-09 16:28:54.68427+03
17030	44	-1	500	2020-02-09 16:54:57.528406+03
17031	15	-1	2830	2020-02-09 16:57:20.975548+03
17032	37	-1	1290	2020-02-09 17:07:47.151686+03
17033	56	-1	2460	2020-02-09 17:18:01.659347+03
17034	49	-1	970	2020-02-09 17:23:48.449538+03
17035	9	-2	2090	2020-02-09 17:46:21.416214+03
17036	14	-2	1350	2020-02-09 17:48:41.05399+03
17037	24	-1	950	2020-02-09 17:50:09.398575+03
17038	56	-1	2460	2020-02-09 18:08:28.19099+03
17039	47	-1	1480	2020-02-09 18:10:03.930256+03
17040	83	-1	1230	2020-02-09 18:17:51.919865+03
17041	7	-2	810	2020-02-09 18:52:05.991973+03
17042	32	-1	710	2020-02-09 18:57:16.94533+03
17043	70	-1	760	2020-02-09 18:59:22.627319+03
17044	32	-1	710	2020-02-09 19:18:43.763098+03
17045	85	-1	730	2020-02-09 19:19:34.722015+03
17046	8	-1	1920	2020-02-09 19:20:38.211813+03
17047	45	-1	1590	2020-02-09 19:22:18.465637+03
17048	37	-1	1290	2020-02-09 19:54:24.429225+03
17049	88	-1	1270	2020-02-09 20:03:53.626275+03
17050	67	-1	350	2020-02-09 20:43:01.424339+03
17051	79	-1	550	2020-02-09 20:58:29.471298+03
17052	10	-1	2080	2020-02-09 21:16:56.613165+03
17053	43	-1	380	2020-02-09 21:18:07.616329+03
17054	39	-1	910	2020-02-09 21:20:08.228238+03
17055	56	-1	2460	2020-02-09 22:11:24.071969+03
17056	47	-1	1480	2020-02-09 22:15:59.953047+03
17057	86	-1	910	2020-02-09 22:36:44.512929+03
17058	37	25	742	2020-02-09 22:37:05.069977+03
17059	12	-1	1650	2020-02-09 22:49:17.411615+03
17060	56	-1	2460	2020-02-09 23:02:51.238398+03
17061	30	-1	1140	2020-02-09 23:14:04.863835+03
17062	69	-1	1100	2020-02-09 23:23:57.479126+03
17063	77	-1	640	2020-02-09 23:24:38.481683+03
17064	6	-1	980	2020-02-09 23:35:31.583274+03
17065	23	-1	4390	2020-02-10 00:16:18.590287+03
17066	27	-1	880	2020-02-10 00:23:17.681435+03
17067	70	-1	760	2020-02-10 00:26:26.6686+03
17068	54	-1	3470	2020-02-10 00:31:24.903326+03
17069	83	-1	1230	2020-02-10 00:44:52.470782+03
17070	92	-1	630	2020-02-10 00:55:00.484117+03
17071	74	23	603	2020-02-10 01:09:29.953681+03
17072	56	-1	2460	2020-02-10 01:15:26.913823+03
17073	65	-1	490	2020-02-10 01:54:42.408263+03
17074	67	-1	350	2020-02-10 02:18:06.413364+03
17075	21	-1	960	2020-02-10 02:21:42.06582+03
17076	90	-1	1780	2020-02-10 02:27:20.624262+03
17077	77	-1	640	2020-02-10 02:34:11.585483+03
17078	23	-1	4390	2020-02-10 02:34:18.64649+03
17079	95	-1	480	2020-02-10 02:56:31.92128+03
17080	32	-1	710	2020-02-10 03:14:34.559917+03
17081	96	-1	1570	2020-02-10 03:16:42.795761+03
17082	44	-1	500	2020-02-10 03:42:30.963796+03
17083	25	-2	1100	2020-02-10 04:01:15.383567+03
17084	87	-1	2320	2020-02-10 04:14:46.452274+03
17085	79	-2	550	2020-02-10 04:36:58.82095+03
17086	67	-1	350	2020-02-10 04:38:56.62294+03
17087	55	-1	3480	2020-02-10 04:49:05.759569+03
17088	8	-1	1920	2020-02-10 05:09:39.374918+03
17089	61	-2	1510	2020-02-10 05:27:04.193685+03
17090	87	-2	2320	2020-02-10 05:38:50.060558+03
17091	82	-1	560	2020-02-10 05:38:57.049919+03
17092	9	-1	2090	2020-02-10 05:50:49.522371+03
17093	69	-1	1100	2020-02-10 06:24:59.544424+03
17094	57	-1	1900	2020-02-10 06:26:35.166696+03
17095	58	-1	2830	2020-02-10 06:51:55.597575+03
17096	22	-2	1070	2020-02-10 07:07:52.268693+03
17097	92	-1	630	2020-02-10 07:39:55.823728+03
17098	86	-1	910	2020-02-10 08:18:34.824433+03
17099	48	-1	640	2020-02-10 08:25:30.67221+03
17100	23	-1	4390	2020-02-10 08:47:52.052373+03
17101	57	-1	1900	2020-02-10 09:01:10.116906+03
17102	56	-2	2460	2020-02-10 09:44:13.68844+03
17103	86	-1	910	2020-02-10 10:03:35.842431+03
17104	28	-1	1860	2020-02-10 10:21:07.397748+03
17105	56	-1	2460	2020-02-10 10:27:28.44465+03
17106	20	-1	830	2020-02-10 10:34:56.707819+03
17107	32	-1	710	2020-02-10 10:38:55.102765+03
17108	50	-1	1140	2020-02-10 10:42:01.79849+03
17109	95	-1	480	2020-02-10 10:55:27.122733+03
17110	89	-2	1420	2020-02-10 11:05:10.904815+03
17111	54	-1	3470	2020-02-10 11:17:51.702033+03
17112	49	-1	970	2020-02-10 11:25:13.874475+03
17113	10	-1	2080	2020-02-10 11:32:12.777311+03
17114	57	-1	1900	2020-02-10 12:04:19.456529+03
17115	76	-1	1070	2020-02-10 12:11:27.941604+03
17116	47	-2	1480	2020-02-10 12:22:29.062341+03
17117	77	-2	640	2020-02-10 12:43:28.516642+03
17118	14	-1	1350	2020-02-10 13:43:54.836764+03
17119	22	-1	1070	2020-02-10 13:48:56.183128+03
17120	3	-1	660	2020-02-10 13:49:12.328713+03
17121	12	39	948	2020-02-10 14:28:06.486564+03
17122	15	-1	2830	2020-02-10 14:36:24.712261+03
17123	36	-1	630	2020-02-10 14:49:17.590409+03
17124	1	-1	640	2020-02-10 14:57:46.999963+03
17125	82	-1	560	2020-02-10 16:19:09.606907+03
17126	60	-2	2700	2020-02-10 16:31:26.042781+03
17127	50	-1	1140	2020-02-10 16:41:25.985605+03
17128	79	-1	550	2020-02-10 16:51:52.724629+03
17129	61	28	678	2020-02-10 17:12:30.775582+03
17130	2	-1	470	2020-02-10 17:58:55.34727+03
17131	9	-1	2090	2020-02-10 18:06:51.468466+03
17132	50	-1	1140	2020-02-10 19:28:21.765822+03
17133	80	-1	1120	2020-02-10 19:48:24.921668+03
17134	93	-1	1620	2020-02-10 20:05:03.814421+03
17135	63	-1	1780	2020-02-10 20:05:35.605707+03
17136	65	-1	490	2020-02-10 20:07:23.173408+03
17137	60	-1	2700	2020-02-10 20:26:36.931447+03
17138	96	-1	1570	2020-02-10 20:27:33.137913+03
17139	89	-2	1420	2020-02-10 20:35:34.580246+03
17140	46	-1	1270	2020-02-10 20:58:03.450553+03
17141	14	-1	1350	2020-02-10 20:58:31.656531+03
17142	51	-1	1310	2020-02-10 21:01:49.492334+03
17143	78	-3	900	2020-02-10 22:04:18.049769+03
17144	39	-1	910	2020-02-10 22:06:36.269094+03
17145	19	-2	1220	2020-02-10 22:16:14.847415+03
17146	47	-1	1480	2020-02-10 22:19:11.272545+03
17147	43	-1	380	2020-02-10 22:24:26.13436+03
17148	58	-1	2830	2020-02-10 22:39:51.193036+03
17149	59	-1	1030	2020-02-10 22:41:11.78062+03
17150	89	-1	1420	2020-02-10 22:41:59.032715+03
17151	64	-2	970	2020-02-10 22:43:42.61613+03
17152	63	-1	1780	2020-02-10 22:50:00.337105+03
17153	42	-1	1790	2020-02-10 23:04:40.16599+03
17154	64	-1	970	2020-02-10 23:40:08.375471+03
17155	25	-1	1100	2020-02-11 00:01:59.623586+03
17156	90	-1	1780	2020-02-11 00:27:13.563212+03
17157	63	27	849	2020-02-11 00:42:08.859025+03
17158	12	-1	1650	2020-02-11 02:21:11.089494+03
17159	86	-1	910	2020-02-11 02:28:57.577646+03
17160	59	-1	1030	2020-02-11 02:37:55.551821+03
17161	51	-2	1310	2020-02-11 02:58:06.408517+03
17162	67	-1	350	2020-02-11 02:58:57.989918+03
17163	9	-2	2090	2020-02-11 03:00:21.415899+03
17164	37	-2	1290	2020-02-11 03:07:09.878006+03
17165	91	23	795	2020-02-11 03:24:00.689448+03
17166	8	-2	1920	2020-02-11 03:32:05.432817+03
17167	19	-1	1220	2020-02-11 03:32:43.634743+03
17168	84	-1	2700	2020-02-11 04:12:03.688417+03
17169	80	-1	1120	2020-02-11 04:38:55.281807+03
17170	3	-1	660	2020-02-11 05:36:13.143952+03
17171	84	-1	2700	2020-02-11 05:49:18.665051+03
17172	17	-1	1500	2020-02-11 05:49:35.054301+03
17173	47	-1	1480	2020-02-11 05:51:33.369204+03
17174	1	-1	640	2020-02-11 05:59:01.139928+03
17175	29	-1	1940	2020-02-11 06:05:45.752882+03
17176	84	-1	2700	2020-02-11 06:13:20.699948+03
17177	79	-1	550	2020-02-11 06:21:37.529321+03
17178	51	-1	1310	2020-02-11 06:57:47.3388+03
17179	40	-1	1430	2020-02-11 07:15:09.0076+03
17180	21	-1	960	2020-02-11 07:53:13.137163+03
17181	5	-1	1620	2020-02-11 07:53:27.744989+03
17182	23	27	2030	2020-02-11 08:01:40.649538+03
17183	73	-1	960	2020-02-11 08:05:14.251964+03
17184	87	-1	2320	2020-02-11 08:22:39.177929+03
17185	40	-1	1430	2020-02-11 08:38:58.228197+03
17186	74	-1	1010	2020-02-11 08:45:41.218133+03
17187	68	-1	490	2020-02-11 08:55:24.442319+03
17188	5	-1	1620	2020-02-11 09:09:03.947489+03
17189	70	-1	760	2020-02-11 09:23:35.662599+03
17190	68	-1	490	2020-02-11 09:31:00.480651+03
17191	79	-1	550	2020-02-11 09:33:19.650656+03
17192	71	-1	1030	2020-02-11 09:34:46.015095+03
17193	74	-1	1010	2020-02-11 10:06:26.008839+03
17194	38	-2	1100	2020-02-11 10:57:55.650093+03
17195	47	-1	1480	2020-02-11 11:00:10.407971+03
17196	18	-1	910	2020-02-11 11:04:20.288961+03
17197	5	-1	1620	2020-02-11 11:34:38.892917+03
17198	11	-1	830	2020-02-11 11:35:37.856303+03
17199	34	-2	1550	2020-02-11 11:36:19.855435+03
17200	76	-1	1070	2020-02-11 11:37:42.306121+03
17201	48	-1	640	2020-02-11 11:46:22.992264+03
17202	31	-1	1190	2020-02-11 11:58:09.757464+03
17203	4	-2	1420	2020-02-11 12:19:58.156696+03
17204	41	-1	830	2020-02-11 12:45:29.444322+03
17205	16	-1	1380	2020-02-11 12:48:42.482298+03
17206	86	-1	910	2020-02-11 12:51:35.694271+03
17207	28	-1	1860	2020-02-11 13:42:07.038794+03
17208	18	-1	910	2020-02-11 13:58:33.295785+03
17209	40	-2	1430	2020-02-11 14:03:44.438856+03
17210	90	-1	1780	2020-02-11 14:06:22.324218+03
17211	63	-1	1780	2020-02-11 14:06:30.749668+03
17212	47	-1	1480	2020-02-11 14:17:16.092617+03
17213	95	-1	480	2020-02-11 15:09:31.068191+03
17214	48	-1	640	2020-02-11 15:10:11.036876+03
17215	2	-2	470	2020-02-11 15:19:10.258466+03
17216	67	-1	350	2020-02-11 15:29:09.911773+03
17217	17	-1	1500	2020-02-11 15:47:17.740023+03
17218	30	-1	1140	2020-02-11 15:51:54.462194+03
17219	4	-1	1420	2020-02-11 15:52:25.714718+03
17220	49	-1	970	2020-02-11 15:55:47.332547+03
17221	1	-1	640	2020-02-11 16:18:45.422848+03
17222	64	-1	970	2020-02-11 16:20:15.916611+03
17223	25	-1	1100	2020-02-11 16:42:58.538196+03
17224	28	-2	1860	2020-02-11 17:00:44.867549+03
17225	3	-1	660	2020-02-11 17:01:20.304537+03
17226	64	-1	970	2020-02-11 17:03:19.275338+03
17227	41	-1	830	2020-02-11 17:19:41.385025+03
17228	22	-1	1070	2020-02-11 17:29:57.409135+03
17229	77	-2	640	2020-02-11 18:30:55.600819+03
17230	6	-1	980	2020-02-11 18:30:55.898321+03
17231	12	-2	1650	2020-02-11 18:31:27.416685+03
17232	48	-1	640	2020-02-11 18:52:09.884818+03
17233	10	-3	2080	2020-02-11 18:57:55.800272+03
17234	12	-1	1650	2020-02-11 19:16:04.97325+03
17235	76	-1	1070	2020-02-11 19:20:10.056632+03
17236	5	-1	1620	2020-02-11 19:22:32.272781+03
17237	39	-1	910	2020-02-11 19:26:51.560874+03
17238	4	-1	1420	2020-02-11 20:09:58.912405+03
17239	23	-1	4390	2020-02-11 20:36:04.559439+03
17240	4	-1	1420	2020-02-11 20:39:21.321745+03
17241	13	-2	460	2020-02-11 20:46:17.341038+03
17242	6	-1	980	2020-02-11 21:10:44.209644+03
17243	34	-1	1550	2020-02-11 21:43:23.021378+03
17244	3	-1	660	2020-02-11 22:07:12.546332+03
17245	36	-1	630	2020-02-11 22:08:15.3669+03
17246	76	33	552	2020-02-11 22:34:48.396989+03
17247	30	-2	1140	2020-02-11 22:40:16.928226+03
17248	34	-1	1550	2020-02-11 22:47:45.444082+03
17249	42	-1	1790	2020-02-11 22:55:30.476617+03
17250	40	-1	1430	2020-02-11 23:03:18.169656+03
17251	37	-2	1290	2020-02-11 23:18:44.55149+03
17252	27	-2	880	2020-02-11 23:24:11.709159+03
17253	82	-1	560	2020-02-11 23:29:18.636693+03
17254	74	-1	1010	2020-02-11 23:37:07.382226+03
17255	22	-1	1070	2020-02-11 23:46:26.599813+03
17256	59	-1	1030	2020-02-11 23:56:36.011012+03
17257	2	-2	470	2020-02-12 00:10:01.378477+03
17258	46	-1	1270	2020-02-12 00:52:19.345981+03
17259	67	-1	350	2020-02-12 00:57:18.218959+03
17260	65	-1	490	2020-02-12 01:19:27.984116+03
17261	17	31	838	2020-02-12 01:20:02.818977+03
17262	10	-2	2080	2020-02-12 01:28:45.764397+03
17263	83	-1	1230	2020-02-12 01:34:02.435764+03
17264	41	-2	830	2020-02-12 01:44:31.184918+03
17265	68	-1	490	2020-02-12 01:46:40.94867+03
17266	63	-1	1780	2020-02-12 02:18:55.797121+03
17267	96	-1	1570	2020-02-12 02:29:26.597292+03
17268	80	-1	1120	2020-02-12 02:29:40.667523+03
17269	59	-1	1030	2020-02-12 02:42:05.901379+03
17270	20	-1	830	2020-02-12 02:42:58.010558+03
17271	87	-1	2320	2020-02-12 02:53:56.239034+03
17272	43	-2	380	2020-02-12 03:00:52.262676+03
17273	12	-1	1650	2020-02-12 03:58:37.108452+03
17274	4	-1	1420	2020-02-12 04:02:32.030469+03
17275	9	-1	2090	2020-02-12 04:09:04.416726+03
17276	90	-1	1780	2020-02-12 04:09:40.093972+03
17277	8	-1	1920	2020-02-12 04:51:47.343291+03
17278	22	-1	1070	2020-02-12 05:01:58.931669+03
17279	95	-1	480	2020-02-12 05:43:05.640316+03
17280	92	-1	630	2020-02-12 05:52:06.631012+03
17281	16	-2	1380	2020-02-12 06:14:28.331184+03
17282	14	-1	1350	2020-02-12 06:15:17.924608+03
17283	51	-1	1310	2020-02-12 06:47:19.978172+03
17284	82	19	290	2020-02-12 07:39:16.270175+03
17285	42	-2	1790	2020-02-12 08:25:07.350622+03
17286	19	24	567	2020-02-12 08:27:00.887119+03
17287	37	-1	1290	2020-02-12 08:45:51.831679+03
17288	82	-1	560	2020-02-12 08:51:47.970031+03
17289	60	-1	2700	2020-02-12 10:29:49.350813+03
17290	76	-1	1070	2020-02-12 10:32:06.002724+03
17291	58	-1	2830	2020-02-12 10:34:45.76898+03
17292	47	-1	1480	2020-02-12 10:36:41.319765+03
17293	4	-1	1420	2020-02-12 10:52:29.446148+03
17294	34	-1	1550	2020-02-12 11:04:17.634387+03
17295	78	-2	900	2020-02-12 11:04:39.749999+03
17296	18	-1	910	2020-02-12 11:17:05.693056+03
17297	8	-1	1920	2020-02-12 11:21:10.260397+03
17298	84	-1	2700	2020-02-12 11:38:57.295985+03
17299	20	-1	830	2020-02-12 11:41:34.225017+03
17300	2	-1	470	2020-02-12 11:47:48.894764+03
17301	83	-1	1230	2020-02-12 12:11:32.973814+03
17302	23	-1	4390	2020-02-12 12:25:51.705021+03
17303	93	-2	1620	2020-02-12 12:26:41.009747+03
17304	91	-1	1620	2020-02-12 12:29:18.005675+03
17305	39	-2	910	2020-02-12 12:34:57.46995+03
17306	1	-1	640	2020-02-12 12:36:58.197527+03
17307	86	34	410	2020-02-12 13:41:32.415989+03
17308	35	-1	670	2020-02-12 13:41:47.296999+03
17309	95	-2	480	2020-02-12 13:48:19.812146+03
17310	69	27	563	2020-02-12 14:19:04.417695+03
17311	26	-1	390	2020-02-12 14:19:56.994146+03
17312	69	-1	1100	2020-02-12 15:09:57.360063+03
17313	11	-1	830	2020-02-12 15:36:25.010715+03
17314	44	-1	500	2020-02-12 16:06:06.640503+03
17315	22	-1	1070	2020-02-12 16:13:31.244877+03
17316	81	-1	1620	2020-02-12 16:19:40.527139+03
17317	13	-1	460	2020-02-12 16:29:26.911125+03
17318	26	-1	390	2020-02-12 16:58:16.653499+03
17319	31	-1	1190	2020-02-12 17:09:33.844135+03
17320	48	-1	640	2020-02-12 17:43:33.010496+03
17321	79	-1	550	2020-02-12 17:44:04.540988+03
17322	25	-2	1100	2020-02-12 18:01:19.700179+03
17323	24	-1	950	2020-02-12 18:27:08.347052+03
17324	47	-1	1480	2020-02-12 18:35:44.156468+03
17325	95	-1	480	2020-02-12 19:43:48.524235+03
17326	42	-2	1790	2020-02-12 20:53:58.485495+03
17327	15	-1	2830	2020-02-12 21:03:23.217377+03
17328	76	-1	1070	2020-02-12 21:16:53.729023+03
17329	60	-1	2700	2020-02-12 21:29:18.569111+03
17330	71	-1	1030	2020-02-12 21:32:32.783791+03
17331	48	-1	640	2020-02-12 21:53:14.138887+03
17332	46	-2	1270	2020-02-12 22:24:11.618715+03
17333	90	-1	1780	2020-02-12 22:45:17.924028+03
17334	49	-1	970	2020-02-12 23:38:38.731086+03
17335	49	-1	970	2020-02-12 23:50:32.855813+03
17336	1	-1	640	2020-02-13 00:03:04.798461+03
17337	48	-1	640	2020-02-13 00:26:18.98106+03
17338	55	-1	3480	2020-02-13 00:33:14.93617+03
17339	27	-1	880	2020-02-13 01:05:19.941546+03
17340	76	-1	1070	2020-02-13 01:29:07.049294+03
17341	84	-1	2700	2020-02-13 01:34:16.001892+03
17342	38	-1	1100	2020-02-13 01:55:16.104663+03
17343	70	-1	760	2020-02-13 02:47:51.493569+03
17344	59	-1	1030	2020-02-13 02:58:05.408861+03
17345	85	-2	730	2020-02-13 03:13:01.880779+03
17346	5	-2	1620	2020-02-13 03:42:26.355364+03
17347	86	-1	910	2020-02-13 03:57:18.50063+03
17348	17	-2	1500	2020-02-13 04:09:30.511143+03
17349	77	-1	640	2020-02-13 04:10:08.325362+03
17350	40	-1	1430	2020-02-13 04:13:25.509845+03
17351	95	-1	480	2020-02-13 04:15:42.081909+03
17352	40	-2	1430	2020-02-13 04:28:54.564307+03
17353	73	-1	960	2020-02-13 04:31:10.611584+03
17354	9	22	1155	2020-02-13 04:52:48.681365+03
17355	6	-2	980	2020-02-13 05:14:20.322397+03
17356	49	-2	970	2020-02-13 05:15:10.716756+03
17357	40	-1	1430	2020-02-13 06:08:44.169612+03
17358	21	-2	960	2020-02-13 06:18:09.624884+03
17359	58	-1	2830	2020-02-13 06:56:18.123888+03
17360	22	-3	1070	2020-02-13 06:59:57.99577+03
17361	3	-1	660	2020-02-13 07:06:12.85024+03
17362	39	-1	910	2020-02-13 07:09:25.660343+03
17363	79	-1	550	2020-02-13 07:18:26.816823+03
17364	30	27	502	2020-02-13 07:20:28.381806+03
17365	30	-1	1140	2020-02-13 07:27:03.078747+03
17366	63	-1	1780	2020-02-13 07:39:18.400759+03
17367	46	-1	1270	2020-02-13 07:49:28.497096+03
17368	39	-2	910	2020-02-13 07:59:20.264392+03
17369	84	32	1609	2020-02-13 08:19:10.213474+03
17370	46	-1	1270	2020-02-13 08:25:34.417179+03
17371	46	-1	1270	2020-02-13 08:29:08.722679+03
17372	83	-1	1230	2020-02-13 09:20:30.3857+03
17373	39	-1	910	2020-02-13 10:06:37.705664+03
17374	10	-2	2080	2020-02-13 10:28:32.639742+03
17375	17	-1	1500	2020-02-13 10:32:59.302898+03
17376	94	-1	1230	2020-02-13 10:47:26.346708+03
17377	8	-1	1920	2020-02-13 10:55:02.769671+03
17378	60	-1	2700	2020-02-13 11:24:00.896739+03
17379	95	-2	480	2020-02-13 11:26:12.681059+03
17380	8	-1	1920	2020-02-13 11:36:38.059676+03
17381	40	-1	1430	2020-02-13 12:00:05.738915+03
17382	41	-1	830	2020-02-13 12:10:22.472616+03
17383	81	-1	1620	2020-02-13 12:17:38.163205+03
17384	31	-2	1190	2020-02-13 12:18:00.692304+03
17385	40	-2	1430	2020-02-13 12:39:07.68734+03
17386	76	-1	1070	2020-02-13 12:53:37.672957+03
17387	66	-1	690	2020-02-13 13:27:00.355175+03
17388	96	-1	1570	2020-02-13 14:09:27.717864+03
17389	11	-1	830	2020-02-13 14:11:53.839329+03
17390	76	-1	1070	2020-02-13 14:39:17.726946+03
17391	41	-1	830	2020-02-13 14:46:01.604493+03
17392	86	-1	910	2020-02-13 14:56:22.872681+03
17393	57	35	850	2020-02-13 15:10:52.63569+03
17394	34	-1	1550	2020-02-13 15:12:44.428348+03
17395	64	-1	970	2020-02-13 15:19:26.679749+03
17396	86	-1	910	2020-02-13 15:47:43.286255+03
17397	58	-1	2830	2020-02-13 17:10:15.846328+03
17398	51	-1	1310	2020-02-13 17:28:12.673305+03
17399	11	-1	830	2020-02-13 17:42:17.516616+03
17400	96	-1	1570	2020-02-13 17:58:01.886129+03
17401	80	-1	1120	2020-02-13 18:05:15.079361+03
17402	14	-1	1350	2020-02-13 18:26:53.415046+03
17403	14	-1	1350	2020-02-13 18:48:32.055795+03
17404	40	-1	1430	2020-02-13 19:18:05.420372+03
17405	64	-1	970	2020-02-13 19:46:33.612729+03
17406	65	14	290	2020-02-13 19:47:26.562858+03
17407	36	-1	630	2020-02-13 20:00:07.441854+03
17408	25	14	503	2020-02-13 20:07:01.155263+03
17409	96	-1	1570	2020-02-13 20:24:45.404207+03
17410	20	-1	830	2020-02-13 20:29:20.776164+03
17411	82	-1	560	2020-02-13 21:00:20.526459+03
17412	76	-1	1070	2020-02-13 21:49:01.70418+03
17413	35	-1	670	2020-02-13 22:03:15.9774+03
17414	67	-1	350	2020-02-13 22:03:55.989337+03
17415	9	-1	2090	2020-02-13 22:13:52.911921+03
17416	47	-1	1480	2020-02-13 22:21:12.87747+03
17417	47	-1	1480	2020-02-13 23:53:33.226554+03
17418	49	-1	970	2020-02-13 23:57:04.474878+03
17419	57	-1	1900	2020-02-14 00:43:08.58208+03
17420	26	-1	390	2020-02-14 01:34:47.171712+03
17421	73	-1	960	2020-02-14 01:51:25.608728+03
17422	93	-1	1620	2020-02-14 01:52:23.095745+03
17423	63	-3	1780	2020-02-14 02:17:16.50535+03
17424	17	-1	1500	2020-02-14 02:26:36.695709+03
17425	20	-1	830	2020-02-14 03:14:31.076812+03
17426	86	-1	910	2020-02-14 03:16:19.837507+03
17427	4	-1	1420	2020-02-14 03:31:33.102413+03
17428	7	-1	810	2020-02-14 03:41:59.406905+03
17429	75	-1	830	2020-02-14 04:13:35.150083+03
17430	9	-1	2090	2020-02-14 04:34:18.902833+03
17431	20	-1	830	2020-02-14 04:38:06.568645+03
17432	20	-1	830	2020-02-14 04:58:07.862128+03
17433	42	-2	1790	2020-02-14 05:04:13.246631+03
17434	4	-1	1420	2020-02-14 05:29:13.171135+03
17435	51	-1	1310	2020-02-14 05:35:42.542436+03
17436	10	-1	2080	2020-02-14 05:44:54.716282+03
17437	62	-1	1220	2020-02-14 05:48:35.83425+03
17438	52	-1	1090	2020-02-14 06:02:43.63492+03
17439	79	-1	550	2020-02-14 06:23:24.968494+03
17440	9	-1	2090	2020-02-14 06:25:30.569803+03
17441	56	-2	2460	2020-02-14 06:58:09.162511+03
17442	38	-1	1100	2020-02-14 07:13:42.221617+03
17443	87	-1	2320	2020-02-14 07:26:38.737403+03
17444	94	29	562	2020-02-14 07:37:16.096382+03
17445	46	-1	1270	2020-02-14 08:11:15.786109+03
17446	44	-2	500	2020-02-14 09:11:25.872415+03
17447	52	-1	1090	2020-02-14 09:16:11.600502+03
17448	51	-2	1310	2020-02-14 09:25:34.235745+03
17449	61	-1	1510	2020-02-14 09:31:00.187247+03
17450	45	-2	1590	2020-02-14 09:37:30.470155+03
17451	79	-2	550	2020-02-14 10:10:59.86802+03
17452	73	-1	960	2020-02-14 10:45:28.625797+03
17453	93	-1	1620	2020-02-14 10:47:01.825086+03
17454	89	-1	1420	2020-02-14 11:02:35.648931+03
17455	5	-1	1620	2020-02-14 11:08:47.521832+03
17456	18	-1	910	2020-02-14 11:09:46.452358+03
17457	19	-1	1220	2020-02-14 11:11:07.280213+03
17458	50	-1	1140	2020-02-14 11:18:47.399427+03
17459	79	-1	550	2020-02-14 11:31:57.197499+03
17460	53	-2	3120	2020-02-14 11:42:15.350223+03
17461	33	-2	900	2020-02-14 11:44:03.092103+03
17462	69	-1	1100	2020-02-14 11:58:35.932043+03
17463	64	-1	970	2020-02-14 12:25:07.817283+03
17464	65	-3	490	2020-02-14 12:36:00.618974+03
17465	23	-1	4390	2020-02-14 12:53:44.274533+03
17466	71	-2	1030	2020-02-14 13:34:58.869756+03
17467	81	-1	1620	2020-02-14 13:39:17.146272+03
17468	64	-1	970	2020-02-14 14:01:52.775553+03
17469	67	-1	350	2020-02-14 14:15:58.742002+03
17470	44	-1	500	2020-02-14 14:19:27.609683+03
17471	19	-1	1220	2020-02-14 15:01:06.842644+03
17472	41	-1	830	2020-02-14 15:21:40.020731+03
17473	34	-1	1550	2020-02-14 16:26:42.594097+03
17474	82	-1	560	2020-02-14 16:51:54.336523+03
17475	6	-1	980	2020-02-14 16:59:33.014459+03
17476	67	-1	350	2020-02-14 17:12:32.12541+03
17477	71	-1	1030	2020-02-14 17:30:45.430878+03
17478	4	-1	1420	2020-02-14 17:41:53.539532+03
17479	14	-1	1350	2020-02-14 17:53:54.322897+03
17480	79	-1	550	2020-02-14 18:05:50.969357+03
17481	53	-1	3120	2020-02-14 18:14:17.679421+03
17482	86	-2	910	2020-02-14 19:09:57.201344+03
17483	86	-1	910	2020-02-14 19:40:52.268617+03
17484	15	-1	2830	2020-02-14 19:42:46.72892+03
17485	15	-1	2830	2020-02-14 20:15:13.80257+03
17486	45	-2	1590	2020-02-14 20:20:49.962119+03
17487	81	-1	1620	2020-02-14 20:25:14.826871+03
17488	40	-1	1430	2020-02-14 20:51:49.514204+03
17489	5	-1	1620	2020-02-14 21:05:25.332901+03
17490	42	-1	1790	2020-02-14 21:22:52.480728+03
17491	20	-1	830	2020-02-14 21:32:11.374408+03
17492	42	-1	1790	2020-02-14 21:38:21.445478+03
17493	41	-1	830	2020-02-14 21:39:59.031092+03
17494	24	-1	950	2020-02-14 22:01:02.385126+03
17495	71	-1	1030	2020-02-14 22:17:24.009988+03
17496	42	-1	1790	2020-02-14 22:30:57.51465+03
17497	84	-1	2700	2020-02-14 22:36:25.613099+03
17498	25	-1	1100	2020-02-14 22:40:04.297547+03
17499	83	-2	1230	2020-02-14 22:50:05.667097+03
17500	26	-1	390	2020-02-14 23:01:45.896419+03
17501	31	-1	1190	2020-02-14 23:08:47.648068+03
17502	72	-1	620	2020-02-14 23:09:41.538549+03
17503	83	-2	1230	2020-02-14 23:16:25.90003+03
17504	51	-1	1310	2020-02-14 23:30:53.957404+03
17505	63	-1	1780	2020-02-15 00:04:14.817743+03
17506	22	-1	1070	2020-02-15 00:28:10.471489+03
17507	4	-1	1420	2020-02-15 00:37:12.658403+03
17508	46	-1	1270	2020-02-15 00:48:39.20094+03
17509	30	-1	1140	2020-02-15 00:49:51.991486+03
17510	30	-1	1140	2020-02-15 00:57:55.810331+03
17511	66	-2	690	2020-02-15 01:07:17.488033+03
17512	4	-1	1420	2020-02-15 02:15:07.639783+03
17513	84	-1	2700	2020-02-15 02:50:16.422139+03
17514	20	-1	830	2020-02-15 03:00:37.379702+03
17515	58	-2	2830	2020-02-15 03:11:07.271654+03
17516	79	-1	550	2020-02-15 03:19:35.254042+03
17517	77	-2	640	2020-02-15 03:22:45.762061+03
17518	29	-1	1940	2020-02-15 03:25:38.966637+03
17519	55	-2	3480	2020-02-15 03:31:15.285003+03
17520	7	-1	810	2020-02-15 03:42:04.871405+03
17521	38	-2	1100	2020-02-15 04:04:07.297895+03
17522	25	-1	1100	2020-02-15 04:05:28.095541+03
17523	3	-1	660	2020-02-15 04:10:03.730872+03
17524	7	-1	810	2020-02-15 04:14:09.112195+03
17525	52	-1	1090	2020-02-15 04:14:11.082772+03
17526	58	-1	2830	2020-02-15 04:24:13.03291+03
17527	44	-1	500	2020-02-15 04:28:55.450986+03
17528	75	-1	830	2020-02-15 04:30:41.339024+03
17529	33	-1	900	2020-02-15 04:45:12.784912+03
17530	41	-3	830	2020-02-15 04:46:11.623998+03
17531	50	21	547	2020-02-15 05:03:05.111169+03
17532	24	-1	950	2020-02-15 05:17:45.27585+03
17533	39	-1	910	2020-02-15 05:37:40.341029+03
17534	71	-1	1030	2020-02-15 05:52:34.188643+03
17535	46	-2	1270	2020-02-15 06:08:19.489944+03
17536	72	-1	620	2020-02-15 06:16:16.52953+03
17537	91	-1	1620	2020-02-15 06:38:08.319591+03
17538	35	-1	670	2020-02-15 06:49:03.013458+03
17539	13	-1	460	2020-02-15 06:49:25.977502+03
17540	77	-2	640	2020-02-15 06:54:38.025463+03
17541	28	-1	1860	2020-02-15 06:57:43.766274+03
17542	45	-1	1590	2020-02-15 07:43:58.846287+03
17543	6	-1	980	2020-02-15 07:46:08.202919+03
17544	49	-2	970	2020-02-15 08:59:18.435919+03
17545	90	-1	1780	2020-02-15 09:08:28.514568+03
17546	19	-2	1220	2020-02-15 09:19:24.135237+03
17547	18	-1	910	2020-02-15 09:48:50.418551+03
17548	13	-1	460	2020-02-15 09:54:32.335496+03
17549	56	-1	2460	2020-02-15 09:59:16.298972+03
17550	48	-1	640	2020-02-15 10:10:29.732992+03
17551	4	-2	1420	2020-02-15 10:13:06.672869+03
17552	37	-1	1290	2020-02-15 10:24:09.696308+03
17553	79	-1	550	2020-02-15 11:01:53.183792+03
17554	60	-1	2700	2020-02-15 11:25:20.948216+03
17555	57	-1	1900	2020-02-15 11:36:09.171316+03
17556	6	-2	980	2020-02-15 12:49:30.157566+03
17557	31	-1	1190	2020-02-15 13:09:03.212943+03
17558	49	-1	970	2020-02-15 13:09:57.660552+03
17559	70	-1	760	2020-02-15 13:24:53.612816+03
17560	76	-2	1070	2020-02-15 13:28:54.709428+03
17561	72	-1	620	2020-02-15 14:01:56.335495+03
17562	73	-2	960	2020-02-15 14:08:29.653044+03
17563	90	-1	1780	2020-02-15 14:26:54.888577+03
17564	47	42	678	2020-02-15 14:26:54.892617+03
17565	10	-2	2080	2020-02-15 14:32:25.453537+03
17566	5	26	831	2020-02-15 15:38:02.839176+03
17567	12	-1	1650	2020-02-15 16:19:44.21296+03
17568	4	-1	1420	2020-02-15 16:39:25.371175+03
17569	25	-2	1100	2020-02-15 16:44:50.883636+03
17570	21	-1	960	2020-02-15 16:50:31.059032+03
17571	94	-2	1230	2020-02-15 17:20:20.939073+03
17572	12	-2	1650	2020-02-15 17:20:42.592834+03
17573	44	-2	500	2020-02-15 17:56:44.144559+03
17574	83	-1	1230	2020-02-15 18:09:37.381425+03
17575	50	-1	1140	2020-02-15 18:54:35.088867+03
17576	59	-1	1030	2020-02-15 19:07:32.020351+03
17577	6	-1	980	2020-02-15 19:20:49.249417+03
17578	91	-1	1620	2020-02-15 20:38:28.114313+03
17579	61	-2	1510	2020-02-15 20:45:22.484018+03
17580	7	-1	810	2020-02-15 21:11:41.26453+03
17581	39	-1	910	2020-02-15 21:12:10.620234+03
17582	86	-1	910	2020-02-15 21:19:05.122202+03
17583	88	-1	1270	2020-02-15 21:32:43.768213+03
17584	90	-1	1780	2020-02-15 21:40:35.239554+03
17585	67	-1	350	2020-02-15 21:58:19.480253+03
17586	29	-1	1940	2020-02-15 22:30:09.061662+03
17587	37	-1	1290	2020-02-15 22:38:50.46515+03
17588	4	-2	1420	2020-02-15 22:53:24.173197+03
17589	12	-1	1650	2020-02-15 23:34:34.673535+03
17590	75	-1	830	2020-02-15 23:50:50.437133+03
17591	8	-1	1920	2020-02-15 23:52:50.012372+03
17592	46	-1	1270	2020-02-15 23:53:33.719053+03
17593	58	-1	2830	2020-02-16 00:06:54.096363+03
17594	67	-1	350	2020-02-16 00:30:06.421316+03
17595	55	-2	3480	2020-02-16 00:40:13.976865+03
17596	42	-1	1790	2020-02-16 00:42:56.270382+03
17597	82	-1	560	2020-02-16 01:32:12.727608+03
17598	71	-1	1030	2020-02-16 01:39:56.789629+03
17599	91	-3	1620	2020-02-16 01:48:00.484698+03
17600	31	-1	1190	2020-02-16 02:20:41.453794+03
17601	36	-1	630	2020-02-16 02:24:02.587523+03
17602	31	-1	1190	2020-02-16 02:27:06.720474+03
17603	20	-1	830	2020-02-16 02:56:17.762337+03
17604	67	-1	350	2020-02-16 03:50:33.782776+03
17605	36	-1	630	2020-02-16 03:57:42.75912+03
17606	55	-1	3480	2020-02-16 04:09:37.56829+03
17607	9	-1	2090	2020-02-16 04:37:00.42299+03
17608	73	-1	960	2020-02-16 04:37:15.849384+03
17609	36	31	343	2020-02-16 05:05:52.524854+03
17610	71	-1	1030	2020-02-16 05:50:50.237587+03
17611	68	-2	490	2020-02-16 06:06:38.101726+03
17612	74	-1	1010	2020-02-16 06:10:00.495259+03
17613	4	-1	1420	2020-02-16 06:21:30.462793+03
17614	60	-1	2700	2020-02-16 06:36:25.890554+03
17615	47	-1	1480	2020-02-16 06:37:57.283679+03
17616	38	-1	1100	2020-02-16 06:51:56.838507+03
17617	58	-1	2830	2020-02-16 07:03:30.777821+03
17618	75	-1	830	2020-02-16 07:04:54.926026+03
17619	91	-1	1620	2020-02-16 07:23:39.634722+03
17620	22	-1	1070	2020-02-16 07:26:16.494207+03
17621	71	-1	1030	2020-02-16 07:31:54.778814+03
17622	56	-1	2460	2020-02-16 07:35:47.127592+03
17623	17	-1	1500	2020-02-16 07:45:46.270105+03
17624	93	-2	1620	2020-02-16 07:56:01.49301+03
17625	4	-2	1420	2020-02-16 08:07:22.582645+03
17626	96	-2	1570	2020-02-16 08:11:47.046462+03
17627	14	-1	1350	2020-02-16 08:12:36.856623+03
17628	67	-1	350	2020-02-16 08:17:50.328879+03
17629	71	-1	1030	2020-02-16 08:22:18.62515+03
17630	79	-2	550	2020-02-16 08:26:11.101427+03
17631	25	-1	1100	2020-02-16 08:36:24.17841+03
17632	12	-1	1650	2020-02-16 08:42:30.210797+03
17633	64	-1	970	2020-02-16 08:45:48.414246+03
17634	72	-1	620	2020-02-16 09:23:20.207476+03
17635	22	-1	1070	2020-02-16 09:37:39.782902+03
17636	81	-1	1620	2020-02-16 10:05:50.088828+03
17637	38	-1	1100	2020-02-16 10:46:10.404758+03
17638	83	-2	1230	2020-02-16 10:50:38.930384+03
17639	14	-1	1350	2020-02-16 10:51:51.768379+03
17640	54	-1	3470	2020-02-16 10:54:50.82911+03
17641	75	-1	830	2020-02-16 10:56:39.545306+03
17642	53	-1	3120	2020-02-16 10:56:51.095093+03
17643	74	-1	1010	2020-02-16 11:23:01.437503+03
17644	40	-1	1430	2020-02-16 11:39:42.052839+03
17645	52	-1	1090	2020-02-16 11:40:52.250788+03
17646	95	-1	480	2020-02-16 12:18:12.921308+03
17647	42	-1	1790	2020-02-16 12:27:53.291375+03
17648	55	-1	3480	2020-02-16 13:00:25.234667+03
17649	20	-1	830	2020-02-16 13:17:38.757039+03
17650	24	-2	950	2020-02-16 13:17:41.049553+03
17651	92	-1	630	2020-02-16 13:22:05.088774+03
17652	56	-1	2460	2020-02-16 13:25:05.57858+03
17653	61	-1	1510	2020-02-16 13:29:29.724222+03
17654	44	-1	500	2020-02-16 13:32:49.378047+03
17655	95	-1	480	2020-02-16 14:15:53.963623+03
17656	94	-1	1230	2020-02-16 14:21:30.91153+03
17657	11	-1	830	2020-02-16 14:23:02.286463+03
17658	24	-1	950	2020-02-16 14:47:08.312512+03
17659	62	-2	1220	2020-02-16 14:48:50.361249+03
17660	76	-1	1070	2020-02-16 14:54:01.749744+03
17661	67	-2	350	2020-02-16 15:16:57.259935+03
17662	58	-1	2830	2020-02-16 16:03:08.047937+03
17663	8	-1	1920	2020-02-16 17:02:44.462112+03
17664	42	32	865	2020-02-16 17:31:00.42706+03
17665	30	-1	1140	2020-02-16 17:33:41.792731+03
17666	71	-1	1030	2020-02-16 17:37:20.618652+03
17667	95	-1	480	2020-02-16 17:39:03.857463+03
17668	20	-1	830	2020-02-16 18:07:51.662656+03
17669	86	-1	910	2020-02-16 18:09:32.362751+03
17670	57	-1	1900	2020-02-16 18:25:11.37485+03
17671	59	-1	1030	2020-02-16 18:26:34.265835+03
17672	72	-1	620	2020-02-16 18:37:32.191902+03
17673	73	-1	960	2020-02-16 18:52:12.855908+03
17674	53	-2	3120	2020-02-16 18:54:22.149976+03
17675	86	-1	910	2020-02-16 19:07:07.696138+03
17676	21	-1	960	2020-02-16 19:15:08.407189+03
17677	4	-1	1420	2020-02-16 19:40:18.440907+03
17678	23	-2	4390	2020-02-16 20:02:20.21442+03
17679	90	-1	1780	2020-02-16 20:02:31.555946+03
17680	71	-1	1030	2020-02-16 20:05:18.142248+03
17681	82	-1	560	2020-02-16 20:43:48.173844+03
17682	69	-2	1100	2020-02-16 20:51:57.294687+03
17683	47	-1	1480	2020-02-16 21:27:22.302363+03
17684	58	-1	2830	2020-02-16 21:32:20.285303+03
17685	71	-1	1030	2020-02-16 22:14:04.804521+03
17686	53	-1	3120	2020-02-16 22:25:13.350894+03
17687	95	-1	480	2020-02-16 22:44:37.170003+03
17688	42	-1	1790	2020-02-16 22:45:49.734112+03
17689	92	-1	630	2020-02-16 22:57:42.734708+03
17690	96	-1	1570	2020-02-16 22:59:33.637844+03
17691	18	-2	910	2020-02-16 23:18:16.470679+03
17692	37	-1	1290	2020-02-16 23:21:09.301999+03
17693	45	-1	1590	2020-02-16 23:28:36.318483+03
17694	51	-2	1310	2020-02-16 23:31:30.741141+03
17695	73	-2	960	2020-02-16 23:34:29.737861+03
17696	59	-1	1030	2020-02-16 23:41:21.911726+03
17697	94	-1	1230	2020-02-16 23:42:36.480089+03
17698	42	-1	1790	2020-02-16 23:53:31.340191+03
17699	51	-1	1310	2020-02-16 23:56:28.836482+03
17700	69	-1	1100	2020-02-17 00:10:12.971634+03
17701	9	-2	2090	2020-02-17 00:15:30.509548+03
17702	36	-2	630	2020-02-17 00:31:54.254942+03
17703	39	-1	910	2020-02-17 00:45:13.92044+03
17704	84	-1	2700	2020-02-17 01:13:47.887026+03
17705	53	-1	3120	2020-02-17 01:25:10.811476+03
17706	87	-2	2320	2020-02-17 01:30:53.293191+03
17707	86	-1	910	2020-02-17 02:08:04.528804+03
17708	23	-1	4390	2020-02-17 02:23:35.755137+03
17709	14	-1	1350	2020-02-17 02:39:54.95431+03
17710	76	-2	1070	2020-02-17 02:48:56.677243+03
17711	35	-1	670	2020-02-17 03:04:56.293472+03
17712	60	24	1124	2020-02-17 03:10:54.683771+03
17713	55	-2	3480	2020-02-17 03:13:53.247207+03
17714	12	-1	1650	2020-02-17 03:27:01.411798+03
17715	77	-1	640	2020-02-17 03:51:33.245222+03
17716	41	-1	830	2020-02-17 04:10:27.753998+03
17717	61	-1	1510	2020-02-17 04:42:28.735116+03
17718	40	-1	1430	2020-02-17 04:52:24.7327+03
17719	32	-1	710	2020-02-17 04:53:41.216078+03
17720	86	-2	910	2020-02-17 05:11:34.764533+03
17721	12	-1	1650	2020-02-17 05:15:10.726388+03
17722	34	-2	1550	2020-02-17 05:27:59.946747+03
17723	81	-2	1620	2020-02-17 05:28:58.561287+03
17724	69	-2	1100	2020-02-17 05:52:40.027361+03
17725	48	-1	640	2020-02-17 05:58:40.624297+03
17726	43	-1	380	2020-02-17 06:16:12.505348+03
17727	35	-1	670	2020-02-17 06:21:22.967292+03
17728	94	-2	1230	2020-02-17 06:23:03.213587+03
17729	77	-1	640	2020-02-17 06:35:10.619608+03
17730	44	-1	500	2020-02-17 06:35:51.077735+03
17731	76	-1	1070	2020-02-17 06:39:37.025666+03
17732	49	-1	970	2020-02-17 06:41:53.006831+03
17733	28	-1	1860	2020-02-17 07:05:40.220344+03
17734	95	-1	480	2020-02-17 07:25:15.338505+03
17735	94	-1	1230	2020-02-17 07:46:48.228399+03
17736	44	16	205	2020-02-17 07:57:25.984404+03
17737	19	-1	1220	2020-02-17 08:05:40.767515+03
17738	84	-1	2700	2020-02-17 08:14:44.90388+03
17739	21	-1	960	2020-02-17 08:34:42.329742+03
17740	17	-1	1500	2020-02-17 08:55:40.095141+03
17741	60	-1	2700	2020-02-17 09:10:53.028446+03
17742	68	-1	490	2020-02-17 09:11:59.549493+03
17743	41	-1	830	2020-02-17 09:22:28.092084+03
17744	78	-1	900	2020-02-17 09:33:25.133948+03
17745	64	-1	970	2020-02-17 10:07:16.255507+03
17746	68	-1	490	2020-02-17 10:12:42.99763+03
17747	65	-1	490	2020-02-17 10:45:25.658733+03
17748	67	-1	350	2020-02-17 10:50:29.662733+03
17749	40	-1	1430	2020-02-17 10:52:03.445454+03
17750	59	-1	1030	2020-02-17 10:53:44.98783+03
17751	60	-1	2700	2020-02-17 11:25:23.96279+03
17752	87	-1	2320	2020-02-17 11:38:23.457961+03
17753	4	-1	1420	2020-02-17 11:44:46.990826+03
17754	32	-1	710	2020-02-17 11:45:19.962118+03
17755	14	-1	1350	2020-02-17 12:04:54.087809+03
17756	83	-1	1230	2020-02-17 12:11:07.170819+03
17757	47	-1	1480	2020-02-17 12:23:15.565595+03
17758	39	-1	910	2020-02-17 12:31:54.315881+03
17759	13	-1	460	2020-02-17 12:36:03.301061+03
17760	29	-1	1940	2020-02-17 12:38:24.078629+03
17761	27	-1	880	2020-02-17 12:41:18.080933+03
17762	52	-1	1090	2020-02-17 12:55:31.742684+03
17763	52	-1	1090	2020-02-17 13:18:39.481476+03
17764	6	-1	980	2020-02-17 13:23:55.787044+03
17765	33	32	413	2020-02-17 13:37:25.296933+03
17766	31	-2	1190	2020-02-17 14:00:08.789846+03
17767	29	-1	1940	2020-02-17 14:59:57.652223+03
17768	94	-1	1230	2020-02-17 15:12:19.006344+03
17769	37	-1	1290	2020-02-17 15:14:24.859895+03
17770	38	-1	1100	2020-02-17 15:17:13.692501+03
17771	20	-1	830	2020-02-17 15:36:13.561241+03
17772	87	-2	2320	2020-02-17 15:42:04.244105+03
17773	9	-1	2090	2020-02-17 15:44:14.241875+03
17774	77	-2	640	2020-02-17 15:52:27.21561+03
17775	3	-1	660	2020-02-17 16:23:27.853433+03
17776	29	-2	1940	2020-02-17 16:38:20.410915+03
17777	47	-1	1480	2020-02-17 16:55:14.076132+03
17778	12	-1	1650	2020-02-17 16:55:16.278954+03
17779	25	-1	1100	2020-02-17 17:10:51.594357+03
17780	27	-1	880	2020-02-17 17:15:19.654183+03
17781	40	27	796	2020-02-17 17:20:46.518356+03
17782	19	-1	1220	2020-02-17 17:39:50.114304+03
17783	41	-1	830	2020-02-17 18:07:17.563013+03
17784	4	-1	1420	2020-02-17 19:14:33.247152+03
17785	55	27	2050	2020-02-17 19:14:47.179582+03
17786	15	-1	2830	2020-02-17 19:35:09.348973+03
17787	69	-2	1100	2020-02-17 19:57:32.099861+03
17788	47	-1	1480	2020-02-17 19:57:43.441598+03
17789	42	-1	1790	2020-02-17 20:01:25.580682+03
17790	64	-2	970	2020-02-17 20:27:34.074326+03
17791	77	-2	640	2020-02-17 20:41:47.966576+03
17792	23	-1	4390	2020-02-17 20:47:04.595937+03
17793	4	-1	1420	2020-02-17 21:02:57.032067+03
17794	41	-2	830	2020-02-17 21:07:56.861948+03
17795	17	-1	1500	2020-02-17 21:15:18.836377+03
17796	5	-1	1620	2020-02-17 21:31:17.484773+03
17797	36	-2	630	2020-02-17 21:52:43.547137+03
17798	96	-1	1570	2020-02-17 22:02:25.877851+03
17799	49	-2	970	2020-02-17 22:18:54.519996+03
17800	46	27	578	2020-02-17 22:47:24.607451+03
17801	55	-1	3480	2020-02-17 23:12:04.477816+03
17802	76	-1	1070	2020-02-17 23:27:14.344914+03
17803	50	-1	1140	2020-02-17 23:29:00.341242+03
17804	44	-1	500	2020-02-17 23:31:08.361162+03
17805	94	-1	1230	2020-02-17 23:38:55.833629+03
17806	4	-1	1420	2020-02-17 23:50:02.359866+03
17807	85	-1	730	2020-02-17 23:57:07.934164+03
17808	46	-1	1270	2020-02-18 00:05:34.470881+03
17809	52	-1	1090	2020-02-18 00:14:00.305946+03
17810	54	-1	3470	2020-02-18 00:19:09.492994+03
17811	63	-1	1780	2020-02-18 01:07:09.762599+03
17812	49	-1	970	2020-02-18 01:33:22.637127+03
17813	25	-2	1100	2020-02-18 01:39:07.726936+03
17814	53	19	1656	2020-02-18 01:43:44.175439+03
17815	94	-1	1230	2020-02-18 01:45:56.198139+03
17816	22	-1	1070	2020-02-18 02:13:25.121052+03
17817	55	-1	3480	2020-02-18 02:50:39.154252+03
17818	28	-1	1860	2020-02-18 03:02:32.541855+03
17819	45	-1	1590	2020-02-18 03:16:33.3187+03
17820	10	-1	2080	2020-02-18 04:03:24.740931+03
17821	3	-1	660	2020-02-18 04:03:32.028472+03
17822	5	-1	1620	2020-02-18 04:12:48.893479+03
17823	72	-1	620	2020-02-18 04:31:16.076603+03
17824	39	-1	910	2020-02-18 04:59:39.965422+03
17825	43	-1	380	2020-02-18 05:00:53.2437+03
17826	56	-2	2460	2020-02-18 05:16:21.176043+03
17827	85	-1	730	2020-02-18 05:38:17.708842+03
17828	41	-1	830	2020-02-18 05:42:44.01285+03
17829	45	-1	1590	2020-02-18 05:44:11.524602+03
17830	87	-1	2320	2020-02-18 05:44:40.441327+03
17831	48	-1	640	2020-02-18 05:52:00.13258+03
17832	4	-1	1420	2020-02-18 06:01:44.665383+03
17833	1	-1	640	2020-02-18 06:15:49.360185+03
17834	10	-1	2080	2020-02-18 07:05:49.04171+03
17835	33	-1	900	2020-02-18 07:07:07.50111+03
17836	81	-1	1620	2020-02-18 07:15:21.579142+03
17837	14	-1	1350	2020-02-18 07:24:48.000278+03
17838	54	-2	3470	2020-02-18 07:43:24.524413+03
17839	59	-1	1030	2020-02-18 07:48:55.299186+03
17840	64	-1	970	2020-02-18 08:19:40.940475+03
17841	11	-2	830	2020-02-18 08:50:51.84106+03
17842	49	-1	970	2020-02-18 08:52:12.751911+03
17843	93	-1	1620	2020-02-18 08:59:53.361635+03
17844	19	-2	1220	2020-02-18 09:30:02.905102+03
17845	18	-1	910	2020-02-18 09:33:01.022504+03
17846	75	-1	830	2020-02-18 09:49:44.152127+03
17847	29	-1	1940	2020-02-18 10:16:04.365815+03
17848	65	-1	490	2020-02-18 10:21:08.826642+03
17849	89	-2	1420	2020-02-18 10:24:12.799531+03
17850	44	-1	500	2020-02-18 10:26:46.258163+03
17851	16	-2	1380	2020-02-18 10:36:32.319021+03
17852	47	-1	1480	2020-02-18 10:38:49.122468+03
17853	18	35	436	2020-02-18 11:19:42.214033+03
17854	4	-2	1420	2020-02-18 11:43:40.465579+03
17855	76	-1	1070	2020-02-18 11:48:54.762786+03
17856	89	-2	1420	2020-02-18 11:51:23.631081+03
17857	14	-1	1350	2020-02-18 11:51:24.343571+03
17858	77	-1	640	2020-02-18 11:57:42.354407+03
17859	44	-1	500	2020-02-18 12:30:19.717841+03
17860	5	-1	1620	2020-02-18 12:33:03.537965+03
17861	83	-1	1230	2020-02-18 12:55:13.655298+03
17862	6	-2	980	2020-02-18 13:24:36.885442+03
17863	31	-1	1190	2020-02-18 13:42:20.03016+03
17864	92	-1	630	2020-02-18 14:46:23.339885+03
17865	86	-2	910	2020-02-18 14:56:43.156323+03
17866	13	-1	460	2020-02-18 15:08:11.93522+03
17867	69	-1	1100	2020-02-18 15:17:37.19367+03
17868	45	-1	1590	2020-02-18 15:26:42.605367+03
17869	73	-1	960	2020-02-18 15:40:18.33206+03
17870	92	-1	630	2020-02-18 15:42:35.162941+03
17871	22	-1	1070	2020-02-18 15:44:32.903495+03
17872	5	-1	1620	2020-02-18 15:47:56.733172+03
17873	49	-1	970	2020-02-18 15:58:32.255077+03
17874	85	-1	730	2020-02-18 16:25:29.124163+03
17875	67	-1	350	2020-02-18 16:28:50.166869+03
17876	33	-1	900	2020-02-18 16:35:29.371037+03
17877	46	-1	1270	2020-02-18 16:47:44.181513+03
17878	8	-1	1920	2020-02-18 17:01:26.63257+03
17879	90	-1	1780	2020-02-18 17:11:55.564757+03
17880	71	-1	1030	2020-02-18 17:21:20.768663+03
17881	51	-2	1310	2020-02-18 17:59:24.158777+03
17882	11	-1	830	2020-02-18 18:00:05.93288+03
17883	38	-1	1100	2020-02-18 18:04:37.747954+03
17884	62	-1	1220	2020-02-18 18:32:36.497942+03
17885	4	-1	1420	2020-02-18 18:42:56.774899+03
17886	3	-1	660	2020-02-18 18:58:25.65817+03
17887	1	-1	640	2020-02-18 19:04:16.885228+03
17888	56	-1	2460	2020-02-18 19:42:39.6224+03
17889	14	-1	1350	2020-02-18 20:13:12.728262+03
17890	17	-1	1500	2020-02-18 20:15:55.792186+03
17891	77	-1	640	2020-02-18 20:17:37.554744+03
17892	7	-2	810	2020-02-18 20:26:16.009429+03
17893	54	-1	3470	2020-02-18 20:34:28.834181+03
17894	84	-2	2700	2020-02-18 20:54:10.403575+03
17895	81	-1	1620	2020-02-18 21:06:22.157231+03
17896	71	-1	1030	2020-02-18 21:49:56.200429+03
17897	64	-1	970	2020-02-18 23:15:37.988677+03
17898	84	-1	2700	2020-02-18 23:26:23.263661+03
17899	94	-1	1230	2020-02-18 23:43:59.362362+03
17900	46	-2	1270	2020-02-18 23:46:42.734047+03
17901	91	-1	1620	2020-02-18 23:51:55.238984+03
17902	31	-1	1190	2020-02-19 00:05:21.031741+03
17903	39	-1	910	2020-02-19 00:14:11.447877+03
17904	59	-2	1030	2020-02-19 00:22:37.654015+03
17905	63	-1	1780	2020-02-19 00:37:09.864577+03
17906	48	22	345	2020-02-19 00:53:28.482418+03
17907	5	-1	1620	2020-02-19 00:55:28.63917+03
17908	77	-3	640	2020-02-19 01:11:53.386206+03
17909	41	-1	830	2020-02-19 01:25:21.545357+03
17910	12	-1	1650	2020-02-19 01:52:51.845507+03
17911	57	-1	1900	2020-02-19 02:03:12.077962+03
17912	84	-2	2700	2020-02-19 02:20:54.250788+03
17913	79	-2	550	2020-02-19 02:26:03.765775+03
17914	46	-1	1270	2020-02-19 03:14:14.525566+03
17915	78	-1	900	2020-02-19 03:18:19.095056+03
17916	55	-2	3480	2020-02-19 04:16:59.486683+03
17917	46	-2	1270	2020-02-19 04:32:11.747564+03
17918	35	-1	670	2020-02-19 04:49:58.868957+03
17919	14	-1	1350	2020-02-19 04:53:34.231974+03
17920	93	-2	1620	2020-02-19 05:15:58.833855+03
17921	35	-1	670	2020-02-19 05:20:42.791336+03
17922	7	-1	810	2020-02-19 05:36:20.393305+03
17923	38	-1	1100	2020-02-19 05:38:55.5416+03
17924	90	-1	1780	2020-02-19 06:10:12.308265+03
17925	29	-1	1940	2020-02-19 06:11:30.149858+03
17926	48	-1	640	2020-02-19 06:15:27.744229+03
17927	56	38	1124	2020-02-19 06:28:26.411189+03
17928	10	-1	2080	2020-02-19 06:31:01.021546+03
17929	12	-1	1650	2020-02-19 06:31:41.027697+03
17930	37	-1	1290	2020-02-19 06:36:27.857853+03
17931	47	-2	1480	2020-02-19 07:15:04.385139+03
17932	77	-1	640	2020-02-19 07:26:24.955453+03
17933	38	-1	1100	2020-02-19 07:53:38.668989+03
17934	50	-1	1140	2020-02-19 08:29:05.68772+03
17935	93	-1	1620	2020-02-19 08:33:53.620153+03
17936	14	-1	1350	2020-02-19 08:39:14.901063+03
17937	46	-1	1270	2020-02-19 08:48:08.040236+03
17938	67	-1	350	2020-02-19 08:55:30.187104+03
17939	75	-2	830	2020-02-19 09:05:50.045624+03
17940	36	-2	630	2020-02-19 09:38:32.234299+03
17941	67	-1	350	2020-02-19 10:27:36.536598+03
17942	28	-1	1860	2020-02-19 10:52:30.25488+03
17943	13	-1	460	2020-02-19 11:01:17.484091+03
17944	70	-1	760	2020-02-19 11:06:14.190431+03
17945	64	-2	970	2020-02-19 12:32:35.549233+03
17946	37	-1	1290	2020-02-19 12:55:50.413414+03
17947	32	-2	710	2020-02-19 13:57:19.30346+03
17948	49	-1	970	2020-02-19 13:59:57.603373+03
17949	57	-2	1900	2020-02-19 14:00:19.529881+03
17950	93	-1	1620	2020-02-19 14:22:25.627266+03
17951	84	-2	2700	2020-02-19 14:39:11.877891+03
17952	50	-1	1140	2020-02-19 15:13:08.496489+03
17953	58	-1	2830	2020-02-19 16:05:52.801169+03
17954	37	-1	1290	2020-02-19 16:40:18.108663+03
17955	30	-1	1140	2020-02-19 16:51:29.86719+03
17956	87	-1	2320	2020-02-19 16:58:43.187895+03
17957	16	13	755	2020-02-19 17:00:05.122074+03
17958	58	24	1281	2020-02-19 17:01:47.830467+03
17959	6	-1	980	2020-02-19 17:04:33.745462+03
17960	95	-1	480	2020-02-19 17:28:52.920657+03
17961	1	-1	640	2020-02-19 17:38:05.496871+03
17962	12	-1	1650	2020-02-19 17:50:09.255361+03
17963	80	-1	1120	2020-02-19 18:07:18.52929+03
17964	71	-1	1030	2020-02-19 18:27:37.85954+03
17965	93	-1	1620	2020-02-19 18:44:09.317634+03
17966	25	-1	1100	2020-02-19 19:28:43.927289+03
17967	20	-1	830	2020-02-19 20:31:09.416911+03
17968	80	-1	1120	2020-02-19 20:35:49.039217+03
17969	54	-1	3470	2020-02-19 21:29:31.519833+03
17970	56	-2	2460	2020-02-19 21:41:34.618858+03
17971	94	-1	1230	2020-02-19 22:05:51.082421+03
17972	49	-1	970	2020-02-19 22:10:27.714052+03
17973	75	-1	830	2020-02-19 22:19:05.728452+03
17974	76	-2	1070	2020-02-19 22:28:26.594295+03
17975	76	-1	1070	2020-02-19 22:29:12.047314+03
17976	90	-1	1780	2020-02-19 22:50:57.352932+03
17977	69	-1	1100	2020-02-19 22:59:23.155384+03
17978	24	-1	950	2020-02-19 23:22:28.343002+03
17979	89	-1	1420	2020-02-19 23:33:33.502213+03
17980	16	-1	1380	2020-02-19 23:40:59.769756+03
17981	26	-1	390	2020-02-20 00:11:45.563412+03
17982	14	-1	1350	2020-02-20 00:23:33.832826+03
17983	32	-2	710	2020-02-20 00:24:44.460779+03
17984	95	-2	480	2020-02-20 00:29:50.518752+03
17985	84	-1	2700	2020-02-20 00:41:33.720241+03
17986	84	-1	2700	2020-02-20 01:09:04.165354+03
17987	5	-1	1620	2020-02-20 01:25:20.665958+03
17988	8	-1	1920	2020-02-20 01:46:33.636881+03
17989	77	-1	640	2020-02-20 02:17:13.538119+03
17990	8	-1	1920	2020-02-20 02:30:18.135679+03
17991	14	-1	1350	2020-02-20 02:36:19.454773+03
17992	87	-1	2320	2020-02-20 02:44:10.329108+03
17993	63	-1	1780	2020-02-20 02:47:45.453682+03
17994	48	-1	640	2020-02-20 02:50:52.494782+03
17995	76	-1	1070	2020-02-20 03:18:49.616257+03
17996	29	-1	1940	2020-02-20 03:30:46.59084+03
17997	34	-1	1550	2020-02-20 03:34:34.43784+03
17998	59	-2	1030	2020-02-20 04:17:34.787293+03
17999	39	-2	910	2020-02-20 04:25:17.093011+03
18000	56	-1	2460	2020-02-20 04:31:37.217224+03
18001	52	19	556	2020-02-20 04:48:34.587224+03
18002	94	-1	1230	2020-02-20 05:35:47.107954+03
18003	30	-1	1140	2020-02-20 05:36:15.480617+03
18004	8	-1	1920	2020-02-20 05:42:36.490713+03
18005	43	-1	380	2020-02-20 06:01:12.539594+03
18006	45	-1	1590	2020-02-20 06:36:41.594393+03
18007	75	-1	830	2020-02-20 07:09:29.326208+03
18008	13	-1	460	2020-02-20 07:17:18.95191+03
18009	38	-1	1100	2020-02-20 07:29:16.995975+03
18010	73	-2	960	2020-02-20 07:30:28.091152+03
18011	94	-1	1230	2020-02-20 07:41:32.34548+03
18012	11	-1	830	2020-02-20 07:49:43.496593+03
18013	95	-1	480	2020-02-20 07:49:44.708324+03
18014	58	-1	2830	2020-02-20 07:53:59.171008+03
18015	63	-1	1780	2020-02-20 07:59:44.251518+03
18016	83	-2	1230	2020-02-20 07:59:48.8251+03
18017	15	-1	2830	2020-02-20 08:04:15.066441+03
18018	18	-1	910	2020-02-20 08:07:31.246366+03
18019	65	-1	490	2020-02-20 08:39:55.909686+03
18020	25	-1	1100	2020-02-20 08:47:28.405612+03
18021	14	-1	1350	2020-02-20 09:23:26.596134+03
18022	47	-2	1480	2020-02-20 09:37:54.560122+03
18023	70	-1	760	2020-02-20 09:48:10.861446+03
18024	26	-3	390	2020-02-20 09:52:57.017931+03
18025	83	-3	1230	2020-02-20 09:55:09.793155+03
18026	48	-1	640	2020-02-20 09:55:42.682751+03
18027	38	-1	1100	2020-02-20 10:07:50.168175+03
18028	17	-1	1500	2020-02-20 10:36:28.49758+03
18029	6	-1	980	2020-02-20 10:37:14.451742+03
18030	83	-1	1230	2020-02-20 10:48:08.574389+03
18031	51	-1	1310	2020-02-20 10:57:43.632196+03
18032	32	-1	710	2020-02-20 11:19:41.686696+03
18033	6	-1	980	2020-02-20 11:35:38.267388+03
18034	88	-1	1270	2020-02-20 12:02:50.405911+03
18035	19	-1	1220	2020-02-20 12:15:07.571657+03
18036	76	-1	1070	2020-02-20 12:42:19.746656+03
18037	34	-1	1550	2020-02-20 12:44:20.742701+03
18038	83	-1	1230	2020-02-20 13:11:14.436081+03
18039	49	-1	970	2020-02-20 13:30:21.343876+03
18040	15	14	1492	2020-02-20 14:00:11.760346+03
18041	49	-1	970	2020-02-20 14:15:35.571542+03
18042	13	-1	460	2020-02-20 14:17:54.505465+03
18043	75	-1	830	2020-02-20 15:13:39.912804+03
18044	87	-1	2320	2020-02-20 15:34:55.085577+03
18045	38	-1	1100	2020-02-20 16:13:23.001621+03
18046	34	-1	1550	2020-02-20 16:42:05.277942+03
18047	17	-1	1500	2020-02-20 16:54:20.243811+03
18048	74	-1	1010	2020-02-20 16:55:34.78638+03
18049	29	-1	1940	2020-02-20 17:37:32.026857+03
18050	95	-1	480	2020-02-20 18:29:47.237076+03
18051	47	-2	1480	2020-02-20 18:30:56.634086+03
18052	54	-1	3470	2020-02-20 18:35:48.626538+03
18053	13	-1	460	2020-02-20 18:39:56.497991+03
18054	42	-1	1790	2020-02-20 18:48:06.497579+03
18055	31	-1	1190	2020-02-20 18:54:01.905255+03
18056	73	-2	960	2020-02-20 19:02:09.03062+03
18057	95	-1	480	2020-02-20 19:04:48.066628+03
18058	21	-1	960	2020-02-20 19:23:30.074456+03
18059	90	-1	1780	2020-02-20 19:36:20.565296+03
18060	96	-2	1570	2020-02-20 19:44:17.073938+03
18061	12	-2	1650	2020-02-20 19:45:32.93587+03
18062	95	-1	480	2020-02-20 19:47:37.130262+03
18063	40	-2	1430	2020-02-20 19:48:21.827332+03
18064	29	-1	1940	2020-02-20 20:01:48.463901+03
18065	60	-1	2700	2020-02-20 20:02:02.264944+03
18066	86	-1	910	2020-02-20 20:05:48.049021+03
18067	27	-2	880	2020-02-20 20:22:42.002298+03
18068	26	-1	390	2020-02-20 20:23:22.745883+03
18069	30	-1	1140	2020-02-20 20:26:14.384603+03
18070	4	-2	1420	2020-02-20 21:02:07.991312+03
18071	95	33	285	2020-02-20 21:11:05.964967+03
18072	17	-1	1500	2020-02-20 21:32:19.319963+03
18073	37	-1	1290	2020-02-20 21:49:33.972241+03
18074	69	-1	1100	2020-02-20 22:13:44.033666+03
18075	45	25	638	2020-02-20 22:15:40.769521+03
18076	24	-1	950	2020-02-20 22:40:31.143491+03
18077	52	-2	1090	2020-02-20 22:52:33.171255+03
18078	77	-1	640	2020-02-20 22:55:00.816114+03
18079	44	-2	500	2020-02-20 23:11:37.662254+03
18080	16	-2	1380	2020-02-20 23:36:17.472189+03
18081	38	-1	1100	2020-02-20 23:52:17.721264+03
18082	1	-1	640	2020-02-20 23:57:20.461624+03
18083	44	-1	500	2020-02-21 00:22:21.744801+03
18084	46	-2	1270	2020-02-21 00:33:53.22545+03
18085	74	-1	1010	2020-02-21 00:44:23.840359+03
18086	22	-1	1070	2020-02-21 01:10:47.372613+03
18087	20	-1	830	2020-02-21 01:27:04.120925+03
18088	76	-2	1070	2020-02-21 02:07:10.51117+03
18089	92	28	304	2020-02-21 02:15:52.892615+03
18090	53	-2	3120	2020-02-21 02:34:36.168918+03
18091	36	-1	630	2020-02-21 02:40:04.75333+03
18092	76	-1	1070	2020-02-21 03:34:46.660262+03
18093	96	-1	1570	2020-02-21 04:02:05.670198+03
18094	68	-1	490	2020-02-21 04:02:13.37317+03
18095	11	-1	830	2020-02-21 04:15:49.20182+03
18096	88	-1	1270	2020-02-21 04:19:45.892842+03
18097	54	-1	3470	2020-02-21 04:22:42.139794+03
18098	90	-1	1780	2020-02-21 04:44:36.580257+03
18099	56	-1	2460	2020-02-21 04:50:10.833257+03
18100	13	-1	460	2020-02-21 05:10:32.49215+03
18101	96	-1	1570	2020-02-21 05:28:03.091609+03
18102	59	-2	1030	2020-02-21 05:38:11.923146+03
18103	59	-1	1030	2020-02-21 06:02:24.322169+03
18104	54	-2	3470	2020-02-21 06:04:39.77467+03
18105	87	-1	2320	2020-02-21 06:11:30.360545+03
18106	39	35	401	2020-02-21 06:45:33.919176+03
18107	43	-1	380	2020-02-21 06:50:32.760822+03
18108	39	-2	910	2020-02-21 07:12:35.623571+03
18109	83	38	589	2020-02-21 07:35:01.899846+03
18110	49	-1	970	2020-02-21 07:45:46.910645+03
18111	48	-1	640	2020-02-21 08:02:08.42923+03
18112	76	-1	1070	2020-02-21 08:09:08.318616+03
18113	46	-1	1270	2020-02-21 08:10:22.207197+03
18114	67	-1	350	2020-02-21 08:31:31.458223+03
18115	17	-2	1500	2020-02-21 09:25:41.22255+03
18116	27	-1	880	2020-02-21 09:39:06.792373+03
18117	21	-1	960	2020-02-21 09:44:16.899386+03
18118	22	-1	1070	2020-02-21 10:01:20.994305+03
18119	60	-1	2700	2020-02-21 10:13:55.593343+03
18120	9	-2	2090	2020-02-21 11:18:03.720207+03
18121	88	-1	1270	2020-02-21 11:23:09.546624+03
18122	64	-2	970	2020-02-21 12:06:14.388684+03
18123	55	-1	3480	2020-02-21 12:39:00.640084+03
18124	18	-2	910	2020-02-21 12:47:11.511676+03
18125	17	-1	1500	2020-02-21 13:26:39.483124+03
18126	23	-1	4390	2020-02-21 13:28:13.412044+03
18127	70	-1	760	2020-02-21 13:55:02.488116+03
18128	7	-1	810	2020-02-21 13:56:19.18213+03
18129	8	-2	1920	2020-02-21 14:07:17.544451+03
18130	13	-1	460	2020-02-21 14:15:44.220742+03
18131	75	-1	830	2020-02-21 14:39:23.165347+03
18132	1	-2	640	2020-02-21 14:46:48.760346+03
18133	2	-1	470	2020-02-21 14:47:10.916065+03
18134	95	-2	480	2020-02-21 15:01:04.050517+03
18135	74	-1	1010	2020-02-21 15:09:49.021564+03
18136	68	-1	490	2020-02-21 15:34:05.494441+03
18137	76	-1	1070	2020-02-21 15:38:33.593941+03
18138	5	-1	1620	2020-02-21 15:51:21.218131+03
18139	56	-1	2460	2020-02-21 16:03:08.784894+03
18140	79	-1	550	2020-02-21 16:10:11.354357+03
18141	2	-1	470	2020-02-21 16:17:16.842597+03
18142	10	-1	2080	2020-02-21 16:25:53.973016+03
18143	68	-2	490	2020-02-21 16:31:40.883482+03
18144	92	-1	630	2020-02-21 16:57:59.214037+03
18145	65	-1	490	2020-02-21 17:01:34.079532+03
18146	33	-1	900	2020-02-21 17:17:36.857194+03
18147	26	-1	390	2020-02-21 17:25:41.81953+03
18148	57	-1	1900	2020-02-21 17:28:39.866174+03
18149	4	-1	1420	2020-02-21 17:37:26.698711+03
18150	30	-1	1140	2020-02-21 17:38:05.368206+03
18151	75	-1	830	2020-02-21 17:42:08.380966+03
18152	56	-1	2460	2020-02-21 17:43:00.122046+03
18153	34	-1	1550	2020-02-21 17:48:21.485687+03
18154	83	-1	1230	2020-02-21 18:12:30.856248+03
18155	17	-1	1500	2020-02-21 18:28:12.85335+03
18156	37	-1	1290	2020-02-21 18:42:00.766392+03
18157	9	-2	2090	2020-02-21 19:01:02.235194+03
18158	29	-1	1940	2020-02-21 19:07:36.364199+03
18159	66	-1	690	2020-02-21 19:20:25.683429+03
18160	57	-1	1900	2020-02-21 19:39:02.71247+03
18161	39	-1	910	2020-02-21 19:44:14.413435+03
18162	91	-1	1620	2020-02-21 19:46:21.280579+03
18163	81	19	690	2020-02-21 19:48:59.187697+03
18164	90	-1	1780	2020-02-21 19:49:25.236777+03
18165	69	-1	1100	2020-02-21 20:00:55.457752+03
18166	90	-1	1780	2020-02-21 20:06:45.233008+03
18167	48	-2	640	2020-02-21 20:36:06.090593+03
18168	88	-1	1270	2020-02-21 20:36:51.796775+03
18169	34	-1	1550	2020-02-21 20:50:46.665179+03
18170	84	-1	2700	2020-02-21 20:59:41.622959+03
18171	21	-1	960	2020-02-21 21:05:51.746902+03
18172	65	-1	490	2020-02-21 21:09:50.918633+03
18173	28	-1	1860	2020-02-21 21:31:50.737561+03
18174	32	-1	710	2020-02-21 21:40:35.474191+03
18175	53	-1	3120	2020-02-21 21:47:12.795334+03
18176	52	-1	1090	2020-02-21 21:50:34.798469+03
18177	10	-2	2080	2020-02-21 21:51:19.300455+03
18178	93	-1	1620	2020-02-21 21:51:27.821826+03
18179	74	-1	1010	2020-02-21 21:52:49.584605+03
18180	5	-1	1620	2020-02-21 22:22:09.121114+03
18181	43	-1	380	2020-02-21 22:37:55.953463+03
18182	90	-1	1780	2020-02-21 22:43:11.274822+03
18183	31	-1	1190	2020-02-21 22:53:13.071538+03
18184	55	-1	3480	2020-02-21 23:10:57.499174+03
18185	36	-2	630	2020-02-21 23:54:14.243661+03
18186	96	-1	1570	2020-02-21 23:57:45.978779+03
18187	56	-1	2460	2020-02-21 23:59:44.46081+03
18188	64	-1	970	2020-02-22 00:02:19.044995+03
18189	71	-2	1030	2020-02-22 00:14:00.616226+03
18190	46	-1	1270	2020-02-22 00:44:19.240936+03
18191	92	-1	630	2020-02-22 00:54:10.461346+03
18192	39	-1	910	2020-02-22 00:56:45.023848+03
18193	62	-1	1220	2020-02-22 01:07:48.315726+03
18194	82	-1	560	2020-02-22 01:08:29.715387+03
18195	34	-1	1550	2020-02-22 01:15:37.311024+03
18196	32	-1	710	2020-02-22 01:25:10.838788+03
18197	73	-2	960	2020-02-22 01:27:15.533841+03
18198	12	-1	1650	2020-02-22 01:35:14.287986+03
18199	24	-1	950	2020-02-22 02:21:48.482278+03
18200	89	-1	1420	2020-02-22 02:28:24.292158+03
18201	73	-2	960	2020-02-22 02:41:35.272957+03
18202	53	-2	3120	2020-02-22 03:03:50.913446+03
18203	50	-1	1140	2020-02-22 03:05:01.147725+03
18204	33	-3	900	2020-02-22 03:07:20.636006+03
18205	6	-1	980	2020-02-22 03:09:25.640508+03
18206	32	-1	710	2020-02-22 04:22:45.93362+03
18207	41	-1	830	2020-02-22 04:25:48.317022+03
18208	47	-1	1480	2020-02-22 04:30:32.710807+03
18209	29	-2	1940	2020-02-22 04:35:48.473086+03
18210	80	-2	1120	2020-02-22 04:36:00.071609+03
18211	10	-1	2080	2020-02-22 04:46:17.961293+03
18212	33	-1	900	2020-02-22 04:57:10.813409+03
18213	35	-1	670	2020-02-22 05:20:53.026284+03
18214	81	-2	1620	2020-02-22 06:00:16.348681+03
18215	58	-1	2830	2020-02-22 06:20:17.157227+03
18216	43	-2	380	2020-02-22 06:43:21.489097+03
18217	73	-1	960	2020-02-22 06:47:11.374018+03
18218	74	-1	1010	2020-02-22 07:02:13.548498+03
18219	45	-1	1590	2020-02-22 07:37:19.438371+03
18220	16	-1	1380	2020-02-22 07:49:37.024456+03
18221	75	-1	830	2020-02-22 07:58:51.26573+03
18222	41	-1	830	2020-02-22 08:03:37.669302+03
18223	92	-1	630	2020-02-22 08:17:13.325949+03
18224	24	-1	950	2020-02-22 08:35:52.080026+03
18225	35	-1	670	2020-02-22 08:40:39.748955+03
18226	28	-1	1860	2020-02-22 09:10:40.904393+03
18227	38	-1	1100	2020-02-22 09:19:54.330765+03
18228	71	-2	1030	2020-02-22 09:29:54.710459+03
18229	25	-1	1100	2020-02-22 09:32:37.677299+03
18230	49	-1	970	2020-02-22 09:38:56.524172+03
18231	47	-1	1480	2020-02-22 09:53:09.957303+03
18232	65	-1	490	2020-02-22 10:07:37.87549+03
18233	87	-1	2320	2020-02-22 10:24:45.700419+03
18234	19	-2	1220	2020-02-22 10:41:13.768681+03
18235	10	-1	2080	2020-02-22 10:41:51.693782+03
18236	30	-2	1140	2020-02-22 10:49:22.766495+03
18237	71	-1	1030	2020-02-22 10:53:14.571128+03
18238	90	-1	1780	2020-02-22 11:29:51.833935+03
18239	77	-2	640	2020-02-22 11:33:20.388288+03
18240	88	-3	1270	2020-02-22 11:41:43.330914+03
18241	54	-1	3470	2020-02-22 12:22:08.895756+03
18242	6	-1	980	2020-02-22 12:35:19.317858+03
18243	34	32	833	2020-02-22 12:41:49.933244+03
18244	85	-1	730	2020-02-22 12:48:35.260357+03
18245	4	-1	1420	2020-02-22 12:50:06.473015+03
18246	36	-1	630	2020-02-22 12:56:26.490859+03
18247	9	-1	2090	2020-02-22 13:16:58.935555+03
18248	92	-1	630	2020-02-22 13:20:29.143958+03
18249	34	-2	1550	2020-02-22 13:29:03.543612+03
18250	91	-1	1620	2020-02-22 13:29:44.425869+03
18251	42	-1	1790	2020-02-22 13:29:48.35926+03
18252	10	-1	2080	2020-02-22 13:53:53.261369+03
18253	87	39	1052	2020-02-22 13:55:38.655284+03
18254	3	-1	660	2020-02-22 14:57:27.174635+03
18255	18	-1	910	2020-02-22 14:57:59.963555+03
18256	47	-1	1480	2020-02-22 15:05:18.848387+03
18257	9	-1	2090	2020-02-22 15:14:00.644688+03
18258	86	-2	910	2020-02-22 15:19:11.423838+03
18259	28	-1	1860	2020-02-22 15:26:38.370798+03
18260	82	-2	560	2020-02-22 15:31:55.657443+03
18261	83	-2	1230	2020-02-22 15:50:34.36753+03
18262	29	-1	1940	2020-02-22 16:24:08.015597+03
18263	86	-1	910	2020-02-22 16:38:25.204538+03
18264	6	-2	980	2020-02-22 16:50:04.886227+03
18265	51	-1	1310	2020-02-22 16:59:06.128438+03
18266	4	-1	1420	2020-02-22 16:59:07.9256+03
18267	27	-1	880	2020-02-22 17:11:01.745893+03
18268	38	-1	1100	2020-02-22 17:12:59.480493+03
18269	5	-1	1620	2020-02-22 17:26:29.302208+03
18270	40	-1	1430	2020-02-22 18:09:33.386904+03
18271	39	-1	910	2020-02-22 18:37:53.632851+03
18272	39	-1	910	2020-02-22 18:40:49.90226+03
18273	91	-2	1620	2020-02-22 18:45:19.248628+03
18274	43	-1	380	2020-02-22 19:37:05.673644+03
18275	13	-1	460	2020-02-22 19:41:53.682903+03
18276	78	-1	900	2020-02-22 19:46:32.842475+03
18277	89	-2	1420	2020-02-22 20:07:24.21396+03
18278	80	-1	1120	2020-02-22 20:28:16.791148+03
18279	95	-1	480	2020-02-22 20:43:48.737441+03
18280	32	-1	710	2020-02-22 20:44:41.305508+03
18281	83	-1	1230	2020-02-22 20:47:16.65648+03
18282	90	-1	1780	2020-02-22 20:55:34.075631+03
18283	52	-2	1090	2020-02-22 21:04:29.742361+03
18284	25	-1	1100	2020-02-22 21:13:43.924313+03
18285	34	-1	1550	2020-02-22 21:21:53.949641+03
18286	93	-2	1620	2020-02-22 21:32:08.417156+03
18287	14	-1	1350	2020-02-22 21:54:11.308617+03
18288	44	-1	500	2020-02-22 22:59:51.811765+03
18289	94	-1	1230	2020-02-22 23:41:52.718889+03
18290	88	-1	1270	2020-02-22 23:44:36.104096+03
18291	17	-2	1500	2020-02-23 00:50:56.311796+03
18292	8	-1	1920	2020-02-23 00:54:23.508578+03
18293	36	-1	630	2020-02-23 01:03:37.076969+03
18294	86	-1	910	2020-02-23 01:11:57.338283+03
18295	84	-1	2700	2020-02-23 01:17:37.574922+03
18296	26	-1	390	2020-02-23 01:28:52.993627+03
18297	48	-1	640	2020-02-23 01:30:29.591109+03
18298	56	-1	2460	2020-02-23 01:47:25.947158+03
18299	12	-1	1650	2020-02-23 01:48:46.81729+03
18300	12	-1	1650	2020-02-23 01:54:37.309265+03
18301	74	-1	1010	2020-02-23 03:30:09.159745+03
18302	67	-1	350	2020-02-23 03:33:10.340209+03
18303	73	23	572	2020-02-23 03:46:40.611124+03
18304	4	-1	1420	2020-02-23 03:56:23.829263+03
18305	7	-1	810	2020-02-23 04:10:03.120287+03
18306	57	-1	1900	2020-02-23 04:12:05.976182+03
18307	2	-1	470	2020-02-23 04:34:29.082255+03
18308	63	-1	1780	2020-02-23 04:35:09.103063+03
18309	49	-2	970	2020-02-23 04:57:59.254928+03
18310	85	-2	730	2020-02-23 05:10:23.118344+03
18311	43	16	187	2020-02-23 05:16:17.920763+03
18312	55	-1	3480	2020-02-23 06:43:24.275033+03
18313	84	-1	2700	2020-02-23 07:33:55.030428+03
18314	25	-1	1100	2020-02-23 07:43:07.594398+03
18315	50	-2	1140	2020-02-23 08:08:48.145741+03
18316	60	-1	2700	2020-02-23 08:41:30.838065+03
18317	2	-1	470	2020-02-23 08:46:34.44079+03
18318	47	-2	1480	2020-02-23 09:13:13.240631+03
18319	10	-2	2080	2020-02-23 09:22:01.658058+03
18320	60	-1	2700	2020-02-23 09:38:15.461573+03
18321	68	-2	490	2020-02-23 09:41:13.03218+03
18322	6	-1	980	2020-02-23 09:50:06.200385+03
18323	10	-1	2080	2020-02-23 09:52:10.605827+03
18324	80	-1	1120	2020-02-23 09:54:26.050188+03
18325	31	-1	1190	2020-02-23 09:54:39.633818+03
18326	17	-1	1500	2020-02-23 10:01:21.461861+03
18327	82	-1	560	2020-02-23 11:15:58.469999+03
18328	42	-2	1790	2020-02-23 11:38:00.36476+03
18329	9	-1	2090	2020-02-23 11:56:00.556398+03
18330	33	-1	900	2020-02-23 12:15:17.225547+03
18331	81	-1	1620	2020-02-23 12:19:59.524415+03
18332	91	-1	1620	2020-02-23 12:36:29.092546+03
18333	56	-1	2460	2020-02-23 13:04:22.224266+03
18334	74	-1	1010	2020-02-23 13:15:41.913753+03
18335	40	-1	1430	2020-02-23 13:36:43.572672+03
18336	40	-1	1430	2020-02-23 13:37:45.567455+03
18337	81	-1	1620	2020-02-23 13:40:05.801011+03
18338	90	-1	1780	2020-02-23 14:05:57.858541+03
18339	67	32	173	2020-02-23 14:09:24.275022+03
18340	89	-1	1420	2020-02-23 14:13:42.405256+03
18341	34	-1	1550	2020-02-23 14:16:35.233839+03
18342	72	9	276	2020-02-23 14:28:51.108566+03
18343	45	-2	1590	2020-02-23 14:39:31.060742+03
18344	1	-1	640	2020-02-23 14:56:22.231995+03
18345	84	-1	2700	2020-02-23 15:18:37.127445+03
18346	50	-1	1140	2020-02-23 15:19:03.015776+03
18347	86	-1	910	2020-02-23 15:21:09.288848+03
18348	59	-1	1030	2020-02-23 15:35:49.77462+03
18349	33	-1	900	2020-02-23 15:53:51.870043+03
18350	53	-1	3120	2020-02-23 16:15:25.216399+03
18351	59	-1	1030	2020-02-23 16:31:58.826312+03
18352	46	-1	1270	2020-02-23 16:33:52.772095+03
18353	87	-1	2320	2020-02-23 16:34:59.75472+03
18354	46	-2	1270	2020-02-23 16:48:40.84297+03
18355	95	-1	480	2020-02-23 16:57:33.511602+03
18356	42	-1	1790	2020-02-23 17:02:28.950198+03
18357	27	-1	880	2020-02-23 17:07:24.86364+03
18358	33	-1	900	2020-02-23 17:40:46.077552+03
18359	46	-1	1270	2020-02-23 17:59:42.594841+03
18360	56	-1	2460	2020-02-23 18:57:43.998681+03
18361	46	-1	1270	2020-02-23 19:02:21.29511+03
18362	54	-2	3470	2020-02-23 19:09:58.454314+03
18363	82	-1	560	2020-02-23 19:14:05.536499+03
18364	55	-1	3480	2020-02-23 19:24:34.562702+03
18365	88	-1	1270	2020-02-23 19:42:31.470252+03
18366	1	-1	640	2020-02-23 19:51:31.298528+03
18367	30	-2	1140	2020-02-23 19:52:11.266655+03
18368	86	-2	910	2020-02-23 20:19:11.26169+03
18369	15	-2	2830	2020-02-23 20:26:51.960089+03
18370	34	-1	1550	2020-02-23 20:40:06.666469+03
18371	1	-2	640	2020-02-23 20:41:57.87763+03
18372	64	-1	970	2020-02-23 21:31:15.502033+03
18373	15	-1	2830	2020-02-23 21:40:01.215217+03
18374	46	-1	1270	2020-02-23 22:30:17.69014+03
18375	41	-2	830	2020-02-23 23:03:05.15689+03
18376	91	-1	1620	2020-02-23 23:18:03.343744+03
18377	35	-1	670	2020-02-23 23:45:22.439902+03
18378	73	-1	960	2020-02-23 23:52:55.722947+03
18379	52	-1	1090	2020-02-24 00:04:22.447138+03
18380	41	-1	830	2020-02-24 00:52:11.952831+03
18381	48	-1	640	2020-02-24 01:34:24.406531+03
18382	94	-1	1230	2020-02-24 01:49:03.959758+03
18383	5	-1	1620	2020-02-24 01:53:14.190827+03
18384	42	-1	1790	2020-02-24 01:54:48.395163+03
18385	9	-2	2090	2020-02-24 01:59:32.176119+03
18386	89	-1	1420	2020-02-24 02:09:43.407891+03
18387	20	-1	830	2020-02-24 02:18:48.125091+03
18388	90	-1	1780	2020-02-24 02:24:57.368103+03
18389	35	-1	670	2020-02-24 02:27:13.230473+03
18390	40	-1	1430	2020-02-24 02:42:24.341922+03
18391	16	-1	1380	2020-02-24 02:47:46.05517+03
18392	80	-1	1120	2020-02-24 02:52:50.379084+03
18393	11	-1	830	2020-02-24 03:02:12.357324+03
18394	60	-2	2700	2020-02-24 03:06:36.402941+03
18395	30	-2	1140	2020-02-24 03:09:42.167818+03
18396	82	-1	560	2020-02-24 03:17:06.46328+03
18397	95	-1	480	2020-02-24 03:22:46.625357+03
18398	96	-2	1570	2020-02-24 03:25:28.388839+03
18399	95	-2	480	2020-02-24 03:28:30.491522+03
18400	11	-1	830	2020-02-24 03:53:53.872594+03
18401	12	-1	1650	2020-02-24 05:09:28.712826+03
18402	29	40	942	2020-02-24 05:15:41.706462+03
18403	28	-1	1860	2020-02-24 05:17:42.59214+03
18404	61	-1	1510	2020-02-24 06:11:28.731915+03
18405	74	-1	1010	2020-02-24 06:14:58.356168+03
18406	67	-1	350	2020-02-24 06:24:45.437116+03
18407	77	-1	640	2020-02-24 06:56:46.98354+03
18408	55	-1	3480	2020-02-24 06:58:03.415161+03
18409	74	-1	1010	2020-02-24 07:28:00.232447+03
18410	14	-2	1350	2020-02-24 07:37:12.376758+03
18411	2	-1	470	2020-02-24 07:51:28.691872+03
18412	12	-2	1650	2020-02-24 08:38:11.761499+03
18413	58	-1	2830	2020-02-24 08:59:50.918186+03
18414	4	-1	1420	2020-02-24 09:00:32.843959+03
18415	46	-2	1270	2020-02-24 09:08:08.557706+03
18416	82	-1	560	2020-02-24 09:21:34.891636+03
18417	29	-1	1940	2020-02-24 09:37:24.017811+03
18418	61	-1	1510	2020-02-24 09:41:24.767201+03
18419	81	-1	1620	2020-02-24 09:45:52.372823+03
18420	38	-2	1100	2020-02-24 10:41:51.197408+03
18421	19	-1	1220	2020-02-24 10:49:08.425794+03
18422	76	-1	1070	2020-02-24 10:58:13.155095+03
18423	46	-1	1270	2020-02-24 11:01:56.076211+03
18424	44	-2	500	2020-02-24 11:06:01.796865+03
18425	8	-1	1920	2020-02-24 11:14:13.058323+03
18426	69	-1	1100	2020-02-24 11:38:01.383927+03
18427	41	-1	830	2020-02-24 11:55:30.428102+03
18428	45	-1	1590	2020-02-24 11:58:48.880734+03
18429	41	-2	830	2020-02-24 12:04:40.626633+03
18430	54	-1	3470	2020-02-24 12:22:20.825787+03
18431	12	-1	1650	2020-02-24 12:26:39.226091+03
18432	25	-1	1100	2020-02-24 12:34:14.444123+03
18433	93	-1	1620	2020-02-24 12:38:55.735897+03
18434	87	-1	2320	2020-02-24 12:47:47.266712+03
18435	93	-1	1620	2020-02-24 13:02:42.861296+03
18436	73	-1	960	2020-02-24 13:07:11.628937+03
18437	74	-1	1010	2020-02-24 13:28:49.333077+03
18438	61	-2	1510	2020-02-24 13:29:54.408859+03
18439	45	-1	1590	2020-02-24 13:49:54.294413+03
18440	41	28	471	2020-02-24 14:02:41.401141+03
18441	53	-1	3120	2020-02-24 14:03:52.487716+03
18442	76	-1	1070	2020-02-24 14:06:05.485764+03
18443	14	-1	1350	2020-02-24 14:21:24.616071+03
18444	61	-1	1510	2020-02-24 14:26:10.320473+03
18445	69	-1	1100	2020-02-24 14:34:28.2826+03
18446	35	26	370	2020-02-24 15:07:30.166968+03
18447	61	-1	1510	2020-02-24 15:15:26.363579+03
18448	80	-1	1120	2020-02-24 15:39:32.169042+03
18449	20	-1	830	2020-02-24 15:48:13.430768+03
18450	71	-1	1030	2020-02-24 15:54:04.145265+03
18451	33	-2	900	2020-02-24 16:01:42.801721+03
18452	39	-1	910	2020-02-24 16:01:43.10059+03
18453	17	-1	1500	2020-02-24 16:25:31.260628+03
18454	55	-1	3480	2020-02-24 16:54:06.580075+03
18455	76	-1	1070	2020-02-24 16:55:48.032125+03
18456	45	-1	1590	2020-02-24 17:04:50.426546+03
18457	60	-1	2700	2020-02-24 17:39:15.281848+03
18458	34	-1	1550	2020-02-24 17:39:52.165164+03
18459	70	-1	760	2020-02-24 17:50:33.697428+03
18460	10	40	1038	2020-02-24 18:03:24.247567+03
18461	49	36	553	2020-02-24 18:09:16.437077+03
18462	53	-2	3120	2020-02-24 18:31:15.543806+03
18463	67	-2	350	2020-02-24 18:41:04.787694+03
18464	93	-1	1620	2020-02-24 18:47:15.285728+03
18465	88	-1	1270	2020-02-24 18:51:23.97841+03
18466	29	-1	1940	2020-02-24 18:59:11.998929+03
18467	7	32	389	2020-02-24 19:07:40.32591+03
18468	84	-1	2700	2020-02-24 19:08:23.067134+03
18469	52	-1	1090	2020-02-24 19:14:14.310343+03
18470	49	-1	970	2020-02-24 19:19:58.963313+03
18471	50	-1	1140	2020-02-24 19:39:47.919486+03
18472	69	-1	1100	2020-02-24 19:42:33.182648+03
18473	6	-2	980	2020-02-24 20:02:14.930219+03
18474	67	-1	350	2020-02-24 20:11:42.433905+03
18475	6	-1	980	2020-02-24 20:23:13.914711+03
18476	26	-2	390	2020-02-24 20:28:32.465194+03
18477	81	-2	1620	2020-02-24 20:32:42.638521+03
18478	82	-1	560	2020-02-24 21:12:47.720696+03
18479	60	-1	2700	2020-02-24 21:14:43.142314+03
18480	21	-1	960	2020-02-24 21:37:03.856574+03
18481	7	-1	810	2020-02-24 21:47:37.155003+03
18482	77	-1	640	2020-02-24 21:49:18.849482+03
18483	47	-1	1480	2020-02-24 21:49:22.73227+03
18484	8	-1	1920	2020-02-24 21:56:33.068957+03
18485	55	-1	3480	2020-02-24 21:59:31.430995+03
18486	92	-2	630	2020-02-24 22:19:26.069063+03
18487	34	-1	1550	2020-02-24 22:31:13.02438+03
18488	94	-1	1230	2020-02-24 22:44:58.652098+03
18489	10	-1	2080	2020-02-24 23:37:59.404891+03
18490	11	-1	830	2020-02-24 23:44:52.294277+03
18491	74	-1	1010	2020-02-24 23:52:01.421302+03
18492	67	-1	350	2020-02-24 23:59:51.140069+03
18493	20	-1	830	2020-02-25 00:08:19.26418+03
18494	89	-1	1420	2020-02-25 00:10:55.710046+03
18495	87	-1	2320	2020-02-25 00:18:06.901716+03
18496	50	-2	1140	2020-02-25 00:19:12.727177+03
18497	12	-1	1650	2020-02-25 00:43:59.692672+03
18498	5	-2	1620	2020-02-25 01:12:08.555825+03
18499	57	-1	1900	2020-02-25 01:34:59.008356+03
18500	47	-1	1480	2020-02-25 01:42:28.785774+03
18501	14	-2	1350	2020-02-25 01:43:52.612012+03
18502	18	-1	910	2020-02-25 02:15:05.572994+03
18503	43	-1	380	2020-02-25 02:33:47.987908+03
18504	44	-1	500	2020-02-25 02:52:08.639043+03
18505	75	-1	830	2020-02-25 04:01:44.14444+03
18506	95	-1	480	2020-02-25 04:14:33.995002+03
18507	55	-1	3480	2020-02-25 04:27:18.33689+03
18508	20	-1	830	2020-02-25 04:29:03.729003+03
18509	67	-1	350	2020-02-25 04:32:30.906163+03
18510	67	-2	350	2020-02-25 04:59:38.383563+03
18511	88	-2	1270	2020-02-25 05:17:56.848331+03
18512	92	-1	630	2020-02-25 05:30:36.546327+03
18513	18	-1	910	2020-02-25 05:49:14.79697+03
18514	83	-1	1230	2020-02-25 05:51:31.647861+03
18515	46	-1	1270	2020-02-25 05:58:05.164525+03
18516	44	-1	500	2020-02-25 06:01:20.327819+03
18517	75	-2	830	2020-02-25 06:03:49.1406+03
18518	15	-1	2830	2020-02-25 06:05:05.450465+03
18519	14	-1	1350	2020-02-25 06:12:42.614414+03
18520	40	-1	1430	2020-02-25 06:43:21.936353+03
18521	89	-1	1420	2020-02-25 06:53:53.581961+03
18522	49	-2	970	2020-02-25 06:58:58.385325+03
18523	68	12	265	2020-02-25 07:09:03.574041+03
18524	52	-2	1090	2020-02-25 07:13:03.373047+03
18525	40	-1	1430	2020-02-25 07:31:24.750135+03
18526	22	-1	1070	2020-02-25 07:49:07.280916+03
18527	42	-1	1790	2020-02-25 08:05:28.512006+03
18528	91	-1	1620	2020-02-25 08:29:24.38297+03
18529	69	-1	1100	2020-02-25 08:34:05.690998+03
18530	29	-1	1940	2020-02-25 08:54:19.83505+03
18531	84	-1	2700	2020-02-25 08:55:45.079026+03
18532	2	-2	470	2020-02-25 09:04:27.667955+03
18533	20	-1	830	2020-02-25 09:16:10.13806+03
18534	8	-1	1920	2020-02-25 09:18:33.980212+03
18535	87	-2	2320	2020-02-25 09:42:22.026143+03
18536	21	-1	960	2020-02-25 09:43:34.951931+03
18537	44	-1	500	2020-02-25 10:01:04.182836+03
18538	52	-1	1090	2020-02-25 10:09:26.813676+03
18539	94	-1	1230	2020-02-25 10:10:49.157296+03
18540	85	-1	730	2020-02-25 10:13:26.033545+03
18541	15	-1	2830	2020-02-25 10:30:48.642998+03
18542	60	-1	2700	2020-02-25 10:36:57.101698+03
18543	6	-2	980	2020-02-25 10:53:47.718678+03
18544	76	-1	1070	2020-02-25 10:53:53.245726+03
18545	18	-1	910	2020-02-25 10:54:41.812244+03
18546	58	-1	2830	2020-02-25 11:04:31.864872+03
18547	30	-2	1140	2020-02-25 11:15:04.552303+03
18548	51	-1	1310	2020-02-25 11:16:01.572886+03
18549	1	-1	640	2020-02-25 11:31:26.654344+03
18550	15	-1	2830	2020-02-25 11:34:26.83517+03
18551	57	-1	1900	2020-02-25 11:39:35.830096+03
18552	30	-1	1140	2020-02-25 11:51:49.261035+03
18553	67	-2	350	2020-02-25 12:42:56.552075+03
18554	13	-1	460	2020-02-25 12:50:29.813524+03
18555	90	-1	1780	2020-02-25 12:55:58.274101+03
18556	28	-1	1860	2020-02-25 13:27:19.007516+03
18557	55	-1	3480	2020-02-25 13:29:25.299246+03
18558	80	-2	1120	2020-02-25 13:36:01.402123+03
18559	26	-1	390	2020-02-25 14:21:23.128646+03
18560	96	-1	1570	2020-02-25 14:33:10.16022+03
18561	20	-1	830	2020-02-25 15:46:50.745321+03
18562	50	-1	1140	2020-02-25 15:52:13.085486+03
18563	47	-1	1480	2020-02-25 16:25:36.411774+03
18564	7	-1	810	2020-02-25 17:09:39.275997+03
18565	17	-1	1500	2020-02-25 17:16:41.769437+03
18566	82	-1	560	2020-02-25 17:23:43.233268+03
18567	93	-1	1620	2020-02-25 17:25:02.66221+03
18568	67	-1	350	2020-02-25 17:31:34.262097+03
18569	57	-1	1900	2020-02-25 17:46:38.263939+03
18570	40	-1	1430	2020-02-25 17:50:08.212839+03
18571	41	-1	830	2020-02-25 17:54:56.888307+03
18572	42	-1	1790	2020-02-25 18:03:06.008223+03
18573	74	-1	1010	2020-02-25 18:14:24.555476+03
18574	91	-1	1620	2020-02-25 18:43:41.733174+03
18575	42	-1	1790	2020-02-25 20:05:38.123869+03
18576	7	-2	810	2020-02-25 20:10:49.453643+03
18577	41	-2	830	2020-02-25 20:14:16.910766+03
18578	19	-1	1220	2020-02-25 20:32:33.960664+03
18579	74	-2	1010	2020-02-25 20:33:08.648193+03
18580	31	-1	1190	2020-02-25 20:34:48.216795+03
18581	69	-2	1100	2020-02-25 21:06:44.422111+03
18582	30	-1	1140	2020-02-25 21:11:09.580077+03
18583	76	-1	1070	2020-02-25 21:36:54.092596+03
18584	83	-1	1230	2020-02-25 21:53:36.871382+03
18585	77	-1	640	2020-02-25 21:56:01.26304+03
18586	94	-1	1230	2020-02-25 22:03:45.900285+03
18587	5	-2	1620	2020-02-25 22:07:20.88318+03
18588	88	-1	1270	2020-02-25 22:26:14.289858+03
18589	22	-1	1070	2020-02-25 22:38:57.993095+03
18590	87	-2	2320	2020-02-25 22:42:25.721913+03
18591	26	-1	390	2020-02-25 23:16:47.423496+03
18592	28	-1	1860	2020-02-25 23:18:41.755606+03
18593	70	-1	760	2020-02-25 23:19:00.942686+03
18594	52	-1	1090	2020-02-25 23:28:52.294575+03
18595	33	-1	900	2020-02-25 23:36:26.965364+03
18596	94	-1	1230	2020-02-25 23:49:41.32565+03
18597	81	-1	1620	2020-02-26 00:10:39.663491+03
18598	35	-1	670	2020-02-26 00:18:48.959484+03
18599	8	-2	1920	2020-02-26 00:24:55.768337+03
18600	64	-1	970	2020-02-26 01:03:08.445222+03
18601	78	-2	900	2020-02-26 01:11:21.916621+03
18602	13	-1	460	2020-02-26 01:19:57.368603+03
18603	12	-1	1650	2020-02-26 01:46:29.991784+03
18604	36	-1	630	2020-02-26 02:30:14.102339+03
18605	53	-1	3120	2020-02-26 02:44:45.422844+03
18606	76	-1	1070	2020-02-26 02:45:16.281772+03
18607	60	-1	2700	2020-02-26 03:35:03.88132+03
18608	9	-1	2090	2020-02-26 03:42:24.302379+03
18609	28	20	975	2020-02-26 03:47:39.902253+03
18610	21	-1	960	2020-02-26 03:55:48.581038+03
18611	86	-1	910	2020-02-26 03:55:57.657169+03
18612	40	-2	1430	2020-02-26 03:59:12.363044+03
18613	78	-1	900	2020-02-26 04:29:06.525083+03
18614	59	-1	1030	2020-02-26 04:29:33.089318+03
18615	35	-1	670	2020-02-26 04:54:23.114788+03
18616	45	-1	1590	2020-02-26 04:59:11.484515+03
18617	50	-1	1140	2020-02-26 05:03:40.599179+03
18618	46	-1	1270	2020-02-26 05:30:35.653467+03
18619	24	-1	950	2020-02-26 05:49:55.746251+03
18620	33	-1	900	2020-02-26 05:51:11.956935+03
18621	6	-1	980	2020-02-26 05:55:41.040337+03
18622	41	-1	830	2020-02-26 06:12:31.0613+03
18623	79	23	265	2020-02-26 06:15:29.834494+03
18624	13	-1	460	2020-02-26 06:41:38.093685+03
18625	6	-1	980	2020-02-26 06:46:24.574841+03
18626	41	-1	830	2020-02-26 06:56:19.41045+03
18627	47	-2	1480	2020-02-26 06:56:25.423964+03
18628	86	-1	910	2020-02-26 07:05:56.873462+03
18629	78	-1	900	2020-02-26 07:06:22.260441+03
18630	18	-1	910	2020-02-26 07:27:06.079453+03
18631	30	-1	1140	2020-02-26 07:32:33.702088+03
18632	67	-1	350	2020-02-26 08:01:41.299657+03
18633	47	-2	1480	2020-02-26 08:23:25.862524+03
18634	95	-1	480	2020-02-26 08:25:17.958813+03
18635	58	-1	2830	2020-02-26 08:27:50.257218+03
18636	63	-1	1780	2020-02-26 08:29:56.215988+03
18637	12	-1	1650	2020-02-26 08:42:10.560339+03
18638	54	-2	3470	2020-02-26 08:46:14.586737+03
18639	17	-1	1500	2020-02-26 09:06:22.726491+03
18640	75	-1	830	2020-02-26 09:09:24.675303+03
18641	36	-1	630	2020-02-26 09:33:27.602251+03
18642	18	-1	910	2020-02-26 09:37:12.855042+03
18643	51	-1	1310	2020-02-26 09:46:56.528442+03
18644	57	-1	1900	2020-02-26 10:06:45.55305+03
18645	77	-1	640	2020-02-26 10:21:22.633119+03
18646	64	-1	970	2020-02-26 10:29:42.01051+03
18647	43	-1	380	2020-02-26 10:29:47.058376+03
18648	36	-1	630	2020-02-26 10:48:46.25076+03
18649	87	-1	2320	2020-02-26 10:50:46.125877+03
18650	92	-2	630	2020-02-26 10:57:41.093972+03
18651	87	-1	2320	2020-02-26 11:06:41.175394+03
18652	39	-1	910	2020-02-26 11:07:51.557028+03
18653	21	-2	960	2020-02-26 11:35:01.090108+03
18654	81	-2	1620	2020-02-26 12:53:08.785456+03
18655	92	-2	630	2020-02-26 12:58:42.460236+03
18656	38	34	539	2020-02-26 13:53:50.460844+03
18657	77	-2	640	2020-02-26 14:20:24.266532+03
18658	10	-1	2080	2020-02-26 14:21:55.963883+03
18659	33	-1	900	2020-02-26 14:32:15.343766+03
18660	67	-1	350	2020-02-26 15:19:07.566423+03
18661	46	-1	1270	2020-02-26 15:22:18.498403+03
18662	60	-1	2700	2020-02-26 15:40:53.118643+03
18663	8	-1	1920	2020-02-26 15:48:32.345817+03
18664	80	-1	1120	2020-02-26 15:54:16.974876+03
18665	30	-1	1140	2020-02-26 15:59:20.471903+03
18666	91	-2	1620	2020-02-26 16:04:39.94871+03
18667	83	-1	1230	2020-02-26 16:06:28.713443+03
18668	49	-1	970	2020-02-26 16:12:27.47147+03
18669	48	-1	640	2020-02-26 16:26:36.27954+03
18670	6	-2	980	2020-02-26 17:08:46.649271+03
18671	91	-2	1620	2020-02-26 17:34:58.466127+03
18672	69	-2	1100	2020-02-26 17:54:16.341903+03
18673	20	-1	830	2020-02-26 18:05:35.424734+03
18674	83	-1	1230	2020-02-26 18:07:52.476554+03
18675	59	-1	1030	2020-02-26 18:23:27.889477+03
18676	26	-1	390	2020-02-26 18:29:51.037069+03
18677	70	-2	760	2020-02-26 18:38:39.363157+03
18678	59	-2	1030	2020-02-26 18:39:54.292856+03
18679	55	-1	3480	2020-02-26 18:40:31.22214+03
18680	35	-1	670	2020-02-26 18:45:50.352368+03
18681	9	-1	2090	2020-02-26 18:49:52.968182+03
18682	54	-1	3470	2020-02-26 19:09:15.979692+03
18683	75	-1	830	2020-02-26 19:13:54.137197+03
18684	32	-1	710	2020-02-26 19:30:18.452082+03
18685	19	-1	1220	2020-02-26 19:40:45.804192+03
18686	46	-2	1270	2020-02-26 19:42:40.758935+03
18687	76	-1	1070	2020-02-26 19:43:24.617195+03
18688	10	-1	2080	2020-02-26 20:24:33.042348+03
18689	8	-1	1920	2020-02-26 20:31:32.784481+03
18690	6	-1	980	2020-02-26 20:43:05.890788+03
18691	17	-1	1500	2020-02-26 21:15:09.935665+03
18692	93	-1	1620	2020-02-26 21:29:55.011648+03
18693	50	-1	1140	2020-02-26 21:34:01.537319+03
18694	6	41	537	2020-02-26 21:36:09.792726+03
18695	35	-2	670	2020-02-26 21:36:27.361881+03
18696	26	19	208	2020-02-26 21:47:30.279257+03
18697	89	-2	1420	2020-02-26 22:10:59.680687+03
18698	22	-1	1070	2020-02-26 22:24:09.763885+03
18699	56	-1	2460	2020-02-26 22:29:14.339571+03
18700	31	25	711	2020-02-26 23:15:31.64454+03
18701	4	-1	1420	2020-02-26 23:15:56.915804+03
18702	92	-1	630	2020-02-26 23:22:41.70206+03
18703	69	-1	1100	2020-02-26 23:23:00.052675+03
18704	30	-1	1140	2020-02-26 23:52:17.955976+03
18705	24	-1	950	2020-02-26 23:57:55.787165+03
18706	34	-1	1550	2020-02-27 00:48:36.387473+03
18707	41	-2	830	2020-02-27 00:49:40.392857+03
18708	89	29	615	2020-02-27 00:51:49.298667+03
18709	12	-1	1650	2020-02-27 01:11:24.547867+03
18710	39	-1	910	2020-02-27 01:18:38.017788+03
18711	69	-1	1100	2020-02-27 01:21:39.28495+03
18712	2	-1	470	2020-02-27 01:59:54.425478+03
18713	7	-1	810	2020-02-27 02:51:35.372736+03
18714	31	-1	1190	2020-02-27 02:58:04.578139+03
18715	14	-2	1350	2020-02-27 03:08:19.70972+03
18716	6	-1	980	2020-02-27 03:10:26.382077+03
18717	84	-1	2700	2020-02-27 03:19:09.180883+03
18718	49	-2	970	2020-02-27 03:48:29.913786+03
18719	9	-1	2090	2020-02-27 03:53:37.518082+03
18720	15	-2	2830	2020-02-27 03:55:58.236977+03
18721	86	-2	910	2020-02-27 04:01:03.18123+03
18722	85	-1	730	2020-02-27 04:07:55.979348+03
18723	72	-2	620	2020-02-27 04:38:29.083433+03
18724	73	-1	960	2020-02-27 04:44:23.542291+03
18725	83	-1	1230	2020-02-27 04:46:27.349971+03
18726	81	-1	1620	2020-02-27 04:50:16.889775+03
18727	12	-1	1650	2020-02-27 04:57:47.141973+03
18728	10	-2	2080	2020-02-27 05:00:27.625709+03
18729	13	-1	460	2020-02-27 05:17:08.135315+03
18730	46	-1	1270	2020-02-27 05:23:38.310721+03
18731	20	-1	830	2020-02-27 05:39:47.109557+03
18732	32	-1	710	2020-02-27 05:47:34.292653+03
18733	4	-1	1420	2020-02-27 06:00:04.921714+03
18734	1	-2	640	2020-02-27 06:12:29.324868+03
18735	12	-1	1650	2020-02-27 06:16:41.31217+03
18736	81	-1	1620	2020-02-27 06:28:25.615394+03
18737	43	-1	380	2020-02-27 06:35:40.711021+03
18738	48	-1	640	2020-02-27 06:37:35.372556+03
18739	34	-1	1550	2020-02-27 06:45:13.961373+03
18740	8	-1	1920	2020-02-27 06:53:03.810451+03
18741	62	-1	1220	2020-02-27 06:56:45.375084+03
18742	84	-1	2700	2020-02-27 07:01:31.786608+03
18743	14	-1	1350	2020-02-27 07:31:24.313915+03
18744	34	-1	1550	2020-02-27 07:36:03.977158+03
18745	67	-1	350	2020-02-27 07:54:21.447126+03
18746	84	-1	2700	2020-02-27 08:09:08.873804+03
18747	73	-1	960	2020-02-27 08:14:13.489173+03
18748	34	-1	1550	2020-02-27 08:16:23.924703+03
18749	2	-2	470	2020-02-27 08:51:44.732308+03
18750	20	-1	830	2020-02-27 09:01:36.240422+03
18751	36	-1	630	2020-02-27 09:03:39.095333+03
18752	9	-1	2090	2020-02-27 09:13:35.803201+03
18753	46	24	535	2020-02-27 09:31:35.444029+03
18754	89	-1	1420	2020-02-27 09:36:12.404784+03
18755	22	-1	1070	2020-02-27 09:40:34.151856+03
18756	40	-1	1430	2020-02-27 09:46:59.616657+03
18757	77	-1	640	2020-02-27 10:02:17.631662+03
18758	38	-2	1100	2020-02-27 10:02:56.565672+03
18759	10	-1	2080	2020-02-27 10:20:23.439814+03
18760	48	-1	640	2020-02-27 10:24:04.492031+03
18761	6	-2	980	2020-02-27 10:42:46.330729+03
18762	78	-1	900	2020-02-27 10:56:33.859296+03
18763	66	-1	690	2020-02-27 11:02:17.441913+03
18764	29	-1	1940	2020-02-27 11:05:49.991411+03
18765	70	-1	760	2020-02-27 11:08:46.108924+03
18766	21	-1	960	2020-02-27 11:51:56.061174+03
18767	4	-1	1420	2020-02-27 12:02:59.312192+03
18768	83	-1	1230	2020-02-27 12:03:00.673616+03
18769	52	-1	1090	2020-02-27 12:45:41.135026+03
18770	3	-1	660	2020-02-27 13:13:50.260218+03
18771	5	-1	1620	2020-02-27 13:23:21.250942+03
18772	46	-1	1270	2020-02-27 13:57:34.130548+03
18773	80	-1	1120	2020-02-27 14:23:46.627033+03
18774	90	39	988	2020-02-27 14:24:31.489357+03
18775	73	-1	960	2020-02-27 14:41:57.990503+03
18776	82	-1	560	2020-02-27 15:37:56.180176+03
18777	70	-1	760	2020-02-27 15:50:23.484692+03
18778	92	-1	630	2020-02-27 15:54:07.853643+03
18779	6	-1	980	2020-02-27 16:21:54.818191+03
18780	24	-1	950	2020-02-27 16:55:31.225088+03
18781	42	-1	1790	2020-02-27 17:26:05.303613+03
18782	46	-1	1270	2020-02-27 17:31:56.182309+03
18783	45	-1	1590	2020-02-27 17:34:59.120576+03
18784	28	-1	1860	2020-02-27 17:37:57.343092+03
18785	75	-2	830	2020-02-27 17:39:15.022384+03
18786	76	-2	1070	2020-02-27 17:49:50.552493+03
18787	85	-1	730	2020-02-27 17:51:22.382161+03
18788	49	-2	970	2020-02-27 18:09:24.736535+03
18789	69	-1	1100	2020-02-27 18:25:02.276859+03
18790	32	-1	710	2020-02-27 18:25:41.80233+03
18791	38	-1	1100	2020-02-27 18:35:02.117924+03
18792	89	-1	1420	2020-02-27 18:42:54.422721+03
18793	55	-1	3480	2020-02-27 18:54:42.058488+03
18794	5	-1	1620	2020-02-27 19:16:50.394016+03
18795	33	-1	900	2020-02-27 19:51:36.462285+03
18796	5	-2	1620	2020-02-27 20:14:37.718095+03
18797	33	-1	900	2020-02-27 20:25:39.898294+03
18798	85	-1	730	2020-02-27 20:36:44.547877+03
18799	46	-1	1270	2020-02-27 20:49:10.595951+03
18800	80	-1	1120	2020-02-27 20:49:44.275299+03
18801	95	-1	480	2020-02-27 21:12:24.314427+03
18802	37	-1	1290	2020-02-27 21:15:30.686446+03
18803	1	-1	640	2020-02-27 21:20:23.76382+03
18804	54	-1	3470	2020-02-27 21:43:04.401241+03
18805	5	-1	1620	2020-02-27 22:03:04.076457+03
18806	41	-1	830	2020-02-27 22:14:05.375532+03
18807	10	-2	2080	2020-02-27 22:19:36.021944+03
18808	28	-1	1860	2020-02-27 22:28:34.357724+03
18809	25	17	451	2020-02-27 22:34:58.856214+03
18810	75	-1	830	2020-02-27 22:36:15.862881+03
18811	33	-2	900	2020-02-27 22:39:58.139794+03
18812	43	-1	380	2020-02-27 22:52:37.233388+03
18813	4	-1	1420	2020-02-27 23:24:23.021289+03
18814	77	-1	640	2020-02-27 23:32:37.743264+03
18815	62	-2	1220	2020-02-28 00:05:28.624991+03
18816	47	-2	1480	2020-02-28 00:29:19.621351+03
18817	83	-1	1230	2020-02-28 00:31:00.173658+03
18818	89	-1	1420	2020-02-28 00:34:54.044254+03
18819	39	-1	910	2020-02-28 00:46:26.942081+03
18820	84	-1	2700	2020-02-28 01:30:36.588549+03
18821	1	-1	640	2020-02-28 02:35:15.237477+03
18822	19	-1	1220	2020-02-28 02:43:54.152446+03
18823	37	-1	1290	2020-02-28 02:54:34.839146+03
18824	65	-1	490	2020-02-28 03:03:28.166953+03
18825	53	-1	3120	2020-02-28 03:04:43.674674+03
18826	33	-1	900	2020-02-28 03:18:31.578572+03
18827	90	-2	1780	2020-02-28 03:29:30.042127+03
18828	47	-1	1480	2020-02-28 03:39:34.833275+03
18829	67	-1	350	2020-02-28 03:56:23.066486+03
18830	14	-1	1350	2020-02-28 04:01:10.530329+03
18831	6	-1	980	2020-02-28 04:17:32.311418+03
18832	13	-1	460	2020-02-28 04:49:02.115744+03
18833	35	-1	670	2020-02-28 04:51:17.280986+03
18834	91	-2	1620	2020-02-28 05:03:51.850544+03
18835	66	11	370	2020-02-28 05:07:07.695547+03
18836	90	-1	1780	2020-02-28 05:08:58.0806+03
18837	76	28	450	2020-02-28 05:11:00.408085+03
18838	96	-2	1570	2020-02-28 05:39:17.934487+03
18839	24	-1	950	2020-02-28 06:15:41.926742+03
18840	30	-1	1140	2020-02-28 06:20:11.691302+03
18841	51	-1	1310	2020-02-28 06:24:24.32287+03
18842	40	-1	1430	2020-02-28 06:36:52.263679+03
18843	79	-2	550	2020-02-28 06:37:44.827747+03
18844	1	-2	640	2020-02-28 07:14:05.634475+03
18845	30	-2	1140	2020-02-28 07:38:40.183519+03
18846	12	-2	1650	2020-02-28 07:44:45.609853+03
18847	54	-1	3470	2020-02-28 07:56:00.602759+03
18848	25	-1	1100	2020-02-28 07:56:37.418793+03
18849	14	41	612	2020-02-28 08:06:44.360709+03
18850	82	-1	560	2020-02-28 08:15:49.149333+03
18851	36	-1	630	2020-02-28 08:24:47.47454+03
18852	33	-1	900	2020-02-28 08:46:53.403887+03
18853	19	-1	1220	2020-02-28 08:47:12.707087+03
18854	50	-3	1140	2020-02-28 09:37:24.25864+03
18855	76	-1	1070	2020-02-28 09:40:56.737341+03
18856	6	-1	980	2020-02-28 10:38:11.223984+03
18857	6	-1	980	2020-02-28 10:39:39.356814+03
18858	47	-1	1480	2020-02-28 10:47:40.318862+03
18859	29	-1	1940	2020-02-28 11:38:37.042574+03
18860	39	-1	910	2020-02-28 12:05:41.454454+03
18861	89	-1	1420	2020-02-28 12:21:49.489083+03
18862	50	-2	1140	2020-02-28 12:26:52.613051+03
18863	85	-1	730	2020-02-28 12:29:57.34926+03
18864	87	-2	2320	2020-02-28 12:30:19.00105+03
18865	50	-2	1140	2020-02-28 12:36:38.505361+03
18866	15	-2	2830	2020-02-28 12:41:46.586121+03
18867	17	-1	1500	2020-02-28 12:58:04.772626+03
18868	82	-1	560	2020-02-28 13:34:13.721396+03
18869	57	-1	1900	2020-02-28 14:26:34.217772+03
18870	10	-1	2080	2020-02-28 14:29:34.309641+03
18871	54	-1	3470	2020-02-28 14:37:02.454196+03
18872	47	-1	1480	2020-02-28 15:06:29.398232+03
18873	7	-1	810	2020-02-28 15:12:03.347181+03
18874	87	-1	2320	2020-02-28 15:19:22.673416+03
18875	74	-2	1010	2020-02-28 15:26:43.85924+03
18876	56	-1	2460	2020-02-28 15:43:58.519957+03
18877	26	-1	390	2020-02-28 16:08:08.428076+03
18878	76	-1	1070	2020-02-28 16:16:19.876649+03
18879	5	-1	1620	2020-02-28 16:27:13.05362+03
18880	88	-2	1270	2020-02-28 16:34:00.660201+03
18881	36	-1	630	2020-02-28 16:56:56.960696+03
18882	63	-1	1780	2020-02-28 17:05:36.159321+03
18883	65	-2	490	2020-02-28 17:17:04.987144+03
18884	51	-2	1310	2020-02-28 17:19:21.527481+03
18885	43	-1	380	2020-02-28 17:25:20.700069+03
18886	31	-1	1190	2020-02-28 17:48:45.321593+03
18887	90	-1	1780	2020-02-28 17:50:13.473286+03
18888	87	-1	2320	2020-02-28 18:09:10.042275+03
18889	89	-1	1420	2020-02-28 18:42:14.852265+03
18890	47	-1	1480	2020-02-28 19:10:10.945629+03
18891	14	-1	1350	2020-02-28 19:53:35.226488+03
18892	13	-2	460	2020-02-28 20:20:06.808841+03
18893	37	-1	1290	2020-02-28 20:34:11.703905+03
18894	34	-1	1550	2020-02-28 20:36:25.477979+03
18895	56	-1	2460	2020-02-28 21:00:05.266858+03
18896	88	27	529	2020-02-28 21:00:29.646684+03
18897	17	-1	1500	2020-02-28 21:03:08.46406+03
18898	96	-1	1570	2020-02-28 21:04:30.425668+03
18899	26	-2	390	2020-02-28 21:13:09.095178+03
18900	83	-1	1230	2020-02-28 21:43:35.749132+03
18901	94	-1	1230	2020-02-28 21:44:38.536983+03
18902	29	-2	1940	2020-02-28 21:45:27.891006+03
18903	56	-1	2460	2020-02-28 21:49:58.664896+03
18904	6	-1	980	2020-02-28 21:55:20.188114+03
18905	70	-1	760	2020-02-28 22:19:21.023937+03
18906	71	-1	1030	2020-02-28 22:30:37.555695+03
18907	3	-1	660	2020-02-28 22:56:31.798224+03
18908	20	-1	830	2020-02-28 23:13:13.344008+03
18909	39	-2	910	2020-02-28 23:41:59.077046+03
18910	44	-1	500	2020-02-28 23:42:09.397959+03
18911	38	-1	1100	2020-02-29 00:28:11.455915+03
18912	12	-1	1650	2020-02-29 00:34:55.872635+03
18913	83	-2	1230	2020-02-29 00:38:01.20779+03
18914	9	-1	2090	2020-02-29 00:43:07.340438+03
18915	8	-1	1920	2020-02-29 00:54:04.78606+03
18916	75	-1	830	2020-02-29 00:54:30.915272+03
18917	58	-1	2830	2020-02-29 02:31:00.478408+03
18918	63	-1	1780	2020-02-29 03:35:42.726787+03
18919	85	-1	730	2020-02-29 03:41:42.452783+03
18920	66	-2	690	2020-02-29 04:03:12.944247+03
18921	35	-1	670	2020-02-29 04:29:45.581539+03
18922	57	-1	1900	2020-02-29 04:40:27.081637+03
18923	59	-1	1030	2020-02-29 04:46:39.691954+03
18924	27	-2	880	2020-02-29 05:08:07.996549+03
18925	57	-1	1900	2020-02-29 05:24:11.091321+03
18926	25	-1	1100	2020-02-29 05:38:56.194525+03
18927	84	-1	2700	2020-02-29 05:43:32.236648+03
18928	60	-1	2700	2020-02-29 05:46:19.448608+03
18929	12	-1	1650	2020-02-29 05:56:41.76287+03
18930	40	-1	1430	2020-02-29 06:53:53.112008+03
18931	49	-1	970	2020-02-29 07:02:45.83278+03
18932	44	-1	500	2020-02-29 07:07:15.884927+03
18933	5	-3	1620	2020-02-29 07:11:02.61279+03
18934	29	-1	1940	2020-02-29 07:17:44.001483+03
18935	55	-1	3480	2020-02-29 07:42:08.482147+03
18936	53	-1	3120	2020-02-29 07:44:55.231872+03
18937	58	-1	2830	2020-02-29 07:58:36.249721+03
18938	33	-1	900	2020-02-29 09:13:59.69473+03
18939	90	-2	1780	2020-02-29 09:24:35.690718+03
18940	38	-1	1100	2020-02-29 09:51:22.080903+03
18941	43	-1	380	2020-02-29 09:58:57.248224+03
18942	1	-1	640	2020-02-29 10:16:11.807836+03
18943	83	-2	1230	2020-02-29 10:22:43.047067+03
18944	6	-2	980	2020-02-29 10:28:17.773319+03
18945	39	-1	910	2020-02-29 10:47:42.507411+03
18946	76	-1	1070	2020-02-29 10:57:03.117815+03
18947	69	-1	1100	2020-02-29 11:33:19.045467+03
18948	78	-1	900	2020-02-29 12:04:09.569863+03
18949	29	-1	1940	2020-02-29 12:05:17.979975+03
18950	52	-1	1090	2020-02-29 12:13:32.228027+03
18951	35	-1	670	2020-02-29 12:51:22.947281+03
18952	57	-1	1900	2020-02-29 13:05:27.077238+03
18953	12	-1	1650	2020-02-29 14:21:28.514368+03
18954	90	-1	1780	2020-02-29 14:29:21.688695+03
18955	54	-1	3470	2020-02-29 14:38:18.634873+03
18956	29	-2	1940	2020-02-29 14:41:41.54784+03
18957	9	-1	2090	2020-02-29 15:02:25.332014+03
18958	87	-1	2320	2020-02-29 15:06:25.07266+03
18959	83	-1	1230	2020-02-29 15:29:44.126132+03
18960	88	-1	1270	2020-02-29 15:38:45.090955+03
18961	73	-1	960	2020-02-29 15:49:25.323813+03
18962	64	-2	970	2020-02-29 16:06:00.113629+03
18963	49	-1	970	2020-02-29 16:11:40.614586+03
18964	9	19	1053	2020-02-29 16:17:34.699082+03
18965	53	-1	3120	2020-02-29 16:40:35.60473+03
18966	57	-1	1900	2020-02-29 17:19:11.471957+03
18967	69	-1	1100	2020-02-29 17:22:14.830921+03
18968	63	-2	1780	2020-02-29 17:22:29.746944+03
18969	57	-2	1900	2020-02-29 17:44:32.430945+03
18970	60	-1	2700	2020-02-29 17:47:08.752003+03
18971	39	-1	910	2020-02-29 17:58:47.780791+03
18972	12	-1	1650	2020-02-29 18:03:49.571533+03
18973	18	-1	910	2020-02-29 18:30:44.469896+03
18974	26	-2	390	2020-02-29 19:03:29.518418+03
18975	17	-2	1500	2020-02-29 19:30:17.740963+03
18976	13	-1	460	2020-02-29 19:41:01.36373+03
18977	39	-1	910	2020-02-29 20:01:48.554867+03
18978	54	-1	3470	2020-02-29 20:15:33.784859+03
18979	54	-1	3470	2020-02-29 20:26:06.748903+03
18980	56	-1	2460	2020-02-29 20:34:08.949224+03
18981	4	-1	1420	2020-02-29 20:55:53.892192+03
18982	65	-2	490	2020-02-29 21:10:52.903886+03
18983	35	-1	670	2020-02-29 21:35:30.413188+03
18984	57	-1	1900	2020-02-29 21:38:31.995207+03
18985	85	-1	730	2020-02-29 21:59:47.789342+03
18986	13	-1	460	2020-02-29 22:07:48.948207+03
18987	44	-1	500	2020-02-29 22:21:37.737721+03
18988	69	-1	1100	2020-02-29 22:28:23.279176+03
18989	35	-1	670	2020-02-29 22:49:42.478348+03
18990	71	-1	1030	2020-02-29 22:50:39.68993+03
18991	70	-2	760	2020-02-29 22:54:50.11975+03
18992	56	-1	2460	2020-02-29 23:39:07.732734+03
18993	54	-1	3470	2020-03-01 00:01:55.479808+03
18994	59	-1	1030	2020-03-01 00:04:10.166834+03
18995	13	-1	460	2020-03-01 00:26:35.555844+03
18996	76	-1	1070	2020-03-01 00:28:40.21135+03
18997	83	-1	1230	2020-03-01 00:31:17.417982+03
18998	1	26	274	2020-03-01 00:50:32.204226+03
18999	34	-1	1550	2020-03-01 01:40:44.070434+03
19000	7	-1	810	2020-03-01 01:47:21.716651+03
19001	76	-2	1070	2020-03-01 02:26:18.650685+03
19002	10	-2	2080	2020-03-01 02:34:52.766851+03
19003	22	-2	1070	2020-03-01 02:47:39.442101+03
19004	44	-1	500	2020-03-01 02:51:43.73895+03
19005	26	-1	390	2020-03-01 02:53:08.626885+03
19006	45	-1	1590	2020-03-01 03:01:57.376688+03
19007	56	-1	2460	2020-03-01 03:02:00.011004+03
19008	29	-2	1940	2020-03-01 03:15:29.502431+03
19009	39	-1	910	2020-03-01 03:33:46.3942+03
19010	39	-2	910	2020-03-01 04:35:07.859951+03
19011	44	-1	500	2020-03-01 04:38:18.052748+03
19012	60	-1	2700	2020-03-01 04:44:17.925751+03
19013	38	-1	1100	2020-03-01 05:10:31.596946+03
19014	69	-1	1100	2020-03-01 05:17:00.841673+03
19015	84	-1	2700	2020-03-01 05:26:42.783392+03
19016	6	-1	980	2020-03-01 05:35:19.600721+03
19017	55	-1	3480	2020-03-01 05:36:50.989165+03
19018	69	23	574	2020-03-01 06:15:40.604348+03
19019	57	-2	1900	2020-03-01 06:19:00.065494+03
19020	70	29	395	2020-03-01 06:45:00.910082+03
19021	51	-1	1310	2020-03-01 06:53:12.891197+03
19022	67	-2	350	2020-03-01 06:56:32.720881+03
19023	30	-1	1140	2020-03-01 06:57:58.159248+03
19024	96	-1	1570	2020-03-01 07:00:57.179006+03
19025	96	-1	1570	2020-03-01 07:18:45.938853+03
19026	25	-2	1100	2020-03-01 07:21:19.926574+03
19027	18	-1	910	2020-03-01 07:21:30.962423+03
19028	94	-1	1230	2020-03-01 07:42:24.738669+03
19029	68	-1	490	2020-03-01 07:44:47.574821+03
19030	42	-1	1790	2020-03-01 07:47:05.049018+03
19031	1	-1	640	2020-03-01 07:54:12.141941+03
19032	46	-2	1270	2020-03-01 08:50:40.26731+03
19033	95	-1	480	2020-03-01 09:04:18.123914+03
19034	83	-1	1230	2020-03-01 09:24:09.512247+03
19035	47	-2	1480	2020-03-01 09:33:29.882071+03
19036	27	-1	880	2020-03-01 09:55:33.940338+03
19037	93	-1	1620	2020-03-01 10:58:45.695388+03
19038	87	-1	2320	2020-03-01 11:14:07.223087+03
19039	75	-2	830	2020-03-01 11:15:45.827151+03
19040	68	-1	490	2020-03-01 11:57:49.630752+03
19041	64	-1	970	2020-03-01 12:07:06.086821+03
19042	64	-2	970	2020-03-01 12:11:56.816714+03
19043	47	-1	1480	2020-03-01 12:31:38.900844+03
19044	92	-1	630	2020-03-01 14:14:25.574274+03
19045	71	-1	1030	2020-03-01 14:18:10.504832+03
19046	37	-1	1290	2020-03-01 14:53:13.219344+03
19047	68	-1	490	2020-03-01 15:00:24.739628+03
19048	40	-1	1430	2020-03-01 15:03:15.548514+03
19049	90	-1	1780	2020-03-01 15:11:06.777312+03
19050	89	-1	1420	2020-03-01 15:30:17.861113+03
19051	83	-1	1230	2020-03-01 15:44:43.648327+03
19052	27	15	459	2020-03-01 15:52:19.249752+03
19053	3	-1	660	2020-03-01 15:57:34.463355+03
19054	76	-1	1070	2020-03-01 16:00:19.722342+03
19055	12	-1	1650	2020-03-01 16:04:52.558115+03
19056	21	-1	960	2020-03-01 16:08:45.466221+03
19057	78	-1	900	2020-03-01 16:12:51.043856+03
19058	48	-1	640	2020-03-01 16:33:26.83834+03
19059	52	-2	1090	2020-03-01 16:39:49.502351+03
19060	38	-1	1100	2020-03-01 16:48:10.609715+03
19061	22	-2	1070	2020-03-01 17:10:21.757857+03
19062	52	-1	1090	2020-03-01 17:20:19.84634+03
19063	20	-1	830	2020-03-01 17:29:16.006768+03
19064	20	48	374	2020-03-01 17:31:25.802906+03
19065	34	-1	1550	2020-03-01 17:41:56.17272+03
19066	87	-2	2320	2020-03-01 17:48:09.204734+03
19067	80	25	656	2020-03-01 18:08:28.486045+03
19068	76	-1	1070	2020-03-01 18:16:03.756916+03
19069	31	-1	1190	2020-03-01 19:04:36.561278+03
19070	12	-1	1650	2020-03-01 19:22:14.599575+03
19071	34	-1	1550	2020-03-01 19:24:23.259161+03
19072	87	-1	2320	2020-03-01 20:23:26.742513+03
19073	47	-2	1480	2020-03-01 20:33:19.971815+03
19074	75	-1	830	2020-03-01 21:00:43.789166+03
19075	65	22	235	2020-03-01 21:06:58.646471+03
19076	48	-1	640	2020-03-01 21:08:02.7352+03
19077	91	-1	1620	2020-03-01 21:39:17.696057+03
19078	13	-1	460	2020-03-01 21:47:21.088982+03
19079	23	-1	4390	2020-03-01 21:54:10.163335+03
19080	46	-2	1270	2020-03-01 22:06:22.69935+03
19081	82	-1	560	2020-03-01 22:23:55.152196+03
19082	46	-1	1270	2020-03-01 22:35:02.991295+03
19083	5	-1	1620	2020-03-01 22:37:50.465121+03
19084	67	-1	350	2020-03-01 22:40:53.883644+03
19085	74	-1	1010	2020-03-01 22:47:43.553413+03
19086	27	-1	880	2020-03-01 23:15:58.77376+03
19087	33	-1	900	2020-03-01 23:16:41.848048+03
19088	36	-1	630	2020-03-01 23:39:01.995096+03
19089	10	-1	2080	2020-03-02 00:13:32.661227+03
19090	66	-1	690	2020-03-02 00:22:09.541087+03
19091	22	37	549	2020-03-02 00:34:10.030209+03
19092	86	-1	910	2020-03-02 00:57:41.51496+03
19093	19	-1	1220	2020-03-02 01:03:37.543332+03
19094	31	-1	1190	2020-03-02 01:19:57.752804+03
19095	75	-1	830	2020-03-02 01:46:07.499964+03
19096	80	-1	1120	2020-03-02 02:00:41.36741+03
19097	88	-2	1270	2020-03-02 02:25:32.292286+03
19098	71	-1	1030	2020-03-02 03:01:04.423763+03
19099	20	-1	830	2020-03-02 03:07:36.2971+03
19100	86	-1	910	2020-03-02 03:18:12.010389+03
19101	96	-1	1570	2020-03-02 03:40:54.7465+03
19102	86	-1	910	2020-03-02 03:49:25.14+03
19103	95	-1	480	2020-03-02 03:54:03.819387+03
19104	33	-1	900	2020-03-02 03:54:59.113225+03
19105	85	23	315	2020-03-02 04:00:11.226881+03
19106	11	-1	830	2020-03-02 04:30:54.015353+03
19107	60	-2	2700	2020-03-02 04:35:01.54799+03
19108	77	36	282	2020-03-02 04:48:34.766974+03
19109	12	34	830	2020-03-02 05:03:08.984243+03
19110	88	-1	1270	2020-03-02 05:05:11.569683+03
19111	69	-1	1100	2020-03-02 05:21:24.619709+03
19112	13	-1	460	2020-03-02 05:21:27.457138+03
19113	74	-1	1010	2020-03-02 05:32:35.293119+03
19114	81	-2	1620	2020-03-02 05:32:41.44562+03
19115	64	32	530	2020-03-02 06:12:27.657417+03
19116	11	-1	830	2020-03-02 06:16:52.221509+03
19117	87	-1	2320	2020-03-02 06:17:35.4813+03
19118	95	-1	480	2020-03-02 06:24:45.012312+03
19119	28	-1	1860	2020-03-02 06:43:56.927349+03
19120	45	-2	1590	2020-03-02 06:46:12.611074+03
19121	22	-1	1070	2020-03-02 06:50:25.151023+03
19122	46	-2	1270	2020-03-02 06:57:23.92743+03
19123	49	-1	970	2020-03-02 07:41:14.771853+03
19124	51	-1	1310	2020-03-02 07:46:45.824301+03
19125	30	-1	1140	2020-03-02 08:07:21.714049+03
19126	48	-1	640	2020-03-02 08:21:22.730069+03
19127	55	-1	3480	2020-03-02 08:44:21.872525+03
19128	4	-1	1420	2020-03-02 08:52:50.79363+03
19129	65	-1	490	2020-03-02 09:32:07.438805+03
19130	88	-1	1270	2020-03-02 10:35:57.976178+03
19131	61	-2	1510	2020-03-02 10:44:47.736917+03
19132	75	-1	830	2020-03-02 11:28:37.601852+03
19133	18	-1	910	2020-03-02 12:07:41.75793+03
19134	55	-1	3480	2020-03-02 12:32:50.884117+03
19135	13	-1	460	2020-03-02 12:43:48.42364+03
19136	68	-2	490	2020-03-02 12:45:55.980163+03
19137	86	-1	910	2020-03-02 12:53:57.087712+03
19138	7	-1	810	2020-03-02 13:30:13.130228+03
19139	51	-1	1310	2020-03-02 13:34:11.580096+03
19140	1	-1	640	2020-03-02 13:44:08.211233+03
19141	5	-1	1620	2020-03-02 14:15:19.434245+03
19142	21	30	577	2020-03-02 14:15:29.343972+03
19143	96	-1	1570	2020-03-02 15:51:00.183642+03
19144	12	-1	1650	2020-03-02 15:53:13.414691+03
19145	36	-2	630	2020-03-02 15:54:12.515136+03
19146	18	-1	910	2020-03-02 15:56:32.234251+03
19147	4	-1	1420	2020-03-02 16:47:08.358328+03
19148	57	-2	1900	2020-03-02 16:54:43.685324+03
19149	49	-2	970	2020-03-02 17:06:10.148032+03
19150	25	-1	1100	2020-03-02 17:45:15.91477+03
19151	2	18	261	2020-03-02 18:04:31.854746+03
19152	29	-1	1940	2020-03-02 18:11:53.468197+03
19153	49	-1	970	2020-03-02 18:18:39.961848+03
19154	69	-1	1100	2020-03-02 18:21:12.769548+03
19155	23	-1	4390	2020-03-02 18:21:19.165813+03
19156	83	-1	1230	2020-03-02 18:25:46.640465+03
19157	33	-1	900	2020-03-02 18:35:21.887125+03
19158	46	-1	1270	2020-03-02 18:44:56.720554+03
19159	11	-1	830	2020-03-02 18:49:03.222616+03
19160	24	-2	950	2020-03-02 18:58:40.614032+03
19161	46	-1	1270	2020-03-02 19:11:50.531631+03
19162	86	-2	910	2020-03-02 19:33:29.619857+03
19163	88	-1	1270	2020-03-02 19:38:51.535763+03
19164	14	-1	1350	2020-03-02 19:41:03.387022+03
19165	36	-1	630	2020-03-02 19:41:08.989408+03
19166	46	-2	1270	2020-03-02 20:36:06.443157+03
19167	24	15	559	2020-03-02 20:40:28.65694+03
19168	69	-1	1100	2020-03-02 20:41:30.854292+03
19169	5	-1	1620	2020-03-02 21:09:03.608702+03
19170	18	-1	910	2020-03-02 21:28:10.820212+03
19171	51	-1	1310	2020-03-02 21:58:09.640385+03
19172	95	-1	480	2020-03-02 22:02:55.530746+03
19173	22	-1	1070	2020-03-02 22:12:09.232656+03
19174	36	-1	630	2020-03-02 22:25:34.715496+03
19175	92	-1	630	2020-03-02 22:30:40.619841+03
19176	88	-1	1270	2020-03-02 22:33:27.515591+03
19177	39	-1	910	2020-03-02 22:35:40.526233+03
19178	32	-1	710	2020-03-02 22:38:12.376949+03
19179	33	-1	900	2020-03-02 23:13:52.876741+03
19180	26	-1	390	2020-03-02 23:16:03.574315+03
19181	6	-1	980	2020-03-02 23:19:45.226484+03
19182	66	-1	690	2020-03-02 23:28:43.310599+03
19183	92	-1	630	2020-03-02 23:39:28.029308+03
19184	12	-1	1650	2020-03-02 23:44:02.492447+03
19185	76	-1	1070	2020-03-03 00:28:37.853241+03
19186	44	24	226	2020-03-03 00:35:25.4191+03
19187	88	-2	1270	2020-03-03 00:54:09.364051+03
19188	55	-2	3480	2020-03-03 00:59:14.764289+03
19189	48	-2	640	2020-03-03 01:16:31.029375+03
19190	83	-1	1230	2020-03-03 01:29:25.307969+03
19191	8	-1	1920	2020-03-03 02:08:52.543205+03
19192	81	-1	1620	2020-03-03 02:20:12.057619+03
19193	72	-1	620	2020-03-03 02:29:58.359031+03
19194	87	-1	2320	2020-03-03 02:44:48.410204+03
19195	76	-1	1070	2020-03-03 02:50:05.059798+03
19196	92	-1	630	2020-03-03 03:28:41.828011+03
19197	18	-1	910	2020-03-03 04:22:06.037619+03
19198	57	-1	1900	2020-03-03 04:31:08.798178+03
19199	49	-1	970	2020-03-03 04:50:41.326743+03
19200	57	-2	1900	2020-03-03 05:28:51.172006+03
19201	18	-1	910	2020-03-03 05:50:50.367213+03
19202	5	36	869	2020-03-03 06:05:47.662767+03
19203	65	-1	490	2020-03-03 06:14:27.789934+03
19204	54	-1	3470	2020-03-03 06:35:57.376336+03
19205	53	-1	3120	2020-03-03 07:22:59.37741+03
19206	61	-1	1510	2020-03-03 07:47:25.822694+03
19207	37	-1	1290	2020-03-03 07:48:42.690757+03
19208	38	-1	1100	2020-03-03 08:32:50.420747+03
19209	39	-2	910	2020-03-03 09:12:42.296946+03
19210	72	-1	620	2020-03-03 09:36:34.448618+03
19211	33	-1	900	2020-03-03 09:52:03.661715+03
19212	78	-2	900	2020-03-03 09:59:53.27091+03
19213	63	-1	1780	2020-03-03 10:05:58.797916+03
19214	25	-1	1100	2020-03-03 10:23:59.092126+03
19215	79	-1	550	2020-03-03 10:36:15.810395+03
19216	83	-1	1230	2020-03-03 11:17:58.057268+03
19217	73	-1	960	2020-03-03 11:21:54.54397+03
19218	88	-1	1270	2020-03-03 11:35:51.011183+03
19219	51	-1	1310	2020-03-03 11:43:42.964353+03
19220	6	-1	980	2020-03-03 11:53:23.933309+03
19221	12	-1	1650	2020-03-03 11:56:17.118836+03
19222	68	-1	490	2020-03-03 12:51:49.835569+03
19223	57	-1	1900	2020-03-03 12:52:38.56784+03
19224	90	-1	1780	2020-03-03 13:08:01.499439+03
19225	14	-1	1350	2020-03-03 13:19:00.704638+03
19226	76	-1	1070	2020-03-03 13:23:55.44339+03
19227	79	-1	550	2020-03-03 14:11:08.793804+03
19228	43	-1	380	2020-03-03 14:55:36.087197+03
19229	11	-1	830	2020-03-03 14:59:02.292178+03
19230	10	-1	2080	2020-03-03 15:15:53.375815+03
19231	71	-1	1030	2020-03-03 15:17:32.239306+03
19232	72	-1	620	2020-03-03 15:25:14.764106+03
19233	47	-1	1480	2020-03-03 15:34:08.835168+03
19234	96	-1	1570	2020-03-03 15:45:39.159962+03
19235	38	-1	1100	2020-03-03 16:15:55.470967+03
19236	54	-1	3470	2020-03-03 16:33:07.218464+03
19237	29	-2	1940	2020-03-03 16:57:15.468756+03
19238	51	-1	1310	2020-03-03 17:07:25.30573+03
19239	67	-1	350	2020-03-03 17:21:56.117757+03
19240	19	-1	1220	2020-03-03 17:42:28.703718+03
19241	58	-2	2830	2020-03-03 17:55:49.924611+03
19242	26	-1	390	2020-03-03 17:58:06.308128+03
19243	10	-1	2080	2020-03-03 18:23:51.125858+03
19244	63	-1	1780	2020-03-03 18:36:42.044567+03
19245	20	-1	830	2020-03-03 20:06:32.813951+03
19246	51	26	579	2020-03-03 20:22:30.746105+03
19247	48	-1	640	2020-03-03 21:07:37.066326+03
19248	30	27	640	2020-03-03 21:29:17.116711+03
19249	77	-1	640	2020-03-03 21:35:03.3374+03
19250	13	-1	460	2020-03-03 22:03:31.370502+03
19251	45	-1	1590	2020-03-03 22:52:04.065442+03
19252	54	-1	3470	2020-03-03 23:16:22.689717+03
19253	1	-1	640	2020-03-03 23:16:54.502749+03
19254	72	-1	620	2020-03-03 23:33:53.639072+03
19255	20	-2	830	2020-03-03 23:38:54.610861+03
19256	45	-2	1590	2020-03-03 23:42:04.74367+03
19257	80	-1	1120	2020-03-03 23:54:19.656491+03
19258	10	-1	2080	2020-03-04 00:05:03.727599+03
19259	91	24	799	2020-03-04 00:08:29.239192+03
19260	8	-1	1920	2020-03-04 00:27:58.238928+03
19261	77	-2	640	2020-03-04 00:30:26.074772+03
19262	60	-1	2700	2020-03-04 00:57:12.627177+03
19263	12	-1	1650	2020-03-04 00:58:11.475041+03
19264	80	-1	1120	2020-03-04 00:59:50.492972+03
19265	95	-1	480	2020-03-04 01:22:57.836135+03
19266	75	-1	830	2020-03-04 01:23:11.613897+03
19267	49	-1	970	2020-03-04 02:12:23.025647+03
19268	23	-1	4390	2020-03-04 02:52:58.218426+03
19269	9	-1	2090	2020-03-04 02:57:38.089306+03
19270	42	-1	1790	2020-03-04 03:00:16.171238+03
19271	10	-2	2080	2020-03-04 03:11:02.513365+03
19272	40	-1	1430	2020-03-04 03:16:47.980935+03
19273	75	-1	830	2020-03-04 03:20:01.552968+03
19274	30	-2	1140	2020-03-04 03:50:17.126741+03
19275	10	-1	2080	2020-03-04 04:14:56.538078+03
19276	18	-2	910	2020-03-04 04:38:41.915437+03
19277	14	-2	1350	2020-03-04 04:42:34.086023+03
19278	54	-1	3470	2020-03-04 04:51:09.751576+03
19279	77	-1	640	2020-03-04 04:53:25.980976+03
19280	75	-1	830	2020-03-04 05:07:14.111902+03
19281	50	16	520	2020-03-04 05:15:42.045383+03
19282	82	-1	560	2020-03-04 05:24:26.044052+03
19283	22	-1	1070	2020-03-04 05:40:12.023805+03
19284	64	-1	970	2020-03-04 05:53:23.651725+03
19285	91	-1	1620	2020-03-04 05:55:15.9796+03
19286	89	-1	1420	2020-03-04 06:02:50.245802+03
19287	69	-2	1100	2020-03-04 06:04:45.586496+03
19288	42	-1	1790	2020-03-04 06:11:26.660014+03
19289	29	-1	1940	2020-03-04 06:11:43.577427+03
19290	95	-1	480	2020-03-04 06:12:07.688942+03
19291	75	32	454	2020-03-04 06:17:46.123566+03
19292	63	-1	1780	2020-03-04 06:37:26.094507+03
19293	12	-1	1650	2020-03-04 07:00:04.211585+03
19294	54	-1	3470	2020-03-04 07:13:21.472922+03
19295	72	-1	620	2020-03-04 07:55:54.854943+03
19296	4	-1	1420	2020-03-04 08:20:00.457012+03
19297	90	-1	1780	2020-03-04 08:40:24.157902+03
19298	8	-1	1920	2020-03-04 08:43:51.42934+03
19299	60	-1	2700	2020-03-04 08:51:16.25912+03
19300	49	-1	970	2020-03-04 09:26:29.134487+03
19301	50	-1	1140	2020-03-04 09:42:54.847845+03
19302	40	-1	1430	2020-03-04 10:18:04.506856+03
19303	64	-1	970	2020-03-04 10:57:24.094732+03
19304	7	-3	810	2020-03-04 11:05:52.306746+03
19305	10	-1	2080	2020-03-04 11:13:19.435211+03
19306	50	-2	1140	2020-03-04 11:19:51.699187+03
19307	29	-1	1940	2020-03-04 11:36:32.571368+03
19308	85	-1	730	2020-03-04 11:44:04.821822+03
19309	68	-1	490	2020-03-04 12:24:12.818025+03
19310	19	-1	1220	2020-03-04 12:29:26.864472+03
19311	86	-1	910	2020-03-04 12:31:15.312701+03
19312	45	-1	1590	2020-03-04 12:43:51.326995+03
19313	12	-1	1650	2020-03-04 12:51:09.243752+03
19314	46	-1	1270	2020-03-04 13:31:26.195534+03
19315	34	-1	1550	2020-03-04 13:35:15.182691+03
19316	62	-1	1220	2020-03-04 13:43:48.893936+03
19317	11	-1	830	2020-03-04 14:08:48.907858+03
19318	83	-2	1230	2020-03-04 14:13:26.269358+03
19319	19	-1	1220	2020-03-04 15:23:10.121167+03
19320	32	-1	710	2020-03-04 15:50:45.475211+03
19321	12	-1	1650	2020-03-04 15:53:49.124614+03
19322	71	-1	1030	2020-03-04 16:02:50.230313+03
19323	69	-1	1100	2020-03-04 16:10:43.587991+03
19324	30	-1	1140	2020-03-04 16:20:52.460791+03
19325	84	-1	2700	2020-03-04 16:28:02.658314+03
19326	64	-1	970	2020-03-04 16:29:38.842474+03
19327	74	24	512	2020-03-04 16:41:53.209619+03
19328	23	-1	4390	2020-03-04 16:45:07.732226+03
19329	64	-1	970	2020-03-04 16:51:36.923308+03
19330	2	-1	470	2020-03-04 17:20:15.093023+03
19331	18	-1	910	2020-03-04 17:24:34.475039+03
19332	35	-1	670	2020-03-04 17:46:27.5358+03
19333	12	-2	1650	2020-03-04 18:09:56.537205+03
19334	8	-1	1920	2020-03-04 18:44:56.36781+03
19335	76	-1	1070	2020-03-04 19:00:46.226848+03
19336	54	35	1470	2020-03-04 19:13:33.611628+03
19337	77	-1	640	2020-03-04 19:20:23.890303+03
19338	30	-1	1140	2020-03-04 19:22:05.778331+03
19339	4	-2	1420	2020-03-04 19:26:08.437855+03
19340	89	-1	1420	2020-03-04 19:39:10.325076+03
19341	10	-1	2080	2020-03-04 20:10:38.012701+03
19342	33	-1	900	2020-03-04 20:27:41.415573+03
19343	52	-1	1090	2020-03-04 20:34:17.703815+03
19344	76	-1	1070	2020-03-04 21:06:58.11559+03
19345	80	-1	1120	2020-03-04 21:10:20.621046+03
19346	16	-1	1380	2020-03-04 22:05:13.552244+03
19347	77	-1	640	2020-03-04 23:21:51.043411+03
19348	32	-1	710	2020-03-05 00:41:45.250996+03
19349	25	-1	1100	2020-03-05 00:46:55.840967+03
19350	14	-1	1350	2020-03-05 00:52:51.582611+03
19351	13	-1	460	2020-03-05 00:56:04.659409+03
19352	18	-2	910	2020-03-05 01:39:07.3892+03
19353	45	-3	1590	2020-03-05 01:39:28.120022+03
19354	13	31	206	2020-03-05 01:43:59.028077+03
19355	42	-1	1790	2020-03-05 01:54:17.267966+03
19356	20	-1	830	2020-03-05 02:01:22.879649+03
19357	16	-1	1380	2020-03-05 02:04:32.179392+03
19358	24	-2	950	2020-03-05 02:11:51.959731+03
19359	16	-1	1380	2020-03-05 02:19:16.11608+03
19360	84	-1	2700	2020-03-05 02:20:02.99978+03
19361	17	-1	1500	2020-03-05 02:59:42.600511+03
19362	54	-1	3470	2020-03-05 03:03:55.793377+03
19363	39	-2	910	2020-03-05 03:08:37.834357+03
19364	86	35	419	2020-03-05 03:31:26.150576+03
19365	37	-2	1290	2020-03-05 03:54:45.987014+03
19366	16	-2	1380	2020-03-05 04:26:01.547488+03
19367	29	-3	1940	2020-03-05 04:44:10.749546+03
19368	4	-2	1420	2020-03-05 05:45:11.822412+03
19369	91	-1	1620	2020-03-05 05:55:30.298309+03
19370	86	-2	910	2020-03-05 06:28:59.688847+03
19371	76	-1	1070	2020-03-05 06:40:59.569928+03
19372	4	37	821	2020-03-05 06:55:58.406832+03
19373	40	-2	1430	2020-03-05 07:02:21.249139+03
19374	54	-2	3470	2020-03-05 07:05:21.409136+03
19375	82	21	257	2020-03-05 07:36:05.784839+03
19376	55	-1	3480	2020-03-05 07:42:41.299024+03
19377	96	-1	1570	2020-03-05 07:59:16.020162+03
19378	1	-1	640	2020-03-05 08:09:23.595247+03
19379	44	-2	500	2020-03-05 08:22:13.947698+03
19380	8	-1	1920	2020-03-05 08:31:07.526627+03
19381	95	-3	480	2020-03-05 08:41:22.615314+03
19382	6	-1	980	2020-03-05 08:52:04.404272+03
19383	71	-2	1030	2020-03-05 08:53:39.195497+03
19384	58	-2	2830	2020-03-05 09:07:14.728462+03
19385	25	-2	1100	2020-03-05 09:15:38.760135+03
19386	92	-1	630	2020-03-05 09:51:19.156337+03
19387	47	-2	1480	2020-03-05 09:58:58.204667+03
19388	93	-2	1620	2020-03-05 10:03:47.844207+03
19389	72	-1	620	2020-03-05 10:10:47.647967+03
19390	4	-1	1420	2020-03-05 10:20:01.954039+03
19391	64	-1	970	2020-03-05 10:35:07.032354+03
19392	31	-1	1190	2020-03-05 10:37:06.710138+03
19393	71	-1	1030	2020-03-05 10:50:20.621443+03
19394	6	-1	980	2020-03-05 10:51:11.010977+03
19395	93	-1	1620	2020-03-05 11:04:00.961557+03
19396	93	26	834	2020-03-05 11:12:24.827449+03
19397	32	-2	710	2020-03-05 11:19:08.780145+03
19398	87	-1	2320	2020-03-05 11:43:00.561423+03
19399	94	-1	1230	2020-03-05 11:48:42.388883+03
19400	46	-2	1270	2020-03-05 12:07:07.78658+03
19401	49	-1	970	2020-03-05 12:24:15.590056+03
19402	20	-1	830	2020-03-05 12:25:59.989933+03
19403	16	-2	1380	2020-03-05 12:32:14.515783+03
19404	45	-1	1590	2020-03-05 12:59:04.761399+03
19405	67	-1	350	2020-03-05 13:01:32.061154+03
19406	20	-1	830	2020-03-05 13:15:50.044987+03
19407	24	-1	950	2020-03-05 13:30:35.047582+03
19408	35	-1	670	2020-03-05 13:46:42.162733+03
19409	60	-1	2700	2020-03-05 13:50:59.952879+03
19410	77	-1	640	2020-03-05 13:58:11.408339+03
19411	77	-1	640	2020-03-05 14:04:13.001447+03
19412	49	-1	970	2020-03-05 14:04:47.315301+03
19413	70	-1	760	2020-03-05 14:25:30.701365+03
19414	21	-1	960	2020-03-05 14:26:02.655865+03
19415	57	-1	1900	2020-03-05 14:46:44.541259+03
19416	47	-2	1480	2020-03-05 15:22:42.624613+03
19417	89	-1	1420	2020-03-05 15:23:25.203854+03
19418	46	-1	1270	2020-03-05 15:38:26.625949+03
19419	72	-1	620	2020-03-05 15:39:59.853928+03
19420	67	-2	350	2020-03-05 15:55:40.301615+03
19421	82	-1	560	2020-03-05 16:03:52.555451+03
19422	70	-1	760	2020-03-05 16:06:34.891332+03
19423	78	-1	900	2020-03-05 16:15:38.43159+03
19424	8	-1	1920	2020-03-05 16:17:39.222701+03
19425	13	-2	460	2020-03-05 16:18:24.977533+03
19426	16	-1	1380	2020-03-05 16:53:11.962772+03
19427	14	-1	1350	2020-03-05 16:57:17.46298+03
19428	96	-1	1570	2020-03-05 17:08:54.648879+03
19429	33	-1	900	2020-03-05 17:20:57.182013+03
19430	50	-1	1140	2020-03-05 17:31:38.736148+03
19431	61	-1	1510	2020-03-05 17:31:43.015329+03
19432	93	-2	1620	2020-03-05 17:38:58.501928+03
19433	67	-1	350	2020-03-05 17:44:07.598067+03
19434	22	-1	1070	2020-03-05 17:47:46.361002+03
19435	33	-1	900	2020-03-05 18:14:26.324104+03
19436	76	-1	1070	2020-03-05 18:21:51.573245+03
19437	49	-1	970	2020-03-05 18:35:37.84881+03
19438	59	-1	1030	2020-03-05 18:40:03.864955+03
19439	24	-1	950	2020-03-05 18:41:15.602578+03
19440	92	-1	630	2020-03-05 18:54:58.052252+03
19441	48	-1	640	2020-03-05 19:17:51.744491+03
19442	93	-1	1620	2020-03-05 19:56:33.124541+03
19443	47	-1	1480	2020-03-05 20:02:13.211119+03
19444	55	-1	3480	2020-03-05 20:04:09.496652+03
19445	1	-1	640	2020-03-05 20:43:27.457061+03
19446	73	-1	960	2020-03-05 20:49:04.636406+03
19447	74	-1	1010	2020-03-05 20:53:24.950394+03
19448	35	-2	670	2020-03-05 21:02:35.875176+03
19449	87	-2	2320	2020-03-05 21:07:16.414155+03
19450	88	-2	1270	2020-03-05 21:35:25.501211+03
19451	75	-1	830	2020-03-05 21:56:53.259551+03
19452	87	-1	2320	2020-03-05 22:11:48.570074+03
19453	76	-1	1070	2020-03-05 22:50:29.003886+03
19454	8	-1	1920	2020-03-05 23:01:21.649922+03
19455	40	-1	1430	2020-03-05 23:12:06.792405+03
19456	47	-1	1480	2020-03-05 23:16:42.178197+03
19457	51	-1	1310	2020-03-05 23:24:09.803302+03
19458	89	-2	1420	2020-03-05 23:46:12.584581+03
19459	32	-1	710	2020-03-05 23:48:15.63846+03
19460	14	-2	1350	2020-03-06 00:02:37.543231+03
19461	47	42	833	2020-03-06 00:11:18.186636+03
19462	54	-1	3470	2020-03-06 00:13:01.000687+03
19463	95	-1	480	2020-03-06 00:29:34.842089+03
19464	57	-1	1900	2020-03-06 00:33:26.962578+03
19465	76	-2	1070	2020-03-06 00:34:07.281908+03
19466	26	-1	390	2020-03-06 00:43:30.135551+03
19467	2	-1	470	2020-03-06 01:00:09.53808+03
19468	90	-1	1780	2020-03-06 01:31:50.708084+03
19469	60	-1	2700	2020-03-06 01:46:05.920358+03
19470	40	-1	1430	2020-03-06 01:53:22.096332+03
19471	30	-1	1140	2020-03-06 01:55:13.125956+03
19472	71	-1	1030	2020-03-06 02:16:47.411004+03
19473	37	-2	1290	2020-03-06 02:19:39.292027+03
19474	23	-1	4390	2020-03-06 02:34:57.974304+03
19475	81	-2	1620	2020-03-06 02:44:27.150296+03
19476	10	-1	2080	2020-03-06 02:48:46.635115+03
19477	71	38	450	2020-03-06 02:50:23.706758+03
19478	22	-1	1070	2020-03-06 03:09:15.41851+03
19479	54	-2	3470	2020-03-06 03:13:28.931587+03
19480	71	-1	1030	2020-03-06 03:15:39.136513+03
19481	24	-1	950	2020-03-06 03:26:06.543719+03
19482	83	-2	1230	2020-03-06 03:52:56.696843+03
19483	45	-1	1590	2020-03-06 03:55:48.390419+03
19484	61	-2	1510	2020-03-06 04:14:12.414596+03
19485	79	-1	550	2020-03-06 05:14:41.983755+03
19486	94	-1	1230	2020-03-06 05:19:07.627352+03
19487	77	-1	640	2020-03-06 05:45:15.883006+03
19488	70	-1	760	2020-03-06 05:45:58.423905+03
19489	12	-1	1650	2020-03-06 05:46:20.732365+03
19490	51	-1	1310	2020-03-06 06:12:18.161611+03
19491	19	-1	1220	2020-03-06 06:16:54.913101+03
19492	27	-1	880	2020-03-06 06:19:38.412665+03
19493	30	-1	1140	2020-03-06 06:38:07.536381+03
19494	46	-1	1270	2020-03-06 06:54:02.680897+03
19495	85	-1	730	2020-03-06 06:55:02.025447+03
19496	69	-2	1100	2020-03-06 06:58:18.087522+03
19497	86	-1	910	2020-03-06 07:14:39.527657+03
19498	90	-1	1780	2020-03-06 07:16:15.931181+03
19499	54	-1	3470	2020-03-06 07:20:37.869375+03
19500	36	-2	630	2020-03-06 07:38:47.385073+03
19501	89	-1	1420	2020-03-06 07:45:45.714107+03
19502	47	-1	1480	2020-03-06 07:49:32.352918+03
19503	68	-2	490	2020-03-06 08:09:37.444271+03
19504	67	-1	350	2020-03-06 08:20:31.587383+03
19505	86	-1	910	2020-03-06 08:21:27.896548+03
19506	56	-1	2460	2020-03-06 08:46:43.11986+03
19507	67	-2	350	2020-03-06 09:24:31.835+03
19508	72	9	327	2020-03-06 09:40:59.777688+03
19509	74	-1	1010	2020-03-06 09:44:38.648323+03
19510	17	-1	1500	2020-03-06 09:49:40.307387+03
19511	83	-1	1230	2020-03-06 09:50:07.347529+03
19512	47	-1	1480	2020-03-06 10:04:06.986535+03
19513	39	-2	910	2020-03-06 10:12:18.194394+03
19514	74	-1	1010	2020-03-06 10:19:45.491775+03
19515	77	-1	640	2020-03-06 10:39:13.45185+03
19516	56	-1	2460	2020-03-06 10:42:37.098433+03
19517	17	-1	1500	2020-03-06 10:47:02.913325+03
19518	17	-1	1500	2020-03-06 10:52:09.273978+03
19519	76	-1	1070	2020-03-06 11:55:21.852472+03
19520	93	-1	1620	2020-03-06 12:09:44.551121+03
19521	1	-1	640	2020-03-06 13:19:45.325581+03
19522	72	-2	620	2020-03-06 13:29:12.518244+03
19523	77	-1	640	2020-03-06 13:38:22.42528+03
19524	95	-1	480	2020-03-06 13:47:49.413727+03
19525	24	-1	950	2020-03-06 13:59:33.714884+03
19526	90	-1	1780	2020-03-06 14:14:23.515957+03
19527	9	-2	2090	2020-03-06 15:04:26.581592+03
19528	20	-1	830	2020-03-06 15:08:32.575471+03
19529	66	-1	690	2020-03-06 15:15:50.554664+03
19530	35	-1	670	2020-03-06 15:17:34.39713+03
19531	27	-1	880	2020-03-06 15:24:49.921241+03
19532	43	-1	380	2020-03-06 15:36:21.823421+03
19533	35	-1	670	2020-03-06 16:05:52.8872+03
19534	69	-1	1100	2020-03-06 16:11:08.599844+03
19535	37	-2	1290	2020-03-06 16:12:12.101983+03
19536	20	-1	830	2020-03-06 16:15:07.300608+03
19537	95	-1	480	2020-03-06 16:25:40.706417+03
19538	4	-2	1420	2020-03-06 16:37:57.710357+03
19539	26	-2	390	2020-03-06 16:45:05.546818+03
19540	1	-2	640	2020-03-06 17:14:17.792516+03
19541	37	44	621	2020-03-06 17:30:22.362062+03
19542	83	-2	1230	2020-03-06 17:43:14.755295+03
19543	56	-1	2460	2020-03-06 17:59:30.024872+03
19544	91	-1	1620	2020-03-06 19:01:09.650382+03
19545	93	-1	1620	2020-03-06 19:04:20.015196+03
19546	71	-1	1030	2020-03-06 19:30:51.567451+03
19547	73	-1	960	2020-03-06 19:47:17.68991+03
19548	93	-1	1620	2020-03-06 19:48:48.054865+03
19549	89	-1	1420	2020-03-06 20:21:37.911229+03
19550	12	-1	1650	2020-03-06 20:28:21.821939+03
19551	12	-1	1650	2020-03-06 21:04:53.879783+03
19552	27	-1	880	2020-03-06 21:14:05.218869+03
19553	1	-1	640	2020-03-06 21:26:37.17775+03
19554	36	-2	630	2020-03-06 22:22:36.435598+03
19555	71	-1	1030	2020-03-06 22:24:57.584738+03
19556	58	-1	2830	2020-03-06 22:29:59.477072+03
19557	3	-1	660	2020-03-06 22:42:22.386954+03
19558	57	-1	1900	2020-03-06 23:05:20.357217+03
19559	1	-2	640	2020-03-06 23:06:47.030181+03
19560	30	-1	1140	2020-03-06 23:16:44.989358+03
19561	57	-1	1900	2020-03-06 23:34:59.461918+03
19562	88	-2	1270	2020-03-07 00:01:54.960706+03
19563	4	-2	1420	2020-03-07 00:46:00.397843+03
19564	34	-1	1550	2020-03-07 00:56:56.29054+03
19565	87	-1	2320	2020-03-07 01:10:31.550537+03
19566	52	-1	1090	2020-03-07 01:22:00.7678+03
19567	88	-1	1270	2020-03-07 02:13:39.376924+03
19568	6	-1	980	2020-03-07 02:40:08.189534+03
19569	82	-1	560	2020-03-07 02:55:25.993719+03
19570	94	-2	1230	2020-03-07 02:58:49.126061+03
19571	42	-1	1790	2020-03-07 03:11:47.698276+03
19572	59	-1	1030	2020-03-07 03:14:39.746359+03
19573	57	-1	1900	2020-03-07 03:39:44.986332+03
19574	87	-1	2320	2020-03-07 04:09:12.254652+03
19575	41	-1	830	2020-03-07 04:30:06.636412+03
19576	35	-1	670	2020-03-07 04:54:13.722531+03
19577	18	-2	910	2020-03-07 05:20:39.120342+03
19578	73	-2	960	2020-03-07 05:22:22.882794+03
19579	95	-1	480	2020-03-07 06:23:47.917481+03
19580	37	-1	1290	2020-03-07 06:46:05.58571+03
19581	91	-1	1620	2020-03-07 06:49:11.047785+03
19582	44	-1	500	2020-03-07 07:18:36.997068+03
19583	83	-2	1230	2020-03-07 07:31:19.296633+03
19584	19	-2	1220	2020-03-07 07:32:23.334022+03
19585	65	-1	490	2020-03-07 07:39:20.449513+03
19586	42	-1	1790	2020-03-07 07:39:58.877826+03
19587	45	-2	1590	2020-03-07 07:43:14.092063+03
19588	83	-1	1230	2020-03-07 08:18:29.692869+03
19589	63	-2	1780	2020-03-07 08:20:18.128184+03
19590	19	27	723	2020-03-07 08:54:08.513417+03
19591	49	-1	970	2020-03-07 08:54:17.478627+03
19592	9	-1	2090	2020-03-07 08:55:05.282471+03
19593	59	-1	1030	2020-03-07 09:04:51.390024+03
19594	4	-2	1420	2020-03-07 09:14:11.654632+03
19595	8	-1	1920	2020-03-07 09:45:18.582107+03
19596	7	-1	810	2020-03-07 10:22:58.599428+03
19597	78	-1	900	2020-03-07 10:33:56.202395+03
19598	57	-1	1900	2020-03-07 10:38:29.961976+03
19599	5	-1	1620	2020-03-07 11:13:00.618027+03
19600	53	-2	3120	2020-03-07 11:18:31.522981+03
19601	71	-1	1030	2020-03-07 11:20:25.949894+03
19602	29	-1	1940	2020-03-07 11:47:38.124124+03
19603	95	-1	480	2020-03-07 11:50:31.102649+03
19604	86	-2	910	2020-03-07 12:36:42.93064+03
19605	29	-1	1940	2020-03-07 13:04:36.429578+03
19606	54	-1	3470	2020-03-07 13:26:10.731878+03
19607	88	-1	1270	2020-03-07 13:42:04.749496+03
19608	14	-2	1350	2020-03-07 14:05:49.414619+03
19609	31	-1	1190	2020-03-07 14:16:28.208084+03
19610	73	-1	960	2020-03-07 14:21:00.777812+03
19611	88	-1	1270	2020-03-07 14:44:53.698202+03
19612	33	-2	900	2020-03-07 14:44:59.33662+03
19613	78	-1	900	2020-03-07 14:48:05.043991+03
19614	79	-1	550	2020-03-07 14:54:38.118687+03
19615	78	21	449	2020-03-07 14:55:42.518806+03
19616	22	-1	1070	2020-03-07 14:57:35.01037+03
19617	76	-1	1070	2020-03-07 15:22:42.897678+03
19618	79	-1	550	2020-03-07 15:55:18.91103+03
19619	44	-1	500	2020-03-07 16:01:30.987192+03
19620	46	-1	1270	2020-03-07 16:13:38.35542+03
19621	61	-1	1510	2020-03-07 16:36:51.460888+03
19622	93	-1	1620	2020-03-07 17:39:27.245454+03
19623	61	-1	1510	2020-03-07 17:41:14.827234+03
19624	4	-1	1420	2020-03-07 17:59:57.778425+03
19625	57	-1	1900	2020-03-07 18:07:00.545897+03
19626	64	-1	970	2020-03-07 18:08:43.875704+03
19627	20	-1	830	2020-03-07 18:09:30.830869+03
19628	2	-1	470	2020-03-07 18:18:23.855535+03
19629	3	-1	660	2020-03-07 18:20:01.718141+03
19630	82	-1	560	2020-03-07 18:20:59.33154+03
19631	31	-1	1190	2020-03-07 18:30:22.781704+03
19632	14	-1	1350	2020-03-07 18:39:04.656992+03
19633	16	10	711	2020-03-07 18:58:14.670546+03
19634	32	-1	710	2020-03-07 19:04:00.093519+03
19635	3	-1	660	2020-03-07 19:12:18.924445+03
19636	67	-2	350	2020-03-07 19:34:47.915013+03
19637	29	-1	1940	2020-03-07 19:35:13.375337+03
19638	45	-1	1590	2020-03-07 19:37:11.584611+03
19639	28	-1	1860	2020-03-07 20:01:11.259466+03
19640	90	-1	1780	2020-03-07 20:16:16.469157+03
19641	33	35	447	2020-03-07 21:08:49.664416+03
19642	54	-1	3470	2020-03-07 21:10:16.597018+03
19643	38	-1	1100	2020-03-07 21:13:58.339386+03
19644	64	-1	970	2020-03-07 21:15:58.645747+03
19645	30	-1	1140	2020-03-07 21:46:30.755352+03
19646	15	-1	2830	2020-03-07 21:57:29.979771+03
19647	87	-1	2320	2020-03-07 22:09:34.636593+03
19648	21	-1	960	2020-03-07 22:14:33.088421+03
19649	10	-1	2080	2020-03-07 22:49:01.906222+03
19650	70	-1	760	2020-03-07 22:51:40.486954+03
19651	10	-1	2080	2020-03-07 22:59:38.837194+03
19652	93	-1	1620	2020-03-07 23:06:19.395733+03
19653	9	-2	2090	2020-03-07 23:10:44.975827+03
19654	76	-1	1070	2020-03-07 23:13:02.532644+03
19655	95	-1	480	2020-03-07 23:23:47.348055+03
19656	59	-1	1030	2020-03-07 23:48:30.563595+03
19657	8	-1	1920	2020-03-07 23:50:05.447004+03
19658	14	-1	1350	2020-03-07 23:58:25.501976+03
19659	25	-1	1100	2020-03-07 23:58:26.066274+03
19660	21	-1	960	2020-03-08 00:11:01.340663+03
19661	18	-1	910	2020-03-08 00:23:01.133543+03
19662	91	-2	1620	2020-03-08 01:33:18.101484+03
19663	45	-1	1590	2020-03-08 01:50:49.386952+03
19664	54	-1	3470	2020-03-08 01:58:44.978478+03
19665	46	-1	1270	2020-03-08 02:38:51.832059+03
19666	24	-1	950	2020-03-08 02:44:38.796141+03
19667	21	-2	960	2020-03-08 02:51:09.12498+03
19668	47	-1	1480	2020-03-08 02:53:45.55292+03
19669	12	-1	1650	2020-03-08 03:17:43.112783+03
19670	12	-1	1650	2020-03-08 03:26:38.232778+03
19671	49	-1	970	2020-03-08 03:32:48.154507+03
19672	40	-2	1430	2020-03-08 03:45:04.579431+03
19673	32	30	303	2020-03-08 04:02:07.634791+03
19674	66	-1	690	2020-03-08 04:10:03.50381+03
19675	15	-2	2830	2020-03-08 04:21:22.36382+03
19676	73	-1	960	2020-03-08 04:25:18.379493+03
19677	67	-1	350	2020-03-08 04:35:29.050814+03
19678	48	-1	640	2020-03-08 04:52:30.809965+03
19679	37	-2	1290	2020-03-08 05:32:38.02176+03
19680	58	-1	2830	2020-03-08 05:33:03.117432+03
19681	31	-1	1190	2020-03-08 05:35:19.856167+03
19682	79	-1	550	2020-03-08 06:01:06.359888+03
19683	65	-1	490	2020-03-08 06:03:35.381106+03
19684	55	-1	3480	2020-03-08 06:36:42.287545+03
19685	52	-1	1090	2020-03-08 06:40:39.102181+03
19686	53	-2	3120	2020-03-08 07:22:48.565408+03
19687	25	-1	1100	2020-03-08 07:45:37.463305+03
19688	28	-1	1860	2020-03-08 08:05:28.889818+03
19689	13	-1	460	2020-03-08 08:18:54.375957+03
19690	93	-1	1620	2020-03-08 09:00:26.731875+03
19691	67	-2	350	2020-03-08 09:19:28.823899+03
19692	36	-1	630	2020-03-08 09:28:08.262745+03
19693	17	-1	1500	2020-03-08 10:15:40.451427+03
19694	1	-1	640	2020-03-08 10:34:52.536674+03
19695	12	-1	1650	2020-03-08 10:36:59.359455+03
19696	94	-1	1230	2020-03-08 10:52:52.893123+03
19697	77	-1	640	2020-03-08 11:08:20.882145+03
19698	69	-1	1100	2020-03-08 11:15:51.57729+03
19699	69	-1	1100	2020-03-08 11:17:43.161855+03
19700	80	-1	1120	2020-03-08 11:44:08.905375+03
19701	23	-1	4390	2020-03-08 12:00:37.973008+03
19702	92	-1	630	2020-03-08 12:38:50.753838+03
19703	39	-1	910	2020-03-08 12:52:52.034447+03
19704	68	-1	490	2020-03-08 13:01:17.256006+03
19705	51	-1	1310	2020-03-08 13:24:11.900472+03
19706	80	-1	1120	2020-03-08 13:25:27.180802+03
19707	87	-1	2320	2020-03-08 13:33:37.391304+03
19708	21	-1	960	2020-03-08 13:41:30.644665+03
19709	26	-1	390	2020-03-08 14:33:15.046361+03
19710	59	-1	1030	2020-03-08 14:38:22.927889+03
19711	2	-2	470	2020-03-08 14:59:29.983398+03
19712	20	-1	830	2020-03-08 15:04:18.143171+03
19713	56	-1	2460	2020-03-08 15:14:49.274499+03
19714	20	-1	830	2020-03-08 15:17:38.789217+03
19715	56	-1	2460	2020-03-08 15:51:59.163058+03
19716	21	-2	960	2020-03-08 15:55:00.036492+03
19717	7	-1	810	2020-03-08 16:11:23.89996+03
19718	28	-1	1860	2020-03-08 16:17:37.547706+03
19719	17	27	756	2020-03-08 16:38:15.265863+03
19720	80	-1	1120	2020-03-08 16:58:13.857854+03
19721	81	-1	1620	2020-03-08 17:10:49.199819+03
19722	84	-3	2700	2020-03-08 17:47:00.881499+03
19723	6	-1	980	2020-03-08 18:23:57.205316+03
19724	14	-1	1350	2020-03-08 18:26:52.288969+03
19725	68	-1	490	2020-03-08 18:35:42.569249+03
19726	93	-1	1620	2020-03-08 18:42:55.865571+03
19727	86	-1	910	2020-03-08 18:46:36.003573+03
19728	70	-1	760	2020-03-08 18:47:08.481336+03
19729	81	-1	1620	2020-03-08 19:19:24.295234+03
19730	16	-1	1380	2020-03-08 19:53:50.458824+03
19731	10	-1	2080	2020-03-08 20:08:21.70178+03
19732	76	-1	1070	2020-03-08 20:13:31.933387+03
19733	38	-1	1100	2020-03-08 20:27:44.309586+03
19734	61	-1	1510	2020-03-08 20:33:43.531541+03
19735	28	-2	1860	2020-03-08 21:25:03.289285+03
19736	20	-1	830	2020-03-08 21:46:00.84439+03
19737	68	18	249	2020-03-08 21:53:24.697046+03
19738	43	-1	380	2020-03-08 21:53:46.673219+03
19739	8	-1	1920	2020-03-08 22:03:49.505811+03
19740	44	-1	500	2020-03-08 22:12:02.19839+03
19741	79	-1	550	2020-03-08 22:19:02.724259+03
19742	34	-2	1550	2020-03-08 22:47:33.84393+03
19743	60	-1	2700	2020-03-08 22:50:40.83148+03
19744	90	-1	1780	2020-03-08 23:04:38.627397+03
19745	91	-1	1620	2020-03-08 23:06:57.024079+03
19746	44	-1	500	2020-03-09 00:00:33.936629+03
19747	19	-1	1220	2020-03-09 00:12:28.061856+03
19748	81	-1	1620	2020-03-09 00:41:43.190585+03
19749	26	-1	390	2020-03-09 00:55:40.662384+03
19750	12	-2	1650	2020-03-09 01:06:20.818555+03
19751	35	-1	670	2020-03-09 01:30:34.180931+03
19752	52	21	610	2020-03-09 01:31:38.779055+03
19753	71	-1	1030	2020-03-09 01:43:29.807472+03
19754	87	-1	2320	2020-03-09 01:45:10.679332+03
19755	47	-1	1480	2020-03-09 01:54:08.417133+03
19756	6	-1	980	2020-03-09 02:14:56.218879+03
19757	69	-2	1100	2020-03-09 02:24:10.320992+03
19758	94	-1	1230	2020-03-09 02:55:34.847354+03
19759	60	-1	2700	2020-03-09 03:04:23.661085+03
19760	13	-1	460	2020-03-09 03:38:16.907264+03
19761	79	-3	550	2020-03-09 03:44:00.796689+03
19762	79	-3	550	2020-03-09 04:06:38.742991+03
19763	61	-1	1510	2020-03-09 04:09:54.932234+03
19764	27	-1	880	2020-03-09 04:21:00.775261+03
19765	95	-1	480	2020-03-09 04:32:38.554326+03
19766	51	-1	1310	2020-03-09 05:05:21.863257+03
19767	11	20	450	2020-03-09 05:32:03.003852+03
19768	83	-1	1230	2020-03-09 05:41:44.370257+03
19769	25	-1	1100	2020-03-09 06:00:07.083076+03
19770	47	-2	1480	2020-03-09 06:20:07.022257+03
19771	5	-2	1620	2020-03-09 06:21:23.093581+03
19772	37	-1	1290	2020-03-09 06:41:43.484338+03
19773	54	-1	3470	2020-03-09 06:43:13.065011+03
19774	4	-1	1420	2020-03-09 07:12:56.911774+03
19775	20	-2	830	2020-03-09 07:21:11.323756+03
19776	33	-1	900	2020-03-09 07:22:05.3551+03
19777	65	-1	490	2020-03-09 07:48:40.827694+03
19778	33	-1	900	2020-03-09 07:53:54.451223+03
19779	39	-1	910	2020-03-09 08:00:38.745638+03
19780	46	-1	1270	2020-03-09 08:05:19.944342+03
19781	39	-1	910	2020-03-09 08:11:51.004483+03
19782	49	-1	970	2020-03-09 08:21:26.237284+03
19783	86	-1	910	2020-03-09 08:35:15.035668+03
19784	15	-1	2830	2020-03-09 08:43:18.30953+03
19785	44	-1	500	2020-03-09 08:46:24.916637+03
19786	86	-2	910	2020-03-09 08:59:52.461676+03
19787	22	-1	1070	2020-03-09 09:14:00.212529+03
19788	69	-2	1100	2020-03-09 09:21:45.074799+03
19789	11	-1	830	2020-03-09 09:25:00.476087+03
19790	57	22	778	2020-03-09 09:54:07.792892+03
19791	15	20	1287	2020-03-09 10:07:56.293443+03
19792	37	-1	1290	2020-03-09 10:11:05.371941+03
19793	22	-1	1070	2020-03-09 11:04:51.273585+03
19794	8	-1	1920	2020-03-09 11:08:42.796473+03
19795	58	-2	2830	2020-03-09 11:14:57.870058+03
19796	85	-2	730	2020-03-09 11:16:47.836228+03
19797	14	-1	1350	2020-03-09 11:28:28.2764+03
19798	73	-1	960	2020-03-09 11:28:38.370603+03
19799	79	-1	550	2020-03-09 11:30:38.20327+03
19800	43	-2	380	2020-03-09 11:31:35.691532+03
19801	45	-1	1590	2020-03-09 11:35:01.813904+03
19802	15	-2	2830	2020-03-09 11:54:15.318803+03
19803	51	-2	1310	2020-03-09 12:26:05.633276+03
19804	13	-2	460	2020-03-09 12:34:12.191184+03
19805	96	-1	1570	2020-03-09 12:42:02.759362+03
19806	43	-1	380	2020-03-09 12:46:56.277969+03
19807	50	-1	1140	2020-03-09 12:52:50.082974+03
19808	74	-1	1010	2020-03-09 12:54:55.299489+03
19809	53	-1	3120	2020-03-09 13:01:18.063485+03
19810	18	-1	910	2020-03-09 13:09:40.507862+03
19811	79	-1	550	2020-03-09 13:23:42.037301+03
19812	76	-1	1070	2020-03-09 13:25:24.998376+03
19813	46	-1	1270	2020-03-09 13:27:58.961513+03
19814	27	-1	880	2020-03-09 14:24:21.989803+03
19815	11	-1	830	2020-03-09 14:56:53.069684+03
19816	6	-2	980	2020-03-09 15:00:42.620171+03
19817	72	-1	620	2020-03-09 15:34:45.002629+03
19818	19	-1	1220	2020-03-09 15:58:45.097797+03
19819	22	-1	1070	2020-03-09 16:06:49.794808+03
19820	77	-1	640	2020-03-09 16:14:43.505563+03
19821	75	-1	830	2020-03-09 16:44:30.224118+03
19822	22	-2	1070	2020-03-09 17:30:04.81127+03
19823	4	-1	1420	2020-03-09 18:24:05.092107+03
19824	82	-1	560	2020-03-09 18:31:36.909539+03
19825	23	-1	4390	2020-03-09 18:47:20.00687+03
19826	92	-1	630	2020-03-09 19:10:13.476414+03
19827	66	-1	690	2020-03-09 19:12:24.327228+03
19828	69	-1	1100	2020-03-09 20:09:12.730474+03
19829	1	-1	640	2020-03-09 20:16:21.207859+03
19830	64	-1	970	2020-03-09 20:24:49.287009+03
19831	10	-1	2080	2020-03-09 21:01:57.342279+03
19832	25	-1	1100	2020-03-09 21:06:28.270391+03
19833	41	-1	830	2020-03-09 21:12:44.655833+03
19834	23	-1	4390	2020-03-09 21:37:04.254265+03
19835	56	-1	2460	2020-03-09 21:37:40.810941+03
19836	23	-1	4390	2020-03-09 21:57:58.424989+03
19837	87	-1	2320	2020-03-09 22:28:54.921657+03
19838	12	-2	1650	2020-03-09 22:35:57.114829+03
19839	48	-1	640	2020-03-09 22:48:43.935411+03
19840	95	-1	480	2020-03-09 22:52:06.570292+03
19841	16	-1	1380	2020-03-09 23:24:15.699579+03
19842	20	-1	830	2020-03-09 23:30:56.455051+03
19843	44	-1	500	2020-03-09 23:45:26.589161+03
19844	49	-1	970	2020-03-10 00:02:01.276354+03
19845	33	-1	900	2020-03-10 00:19:26.35463+03
19846	83	-1	1230	2020-03-10 00:31:13.386664+03
19847	93	-2	1620	2020-03-10 00:38:32.476431+03
19848	59	22	439	2020-03-10 00:39:17.030016+03
19849	53	22	1261	2020-03-10 01:03:08.594265+03
19850	63	-1	1780	2020-03-10 01:59:56.263472+03
19851	30	-1	1140	2020-03-10 02:54:43.111872+03
19852	18	-2	910	2020-03-10 03:09:13.873689+03
19853	8	22	899	2020-03-10 03:27:43.238989+03
19854	56	-1	2460	2020-03-10 04:02:34.978641+03
19855	22	-1	1070	2020-03-10 04:07:22.238071+03
19856	45	20	799	2020-03-10 04:09:04.661691+03
19857	27	-1	880	2020-03-10 04:17:56.671304+03
19858	37	-1	1290	2020-03-10 04:18:57.341322+03
19859	54	-1	3470	2020-03-10 04:34:53.426711+03
19860	76	-1	1070	2020-03-10 04:52:57.48044+03
19861	58	-1	2830	2020-03-10 04:55:05.49773+03
19862	30	-1	1140	2020-03-10 04:56:20.392021+03
19863	56	-1	2460	2020-03-10 05:00:54.490366+03
19864	54	-1	3470	2020-03-10 05:07:04.20299+03
19865	48	-1	640	2020-03-10 05:55:17.896131+03
19866	38	-1	1100	2020-03-10 06:08:58.123174+03
19867	64	-1	970	2020-03-10 06:09:07.787174+03
19868	89	-1	1420	2020-03-10 06:12:23.214738+03
19869	75	-1	830	2020-03-10 06:13:07.689755+03
19870	6	-1	980	2020-03-10 06:16:19.545731+03
19871	68	-1	490	2020-03-10 06:18:20.155528+03
19872	73	-1	960	2020-03-10 06:32:07.687592+03
19873	77	-2	640	2020-03-10 06:39:16.223118+03
19874	52	-1	1090	2020-03-10 07:04:04.8102+03
19875	39	-1	910	2020-03-10 07:09:49.832316+03
19876	63	-1	1780	2020-03-10 07:15:11.565129+03
19877	48	-1	640	2020-03-10 07:23:07.135231+03
19878	11	-2	830	2020-03-10 07:27:24.75704+03
19879	74	-1	1010	2020-03-10 07:28:16.758578+03
19880	45	-1	1590	2020-03-10 07:30:25.717718+03
19881	6	-1	980	2020-03-10 07:40:07.371997+03
19882	42	-2	1790	2020-03-10 07:55:00.679949+03
19883	82	-1	560	2020-03-10 08:34:04.408332+03
19884	15	-3	2830	2020-03-10 08:41:02.89738+03
19885	14	-1	1350	2020-03-10 08:55:47.332208+03
19886	89	-1	1420	2020-03-10 09:00:31.435984+03
19887	70	-1	760	2020-03-10 09:08:52.75457+03
19888	11	-1	830	2020-03-10 10:31:02.167432+03
19889	47	-1	1480	2020-03-10 10:48:13.858464+03
19890	34	-1	1550	2020-03-10 11:43:50.159068+03
19891	39	-1	910	2020-03-10 12:07:38.925171+03
19892	1	-1	640	2020-03-10 12:24:03.34516+03
19893	23	-1	4390	2020-03-10 12:29:23.037704+03
19894	9	-2	2090	2020-03-10 12:55:25.486712+03
19895	53	-1	3120	2020-03-10 12:57:34.791028+03
19896	5	-2	1620	2020-03-10 13:01:53.882075+03
19897	46	45	519	2020-03-10 13:33:28.214417+03
19898	89	-1	1420	2020-03-10 13:37:44.854337+03
19899	20	-1	830	2020-03-10 13:47:24.75843+03
19900	9	-1	2090	2020-03-10 14:07:41.611979+03
19901	5	-1	1620	2020-03-10 14:23:41.663279+03
19902	9	-1	2090	2020-03-10 14:54:39.684709+03
19903	29	-1	1940	2020-03-10 15:07:01.20777+03
19904	29	-1	1940	2020-03-10 15:31:20.60051+03
19905	81	28	778	2020-03-10 15:33:22.088002+03
19906	50	-2	1140	2020-03-10 15:34:06.237057+03
19907	36	-1	630	2020-03-10 15:40:47.284724+03
19908	39	-2	910	2020-03-10 15:48:53.216363+03
19909	19	-1	1220	2020-03-10 16:42:21.080192+03
19910	38	-2	1100	2020-03-10 17:07:57.192901+03
19911	42	-1	1790	2020-03-10 17:28:16.399464+03
19912	45	-1	1590	2020-03-10 18:23:28.315339+03
19913	46	-1	1270	2020-03-10 19:03:12.683643+03
19914	30	-1	1140	2020-03-10 19:03:35.445838+03
19915	19	-2	1220	2020-03-10 20:01:13.914721+03
19916	11	-1	830	2020-03-10 20:13:37.645782+03
19917	5	-1	1620	2020-03-10 20:26:45.352655+03
19918	39	-1	910	2020-03-10 20:27:01.053312+03
19919	72	-2	620	2020-03-10 21:17:19.25913+03
19920	51	-1	1310	2020-03-10 21:18:37.714172+03
19921	32	-1	710	2020-03-10 21:42:58.096367+03
19922	11	-1	830	2020-03-10 21:57:44.359521+03
19923	75	-1	830	2020-03-10 22:28:10.706173+03
19924	10	-1	2080	2020-03-10 22:45:40.712538+03
19925	35	-2	670	2020-03-10 22:53:59.405117+03
19926	95	-1	480	2020-03-10 23:16:43.606358+03
19927	64	-1	970	2020-03-10 23:37:15.470568+03
19928	39	-1	910	2020-03-11 00:06:29.643077+03
19929	16	-1	1380	2020-03-11 00:08:03.826058+03
19930	32	-1	710	2020-03-11 01:43:22.724965+03
19931	48	25	321	2020-03-11 01:43:47.83988+03
19932	84	-1	2700	2020-03-11 01:57:37.976874+03
19933	71	-2	1030	2020-03-11 02:00:48.240285+03
19934	64	-2	970	2020-03-11 02:07:01.876519+03
19935	49	-2	970	2020-03-11 02:22:46.128392+03
19936	55	-1	3480	2020-03-11 02:23:53.782833+03
19937	78	-1	900	2020-03-11 02:52:11.459258+03
19938	37	-2	1290	2020-03-11 03:24:42.707025+03
19939	49	-1	970	2020-03-11 03:38:27.805813+03
19940	42	-2	1790	2020-03-11 03:39:17.573374+03
19941	57	-1	1900	2020-03-11 03:44:18.988671+03
19942	52	-1	1090	2020-03-11 03:47:58.188444+03
19943	94	-1	1230	2020-03-11 03:49:38.529308+03
19944	86	-1	910	2020-03-11 04:52:42.213549+03
19945	14	-2	1350	2020-03-11 05:04:16.990529+03
19946	14	-2	1350	2020-03-11 05:20:54.012023+03
19947	4	-1	1420	2020-03-11 05:34:38.244331+03
19948	87	-1	2320	2020-03-11 05:52:57.835511+03
19949	29	-1	1940	2020-03-11 05:56:46.701885+03
19950	19	-1	1220	2020-03-11 06:03:23.251936+03
19951	46	-1	1270	2020-03-11 06:34:45.132765+03
19952	42	-1	1790	2020-03-11 06:35:57.643215+03
19953	28	-1	1860	2020-03-11 07:21:15.860697+03
19954	42	-2	1790	2020-03-11 07:51:34.251849+03
19955	38	-1	1100	2020-03-11 08:08:37.880241+03
19956	10	-2	2080	2020-03-11 08:23:49.889929+03
19957	63	-1	1780	2020-03-11 08:26:18.177173+03
19958	91	-1	1620	2020-03-11 08:28:34.299182+03
19959	88	-1	1270	2020-03-11 09:10:13.465261+03
19960	21	-1	960	2020-03-11 10:03:13.779455+03
19961	6	-1	980	2020-03-11 10:19:16.031054+03
19962	14	-1	1350	2020-03-11 11:06:19.71695+03
19963	10	-1	2080	2020-03-11 11:50:40.8466+03
19964	86	-1	910	2020-03-11 12:10:48.913823+03
19965	62	-1	1220	2020-03-11 12:12:07.253974+03
19966	55	-1	3480	2020-03-11 12:27:58.284757+03
19967	5	-1	1620	2020-03-11 12:33:55.608513+03
19968	1	-1	640	2020-03-11 12:47:16.783634+03
19969	54	-1	3470	2020-03-11 13:00:40.097046+03
19970	88	-1	1270	2020-03-11 13:07:03.228935+03
19971	10	-3	2080	2020-03-11 13:09:12.194162+03
19972	78	-1	900	2020-03-11 13:34:47.934804+03
19973	88	-1	1270	2020-03-11 13:35:54.484483+03
19974	30	-1	1140	2020-03-11 13:38:38.286528+03
19975	86	-1	910	2020-03-11 13:57:41.550227+03
19976	64	-1	970	2020-03-11 14:07:23.582777+03
19977	63	-1	1780	2020-03-11 14:19:50.796578+03
19978	48	-2	640	2020-03-11 14:21:01.569321+03
19979	84	-1	2700	2020-03-11 14:22:50.033566+03
19980	8	-1	1920	2020-03-11 14:31:01.56511+03
19981	89	-1	1420	2020-03-11 14:40:31.048008+03
19982	80	-2	1120	2020-03-11 15:09:51.658968+03
19983	95	-1	480	2020-03-11 15:59:18.041088+03
19984	67	-1	350	2020-03-11 16:28:49.74444+03
19985	75	-2	830	2020-03-11 16:37:57.235374+03
19986	16	-1	1380	2020-03-11 17:01:21.361178+03
19987	12	-1	1650	2020-03-11 17:27:29.743694+03
19988	23	-2	4390	2020-03-11 17:39:01.574746+03
19989	79	-1	550	2020-03-11 17:54:24.329187+03
19990	87	-1	2320	2020-03-11 17:56:52.527996+03
19991	90	-1	1780	2020-03-11 18:19:22.961372+03
19992	77	-1	640	2020-03-11 18:23:29.295689+03
19993	15	-1	2830	2020-03-11 18:28:06.841115+03
19994	75	-2	830	2020-03-11 18:31:33.379375+03
19995	66	-2	690	2020-03-11 19:32:45.304001+03
19996	35	-1	670	2020-03-11 19:44:25.117605+03
19997	77	-1	640	2020-03-11 19:46:05.961024+03
19998	54	-1	3470	2020-03-11 19:58:05.071098+03
19999	83	-1	1230	2020-03-11 20:08:54.96555+03
20000	14	-1	1350	2020-03-11 20:23:13.812665+03
20001	96	-2	1570	2020-03-11 20:45:05.586145+03
20002	79	-1	550	2020-03-11 21:57:01.061306+03
20003	95	-1	480	2020-03-11 22:01:56.958483+03
20004	50	-1	1140	2020-03-11 22:17:20.856181+03
20005	89	-1	1420	2020-03-11 22:30:55.882626+03
20006	18	-2	910	2020-03-11 22:47:20.920901+03
20007	40	-2	1430	2020-03-11 22:55:58.509989+03
20008	77	-1	640	2020-03-11 22:58:05.037213+03
20009	22	-1	1070	2020-03-11 23:15:11.445183+03
20010	19	-1	1220	2020-03-11 23:22:50.252732+03
20011	86	-1	910	2020-03-11 23:30:35.20965+03
20012	14	-1	1350	2020-03-11 23:40:15.102961+03
20013	13	-1	460	2020-03-11 23:46:50.91017+03
20014	91	-1	1620	2020-03-12 00:07:35.468133+03
20015	81	-1	1620	2020-03-12 00:16:07.87189+03
20016	88	-2	1270	2020-03-12 00:20:31.295364+03
20017	40	-1	1430	2020-03-12 00:42:44.963552+03
20018	84	37	1480	2020-03-12 00:57:16.206308+03
20019	91	-1	1620	2020-03-12 01:01:43.35208+03
20020	25	-1	1100	2020-03-12 01:08:44.572885+03
20021	95	-2	480	2020-03-12 01:22:27.511868+03
20022	90	-1	1780	2020-03-12 01:27:50.060383+03
20023	81	-1	1620	2020-03-12 01:29:24.42938+03
20024	5	-1	1620	2020-03-12 01:33:16.535378+03
20025	88	-1	1270	2020-03-12 01:47:04.622658+03
20026	29	-1	1940	2020-03-12 01:49:59.480513+03
20027	8	-1	1920	2020-03-12 02:26:02.412462+03
20028	29	-1	1940	2020-03-12 02:43:04.476882+03
20029	25	-1	1100	2020-03-12 02:51:19.648768+03
20030	81	-1	1620	2020-03-12 03:09:32.86819+03
20031	31	-1	1190	2020-03-12 03:29:39.758567+03
20032	51	-1	1310	2020-03-12 03:35:17.106034+03
20033	14	-1	1350	2020-03-12 04:15:27.513175+03
20034	38	-1	1100	2020-03-12 04:41:34.972367+03
20035	54	-1	3470	2020-03-12 04:49:10.63977+03
20036	61	-1	1510	2020-03-12 04:50:34.45638+03
20037	47	-2	1480	2020-03-12 04:54:44.908761+03
20038	50	-2	1140	2020-03-12 04:56:34.669222+03
20039	59	-2	1030	2020-03-12 05:26:36.815969+03
20040	14	-1	1350	2020-03-12 05:33:23.620855+03
20041	16	-1	1380	2020-03-12 05:48:59.031908+03
20042	42	-1	1790	2020-03-12 06:06:06.801479+03
20043	32	-1	710	2020-03-12 06:25:40.984227+03
20044	81	-2	1620	2020-03-12 06:56:38.047468+03
20045	10	-2	2080	2020-03-12 07:17:23.587091+03
20046	10	-1	2080	2020-03-12 07:29:13.166475+03
20047	39	28	388	2020-03-12 07:51:20.358424+03
20048	29	-1	1940	2020-03-12 08:18:39.74356+03
20049	54	-1	3470	2020-03-12 08:42:10.52514+03
20050	60	23	1189	2020-03-12 09:21:41.982607+03
20051	28	-1	1860	2020-03-12 09:38:51.017632+03
20052	54	-1	3470	2020-03-12 09:51:36.293039+03
20053	93	-1	1620	2020-03-12 09:58:49.750475+03
20054	95	-1	480	2020-03-12 10:18:27.089924+03
20055	17	-1	1500	2020-03-12 10:32:13.387287+03
20056	71	-1	1030	2020-03-12 10:37:14.595972+03
20057	40	-1	1430	2020-03-12 10:45:17.092276+03
20058	21	-1	960	2020-03-12 10:55:09.030664+03
20059	47	-2	1480	2020-03-12 11:24:25.246119+03
20060	19	-1	1220	2020-03-12 11:28:58.530034+03
20061	49	-1	970	2020-03-12 11:29:18.633917+03
20062	14	-1	1350	2020-03-12 12:15:36.006022+03
20063	15	-1	2830	2020-03-12 12:47:13.204054+03
20064	73	-1	960	2020-03-12 12:51:48.731176+03
20065	23	-1	4390	2020-03-12 13:08:56.73006+03
20066	38	-1	1100	2020-03-12 13:40:38.1495+03
20067	37	-1	1290	2020-03-12 13:51:59.528202+03
20068	75	-1	830	2020-03-12 14:10:05.274675+03
20069	43	-1	380	2020-03-12 14:10:30.9356+03
20070	49	-1	970	2020-03-12 14:10:45.810165+03
20071	1	-3	640	2020-03-12 14:57:28.468554+03
20072	77	-2	640	2020-03-12 15:01:25.946507+03
20073	12	-1	1650	2020-03-12 15:02:27.826136+03
20074	83	-2	1230	2020-03-12 15:30:23.950325+03
20075	77	-1	640	2020-03-12 15:43:17.321567+03
20076	87	-2	2320	2020-03-12 16:01:07.134291+03
20077	71	-1	1030	2020-03-12 16:09:49.875114+03
20078	20	-1	830	2020-03-12 16:12:23.13877+03
20079	20	-1	830	2020-03-12 16:21:18.060693+03
20080	53	-1	3120	2020-03-12 16:54:14.569529+03
20081	31	-1	1190	2020-03-12 16:56:39.239158+03
20082	89	-1	1420	2020-03-12 17:32:29.665663+03
20083	93	-1	1620	2020-03-12 18:18:33.745531+03
20084	79	-1	550	2020-03-12 18:34:50.596599+03
20085	57	-1	1900	2020-03-12 19:00:56.820432+03
20086	76	-1	1070	2020-03-12 19:12:13.186048+03
20087	13	-1	460	2020-03-12 20:07:24.522831+03
20088	25	-1	1100	2020-03-12 20:36:38.607048+03
20089	5	-1	1620	2020-03-12 20:37:06.622013+03
20090	83	40	717	2020-03-12 20:49:04.982076+03
20091	22	-1	1070	2020-03-12 21:01:40.086776+03
20092	75	-1	830	2020-03-12 21:08:43.128575+03
20093	34	-1	1550	2020-03-12 21:37:19.361841+03
20094	37	-2	1290	2020-03-12 22:13:57.805365+03
20095	18	-2	910	2020-03-12 22:46:57.294015+03
20096	9	-2	2090	2020-03-12 23:24:31.914294+03
20097	40	29	766	2020-03-12 23:26:20.135772+03
20098	7	-1	810	2020-03-12 23:46:05.148601+03
20099	1	-1	640	2020-03-12 23:56:13.51496+03
20100	66	-1	690	2020-03-13 00:04:04.569358+03
20101	31	-1	1190	2020-03-13 00:07:33.022218+03
20102	93	-1	1620	2020-03-13 00:08:18.882209+03
20103	56	-1	2460	2020-03-13 00:18:07.364983+03
20104	93	-1	1620	2020-03-13 00:43:50.889081+03
20105	18	-1	910	2020-03-13 00:46:34.833163+03
20106	19	-1	1220	2020-03-13 00:47:34.138499+03
20107	5	-1	1620	2020-03-13 01:37:13.55253+03
20108	6	-1	980	2020-03-13 01:41:04.21996+03
20109	85	-1	730	2020-03-13 01:59:53.128867+03
20110	50	-1	1140	2020-03-13 02:02:42.099663+03
20111	29	-1	1940	2020-03-13 02:17:22.013681+03
20112	36	-1	630	2020-03-13 02:44:09.128422+03
20113	86	-1	910	2020-03-13 03:16:42.751533+03
20114	13	-1	460	2020-03-13 03:26:27.154299+03
20115	84	-2	2700	2020-03-13 03:27:15.107539+03
20116	86	-1	910	2020-03-13 03:33:43.574342+03
20117	48	-1	640	2020-03-13 03:44:25.231039+03
20118	47	-1	1480	2020-03-13 03:44:56.447285+03
20119	11	-2	830	2020-03-13 03:48:46.492284+03
20120	37	-1	1290	2020-03-13 03:58:18.100783+03
20121	32	-1	710	2020-03-13 04:20:05.853708+03
20122	96	-2	1570	2020-03-13 04:21:00.661689+03
20123	79	-2	550	2020-03-13 04:21:56.302463+03
20124	69	-1	1100	2020-03-13 04:45:18.318755+03
20125	67	41	162	2020-03-13 05:05:32.126209+03
20126	77	-2	640	2020-03-13 05:24:36.456486+03
20127	80	-1	1120	2020-03-13 05:35:48.625705+03
20128	15	-1	2830	2020-03-13 05:48:04.11958+03
20129	41	-1	830	2020-03-13 06:09:40.739395+03
20130	48	-2	640	2020-03-13 06:39:09.023593+03
20131	20	-1	830	2020-03-13 06:41:10.841959+03
20132	68	-2	490	2020-03-13 06:51:30.079284+03
20133	24	-1	950	2020-03-13 07:03:58.614749+03
20134	80	-1	1120	2020-03-13 07:08:24.175075+03
20135	20	-1	830	2020-03-13 07:16:47.65165+03
20136	38	-1	1100	2020-03-13 07:20:24.540643+03
20137	2	-1	470	2020-03-13 08:25:16.268781+03
20138	75	-1	830	2020-03-13 08:44:31.360835+03
20139	84	-1	2700	2020-03-13 08:45:28.786328+03
20140	37	-2	1290	2020-03-13 09:05:47.946738+03
20141	34	-1	1550	2020-03-13 09:10:38.972475+03
20142	8	-1	1920	2020-03-13 09:18:01.262524+03
20143	39	-1	910	2020-03-13 09:20:31.674963+03
20144	55	-1	3480	2020-03-13 09:25:00.072719+03
20145	54	-1	3470	2020-03-13 09:27:54.135968+03
20146	88	-1	1270	2020-03-13 09:32:43.228922+03
20147	76	-2	1070	2020-03-13 09:32:52.088636+03
20148	85	-1	730	2020-03-13 09:33:27.281528+03
20149	28	-1	1860	2020-03-13 10:24:42.066412+03
20150	81	-1	1620	2020-03-13 10:52:37.463534+03
20151	11	-1	830	2020-03-13 11:25:44.3734+03
20152	66	-1	690	2020-03-13 11:53:16.323716+03
20153	33	-1	900	2020-03-13 12:13:16.319138+03
20154	18	-1	910	2020-03-13 12:47:12.852736+03
20155	62	-1	1220	2020-03-13 12:55:51.157758+03
20156	81	-1	1620	2020-03-13 13:38:09.74331+03
20157	68	-1	490	2020-03-13 14:00:20.886567+03
20158	9	-1	2090	2020-03-13 14:01:00.913952+03
20159	36	-1	630	2020-03-13 14:35:40.195584+03
20160	22	-1	1070	2020-03-13 14:41:14.538281+03
20161	49	-1	970	2020-03-13 14:42:54.697586+03
20162	82	-2	560	2020-03-13 14:44:50.700975+03
20163	87	-1	2320	2020-03-13 14:47:46.048337+03
20164	53	-1	3120	2020-03-13 15:13:32.498822+03
20165	59	-2	1030	2020-03-13 15:35:14.625674+03
20166	89	-1	1420	2020-03-13 15:50:04.672221+03
20167	43	-3	380	2020-03-13 16:18:28.351878+03
20168	54	-1	3470	2020-03-13 16:37:48.55683+03
20169	7	-1	810	2020-03-13 16:38:27.583342+03
20170	41	-1	830	2020-03-13 18:07:26.082514+03
20171	39	-1	910	2020-03-13 19:03:41.345172+03
20172	28	-1	1860	2020-03-13 19:35:51.649221+03
20173	1	-1	640	2020-03-13 20:08:36.241717+03
20174	85	-1	730	2020-03-13 20:11:50.29198+03
20175	86	-1	910	2020-03-13 20:34:18.2727+03
20176	17	-1	1500	2020-03-13 20:36:17.44953+03
20177	70	-1	760	2020-03-13 21:07:26.45051+03
20178	10	-1	2080	2020-03-13 21:19:19.81402+03
20179	3	-1	660	2020-03-13 21:21:03.674242+03
20180	94	-1	1230	2020-03-13 21:41:06.633861+03
20181	67	-1	350	2020-03-13 21:45:58.781013+03
20182	4	-1	1420	2020-03-13 21:58:40.802449+03
20183	33	-1	900	2020-03-13 21:59:14.335537+03
20184	8	-1	1920	2020-03-13 22:00:21.947146+03
20185	80	-1	1120	2020-03-13 22:08:33.88126+03
20186	13	-2	460	2020-03-13 22:11:59.68448+03
20187	52	-1	1090	2020-03-13 22:23:15.46972+03
20188	16	-1	1380	2020-03-13 22:25:02.640037+03
20189	82	-1	560	2020-03-13 22:29:57.167414+03
20190	51	-1	1310	2020-03-13 22:34:17.259315+03
20191	32	-2	710	2020-03-13 22:40:46.902939+03
20192	4	-1	1420	2020-03-13 22:44:03.156146+03
20193	71	-1	1030	2020-03-13 23:13:30.567099+03
20194	47	-1	1480	2020-03-13 23:44:36.963707+03
20195	80	-1	1120	2020-03-13 23:47:27.009097+03
20196	47	-1	1480	2020-03-14 00:31:55.984644+03
20197	51	-2	1310	2020-03-14 01:00:25.278093+03
20198	66	14	388	2020-03-14 01:02:52.437145+03
20199	85	-2	730	2020-03-14 01:03:50.596418+03
20200	76	-1	1070	2020-03-14 01:16:47.551717+03
20201	79	-1	550	2020-03-14 01:23:18.597996+03
20202	39	-1	910	2020-03-14 01:49:54.34271+03
20203	35	-1	670	2020-03-14 01:51:55.718876+03
20204	40	-2	1430	2020-03-14 02:16:46.393441+03
20205	78	-2	900	2020-03-14 02:21:12.250669+03
20206	67	-2	350	2020-03-14 02:26:19.559608+03
20207	34	-1	1550	2020-03-14 02:39:40.642311+03
20208	38	-1	1100	2020-03-14 02:40:36.514495+03
20209	43	14	177	2020-03-14 02:55:07.857225+03
20210	36	-1	630	2020-03-14 03:12:46.163941+03
20211	40	-1	1430	2020-03-14 04:25:05.127321+03
20212	64	-1	970	2020-03-14 04:30:27.455467+03
20213	60	-1	2700	2020-03-14 04:41:39.671197+03
20214	53	-2	3120	2020-03-14 04:46:53.928285+03
20215	59	-1	1030	2020-03-14 05:02:01.393543+03
20216	42	-2	1790	2020-03-14 05:33:04.057584+03
20217	84	-1	2700	2020-03-14 05:42:06.658303+03
20218	81	-1	1620	2020-03-14 06:19:45.300726+03
20219	61	-1	1510	2020-03-14 06:21:05.813378+03
20220	57	-1	1900	2020-03-14 06:25:28.797333+03
20221	22	-1	1070	2020-03-14 06:31:11.37733+03
20222	81	-2	1620	2020-03-14 06:47:39.686427+03
20223	4	-1	1420	2020-03-14 06:52:51.250705+03
20224	60	-1	2700	2020-03-14 06:55:50.989955+03
20225	94	17	578	2020-03-14 07:49:00.770233+03
20226	63	-1	1780	2020-03-14 08:14:23.790231+03
20227	7	-1	810	2020-03-14 08:40:17.205074+03
20228	58	-2	2830	2020-03-14 08:53:43.492681+03
20229	51	-1	1310	2020-03-14 08:57:37.135327+03
20230	20	-2	830	2020-03-14 10:03:05.715829+03
20231	29	-1	1940	2020-03-14 10:06:55.864201+03
20232	4	-1	1420	2020-03-14 10:49:51.859299+03
20233	69	-1	1100	2020-03-14 10:56:51.75957+03
20234	23	-1	4390	2020-03-14 11:01:33.480635+03
20235	10	-1	2080	2020-03-14 11:09:32.183044+03
20236	57	-1	1900	2020-03-14 11:26:02.976342+03
20237	67	-1	350	2020-03-14 11:46:05.902219+03
20238	86	-1	910	2020-03-14 11:59:05.161429+03
20239	55	28	1942	2020-03-14 12:20:44.946776+03
20240	20	-1	830	2020-03-14 12:23:04.689971+03
20241	91	-1	1620	2020-03-14 12:40:32.661233+03
20242	64	-2	970	2020-03-14 12:49:50.672033+03
20243	58	-1	2830	2020-03-14 12:55:58.714635+03
20244	70	-1	760	2020-03-14 12:56:25.433311+03
20245	67	-1	350	2020-03-14 13:30:15.371874+03
20246	48	-1	640	2020-03-14 13:40:40.152404+03
20247	22	-1	1070	2020-03-14 13:44:23.216262+03
20248	52	-2	1090	2020-03-14 14:08:07.528997+03
20249	2	-1	470	2020-03-14 14:11:19.31133+03
20250	16	-1	1380	2020-03-14 14:17:04.206469+03
20251	19	-2	1220	2020-03-14 14:18:06.720061+03
20252	63	29	783	2020-03-14 14:19:33.968969+03
20253	45	-2	1590	2020-03-14 14:34:26.297386+03
20254	95	28	245	2020-03-14 14:49:31.957364+03
20255	50	-1	1140	2020-03-14 14:58:48.107644+03
20256	1	-1	640	2020-03-14 15:05:17.406636+03
20257	42	-2	1790	2020-03-14 15:05:34.99073+03
20258	34	-1	1550	2020-03-14 15:15:58.274302+03
20259	19	-1	1220	2020-03-14 15:17:48.807798+03
20260	10	-1	2080	2020-03-14 16:05:20.532296+03
20261	68	-1	490	2020-03-14 16:59:49.969708+03
20262	52	-1	1090	2020-03-14 17:37:26.335417+03
20263	87	-1	2320	2020-03-14 17:48:17.67576+03
20264	68	-1	490	2020-03-14 17:55:06.354641+03
20265	45	-1	1590	2020-03-14 18:03:15.826641+03
20266	61	-2	1510	2020-03-14 18:20:07.000373+03
20267	10	-1	2080	2020-03-14 18:24:47.810496+03
20268	7	-1	810	2020-03-14 18:30:53.932897+03
20269	10	-1	2080	2020-03-14 18:39:39.871646+03
20270	77	-1	640	2020-03-14 18:53:20.505993+03
20271	74	-2	1010	2020-03-14 19:14:10.954069+03
20272	71	-1	1030	2020-03-14 19:27:11.993663+03
20273	9	-1	2090	2020-03-14 20:23:38.4701+03
20274	21	-1	960	2020-03-14 21:07:59.276109+03
20275	31	-2	1190	2020-03-14 21:18:53.833208+03
20276	14	-2	1350	2020-03-14 21:31:47.225722+03
20277	67	-1	350	2020-03-14 22:34:02.591571+03
20278	57	-1	1900	2020-03-14 22:46:02.089938+03
20279	81	-1	1620	2020-03-14 23:11:16.577587+03
20280	18	-1	910	2020-03-14 23:42:29.843281+03
20281	1	-1	640	2020-03-15 00:00:51.281192+03
20282	87	-1	2320	2020-03-15 00:02:33.646991+03
20283	4	-1	1420	2020-03-15 00:26:53.852826+03
20284	46	-1	1270	2020-03-15 00:35:50.327379+03
20285	6	-1	980	2020-03-15 00:46:11.045269+03
20286	22	-1	1070	2020-03-15 00:47:43.662297+03
20287	46	-1	1270	2020-03-15 00:59:22.955461+03
20288	8	-1	1920	2020-03-15 01:07:40.706967+03
20289	70	-1	760	2020-03-15 01:14:07.23973+03
20290	89	-1	1420	2020-03-15 01:20:48.262747+03
20291	96	-2	1570	2020-03-15 01:46:02.815957+03
20292	13	-1	460	2020-03-15 01:59:58.942958+03
20293	12	-2	1650	2020-03-15 02:30:58.928619+03
20294	22	-1	1070	2020-03-15 02:51:41.239456+03
20295	10	38	954	2020-03-15 03:00:40.334413+03
20296	92	-1	630	2020-03-15 03:01:55.941445+03
20297	5	-1	1620	2020-03-15 03:07:14.706266+03
20298	32	-1	710	2020-03-15 03:16:17.941456+03
20299	75	-2	830	2020-03-15 04:20:07.882495+03
20300	58	-1	2830	2020-03-15 04:24:42.498985+03
20301	35	-1	670	2020-03-15 04:40:41.86832+03
20302	18	28	519	2020-03-15 04:42:54.750795+03
20303	73	-1	960	2020-03-15 04:59:32.711863+03
20304	48	-1	640	2020-03-15 05:01:26.446885+03
20305	42	28	739	2020-03-15 05:09:43.439814+03
20306	88	-2	1270	2020-03-15 05:16:11.629936+03
20307	87	-1	2320	2020-03-15 05:24:20.181906+03
20308	32	-1	710	2020-03-15 05:31:35.102603+03
20309	95	-1	480	2020-03-15 05:42:31.398853+03
20310	80	-1	1120	2020-03-15 05:47:34.82788+03
20311	16	-1	1380	2020-03-15 05:59:59.900181+03
20312	91	-2	1620	2020-03-15 06:44:18.330192+03
20313	77	-1	640	2020-03-15 07:03:22.448136+03
20314	92	-2	630	2020-03-15 07:12:26.119911+03
20315	6	-2	980	2020-03-15 07:19:59.937264+03
20316	77	-2	640	2020-03-15 07:24:59.446784+03
20317	57	-1	1900	2020-03-15 07:38:30.716876+03
20318	44	-1	500	2020-03-15 08:17:44.3661+03
20319	67	-1	350	2020-03-15 08:42:23.97189+03
20320	18	-1	910	2020-03-15 08:47:45.903842+03
20321	20	-1	830	2020-03-15 08:58:43.825272+03
20322	11	-1	830	2020-03-15 09:05:25.440819+03
20323	87	-1	2320	2020-03-15 09:33:30.821794+03
20324	71	-2	1030	2020-03-15 09:34:54.634642+03
20325	24	-1	950	2020-03-15 10:03:31.677836+03
20326	35	-1	670	2020-03-15 10:47:06.37144+03
20327	75	-2	830	2020-03-15 11:21:21.586575+03
20328	95	-2	480	2020-03-15 11:29:47.962145+03
20329	58	-1	2830	2020-03-15 11:37:02.895322+03
20330	56	-1	2460	2020-03-15 11:39:19.873432+03
20331	76	33	581	2020-03-15 11:48:18.53246+03
20332	39	-1	910	2020-03-15 12:08:26.752799+03
20333	36	19	291	2020-03-15 12:33:51.189095+03
20334	69	-1	1100	2020-03-15 13:02:22.82083+03
20335	49	-2	970	2020-03-15 13:07:27.297523+03
20336	40	-1	1430	2020-03-15 13:21:13.986721+03
20337	96	22	896	2020-03-15 13:50:50.116731+03
20338	30	-1	1140	2020-03-15 14:11:30.264863+03
20339	17	-1	1500	2020-03-15 14:43:45.319953+03
20340	28	-2	1860	2020-03-15 14:46:56.528214+03
20341	32	-1	710	2020-03-15 15:08:17.809608+03
20342	21	-1	960	2020-03-15 15:09:12.715751+03
20343	17	-1	1500	2020-03-15 15:11:42.708997+03
20344	30	-1	1140	2020-03-15 15:47:30.269229+03
20345	69	-1	1100	2020-03-15 15:53:09.604351+03
20346	29	-1	1940	2020-03-15 16:03:45.984742+03
20347	17	-2	1500	2020-03-15 16:26:45.972058+03
20348	73	-2	960	2020-03-15 16:32:05.71485+03
20349	51	-1	1310	2020-03-15 16:36:26.210964+03
20350	30	-1	1140	2020-03-15 16:38:15.329924+03
20351	77	-1	640	2020-03-15 17:20:20.174623+03
20352	74	-1	1010	2020-03-15 17:28:30.368874+03
20353	79	19	302	2020-03-15 17:50:24.616313+03
20354	96	-1	1570	2020-03-15 17:57:06.48724+03
20355	86	-1	910	2020-03-15 18:03:45.06789+03
20356	63	-2	1780	2020-03-15 18:06:33.444552+03
20357	12	-1	1650	2020-03-15 18:13:13.97557+03
20358	1	-1	640	2020-03-15 18:31:09.263672+03
20359	83	-1	1230	2020-03-15 18:38:41.392229+03
20360	12	-1	1650	2020-03-15 18:39:52.240847+03
20361	89	-1	1420	2020-03-15 18:40:49.648653+03
20362	63	-1	1780	2020-03-15 18:41:31.880841+03
20363	73	-2	960	2020-03-15 18:57:41.738678+03
20364	24	-1	950	2020-03-15 19:27:41.264207+03
20365	83	-2	1230	2020-03-15 19:30:03.193862+03
20366	62	-1	1220	2020-03-15 21:01:59.081912+03
20367	40	-1	1430	2020-03-15 21:14:19.483935+03
20368	72	-1	620	2020-03-15 21:18:42.593054+03
20369	96	-2	1570	2020-03-15 21:21:51.179201+03
20370	64	-1	970	2020-03-15 21:35:01.24137+03
20371	2	-1	470	2020-03-15 22:58:53.187956+03
20372	44	-1	500	2020-03-15 23:14:03.715858+03
20373	77	-1	640	2020-03-15 23:16:29.330347+03
20374	76	-1	1070	2020-03-16 00:02:58.250224+03
20375	27	-1	880	2020-03-16 00:10:50.442757+03
20376	90	-2	1780	2020-03-16 00:26:48.047827+03
20377	73	-1	960	2020-03-16 01:05:47.989044+03
20378	12	-1	1650	2020-03-16 01:14:34.252893+03
20379	46	-1	1270	2020-03-16 01:19:44.649135+03
20380	43	-1	380	2020-03-16 01:31:08.744344+03
20381	66	-1	690	2020-03-16 02:13:35.590485+03
20382	91	-2	1620	2020-03-16 02:24:56.853303+03
20383	17	-1	1500	2020-03-16 02:48:02.334669+03
20384	21	-2	960	2020-03-16 02:49:30.338887+03
20385	15	-1	2830	2020-03-16 03:06:24.418894+03
20386	87	49	1178	2020-03-16 03:13:11.96938+03
20387	53	-1	3120	2020-03-16 03:14:55.800627+03
20388	69	-2	1100	2020-03-16 03:30:53.447994+03
20389	37	-2	1290	2020-03-16 03:50:42.554891+03
20390	21	-2	960	2020-03-16 04:08:34.12104+03
20391	49	-1	970	2020-03-16 04:16:30.844483+03
20392	11	-1	830	2020-03-16 04:23:56.012517+03
20393	79	-1	550	2020-03-16 04:41:29.804705+03
20394	35	-1	670	2020-03-16 05:28:44.187157+03
20395	54	-1	3470	2020-03-16 05:50:07.510075+03
20396	51	-1	1310	2020-03-16 05:57:46.731287+03
20397	31	-2	1190	2020-03-16 06:27:03.194074+03
20398	26	-1	390	2020-03-16 06:27:58.728283+03
20399	63	-1	1780	2020-03-16 06:54:08.163205+03
20400	72	-1	620	2020-03-16 06:57:04.309439+03
20401	52	-1	1090	2020-03-16 07:10:08.071681+03
20402	49	-2	970	2020-03-16 07:10:23.619295+03
20403	37	-1	1290	2020-03-16 07:12:32.844797+03
20404	75	-1	830	2020-03-16 07:22:47.419778+03
20405	30	-1	1140	2020-03-16 07:25:44.444872+03
20406	70	-1	760	2020-03-16 07:36:27.853632+03
20407	89	-1	1420	2020-03-16 07:56:46.826067+03
20408	19	-1	1220	2020-03-16 08:22:16.325088+03
20409	14	-1	1350	2020-03-16 08:40:47.360518+03
20410	65	-2	490	2020-03-16 09:20:55.592688+03
20411	1	-2	640	2020-03-16 09:26:57.196377+03
20412	67	-1	350	2020-03-16 09:28:23.074146+03
20413	78	-1	900	2020-03-16 09:59:27.109283+03
20414	82	-1	560	2020-03-16 10:23:06.714584+03
20415	47	-1	1480	2020-03-16 10:24:14.780609+03
20416	46	-1	1270	2020-03-16 10:28:58.241437+03
20417	56	-1	2460	2020-03-16 10:56:34.544625+03
20418	9	-1	2090	2020-03-16 11:02:55.330599+03
20419	26	-1	390	2020-03-16 11:16:35.675169+03
20420	48	-1	640	2020-03-16 11:25:42.592012+03
20421	40	-2	1430	2020-03-16 11:32:31.869741+03
20422	19	-1	1220	2020-03-16 11:51:42.549094+03
20423	6	-2	980	2020-03-16 12:00:13.955203+03
20424	30	-1	1140	2020-03-16 12:04:23.4958+03
20425	14	-1	1350	2020-03-16 12:20:05.491967+03
20426	7	-1	810	2020-03-16 13:01:51.360129+03
20427	76	-1	1070	2020-03-16 13:03:09.106669+03
20428	29	-1	1940	2020-03-16 13:26:27.238027+03
20429	33	-1	900	2020-03-16 13:34:43.937753+03
20430	92	-1	630	2020-03-16 13:38:25.158453+03
20431	90	-1	1780	2020-03-16 14:12:26.552685+03
20432	54	-1	3470	2020-03-16 14:15:30.523301+03
20433	14	-1	1350	2020-03-16 14:18:31.877217+03
20434	82	-1	560	2020-03-16 14:18:35.175138+03
20435	12	-1	1650	2020-03-16 14:21:06.186421+03
20436	49	-1	970	2020-03-16 14:48:40.139575+03
20437	53	-1	3120	2020-03-16 15:12:08.013633+03
20438	21	-1	960	2020-03-16 15:35:37.354553+03
20439	27	-1	880	2020-03-16 15:38:46.285866+03
20440	51	-1	1310	2020-03-16 16:27:44.549953+03
20441	81	-1	1620	2020-03-16 16:40:39.334905+03
20442	71	-1	1030	2020-03-16 16:40:58.383602+03
20443	10	-1	2080	2020-03-16 17:02:36.822209+03
20444	30	-1	1140	2020-03-16 17:04:12.327686+03
20445	27	-2	880	2020-03-16 17:57:23.782013+03
20446	59	-1	1030	2020-03-16 17:57:32.36912+03
20447	18	-1	910	2020-03-16 18:17:05.040092+03
20448	75	-1	830	2020-03-16 18:24:07.116238+03
20449	38	-1	1100	2020-03-16 18:34:15.506014+03
20450	80	-1	1120	2020-03-16 18:38:46.748083+03
20451	17	-1	1500	2020-03-16 18:50:25.59033+03
20452	88	-1	1270	2020-03-16 19:22:25.545266+03
20453	57	-1	1900	2020-03-16 19:31:07.521052+03
20454	21	-1	960	2020-03-16 19:39:45.975877+03
20455	90	-1	1780	2020-03-16 19:44:41.487439+03
20456	36	-1	630	2020-03-16 19:50:23.8696+03
20457	22	-1	1070	2020-03-16 19:55:41.645051+03
20458	10	-1	2080	2020-03-16 19:59:23.308674+03
20459	44	-1	500	2020-03-16 19:59:38.924751+03
20460	14	-1	1350	2020-03-16 20:51:54.044553+03
20461	61	-1	1510	2020-03-16 20:55:41.472518+03
20462	34	-1	1550	2020-03-16 21:04:26.984477+03
20463	30	-1	1140	2020-03-16 21:19:34.774677+03
20464	5	-1	1620	2020-03-16 21:30:58.0913+03
20465	31	-1	1190	2020-03-16 21:36:16.560736+03
20466	12	-1	1650	2020-03-16 21:56:20.951393+03
20467	69	-1	1100	2020-03-16 21:57:36.525933+03
20468	58	-1	2830	2020-03-16 22:12:06.203928+03
20469	51	-1	1310	2020-03-16 22:14:42.209776+03
20470	39	-1	910	2020-03-16 22:34:45.70139+03
20471	46	-1	1270	2020-03-16 22:58:26.69609+03
20472	52	-1	1090	2020-03-16 23:00:45.488194+03
20473	7	-1	810	2020-03-16 23:02:45.922727+03
20474	62	14	639	2020-03-16 23:22:08.958412+03
20475	89	-1	1420	2020-03-16 23:32:00.498564+03
20476	64	-1	970	2020-03-17 00:00:45.757686+03
20477	87	-2	2320	2020-03-17 00:03:44.403781+03
20478	33	-1	900	2020-03-17 00:07:56.735266+03
20479	60	-1	2700	2020-03-17 00:30:16.77051+03
20480	39	-2	910	2020-03-17 01:06:35.732954+03
20481	13	-1	460	2020-03-17 01:08:54.216438+03
20482	48	-1	640	2020-03-17 01:18:01.831202+03
20483	96	-1	1570	2020-03-17 01:28:04.259013+03
20484	52	-1	1090	2020-03-17 01:35:30.381194+03
20485	35	-1	670	2020-03-17 02:13:41.731511+03
20486	4	-1	1420	2020-03-17 02:39:32.061873+03
20487	1	-1	640	2020-03-17 02:43:34.000401+03
20488	3	-1	660	2020-03-17 02:54:13.774012+03
20489	92	-1	630	2020-03-17 02:55:14.037837+03
20490	29	-1	1940	2020-03-17 02:57:30.823914+03
20491	23	-1	4390	2020-03-17 02:57:55.17914+03
20492	14	-1	1350	2020-03-17 03:27:32.133835+03
20493	75	-1	830	2020-03-17 04:40:13.209607+03
20494	81	-1	1620	2020-03-17 04:57:28.114061+03
20495	23	-1	4390	2020-03-17 05:11:46.689244+03
20496	84	-1	2700	2020-03-17 05:19:37.413475+03
20497	72	-1	620	2020-03-17 05:19:41.964348+03
20498	57	-1	1900	2020-03-17 05:39:25.617168+03
20499	77	-2	640	2020-03-17 05:42:47.365329+03
20500	6	-1	980	2020-03-17 05:43:19.643399+03
20501	77	-2	640	2020-03-17 06:11:34.539711+03
20502	20	-2	830	2020-03-17 06:46:56.739613+03
20503	19	-1	1220	2020-03-17 07:01:31.697249+03
20504	76	-1	1070	2020-03-17 07:14:25.534447+03
20505	75	-1	830	2020-03-17 07:35:51.150609+03
20506	61	-1	1510	2020-03-17 07:42:54.236406+03
20507	4	-1	1420	2020-03-17 07:43:19.904994+03
20508	33	-1	900	2020-03-17 07:48:27.092607+03
20509	30	-2	1140	2020-03-17 08:11:47.214468+03
20510	90	-1	1780	2020-03-17 08:26:55.811126+03
20511	77	-1	640	2020-03-17 08:27:17.049775+03
20512	95	-1	480	2020-03-17 08:41:18.844776+03
20513	32	-1	710	2020-03-17 08:56:56.649144+03
20514	43	-1	380	2020-03-17 10:13:19.981762+03
20515	32	-1	710	2020-03-17 10:13:23.494059+03
20516	90	-1	1780	2020-03-17 10:13:41.905428+03
20517	62	-1	1220	2020-03-17 10:43:17.498762+03
20518	65	-1	490	2020-03-17 10:44:38.212257+03
20519	93	-1	1620	2020-03-17 10:46:17.630336+03
20520	68	-1	490	2020-03-17 11:12:54.726671+03
20521	63	-1	1780	2020-03-17 12:18:02.785711+03
20522	73	-1	960	2020-03-17 12:21:26.741459+03
20523	84	-1	2700	2020-03-17 12:23:13.878465+03
20524	36	-1	630	2020-03-17 12:52:28.712408+03
20525	39	-1	910	2020-03-17 13:17:34.235408+03
20526	60	-1	2700	2020-03-17 13:27:20.440454+03
20527	6	-1	980	2020-03-17 13:43:29.117404+03
20528	27	-1	880	2020-03-17 13:44:11.120867+03
20529	18	-1	910	2020-03-17 14:02:19.881099+03
20530	47	-1	1480	2020-03-17 14:18:25.151957+03
20531	14	-1	1350	2020-03-17 14:25:48.1099+03
20532	70	-1	760	2020-03-17 15:07:38.380805+03
20533	22	-2	1070	2020-03-17 15:10:16.567384+03
20534	38	-1	1100	2020-03-17 15:55:52.373599+03
20535	90	-1	1780	2020-03-17 16:02:19.877967+03
20536	12	-1	1650	2020-03-17 16:14:23.123634+03
20537	82	-1	560	2020-03-17 16:30:15.767288+03
20538	10	-2	2080	2020-03-17 16:33:03.859924+03
20539	43	-1	380	2020-03-17 16:40:02.688693+03
20540	21	-1	960	2020-03-17 17:35:31.364641+03
20541	55	-1	3480	2020-03-17 17:56:44.336588+03
20542	8	-1	1920	2020-03-17 18:04:13.194104+03
20543	33	-1	900	2020-03-17 18:05:10.269127+03
20544	16	-1	1380	2020-03-17 18:09:41.904497+03
20545	27	-2	880	2020-03-17 18:26:06.578165+03
20546	30	-1	1140	2020-03-17 18:49:14.2215+03
20547	90	-1	1780	2020-03-17 18:57:59.831945+03
20548	34	-2	1550	2020-03-17 19:09:45.93248+03
20549	84	-1	2700	2020-03-17 19:14:00.659056+03
20550	86	-1	910	2020-03-17 19:22:58.764786+03
20551	34	-1	1550	2020-03-17 19:45:22.45512+03
20552	67	-1	350	2020-03-17 19:49:24.913445+03
20553	29	-2	1940	2020-03-17 19:51:26.531501+03
20554	83	-1	1230	2020-03-17 20:01:56.852336+03
20555	45	-1	1590	2020-03-17 20:13:39.085765+03
20556	88	23	756	2020-03-17 20:59:58.58172+03
20557	6	-2	980	2020-03-17 21:01:14.644122+03
20558	57	-1	1900	2020-03-17 21:08:31.510844+03
20559	91	-2	1620	2020-03-17 21:39:45.291826+03
20560	48	-1	640	2020-03-17 21:58:39.821825+03
20561	19	-1	1220	2020-03-17 22:08:32.522745+03
20562	81	-1	1620	2020-03-17 22:15:31.990641+03
20563	48	-1	640	2020-03-17 23:02:00.254335+03
20564	73	21	488	2020-03-17 23:14:19.55733+03
20565	50	-1	1140	2020-03-17 23:53:00.0974+03
20566	80	-2	1120	2020-03-18 00:15:10.798201+03
20567	82	-1	560	2020-03-18 00:45:51.056999+03
20568	28	-1	1860	2020-03-18 01:56:32.155229+03
20569	64	-1	970	2020-03-18 02:02:48.041006+03
20570	93	-1	1620	2020-03-18 02:49:38.002764+03
20571	18	-1	910	2020-03-18 02:51:54.518551+03
20572	54	-1	3470	2020-03-18 03:05:29.267363+03
20573	26	-1	390	2020-03-18 03:09:00.970942+03
20574	31	-2	1190	2020-03-18 03:14:43.370951+03
20575	71	-2	1030	2020-03-18 03:20:11.614738+03
20576	38	-1	1100	2020-03-18 03:38:39.368307+03
20577	1	26	307	2020-03-18 03:44:18.805526+03
20578	94	-1	1230	2020-03-18 03:49:08.427625+03
20579	23	-1	4390	2020-03-18 04:00:50.611285+03
20580	26	-2	390	2020-03-18 04:20:24.124593+03
20581	46	-2	1270	2020-03-18 04:35:23.176608+03
20582	51	-1	1310	2020-03-18 04:54:14.69821+03
20583	13	-1	460	2020-03-18 05:06:03.475114+03
20584	87	-2	2320	2020-03-18 05:48:03.328374+03
20585	30	-1	1140	2020-03-18 06:43:31.929713+03
20586	91	-1	1620	2020-03-18 07:19:09.494489+03
20587	48	-1	640	2020-03-18 07:33:03.082747+03
20588	32	-1	710	2020-03-18 07:41:02.300394+03
20589	22	-1	1070	2020-03-18 08:18:08.881335+03
20590	31	-1	1190	2020-03-18 08:34:43.720166+03
20591	87	-1	2320	2020-03-18 09:17:26.946039+03
20592	35	33	347	2020-03-18 09:18:13.227975+03
20593	41	-2	830	2020-03-18 09:34:10.689398+03
20594	84	-1	2700	2020-03-18 09:42:13.308878+03
20595	54	-1	3470	2020-03-18 09:57:33.477006+03
20596	54	-1	3470	2020-03-18 10:05:56.181517+03
20597	73	-1	960	2020-03-18 10:06:46.528173+03
20598	5	-1	1620	2020-03-18 10:12:34.345809+03
20599	12	-1	1650	2020-03-18 10:24:36.15984+03
20600	93	-1	1620	2020-03-18 11:14:49.057424+03
20601	33	-1	900	2020-03-18 11:17:55.125544+03
20602	89	-1	1420	2020-03-18 11:55:46.350312+03
20603	90	-1	1780	2020-03-18 12:29:17.744134+03
20604	92	-2	630	2020-03-18 13:14:01.876855+03
20605	42	-1	1790	2020-03-18 13:22:40.570098+03
20606	57	-1	1900	2020-03-18 13:26:36.176877+03
20607	63	-1	1780	2020-03-18 13:55:23.418326+03
20608	36	-1	630	2020-03-18 14:01:39.497156+03
20609	87	-1	2320	2020-03-18 14:56:55.309575+03
20610	78	-1	900	2020-03-18 15:58:05.838051+03
20611	12	-1	1650	2020-03-18 16:22:47.981545+03
20612	63	-2	1780	2020-03-18 16:39:08.252997+03
20613	41	-1	830	2020-03-18 16:52:47.509847+03
20614	41	-1	830	2020-03-18 17:00:21.479012+03
20615	83	-2	1230	2020-03-18 17:27:15.752303+03
20616	69	22	531	2020-03-18 17:52:12.13149+03
20617	18	-2	910	2020-03-18 17:54:40.368959+03
20618	33	-1	900	2020-03-18 18:46:02.563239+03
20619	7	-1	810	2020-03-18 18:46:19.202093+03
20620	84	-1	2700	2020-03-18 19:15:21.110784+03
20621	25	-1	1100	2020-03-18 19:38:02.882664+03
20622	79	-2	550	2020-03-18 19:40:11.510452+03
20623	9	-1	2090	2020-03-18 19:53:45.457981+03
20624	30	-2	1140	2020-03-18 20:07:59.375296+03
20625	87	-1	2320	2020-03-18 20:20:54.269636+03
20626	23	-2	4390	2020-03-18 20:41:36.155779+03
20627	44	-1	500	2020-03-18 20:49:22.865363+03
20628	83	-1	1230	2020-03-18 21:06:29.129122+03
20629	63	-1	1780	2020-03-18 21:16:52.08724+03
20630	2	-1	470	2020-03-18 21:27:39.230826+03
20631	49	-1	970	2020-03-18 21:46:12.180595+03
20632	13	-1	460	2020-03-18 22:10:51.919396+03
20633	7	-1	810	2020-03-18 22:16:28.347874+03
20634	50	-1	1140	2020-03-18 22:26:22.259944+03
20635	84	-1	2700	2020-03-18 22:47:44.374108+03
20636	10	-1	2080	2020-03-18 22:52:06.219774+03
20637	27	-1	880	2020-03-18 22:59:26.254676+03
20638	36	-1	630	2020-03-18 23:14:36.546981+03
20639	36	-2	630	2020-03-18 23:24:23.107745+03
20640	34	-1	1550	2020-03-18 23:27:30.513692+03
20641	6	-1	980	2020-03-18 23:29:00.016038+03
20642	90	-1	1780	2020-03-19 00:28:20.148733+03
20643	37	-2	1290	2020-03-19 00:33:21.760393+03
20644	8	-1	1920	2020-03-19 00:47:45.191561+03
20645	94	-1	1230	2020-03-19 00:59:23.847589+03
20646	23	38	2473	2020-03-19 01:09:14.064312+03
20647	86	-1	910	2020-03-19 01:14:15.677699+03
20648	22	-1	1070	2020-03-19 01:19:10.555328+03
20649	22	-1	1070	2020-03-19 01:23:43.256629+03
20650	87	-1	2320	2020-03-19 01:50:22.455013+03
20651	1	-1	640	2020-03-19 02:20:28.466853+03
20652	13	-1	460	2020-03-19 03:19:35.556619+03
20653	3	-1	660	2020-03-19 03:21:37.967209+03
20654	46	-1	1270	2020-03-19 03:28:18.359817+03
20655	39	-1	910	2020-03-19 03:37:05.18864+03
20656	12	-1	1650	2020-03-19 04:39:01.821253+03
20657	18	-1	910	2020-03-19 04:41:15.489612+03
20658	60	-1	2700	2020-03-19 05:11:58.436681+03
20659	60	-1	2700	2020-03-19 05:22:23.457632+03
20660	13	-1	460	2020-03-19 05:52:06.064535+03
20661	8	-1	1920	2020-03-19 06:18:40.813602+03
20662	88	-1	1270	2020-03-19 06:22:58.650561+03
20663	90	-1	1780	2020-03-19 06:37:59.202655+03
20664	23	-2	4390	2020-03-19 06:51:47.743804+03
20665	7	-1	810	2020-03-19 06:55:35.67759+03
20666	94	-1	1230	2020-03-19 06:59:02.715642+03
20667	87	-1	2320	2020-03-19 07:06:00.87684+03
20668	23	-1	4390	2020-03-19 07:38:18.592886+03
20669	80	-1	1120	2020-03-19 07:44:37.391686+03
20670	39	-2	910	2020-03-19 07:48:25.486691+03
20671	49	23	511	2020-03-19 08:12:30.45439+03
20672	92	27	370	2020-03-19 08:24:20.846953+03
20673	7	-1	810	2020-03-19 08:55:53.110185+03
20674	67	-1	350	2020-03-19 09:53:00.82574+03
20675	75	-1	830	2020-03-19 10:01:47.484722+03
20676	87	-2	2320	2020-03-19 10:31:04.894724+03
20677	58	-1	2830	2020-03-19 11:00:09.007964+03
20678	89	-1	1420	2020-03-19 11:41:54.693101+03
20679	29	-2	1940	2020-03-19 11:52:51.619571+03
20680	61	-1	1510	2020-03-19 12:45:02.171536+03
20681	51	-1	1310	2020-03-19 12:45:47.2447+03
20682	5	-1	1620	2020-03-19 13:14:04.346043+03
20683	8	-1	1920	2020-03-19 13:31:40.715563+03
20684	31	-1	1190	2020-03-19 13:43:45.014216+03
20685	40	-1	1430	2020-03-19 14:00:12.811593+03
20686	60	-1	2700	2020-03-19 14:08:27.04117+03
20687	89	-1	1420	2020-03-19 14:15:24.195397+03
20688	37	-1	1290	2020-03-19 14:36:51.682895+03
20689	71	-1	1030	2020-03-19 14:49:54.836536+03
20690	34	-1	1550	2020-03-19 15:07:19.006351+03
20691	52	-1	1090	2020-03-19 15:08:27.813769+03
20692	94	-3	1230	2020-03-19 15:18:12.568348+03
20693	86	-1	910	2020-03-19 15:31:59.002575+03
20694	32	-1	710	2020-03-19 15:47:06.977793+03
20695	27	-1	880	2020-03-19 16:07:37.868666+03
20696	40	-1	1430	2020-03-19 16:13:50.18672+03
20697	24	-1	950	2020-03-19 16:25:16.707951+03
20698	28	-1	1860	2020-03-19 16:27:43.210697+03
20699	13	-2	460	2020-03-19 16:32:54.994576+03
20700	35	-1	670	2020-03-19 16:40:11.89251+03
20701	84	-1	2700	2020-03-19 16:54:23.306115+03
20702	55	-1	3480	2020-03-19 17:10:27.773102+03
20703	35	-2	670	2020-03-19 17:15:00.527755+03
20704	33	-2	900	2020-03-19 17:16:23.156005+03
20705	50	-1	1140	2020-03-19 17:20:26.449873+03
20706	29	-1	1940	2020-03-19 17:38:29.742043+03
20707	34	-1	1550	2020-03-19 17:38:32.590487+03
20708	67	-1	350	2020-03-19 18:33:58.43099+03
20709	60	-1	2700	2020-03-19 18:41:12.239504+03
20710	29	37	907	2020-03-19 18:47:27.71496+03
20711	21	-1	960	2020-03-19 18:59:00.631565+03
20712	56	-1	2460	2020-03-19 19:07:54.947966+03
20713	64	-1	970	2020-03-19 19:22:31.074942+03
20714	46	-1	1270	2020-03-19 20:15:13.339181+03
20715	66	-2	690	2020-03-19 20:16:40.121685+03
20716	80	-1	1120	2020-03-19 20:17:48.740219+03
20717	13	-2	460	2020-03-19 21:06:43.477195+03
20718	64	-1	970	2020-03-19 21:25:18.29636+03
20719	37	-1	1290	2020-03-19 21:30:47.517455+03
20720	37	-1	1290	2020-03-19 23:04:34.079013+03
20721	21	-1	960	2020-03-19 23:11:20.408859+03
20722	89	-1	1420	2020-03-19 23:33:50.270906+03
20723	61	-1	1510	2020-03-19 23:58:46.678296+03
20724	8	-3	1920	2020-03-19 23:59:48.325046+03
20725	11	-2	830	2020-03-20 00:11:28.304993+03
20726	95	-1	480	2020-03-20 00:12:28.030121+03
20727	47	-1	1480	2020-03-20 00:23:36.460067+03
20728	23	-1	4390	2020-03-20 00:24:44.559462+03
20729	34	-1	1550	2020-03-20 00:34:54.906922+03
20730	73	-1	960	2020-03-20 00:40:18.905481+03
20731	14	-1	1350	2020-03-20 00:45:34.496324+03
20732	9	-2	2090	2020-03-20 00:58:17.560282+03
20733	61	21	620	2020-03-20 00:58:56.805615+03
20734	36	-2	630	2020-03-20 01:01:27.74247+03
20735	45	-1	1590	2020-03-20 01:17:00.955438+03
20736	5	-1	1620	2020-03-20 01:59:10.915134+03
20737	31	-1	1190	2020-03-20 02:18:44.334452+03
20738	35	-1	670	2020-03-20 02:44:38.454946+03
20739	12	-1	1650	2020-03-20 03:10:52.360708+03
20740	71	-1	1030	2020-03-20 03:51:52.701007+03
20741	80	-1	1120	2020-03-20 04:25:42.558875+03
20742	40	-1	1430	2020-03-20 05:26:20.661898+03
20743	10	-1	2080	2020-03-20 05:38:35.042461+03
20744	96	-1	1570	2020-03-20 05:50:15.231497+03
20745	19	-1	1220	2020-03-20 06:42:33.990206+03
20746	39	-1	910	2020-03-20 07:10:38.88341+03
20747	3	20	334	2020-03-20 07:21:00.997344+03
20748	57	-1	1900	2020-03-20 07:55:51.719481+03
20749	49	-1	970	2020-03-20 07:59:34.09823+03
20750	33	-2	900	2020-03-20 08:22:32.488802+03
20751	40	-2	1430	2020-03-20 08:34:08.033014+03
20752	78	-1	900	2020-03-20 09:29:53.418894+03
20753	6	-1	980	2020-03-20 09:31:13.931953+03
20754	12	-1	1650	2020-03-20 09:36:58.040231+03
20755	8	-1	1920	2020-03-20 10:50:09.856417+03
20756	28	-1	1860	2020-03-20 11:09:34.349042+03
20757	43	-1	380	2020-03-20 11:09:39.913279+03
20758	53	-1	3120	2020-03-20 11:29:34.98674+03
20759	17	-1	1500	2020-03-20 12:40:45.030773+03
20760	79	-1	550	2020-03-20 12:52:47.43704+03
20761	55	-1	3480	2020-03-20 13:02:11.947213+03
20762	12	54	814	2020-03-20 13:06:46.807641+03
20763	57	-1	1900	2020-03-20 13:11:25.915123+03
20764	6	-1	980	2020-03-20 13:22:41.726428+03
20765	89	-1	1420	2020-03-20 13:30:14.389164+03
20766	65	-1	490	2020-03-20 13:37:07.468921+03
20767	76	-2	1070	2020-03-20 14:20:04.134017+03
20768	12	-1	1650	2020-03-20 14:35:27.75425+03
20769	38	-1	1100	2020-03-20 14:37:43.803157+03
20770	93	-1	1620	2020-03-20 14:41:33.379097+03
20771	8	-1	1920	2020-03-20 15:01:14.264024+03
20772	12	-1	1650	2020-03-20 15:13:16.788397+03
20773	1	-1	640	2020-03-20 15:42:00.311016+03
20774	24	-1	950	2020-03-20 16:16:02.274926+03
20775	37	-1	1290	2020-03-20 16:29:38.259112+03
20776	78	-1	900	2020-03-20 16:36:01.460279+03
20777	31	-2	1190	2020-03-20 16:55:33.107649+03
20778	77	-1	640	2020-03-20 16:57:59.507238+03
20779	78	-1	900	2020-03-20 17:00:58.841527+03
20780	21	-2	960	2020-03-20 17:15:27.596834+03
20781	17	-1	1500	2020-03-20 17:23:02.77559+03
20782	70	-1	760	2020-03-20 17:43:18.226014+03
20783	72	-1	620	2020-03-20 17:50:53.746862+03
20784	42	-1	1790	2020-03-20 18:02:00.537735+03
20785	96	-1	1570	2020-03-20 18:30:04.896453+03
20786	90	-1	1780	2020-03-20 18:41:00.040481+03
20787	19	-1	1220	2020-03-20 18:44:24.355756+03
20788	31	-1	1190	2020-03-20 18:50:50.645217+03
20789	29	-1	1940	2020-03-20 20:19:01.919648+03
20790	69	-1	1100	2020-03-20 20:37:39.527359+03
20791	59	-2	1030	2020-03-20 20:54:53.114969+03
20792	92	-1	630	2020-03-20 21:29:29.868773+03
20793	45	-2	1590	2020-03-20 21:31:17.212548+03
20794	42	-1	1790	2020-03-20 21:54:50.591599+03
20795	73	-1	960	2020-03-20 21:59:58.17322+03
20796	23	-1	4390	2020-03-20 22:14:38.211775+03
20797	47	-1	1480	2020-03-20 22:22:54.032389+03
20798	3	-2	660	2020-03-20 22:58:48.900591+03
20799	67	-1	350	2020-03-20 23:21:52.940587+03
20800	89	25	714	2020-03-20 23:25:26.80809+03
20801	6	-1	980	2020-03-20 23:40:43.60843+03
20802	40	-1	1430	2020-03-20 23:43:19.878522+03
20803	23	-1	4390	2020-03-21 00:02:59.332068+03
20804	42	-1	1790	2020-03-21 00:12:46.081475+03
20805	22	-2	1070	2020-03-21 00:32:12.668803+03
20806	42	-2	1790	2020-03-21 00:45:35.399052+03
20807	73	-1	960	2020-03-21 00:52:08.196713+03
20808	33	-2	900	2020-03-21 00:53:01.542563+03
20809	91	-1	1620	2020-03-21 00:56:35.453159+03
20810	38	-1	1100	2020-03-21 02:12:37.619603+03
20811	71	-2	1030	2020-03-21 02:22:10.170981+03
20812	60	-2	2700	2020-03-21 02:29:59.293159+03
20813	3	-1	660	2020-03-21 02:36:03.349476+03
20814	90	-1	1780	2020-03-21 02:49:59.42688+03
20815	18	-1	910	2020-03-21 03:13:25.666741+03
20816	61	-1	1510	2020-03-21 03:26:15.594512+03
20817	13	-1	460	2020-03-21 03:46:53.640174+03
20818	47	-1	1480	2020-03-21 03:55:29.13199+03
20819	10	-1	2080	2020-03-21 04:07:46.953971+03
20820	11	-1	830	2020-03-21 04:51:59.405827+03
20821	13	-1	460	2020-03-21 05:11:16.272649+03
20822	21	-1	960	2020-03-21 05:37:51.750019+03
20823	76	-1	1070	2020-03-21 06:08:56.576689+03
20824	1	-2	640	2020-03-21 06:10:02.367072+03
20825	3	-1	660	2020-03-21 06:17:32.608906+03
20826	72	12	256	2020-03-21 06:43:28.285723+03
20827	26	-1	390	2020-03-21 06:48:28.885418+03
20828	71	-1	1030	2020-03-21 07:00:34.46262+03
20829	65	-1	490	2020-03-21 07:10:36.520198+03
20830	80	-1	1120	2020-03-21 07:15:47.621338+03
20831	51	-1	1310	2020-03-21 07:56:11.152763+03
20832	88	-3	1270	2020-03-21 08:00:40.379188+03
20833	20	-1	830	2020-03-21 09:07:19.953592+03
20834	81	-1	1620	2020-03-21 09:25:41.334318+03
20835	58	-1	2830	2020-03-21 09:31:21.237582+03
20836	56	-1	2460	2020-03-21 09:34:47.050974+03
20837	86	-1	910	2020-03-21 09:39:31.40993+03
20838	90	-2	1780	2020-03-21 09:43:16.65801+03
20839	80	-1	1120	2020-03-21 09:54:30.91189+03
20840	59	-1	1030	2020-03-21 10:02:47.844398+03
20841	44	-1	500	2020-03-21 10:05:25.244113+03
20842	31	-1	1190	2020-03-21 10:08:29.666818+03
20843	96	-1	1570	2020-03-21 10:47:40.508169+03
20844	40	-1	1430	2020-03-21 10:52:17.373928+03
20845	42	-1	1790	2020-03-21 10:57:43.471298+03
20846	36	-1	630	2020-03-21 11:22:40.53604+03
20847	55	-1	3480	2020-03-21 11:26:45.373895+03
20848	8	-1	1920	2020-03-21 11:30:15.899029+03
20849	73	-2	960	2020-03-21 12:31:05.645647+03
20850	65	-1	490	2020-03-21 12:48:05.196991+03
20851	12	-2	1650	2020-03-21 13:35:20.719444+03
20852	54	-1	3470	2020-03-21 13:49:39.882048+03
20853	32	-1	710	2020-03-21 13:58:52.833505+03
20854	8	-2	1920	2020-03-21 13:59:27.558821+03
20855	70	-1	760	2020-03-21 14:06:00.410575+03
20856	36	-1	630	2020-03-21 14:06:17.656846+03
20857	3	-2	660	2020-03-21 14:20:02.063301+03
20858	76	-2	1070	2020-03-21 14:47:18.805167+03
20859	33	-1	900	2020-03-21 14:50:52.634476+03
20860	74	-1	1010	2020-03-21 14:54:42.595496+03
20861	63	-1	1780	2020-03-21 15:11:17.028189+03
20862	62	-1	1220	2020-03-21 15:13:06.040617+03
20863	57	-1	1900	2020-03-21 15:26:39.024448+03
20864	78	-1	900	2020-03-21 15:27:28.116452+03
20865	51	-1	1310	2020-03-21 15:41:11.21049+03
20866	61	-2	1510	2020-03-21 15:49:47.049557+03
20867	17	-2	1500	2020-03-21 15:53:31.483255+03
20868	11	-1	830	2020-03-21 15:56:03.885182+03
20869	42	-1	1790	2020-03-21 15:59:01.543984+03
20870	68	-1	490	2020-03-21 16:46:55.855815+03
20871	83	-2	1230	2020-03-21 16:47:35.179733+03
20872	39	-1	910	2020-03-21 16:48:47.333347+03
20873	5	-1	1620	2020-03-21 17:30:37.624191+03
20874	20	-1	830	2020-03-21 18:16:04.039175+03
20875	35	-1	670	2020-03-21 18:48:30.699093+03
20876	21	-1	960	2020-03-21 18:57:00.205456+03
20877	96	-1	1570	2020-03-21 19:45:24.255454+03
20878	14	-1	1350	2020-03-21 19:56:09.5613+03
20879	64	-1	970	2020-03-21 19:59:37.073456+03
20880	42	-1	1790	2020-03-21 20:27:50.708044+03
20881	33	-1	900	2020-03-21 21:10:20.502336+03
20882	64	-1	970	2020-03-21 21:40:36.409863+03
20883	94	-1	1230	2020-03-21 21:48:44.797152+03
20884	40	-1	1430	2020-03-21 21:51:53.218837+03
20885	70	-2	760	2020-03-21 22:10:33.459362+03
20886	20	-1	830	2020-03-21 22:31:08.565875+03
20887	18	-2	910	2020-03-21 23:08:02.65261+03
20888	19	-1	1220	2020-03-21 23:37:19.873173+03
20889	86	-1	910	2020-03-21 23:40:21.269898+03
20890	25	15	657	2020-03-21 23:52:09.221112+03
20891	13	-1	460	2020-03-21 23:53:20.363809+03
20892	37	-1	1290	2020-03-21 23:57:24.909897+03
20893	54	-1	3470	2020-03-22 00:01:03.636876+03
20894	88	-1	1270	2020-03-22 00:01:06.256675+03
20895	28	-1	1860	2020-03-22 00:17:57.519956+03
20896	85	-1	730	2020-03-22 00:19:50.291896+03
20897	90	-1	1780	2020-03-22 00:47:40.800222+03
20898	70	-1	760	2020-03-22 00:56:39.150988+03
20899	95	-1	480	2020-03-22 01:14:24.631479+03
20900	11	-1	830	2020-03-22 01:21:02.372268+03
20901	93	-1	1620	2020-03-22 01:31:12.657039+03
20902	26	24	193	2020-03-22 01:44:02.107522+03
20903	36	-1	630	2020-03-22 01:44:39.906558+03
20904	59	-1	1030	2020-03-22 02:32:06.915244+03
20905	10	-1	2080	2020-03-22 02:52:01.172379+03
20906	5	-1	1620	2020-03-22 02:52:18.5+03
20907	84	-1	2700	2020-03-22 03:03:06.590645+03
20908	58	29	1588	2020-03-22 03:08:25.632714+03
20909	93	-1	1620	2020-03-22 03:53:37.205816+03
20910	7	-1	810	2020-03-22 04:00:56.831008+03
20911	7	-1	810	2020-03-22 04:10:19.663939+03
20912	36	-2	630	2020-03-22 04:12:43.476352+03
20913	83	-1	1230	2020-03-22 04:45:19.719768+03
20914	56	-1	2460	2020-03-22 04:58:45.086355+03
20915	51	-2	1310	2020-03-22 05:16:39.865326+03
20916	84	-1	2700	2020-03-22 06:02:27.082184+03
20917	79	-2	550	2020-03-22 06:27:47.540375+03
20918	87	-1	2320	2020-03-22 06:31:01.781292+03
20919	85	-2	730	2020-03-22 06:31:22.806715+03
20920	77	-1	640	2020-03-22 06:51:47.198827+03
20921	38	-2	1100	2020-03-22 06:54:38.897715+03
20922	30	-2	1140	2020-03-22 07:31:43.898534+03
20923	22	-1	1070	2020-03-22 07:40:48.608691+03
20924	30	-1	1140	2020-03-22 07:45:09.861042+03
20925	43	-1	380	2020-03-22 07:54:11.606284+03
20926	38	-1	1100	2020-03-22 08:08:05.306665+03
20927	32	-1	710	2020-03-22 08:08:18.870914+03
20928	86	-2	910	2020-03-22 08:14:26.221754+03
20929	67	-2	350	2020-03-22 08:36:27.82003+03
20930	21	-1	960	2020-03-22 08:56:39.816494+03
20931	78	-1	900	2020-03-22 09:11:21.027369+03
20932	82	-1	560	2020-03-22 09:19:10.365484+03
20933	95	-1	480	2020-03-22 09:31:59.809663+03
20934	46	-1	1270	2020-03-22 09:33:27.385564+03
20935	38	-1	1100	2020-03-22 09:39:17.739888+03
20936	21	-1	960	2020-03-22 09:41:51.172743+03
20937	20	-1	830	2020-03-22 10:09:36.734971+03
20938	45	-2	1590	2020-03-22 10:14:18.831452+03
20939	14	-1	1350	2020-03-22 10:15:57.732056+03
20940	4	-1	1420	2020-03-22 10:28:26.618039+03
20941	33	-1	900	2020-03-22 10:39:19.981104+03
20942	57	-1	1900	2020-03-22 11:18:09.542581+03
20943	5	-1	1620	2020-03-22 11:29:15.687496+03
20944	70	-1	760	2020-03-22 11:31:36.135954+03
20945	8	-1	1920	2020-03-22 11:48:39.897511+03
20946	34	23	706	2020-03-22 12:17:06.047737+03
20947	94	-1	1230	2020-03-22 12:45:43.662337+03
20948	65	-1	490	2020-03-22 12:55:31.70063+03
20949	14	-1	1350	2020-03-22 12:55:57.475707+03
20950	67	-1	350	2020-03-22 13:29:13.247811+03
20951	58	-1	2830	2020-03-22 14:03:01.085616+03
20952	63	-1	1780	2020-03-22 14:35:24.305856+03
20953	34	-1	1550	2020-03-22 14:36:03.72702+03
20954	51	-1	1310	2020-03-22 14:50:20.167402+03
20955	6	-1	980	2020-03-22 14:58:05.887572+03
20956	64	-1	970	2020-03-22 15:13:35.558063+03
20957	24	-1	950	2020-03-22 15:35:55.510536+03
20958	76	-1	1070	2020-03-22 15:48:26.357173+03
20959	11	-1	830	2020-03-22 15:55:46.276285+03
20960	69	-1	1100	2020-03-22 16:27:07.85705+03
20961	11	-1	830	2020-03-22 16:40:07.481762+03
20962	22	-2	1070	2020-03-22 16:42:45.523283+03
20963	1	-1	640	2020-03-22 16:52:46.180259+03
20964	92	-1	630	2020-03-22 17:22:04.41208+03
20965	6	-1	980	2020-03-22 17:32:47.331214+03
20966	52	-1	1090	2020-03-22 17:38:40.46999+03
20967	54	-1	3470	2020-03-22 17:40:15.326692+03
20968	88	-1	1270	2020-03-22 17:46:59.557689+03
20969	72	-1	620	2020-03-22 17:48:48.038429+03
20970	94	-2	1230	2020-03-22 17:48:55.513579+03
20971	27	18	447	2020-03-22 18:33:43.518147+03
20972	67	-1	350	2020-03-22 19:01:59.129283+03
20973	78	-1	900	2020-03-22 19:11:09.140516+03
20974	31	-1	1190	2020-03-22 19:14:37.310464+03
20975	64	-2	970	2020-03-22 19:16:16.806733+03
20976	17	-1	1500	2020-03-22 19:40:40.478948+03
20977	87	-1	2320	2020-03-22 19:42:49.139465+03
20978	83	-2	1230	2020-03-22 20:31:06.076404+03
20979	71	-1	1030	2020-03-22 20:31:13.443358+03
20980	69	-1	1100	2020-03-22 20:42:24.750682+03
20981	20	-1	830	2020-03-22 21:01:51.472201+03
20982	6	-2	980	2020-03-22 21:03:26.445346+03
20983	86	-1	910	2020-03-22 21:15:18.553534+03
20984	54	-1	3470	2020-03-22 21:44:49.474275+03
20985	93	-2	1620	2020-03-22 23:17:56.983012+03
20986	81	-1	1620	2020-03-22 23:23:21.707832+03
20987	51	-1	1310	2020-03-22 23:47:20.707569+03
20988	10	-1	2080	2020-03-22 23:56:32.746883+03
20989	52	-2	1090	2020-03-22 23:59:21.620242+03
20990	10	-1	2080	2020-03-23 00:05:38.19848+03
20991	89	-2	1420	2020-03-23 00:33:01.959893+03
20992	22	-1	1070	2020-03-23 00:33:03.571602+03
20993	29	-1	1940	2020-03-23 00:38:04.053044+03
20994	28	-1	1860	2020-03-23 00:45:07.603514+03
20995	86	-1	910	2020-03-23 01:21:07.71104+03
20996	96	-1	1570	2020-03-23 02:08:12.916306+03
20997	47	-1	1480	2020-03-23 02:28:21.72333+03
20998	45	-1	1590	2020-03-23 02:36:09.310949+03
20999	18	-2	910	2020-03-23 02:38:30.611725+03
21000	88	-1	1270	2020-03-23 02:43:20.228425+03
21001	80	-1	1120	2020-03-23 02:45:30.707872+03
21002	81	-1	1620	2020-03-23 02:49:54.805827+03
21003	1	-1	640	2020-03-23 02:51:47.189355+03
21004	74	-1	1010	2020-03-23 03:18:14.856646+03
21005	39	-1	910	2020-03-23 03:39:21.082318+03
21006	17	-1	1500	2020-03-23 03:49:06.149271+03
21007	83	-1	1230	2020-03-23 04:03:41.466285+03
21008	34	-2	1550	2020-03-23 04:05:30.366371+03
21009	1	-1	640	2020-03-23 04:08:02.232342+03
21010	31	22	649	2020-03-23 04:42:34.029798+03
21011	64	-1	970	2020-03-23 04:57:17.118227+03
21012	18	-1	910	2020-03-23 05:14:30.366084+03
21013	29	-1	1940	2020-03-23 05:28:03.050953+03
21014	91	-1	1620	2020-03-23 05:34:03.132288+03
21015	50	-1	1140	2020-03-23 06:17:13.591351+03
21016	64	-1	970	2020-03-23 06:25:02.045757+03
21017	40	-1	1430	2020-03-23 07:17:13.768095+03
21018	48	-2	640	2020-03-23 07:46:51.375262+03
21019	49	-1	970	2020-03-23 07:49:42.384381+03
21020	84	-2	2700	2020-03-23 07:50:02.08503+03
21021	5	-1	1620	2020-03-23 07:54:50.868834+03
21022	49	-1	970	2020-03-23 08:23:39.119923+03
21023	17	-2	1500	2020-03-23 08:30:10.82659+03
21024	59	-1	1030	2020-03-23 08:49:11.282423+03
21025	44	-1	500	2020-03-23 09:40:08.664105+03
21026	8	-1	1920	2020-03-23 10:34:51.626317+03
21027	15	-2	2830	2020-03-23 11:09:30.594997+03
21028	18	-1	910	2020-03-23 11:48:14.407597+03
21029	24	-1	950	2020-03-23 11:54:18.817555+03
21030	39	-1	910	2020-03-23 11:54:22.891059+03
21031	45	-2	1590	2020-03-23 12:08:45.695196+03
21032	4	-1	1420	2020-03-23 12:22:20.09415+03
21033	5	-1	1620	2020-03-23 12:39:05.64395+03
21034	40	-1	1430	2020-03-23 12:42:23.517996+03
21035	42	-1	1790	2020-03-23 12:58:32.7311+03
21036	45	-1	1590	2020-03-23 13:30:11.672186+03
21037	48	-2	640	2020-03-23 13:48:15.058143+03
21038	50	24	666	2020-03-23 14:13:20.653137+03
21039	3	-1	660	2020-03-23 14:39:33.759452+03
21040	53	-1	3120	2020-03-23 14:54:58.146396+03
21041	45	-1	1590	2020-03-23 15:02:04.535864+03
21042	57	-2	1900	2020-03-23 15:04:24.79844+03
21043	82	-2	560	2020-03-23 15:13:48.444063+03
21044	43	-1	380	2020-03-23 15:17:00.29259+03
21045	19	-2	1220	2020-03-23 15:31:07.495952+03
21046	16	-1	1380	2020-03-23 15:37:40.426677+03
21047	38	-2	1100	2020-03-23 15:48:43.466561+03
21048	7	-1	810	2020-03-23 15:51:29.311269+03
21049	57	-1	1900	2020-03-23 15:52:29.270092+03
21050	75	-2	830	2020-03-23 16:01:06.77943+03
21051	4	-1	1420	2020-03-23 16:46:31.651735+03
21052	21	-1	960	2020-03-23 16:56:43.431043+03
21053	86	-1	910	2020-03-23 16:59:05.037859+03
21054	90	-1	1780	2020-03-23 17:15:45.398113+03
21055	9	-1	2090	2020-03-23 17:18:46.855229+03
21056	95	-2	480	2020-03-23 17:50:23.475183+03
21057	66	-1	690	2020-03-23 17:51:24.827149+03
21058	56	-1	2460	2020-03-23 17:57:28.640818+03
21059	18	-1	910	2020-03-23 17:59:23.354838+03
21060	72	-1	620	2020-03-23 18:03:46.798626+03
21061	35	-1	670	2020-03-23 18:28:16.591862+03
21062	54	-1	3470	2020-03-23 18:45:23.58057+03
21063	3	-1	660	2020-03-23 18:56:59.752054+03
21064	87	-1	2320	2020-03-23 19:13:06.531793+03
21065	1	-1	640	2020-03-23 19:15:41.219963+03
21066	51	-1	1310	2020-03-23 19:26:15.590265+03
21067	14	-2	1350	2020-03-23 19:44:38.791447+03
21068	93	-1	1620	2020-03-23 19:57:25.727162+03
21069	82	-1	560	2020-03-23 20:25:17.745475+03
21070	80	-1	1120	2020-03-23 20:34:42.792811+03
21071	89	-1	1420	2020-03-23 20:37:03.737196+03
21072	18	-1	910	2020-03-23 20:55:18.559442+03
21073	36	-1	630	2020-03-23 21:00:04.928336+03
21074	26	-1	390	2020-03-23 21:26:30.390845+03
21075	39	-1	910	2020-03-23 21:45:13.87106+03
21076	34	-2	1550	2020-03-23 21:56:36.071156+03
21077	8	-1	1920	2020-03-23 21:57:20.678395+03
21078	88	-1	1270	2020-03-23 21:59:37.169795+03
21079	62	-1	1220	2020-03-23 22:03:11.824551+03
21080	9	24	1219	2020-03-23 22:04:07.563605+03
21081	70	-1	760	2020-03-23 22:15:44.082447+03
21082	36	-2	630	2020-03-23 22:17:23.675232+03
21083	74	-1	1010	2020-03-23 22:24:15.656005+03
21084	39	-1	910	2020-03-23 22:25:14.053126+03
21085	39	-1	910	2020-03-23 22:30:37.703881+03
21086	41	-1	830	2020-03-23 22:59:48.399691+03
21087	78	-2	900	2020-03-23 23:48:47.13021+03
21088	33	-2	900	2020-03-24 00:03:07.298212+03
21089	57	-1	1900	2020-03-24 00:04:12.561363+03
21090	59	-1	1030	2020-03-24 00:04:18.480662+03
21091	83	-1	1230	2020-03-24 00:17:37.533765+03
21092	80	-1	1120	2020-03-24 00:50:30.447919+03
21093	67	-1	350	2020-03-24 00:55:49.09075+03
21094	1	-1	640	2020-03-24 01:53:48.661701+03
21095	7	-1	810	2020-03-24 02:40:01.976294+03
21096	31	-1	1190	2020-03-24 02:56:22.532654+03
21097	54	-2	3470	2020-03-24 03:13:42.207211+03
21098	39	-1	910	2020-03-24 03:41:14.643884+03
21099	9	-1	2090	2020-03-24 04:10:37.909226+03
21100	60	-1	2700	2020-03-24 04:33:45.185711+03
21101	33	-1	900	2020-03-24 04:42:30.859316+03
21102	5	-1	1620	2020-03-24 04:46:26.070392+03
21103	10	-2	2080	2020-03-24 04:58:00.166332+03
21104	58	-1	2830	2020-03-24 05:00:11.174053+03
21105	77	33	343	2020-03-24 05:05:11.671521+03
21106	69	-2	1100	2020-03-24 05:54:48.43799+03
21107	14	26	707	2020-03-24 06:12:36.481137+03
21108	4	-1	1420	2020-03-24 07:22:06.609666+03
21109	88	-1	1270	2020-03-24 07:45:22.533748+03
21110	69	-1	1100	2020-03-24 07:58:41.215093+03
21111	93	-1	1620	2020-03-24 08:01:13.668277+03
21112	89	-1	1420	2020-03-24 08:27:17.280474+03
21113	1	-1	640	2020-03-24 09:16:53.226126+03
21114	83	-1	1230	2020-03-24 09:25:28.547161+03
21115	93	-2	1620	2020-03-24 10:20:52.702783+03
21116	12	-1	1650	2020-03-24 10:59:53.55244+03
21117	32	-1	710	2020-03-24 11:05:32.43006+03
21118	50	-1	1140	2020-03-24 11:05:57.225706+03
21119	85	-2	730	2020-03-24 11:28:21.852181+03
21120	93	34	843	2020-03-24 12:03:18.087321+03
21121	53	-1	3120	2020-03-24 12:23:45.916862+03
21122	49	-1	970	2020-03-24 12:28:42.544658+03
21123	90	-1	1780	2020-03-24 12:40:41.943135+03
21124	92	-1	630	2020-03-24 12:49:48.00038+03
21125	74	-1	1010	2020-03-24 13:02:04.554792+03
21126	63	-1	1780	2020-03-24 13:36:58.198646+03
21127	31	-1	1190	2020-03-24 13:38:54.784259+03
21128	33	-1	900	2020-03-24 13:45:18.579174+03
21129	51	-1	1310	2020-03-24 13:57:55.7795+03
21130	24	-1	950	2020-03-24 14:16:12.364044+03
21131	34	-1	1550	2020-03-24 14:25:34.509908+03
21132	82	-1	560	2020-03-24 14:39:32.496641+03
21133	64	-1	970	2020-03-24 15:03:32.193317+03
21134	92	-1	630	2020-03-24 15:15:28.81493+03
21135	95	-1	480	2020-03-24 15:28:18.227861+03
21136	29	-2	1940	2020-03-24 15:42:00.963653+03
21137	46	-2	1270	2020-03-24 16:26:40.876966+03
21138	12	-1	1650	2020-03-24 16:33:40.59613+03
21139	54	-1	3470	2020-03-24 16:46:18.773689+03
21140	82	-1	560	2020-03-24 17:01:03.750229+03
21141	79	-1	550	2020-03-24 17:41:11.497431+03
21142	74	-1	1010	2020-03-24 18:10:22.34507+03
21143	22	-1	1070	2020-03-24 18:11:21.885818+03
21144	20	-2	830	2020-03-24 18:19:34.22339+03
21145	60	-1	2700	2020-03-24 18:29:50.683116+03
21146	6	40	516	2020-03-24 18:52:43.291952+03
21147	17	-1	1500	2020-03-24 19:28:05.386257+03
21148	87	-2	2320	2020-03-24 19:46:13.494226+03
21149	73	-1	960	2020-03-24 20:05:16.98384+03
21150	35	-1	670	2020-03-24 20:45:31.022401+03
21151	18	-1	910	2020-03-24 20:45:31.985663+03
21152	11	-1	830	2020-03-24 21:18:36.973332+03
21153	55	-1	3480	2020-03-24 21:23:59.191274+03
21154	38	-2	1100	2020-03-24 21:26:24.70972+03
21155	3	-1	660	2020-03-24 21:34:16.42481+03
21156	79	-1	550	2020-03-24 21:37:23.900263+03
21157	18	-1	910	2020-03-24 21:55:50.796574+03
21158	53	-1	3120	2020-03-24 21:57:10.321657+03
21159	25	-1	1100	2020-03-24 22:28:45.737532+03
21160	50	-1	1140	2020-03-24 22:59:52.55584+03
21161	79	-2	550	2020-03-25 00:36:49.709967+03
21162	58	-1	2830	2020-03-25 00:42:49.77237+03
21163	83	-1	1230	2020-03-25 00:46:06.890519+03
21164	15	-1	2830	2020-03-25 00:59:21.197363+03
21165	49	-2	970	2020-03-25 01:01:37.19652+03
21166	14	-1	1350	2020-03-25 01:10:57.733868+03
21167	88	-2	1270	2020-03-25 01:31:12.025991+03
21168	83	-1	1230	2020-03-25 02:02:52.210104+03
21169	80	21	491	2020-03-25 02:14:18.23277+03
21170	41	-2	830	2020-03-25 02:28:10.660306+03
21171	74	-1	1010	2020-03-25 02:29:22.425888+03
21172	8	-2	1920	2020-03-25 02:37:38.259495+03
21173	10	-1	2080	2020-03-25 02:40:15.512938+03
21174	43	-2	380	2020-03-25 03:05:59.070368+03
21175	22	-2	1070	2020-03-25 03:44:04.947626+03
21176	5	-1	1620	2020-03-25 03:45:33.064135+03
21177	76	-1	1070	2020-03-25 04:30:38.00127+03
21178	58	-1	2830	2020-03-25 04:36:47.048062+03
21179	69	-1	1100	2020-03-25 04:39:23.687222+03
21180	17	-1	1500	2020-03-25 04:42:28.839247+03
21181	9	-1	2090	2020-03-25 04:43:23.918573+03
21182	11	20	456	2020-03-25 04:44:41.597227+03
21183	38	-1	1100	2020-03-25 04:46:32.038353+03
21184	19	-1	1220	2020-03-25 05:36:31.290118+03
21185	22	-1	1070	2020-03-25 05:46:15.643352+03
21186	87	-1	2320	2020-03-25 06:03:23.370955+03
21187	69	-1	1100	2020-03-25 06:08:37.560159+03
21188	70	-1	760	2020-03-25 06:19:11.70292+03
21189	60	-1	2700	2020-03-25 06:37:37.041067+03
21190	76	-1	1070	2020-03-25 07:29:43.455937+03
21191	45	-1	1590	2020-03-25 07:37:10.259592+03
21192	38	-1	1100	2020-03-25 07:47:45.8774+03
21193	71	-1	1030	2020-03-25 07:50:52.746863+03
21194	54	-1	3470	2020-03-25 08:34:16.666266+03
21195	6	-1	980	2020-03-25 08:41:07.653335+03
21196	19	-1	1220	2020-03-25 09:15:42.932278+03
21197	25	-1	1100	2020-03-25 09:30:14.023628+03
21198	6	-1	980	2020-03-25 10:17:48.256584+03
21199	6	-2	980	2020-03-25 10:23:16.071946+03
21200	86	-1	910	2020-03-25 10:41:29.41177+03
21201	13	-1	460	2020-03-25 11:36:33.113447+03
21202	60	-1	2700	2020-03-25 11:36:42.470361+03
21203	55	-2	3480	2020-03-25 12:20:46.838757+03
21204	53	-1	3120	2020-03-25 12:26:05.147676+03
21205	18	-1	910	2020-03-25 12:27:11.207459+03
21206	42	-1	1790	2020-03-25 12:32:32.515303+03
21207	54	24	1629	2020-03-25 12:41:27.821412+03
21208	40	-1	1430	2020-03-25 12:50:53.634652+03
21209	13	-2	460	2020-03-25 12:59:34.056381+03
21210	39	-1	910	2020-03-25 13:03:35.476192+03
21211	12	-1	1650	2020-03-25 13:21:45.869823+03
21212	21	-1	960	2020-03-25 13:27:51.776988+03
21213	67	-1	350	2020-03-25 14:07:49.838617+03
21214	1	-1	640	2020-03-25 14:25:42.85287+03
21215	82	-1	560	2020-03-25 15:24:00.737276+03
21216	75	-1	830	2020-03-25 15:49:38.410637+03
21217	47	-2	1480	2020-03-25 16:57:50.489975+03
21218	36	-1	630	2020-03-25 17:10:01.156024+03
21219	90	-2	1780	2020-03-25 17:14:25.507932+03
21220	93	-1	1620	2020-03-25 17:19:07.749297+03
21221	12	-1	1650	2020-03-25 17:31:24.602278+03
21222	7	-1	810	2020-03-25 17:42:41.532425+03
21223	22	-1	1070	2020-03-25 17:56:06.064617+03
21224	30	30	544	2020-03-25 18:03:28.631654+03
21225	40	-2	1430	2020-03-25 18:04:33.094399+03
21226	47	-2	1480	2020-03-25 18:05:46.876608+03
21227	61	-1	1510	2020-03-25 18:08:12.4294+03
21228	19	-1	1220	2020-03-25 18:14:22.089814+03
21229	31	-1	1190	2020-03-25 18:26:18.541217+03
21230	31	-1	1190	2020-03-25 18:29:48.804724+03
21231	64	-1	970	2020-03-25 19:00:54.035284+03
21232	72	-1	620	2020-03-25 19:04:30.256762+03
21233	7	-1	810	2020-03-25 19:40:20.041264+03
21234	47	-1	1480	2020-03-25 19:42:04.388229+03
21235	63	-1	1780	2020-03-25 19:49:02.488862+03
21236	69	-1	1100	2020-03-25 19:53:25.290652+03
21237	9	-1	2090	2020-03-25 19:58:03.807289+03
21238	16	14	730	2020-03-25 20:36:52.956277+03
21239	42	-1	1790	2020-03-25 20:45:11.702525+03
21240	6	-1	980	2020-03-25 21:49:14.032632+03
21241	35	-1	670	2020-03-25 22:00:13.301111+03
21242	31	-1	1190	2020-03-25 22:07:52.941031+03
21243	25	-1	1100	2020-03-25 22:08:26.821293+03
21244	77	-1	640	2020-03-25 22:26:37.009329+03
21245	80	-2	1120	2020-03-25 22:31:03.646026+03
21246	29	-1	1940	2020-03-25 22:52:58.108564+03
21247	87	-1	2320	2020-03-25 22:55:31.932895+03
21248	21	20	533	2020-03-25 22:58:56.452968+03
21249	5	-1	1620	2020-03-25 23:08:14.520755+03
21250	81	-1	1620	2020-03-25 23:08:48.571626+03
21251	33	-1	900	2020-03-25 23:23:52.178089+03
21252	94	-2	1230	2020-03-25 23:25:53.902958+03
21253	83	-2	1230	2020-03-25 23:27:01.563367+03
21254	70	-2	760	2020-03-25 23:36:49.357558+03
21255	95	-1	480	2020-03-25 23:54:12.892178+03
21256	18	-1	910	2020-03-25 23:54:54.396818+03
21257	53	-2	3120	2020-03-25 23:56:10.633521+03
21258	40	-2	1430	2020-03-26 00:00:38.774258+03
21259	63	-1	1780	2020-03-26 00:08:45.74535+03
21260	10	-1	2080	2020-03-26 00:22:36.940787+03
21261	85	-2	730	2020-03-26 00:49:46.968911+03
21262	96	-1	1570	2020-03-26 00:51:49.645057+03
21263	95	-2	480	2020-03-26 00:52:34.305005+03
21264	16	-2	1380	2020-03-26 01:09:30.214341+03
21265	55	-1	3480	2020-03-26 01:27:30.680135+03
21266	71	-3	1030	2020-03-26 02:35:18.869055+03
21267	26	-2	390	2020-03-26 02:41:02.368961+03
21268	32	-2	710	2020-03-26 02:54:24.415429+03
21269	58	-1	2830	2020-03-26 03:17:09.774252+03
21270	54	-1	3470	2020-03-26 03:38:22.736846+03
21271	67	-1	350	2020-03-26 03:59:47.297732+03
21272	90	-1	1780	2020-03-26 04:07:05.929718+03
21273	86	-2	910	2020-03-26 04:30:35.043922+03
21274	9	-1	2090	2020-03-26 04:30:59.100037+03
21275	90	-1	1780	2020-03-26 04:32:07.686881+03
21276	33	-1	900	2020-03-26 05:31:28.454563+03
21277	10	-1	2080	2020-03-26 05:34:35.458665+03
21278	21	-1	960	2020-03-26 05:40:33.906416+03
21279	69	-1	1100	2020-03-26 05:41:14.962751+03
21280	77	-1	640	2020-03-26 05:42:40.635468+03
21281	1	-1	640	2020-03-26 05:46:54.272045+03
21282	89	-1	1420	2020-03-26 05:51:36.022516+03
21283	89	-1	1420	2020-03-26 06:25:10.051308+03
21284	2	-1	470	2020-03-26 06:47:21.431641+03
21285	88	-1	1270	2020-03-26 07:00:52.06686+03
21286	73	-1	960	2020-03-26 07:41:28.298113+03
21287	51	32	695	2020-03-26 07:45:45.398774+03
21288	53	-1	3120	2020-03-26 08:03:42.231897+03
21289	48	-1	640	2020-03-26 08:30:08.814214+03
21290	63	-1	1780	2020-03-26 09:09:09.62862+03
21291	53	-1	3120	2020-03-26 09:24:28.24085+03
21292	7	-1	810	2020-03-26 10:16:14.408932+03
21293	3	-1	660	2020-03-26 10:44:23.847423+03
21294	94	-1	1230	2020-03-26 11:01:20.379008+03
21295	80	-1	1120	2020-03-26 11:30:57.703764+03
21296	71	-1	1030	2020-03-26 12:26:36.685794+03
21297	33	-1	900	2020-03-26 12:29:37.591694+03
21298	28	-1	1860	2020-03-26 12:42:25.980866+03
21299	21	-1	960	2020-03-26 12:49:07.918119+03
21300	78	-2	900	2020-03-26 12:54:57.241552+03
21301	51	-1	1310	2020-03-26 13:12:16.876073+03
21302	21	-1	960	2020-03-26 13:15:25.095161+03
21303	74	-1	1010	2020-03-26 13:47:36.11152+03
21304	7	-2	810	2020-03-26 13:58:46.711082+03
21305	6	-1	980	2020-03-26 14:10:53.874076+03
21306	19	-1	1220	2020-03-26 14:15:03.688103+03
21307	55	-1	3480	2020-03-26 14:15:58.332163+03
21308	44	-1	500	2020-03-26 14:25:18.340374+03
21309	27	-1	880	2020-03-26 14:50:18.185162+03
21310	96	-1	1570	2020-03-26 15:05:27.698124+03
21311	77	-1	640	2020-03-26 15:31:30.761439+03
21312	44	-1	500	2020-03-26 15:34:07.262467+03
21313	62	-1	1220	2020-03-26 15:34:45.915878+03
21314	89	-1	1420	2020-03-26 15:56:07.81798+03
21315	17	-2	1500	2020-03-26 16:06:47.212353+03
21316	14	-1	1350	2020-03-26 16:08:32.158504+03
21317	14	-1	1350	2020-03-26 16:19:31.492131+03
21318	8	31	804	2020-03-26 16:38:26.382663+03
21319	8	-1	1920	2020-03-26 16:44:19.925728+03
21320	67	-1	350	2020-03-26 17:00:34.194551+03
21321	43	-2	380	2020-03-26 17:00:53.828339+03
21322	10	-1	2080	2020-03-26 17:03:22.125741+03
21323	92	-1	630	2020-03-26 17:39:45.855878+03
21324	29	-1	1940	2020-03-26 18:03:07.775821+03
21325	76	-1	1070	2020-03-26 18:25:40.183184+03
21326	53	-1	3120	2020-03-26 18:28:57.48953+03
21327	21	-1	960	2020-03-26 18:29:56.607708+03
21328	95	-1	480	2020-03-26 18:40:08.005366+03
21329	28	21	934	2020-03-26 18:57:29.156451+03
21330	18	-1	910	2020-03-26 19:08:58.887315+03
21331	16	-1	1380	2020-03-26 19:13:43.288764+03
21332	34	-1	1550	2020-03-26 19:15:07.504856+03
21333	51	-1	1310	2020-03-26 19:16:41.735601+03
21334	54	-1	3470	2020-03-26 19:47:28.532131+03
21335	13	-1	460	2020-03-26 19:56:05.613489+03
21336	11	-1	830	2020-03-26 19:56:40.934106+03
21337	40	-2	1430	2020-03-26 20:16:43.097579+03
21338	9	-1	2090	2020-03-26 20:43:22.693077+03
21339	47	-1	1480	2020-03-26 20:51:27.102603+03
21340	9	-1	2090	2020-03-26 21:07:39.207403+03
21341	46	-1	1270	2020-03-26 21:16:14.546914+03
21342	18	-1	910	2020-03-26 21:16:22.410321+03
21343	38	34	482	2020-03-26 21:37:19.065837+03
21344	49	-2	970	2020-03-26 21:56:33.893031+03
21345	72	-1	620	2020-03-26 22:01:51.292956+03
21346	59	-1	1030	2020-03-26 22:03:27.499278+03
21347	20	-1	830	2020-03-26 22:20:35.56386+03
21348	52	-1	1090	2020-03-26 22:33:58.380018+03
21349	37	-1	1290	2020-03-26 22:46:22.839389+03
21350	13	-1	460	2020-03-26 23:02:34.776254+03
21351	90	33	781	2020-03-26 23:21:53.69079+03
21352	24	25	402	2020-03-26 23:27:15.075382+03
21353	13	-1	460	2020-03-26 23:46:57.799136+03
21354	85	-1	730	2020-03-26 23:53:05.864387+03
21355	90	-1	1780	2020-03-26 23:56:16.955649+03
21356	64	-1	970	2020-03-26 23:58:47.781931+03
21357	85	-1	730	2020-03-27 00:02:17.117326+03
21358	64	-1	970	2020-03-27 00:06:18.655874+03
21359	74	-1	1010	2020-03-27 00:40:30.067635+03
21360	39	-1	910	2020-03-27 01:00:21.997885+03
21361	59	-1	1030	2020-03-27 01:01:18.320186+03
21362	63	-1	1780	2020-03-27 01:04:37.986383+03
21363	71	-2	1030	2020-03-27 01:06:19.768614+03
21364	24	-1	950	2020-03-27 01:12:42.677029+03
21365	95	-1	480	2020-03-27 01:22:56.568759+03
21366	66	-1	690	2020-03-27 01:24:42.864917+03
21367	95	-1	480	2020-03-27 01:25:14.873483+03
21368	43	-1	380	2020-03-27 01:59:51.754177+03
21369	76	-1	1070	2020-03-27 02:14:08.121764+03
21370	12	-1	1650	2020-03-27 02:22:26.409172+03
21371	84	-1	2700	2020-03-27 02:40:27.571427+03
21372	46	-1	1270	2020-03-27 02:43:26.097149+03
21373	73	-1	960	2020-03-27 03:05:26.66092+03
21374	47	-1	1480	2020-03-27 03:09:43.048454+03
21375	33	-1	900	2020-03-27 03:20:59.73044+03
21376	58	-1	2830	2020-03-27 03:32:05.174471+03
21377	34	-1	1550	2020-03-27 03:34:31.035562+03
21378	30	-1	1140	2020-03-27 03:44:08.639753+03
21379	52	-1	1090	2020-03-27 03:57:09.018942+03
21380	8	-1	1920	2020-03-27 04:03:39.05677+03
21381	22	-1	1070	2020-03-27 04:08:25.783741+03
21382	49	-1	970	2020-03-27 04:28:32.810079+03
21383	37	-1	1290	2020-03-27 04:49:36.34534+03
21384	59	-1	1030	2020-03-27 04:52:07.614724+03
21385	94	-1	1230	2020-03-27 05:35:15.713175+03
21386	34	-1	1550	2020-03-27 05:49:44.116675+03
21387	74	-1	1010	2020-03-27 05:51:07.077843+03
21388	12	-1	1650	2020-03-27 06:07:20.060032+03
21389	89	-1	1420	2020-03-27 06:07:48.538222+03
21390	56	-1	2460	2020-03-27 06:24:24.820097+03
21391	64	31	539	2020-03-27 06:43:20.319685+03
21392	31	-1	1190	2020-03-27 06:48:04.693164+03
21393	10	-1	2080	2020-03-27 07:09:50.87235+03
21394	30	-1	1140	2020-03-27 07:18:57.068593+03
21395	29	-2	1940	2020-03-27 07:26:41.90646+03
21396	9	-1	2090	2020-03-27 07:36:36.778211+03
21397	94	-1	1230	2020-03-27 07:41:54.926014+03
21398	88	-2	1270	2020-03-27 07:56:58.852938+03
21399	51	-1	1310	2020-03-27 07:59:00.468634+03
21400	19	-1	1220	2020-03-27 08:01:04.321262+03
21401	29	-1	1940	2020-03-27 08:39:32.713357+03
21402	34	-2	1550	2020-03-27 08:44:55.588716+03
21403	27	-1	880	2020-03-27 08:45:40.746148+03
21404	30	-1	1140	2020-03-27 08:52:35.815259+03
21405	48	-1	640	2020-03-27 08:53:53.94441+03
21406	96	-1	1570	2020-03-27 08:55:11.414265+03
21407	65	-1	490	2020-03-27 09:05:43.832286+03
21408	53	-2	3120	2020-03-27 09:45:54.678045+03
21409	36	-2	630	2020-03-27 10:56:36.738574+03
21410	69	-3	1100	2020-03-27 10:59:18.478992+03
21411	31	-2	1190	2020-03-27 10:59:47.165886+03
21412	49	-1	970	2020-03-27 11:17:44.251801+03
21413	41	-1	830	2020-03-27 11:39:02.710473+03
21414	64	-1	970	2020-03-27 11:52:19.404681+03
21415	80	-2	1120	2020-03-27 12:24:42.061058+03
21416	79	-2	550	2020-03-27 12:51:22.008588+03
21417	22	47	443	2020-03-27 12:57:34.379385+03
21418	53	-1	3120	2020-03-27 12:58:16.460418+03
21419	11	-1	830	2020-03-27 13:26:58.849498+03
21420	11	-1	830	2020-03-27 13:37:15.6102+03
21421	30	-1	1140	2020-03-27 13:50:19.935989+03
21422	39	-2	910	2020-03-27 13:59:05.824451+03
21423	12	-1	1650	2020-03-27 14:16:05.906619+03
21424	47	-1	1480	2020-03-27 15:04:17.215991+03
21425	65	-1	490	2020-03-27 15:05:25.633944+03
21426	14	-2	1350	2020-03-27 15:10:51.232261+03
21427	31	-1	1190	2020-03-27 15:11:50.313479+03
21428	94	-1	1230	2020-03-27 15:29:38.692164+03
21429	32	-1	710	2020-03-27 15:36:20.768607+03
21430	93	-1	1620	2020-03-27 15:38:09.844241+03
21431	58	-2	2830	2020-03-27 15:39:34.227482+03
21432	11	-1	830	2020-03-27 15:40:23.808108+03
21433	38	-1	1100	2020-03-27 15:44:51.640331+03
21434	33	-1	900	2020-03-27 15:48:38.428075+03
21435	64	-1	970	2020-03-27 16:33:26.387113+03
21436	14	-1	1350	2020-03-27 16:34:18.151392+03
21437	57	-2	1900	2020-03-27 16:45:32.116291+03
21438	31	-1	1190	2020-03-27 17:19:23.916038+03
21439	96	-1	1570	2020-03-27 17:20:53.529093+03
21440	35	-1	670	2020-03-27 17:34:13.278071+03
21441	13	-1	460	2020-03-27 18:02:15.27241+03
21442	70	-2	760	2020-03-27 18:08:16.29491+03
21443	64	-1	970	2020-03-27 18:21:06.488218+03
21444	88	-1	1270	2020-03-27 18:31:28.008342+03
21445	39	-1	910	2020-03-27 18:46:07.431771+03
21446	86	-1	910	2020-03-27 18:50:21.675156+03
21447	92	-2	630	2020-03-27 19:00:17.462642+03
21448	11	-1	830	2020-03-27 19:26:45.484877+03
21449	75	-1	830	2020-03-27 19:47:34.029455+03
21450	21	-1	960	2020-03-27 20:06:52.154518+03
21451	57	-1	1900	2020-03-27 20:09:14.385823+03
21452	21	-1	960	2020-03-27 20:20:14.673519+03
21453	15	-1	2830	2020-03-27 21:29:06.695513+03
21454	41	-1	830	2020-03-27 21:30:17.197517+03
21455	59	-1	1030	2020-03-27 22:05:22.169124+03
21456	35	-1	670	2020-03-27 22:26:05.195758+03
21457	56	-1	2460	2020-03-27 22:33:56.960786+03
21458	67	-1	350	2020-03-27 23:24:40.970856+03
21459	35	-1	670	2020-03-27 23:36:30.039118+03
21460	96	-1	1570	2020-03-27 23:52:17.799228+03
21461	4	-1	1420	2020-03-28 00:52:14.267954+03
21462	19	-2	1220	2020-03-28 01:12:09.043624+03
21463	26	-1	390	2020-03-28 01:16:15.527707+03
21464	36	33	337	2020-03-28 01:21:16.92024+03
21465	64	-1	970	2020-03-28 01:23:31.171909+03
21466	81	-1	1620	2020-03-28 01:23:31.426415+03
21467	46	-1	1270	2020-03-28 01:36:17.451969+03
21468	60	-1	2700	2020-03-28 01:57:07.947533+03
21469	60	-1	2700	2020-03-28 02:07:56.020663+03
21470	14	-1	1350	2020-03-28 02:20:12.429771+03
21471	35	-1	670	2020-03-28 02:20:17.274358+03
21472	82	-2	560	2020-03-28 02:32:38.429866+03
21473	67	-1	350	2020-03-28 02:37:58.230439+03
21474	71	-1	1030	2020-03-28 02:47:32.090768+03
21475	76	-1	1070	2020-03-28 02:52:18.340489+03
21476	56	-1	2460	2020-03-28 03:24:15.384817+03
21477	4	-1	1420	2020-03-28 03:46:51.581273+03
21478	79	-1	550	2020-03-28 04:07:59.959431+03
21479	20	-1	830	2020-03-28 04:22:35.110699+03
21480	76	-2	1070	2020-03-28 04:50:06.899818+03
21481	61	-1	1510	2020-03-28 05:07:11.127876+03
21482	56	-1	2460	2020-03-28 05:48:07.844787+03
21483	38	-1	1100	2020-03-28 05:55:57.388524+03
21484	70	-1	760	2020-03-28 06:07:44.852529+03
21485	76	-1	1070	2020-03-28 07:37:33.872743+03
21486	6	-1	980	2020-03-28 07:55:16.714448+03
21487	35	-2	670	2020-03-28 08:36:29.837612+03
21488	75	-1	830	2020-03-28 08:44:14.624898+03
21489	15	-1	2830	2020-03-28 08:47:35.473652+03
21490	46	-2	1270	2020-03-28 08:54:41.284096+03
21491	64	-1	970	2020-03-28 09:18:00.213104+03
21492	18	-1	910	2020-03-28 09:23:49.094418+03
21493	30	-2	1140	2020-03-28 09:46:14.300109+03
21494	17	-1	1500	2020-03-28 10:09:19.888053+03
21495	91	-1	1620	2020-03-28 10:16:57.638283+03
21496	30	-1	1140	2020-03-28 10:28:08.844835+03
21497	91	-1	1620	2020-03-28 11:52:30.717227+03
21498	38	-1	1100	2020-03-28 12:52:11.20337+03
21499	90	-1	1780	2020-03-28 14:00:03.622881+03
21500	19	26	669	2020-03-28 14:02:53.378738+03
21501	40	-1	1430	2020-03-28 14:26:30.135131+03
21502	82	23	251	2020-03-28 15:09:21.440331+03
21503	51	-2	1310	2020-03-28 15:18:17.031804+03
21504	58	-1	2830	2020-03-28 15:24:14.951899+03
21505	3	-1	660	2020-03-28 15:25:29.77704+03
21506	68	-2	490	2020-03-28 15:45:07.059866+03
21507	27	-1	880	2020-03-28 15:57:07.092767+03
21508	45	-1	1590	2020-03-28 16:19:57.346169+03
21509	69	-1	1100	2020-03-28 16:53:19.917142+03
21510	88	-1	1270	2020-03-28 17:29:46.108427+03
21511	48	-1	640	2020-03-28 17:33:12.048214+03
21512	91	-1	1620	2020-03-28 17:45:28.057442+03
21513	83	-1	1230	2020-03-28 17:47:53.512384+03
21514	32	-2	710	2020-03-28 17:56:24.865021+03
21515	87	-2	2320	2020-03-28 18:16:10.573811+03
21516	57	-1	1900	2020-03-28 18:17:32.614053+03
21517	60	-1	2700	2020-03-28 18:24:44.620306+03
21518	20	-2	830	2020-03-28 19:25:45.334957+03
21519	40	-1	1430	2020-03-28 19:35:52.520385+03
21520	21	-1	960	2020-03-28 19:38:35.159094+03
21521	3	-1	660	2020-03-28 19:42:51.593623+03
21522	44	-2	500	2020-03-28 19:50:17.534805+03
21523	65	-1	490	2020-03-28 19:52:11.795947+03
21524	31	-1	1190	2020-03-28 20:01:15.091979+03
21525	4	-1	1420	2020-03-28 20:11:21.213522+03
21526	42	-1	1790	2020-03-28 20:58:02.702594+03
21527	28	-1	1860	2020-03-28 21:01:26.430331+03
21528	94	-1	1230	2020-03-28 21:17:35.925507+03
21529	17	-2	1500	2020-03-28 21:29:13.727971+03
21530	79	-1	550	2020-03-28 21:58:03.743374+03
21531	22	-1	1070	2020-03-28 22:04:14.194895+03
21532	64	-1	970	2020-03-28 22:15:51.469757+03
21533	55	-1	3480	2020-03-28 22:36:01.24423+03
21534	26	-1	390	2020-03-28 22:42:22.076053+03
21535	4	-1	1420	2020-03-28 22:49:33.938306+03
21536	82	-1	560	2020-03-28 23:28:24.667037+03
21537	82	-1	560	2020-03-28 23:46:49.455278+03
21538	58	-1	2830	2020-03-29 00:02:45.681991+03
21539	74	-3	1010	2020-03-29 00:11:08.546355+03
21540	8	-1	1920	2020-03-29 00:15:24.115984+03
21541	46	-1	1270	2020-03-29 00:18:10.788457+03
21542	70	-1	760	2020-03-29 00:27:29.865335+03
21543	45	-1	1590	2020-03-29 00:34:53.561785+03
21544	40	-1	1430	2020-03-29 01:03:10.239682+03
21545	63	-1	1780	2020-03-29 01:08:52.797896+03
21546	4	-1	1420	2020-03-29 01:09:25.914768+03
21547	23	-1	4390	2020-03-29 01:21:29.802062+03
21548	17	-1	1500	2020-03-29 01:36:07.710043+03
21549	94	20	725	2020-03-29 01:36:31.531935+03
21550	28	-1	1860	2020-03-29 01:51:54.805465+03
21551	65	-1	490	2020-03-29 01:55:41.266702+03
21552	57	39	784	2020-03-29 01:56:31.695745+03
21553	37	-1	1290	2020-03-29 02:52:48.637522+03
21554	4	-2	1420	2020-03-29 03:03:28.481471+03
21555	32	-1	710	2020-03-29 03:32:10.283273+03
21556	56	-1	2460	2020-03-29 04:08:02.005531+03
21557	7	30	457	2020-03-29 04:18:36.124873+03
21558	67	-2	350	2020-03-29 04:31:39.475006+03
21559	89	-1	1420	2020-03-29 04:37:14.699944+03
21560	84	-1	2700	2020-03-29 04:50:43.883018+03
21561	16	-1	1380	2020-03-29 05:13:39.344572+03
21562	82	-1	560	2020-03-29 05:55:52.312324+03
21563	42	-1	1790	2020-03-29 05:57:09.016101+03
21564	90	-1	1780	2020-03-29 07:51:11.496144+03
21565	48	-1	640	2020-03-29 08:07:42.661296+03
21566	11	-1	830	2020-03-29 09:04:06.983437+03
21567	78	-1	900	2020-03-29 09:24:38.875376+03
21568	35	-1	670	2020-03-29 09:53:43.890442+03
21569	39	-1	910	2020-03-29 09:55:59.918191+03
21570	85	-1	730	2020-03-29 10:20:30.901856+03
21571	94	-1	1230	2020-03-29 10:38:32.655079+03
21572	33	-1	900	2020-03-29 11:33:40.602586+03
21573	82	-1	560	2020-03-29 11:37:48.071404+03
21574	12	-1	1650	2020-03-29 12:03:03.08864+03
21575	49	-1	970	2020-03-29 12:05:34.996875+03
21576	75	-1	830	2020-03-29 12:37:18.957288+03
21577	47	-1	1480	2020-03-29 13:15:11.345201+03
21578	42	-1	1790	2020-03-29 13:29:06.807104+03
21579	76	-1	1070	2020-03-29 13:58:26.48925+03
21580	47	-2	1480	2020-03-29 14:24:32.204001+03
21581	46	-1	1270	2020-03-29 14:38:50.548793+03
21582	13	42	193	2020-03-29 15:19:34.35011+03
21583	4	-1	1420	2020-03-29 15:29:44.717822+03
21584	9	-1	2090	2020-03-29 15:50:20.738493+03
21585	94	-1	1230	2020-03-29 16:35:00.116311+03
21586	19	-3	1220	2020-03-29 16:48:29.55374+03
21587	93	-1	1620	2020-03-29 16:58:00.045792+03
21588	56	42	1245	2020-03-29 17:12:33.448475+03
21589	76	-1	1070	2020-03-29 17:18:42.251984+03
21590	96	-2	1570	2020-03-29 17:25:00.155099+03
21591	5	-1	1620	2020-03-29 17:55:02.607022+03
21592	52	-1	1090	2020-03-29 17:55:07.423493+03
21593	46	-1	1270	2020-03-29 18:01:03.114368+03
21594	73	-1	960	2020-03-29 18:07:47.259516+03
21595	46	-1	1270	2020-03-29 19:59:26.998449+03
21596	46	-1	1270	2020-03-29 20:28:04.089815+03
21597	46	-1	1270	2020-03-29 20:32:56.783659+03
21598	17	-2	1500	2020-03-29 21:01:14.373479+03
21599	83	-1	1230	2020-03-29 21:05:30.190721+03
21600	22	-1	1070	2020-03-29 21:14:35.854926+03
21601	6	-1	980	2020-03-29 21:16:18.147745+03
21602	33	-1	900	2020-03-29 22:09:32.613268+03
21603	41	-1	830	2020-03-29 23:42:59.87169+03
21604	21	-1	960	2020-03-29 23:55:54.817435+03
21605	67	-1	350	2020-03-29 23:57:07.882288+03
21606	59	-1	1030	2020-03-30 00:15:03.021693+03
21607	94	-2	1230	2020-03-30 00:21:33.156251+03
21608	34	-1	1550	2020-03-30 00:42:35.038113+03
21609	38	-1	1100	2020-03-30 01:04:34.536648+03
21610	64	-1	970	2020-03-30 01:20:40.363276+03
21611	40	-1	1430	2020-03-30 01:27:49.005858+03
21612	29	-2	1940	2020-03-30 01:30:56.796425+03
21613	6	-1	980	2020-03-30 01:47:01.29906+03
21614	73	-2	960	2020-03-30 01:52:05.752723+03
21615	95	-1	480	2020-03-30 02:02:01.969157+03
21616	10	-2	2080	2020-03-30 02:40:44.979238+03
21617	3	-1	660	2020-03-30 02:55:29.920797+03
21618	1	-2	640	2020-03-30 03:28:11.383583+03
21619	77	-1	640	2020-03-30 03:31:53.381168+03
21620	32	-1	710	2020-03-30 03:38:09.948112+03
21621	88	-1	1270	2020-03-30 03:46:32.473942+03
21622	12	-1	1650	2020-03-30 03:51:32.093937+03
21623	32	-1	710	2020-03-30 04:19:13.057116+03
21624	49	-2	970	2020-03-30 04:46:58.841875+03
21625	36	-1	630	2020-03-30 05:04:06.396976+03
21626	88	-1	1270	2020-03-30 06:05:05.378305+03
21627	14	-1	1350	2020-03-30 06:06:52.72299+03
21628	58	-1	2830	2020-03-30 07:04:10.533947+03
21629	57	-1	1900	2020-03-30 07:12:16.836559+03
21630	62	-1	1220	2020-03-30 07:31:34.433118+03
21631	72	-1	620	2020-03-30 07:31:53.087226+03
21632	56	-1	2460	2020-03-30 09:01:46.204803+03
21633	53	-1	3120	2020-03-30 09:05:21.290542+03
21634	78	-2	900	2020-03-30 09:06:11.78941+03
21635	48	-1	640	2020-03-30 09:13:39.517197+03
21636	94	-1	1230	2020-03-30 09:17:32.395266+03
21637	46	-1	1270	2020-03-30 09:26:05.050054+03
21638	24	-1	950	2020-03-30 10:36:39.366156+03
21639	30	-1	1140	2020-03-30 10:37:25.609434+03
21640	22	-1	1070	2020-03-30 10:56:09.643428+03
21641	81	-1	1620	2020-03-30 11:31:42.64761+03
21642	85	-1	730	2020-03-30 11:50:04.137984+03
21643	65	-1	490	2020-03-30 12:24:08.399071+03
21644	93	-2	1620	2020-03-30 13:15:25.406446+03
21645	2	-2	470	2020-03-30 13:19:28.470081+03
21646	58	-1	2830	2020-03-30 13:25:12.505567+03
21647	35	-1	670	2020-03-30 14:00:45.3965+03
21648	68	-1	490	2020-03-30 14:10:38.964617+03
21649	63	-1	1780	2020-03-30 14:14:39.656819+03
21650	86	-1	910	2020-03-30 14:40:52.074398+03
21651	65	-1	490	2020-03-30 14:53:34.018851+03
21652	89	-1	1420	2020-03-30 14:55:26.274772+03
21653	48	-1	640	2020-03-30 14:55:32.157302+03
21654	74	-2	1010	2020-03-30 14:59:22.85562+03
21655	59	-1	1030	2020-03-30 15:01:13.668945+03
21656	22	-1	1070	2020-03-30 15:23:29.583309+03
21657	15	-2	2830	2020-03-30 15:25:14.90628+03
21658	9	-1	2090	2020-03-30 15:53:01.719615+03
21659	83	-1	1230	2020-03-30 16:00:43.49103+03
21660	33	-1	900	2020-03-30 16:02:24.146791+03
21661	38	-1	1100	2020-03-30 16:05:40.089492+03
21662	42	-1	1790	2020-03-30 16:14:45.519692+03
21663	64	-1	970	2020-03-30 16:38:25.782771+03
21664	89	-2	1420	2020-03-30 16:42:37.948297+03
21665	32	-1	710	2020-03-30 16:59:24.184191+03
21666	38	-1	1100	2020-03-30 17:01:47.622786+03
21667	64	-1	970	2020-03-30 17:28:53.22654+03
21668	61	-2	1510	2020-03-30 17:31:20.474452+03
21669	84	-1	2700	2020-03-30 17:41:37.774633+03
21670	74	-1	1010	2020-03-30 17:51:33.420993+03
21671	38	-1	1100	2020-03-30 17:52:05.380806+03
21672	73	-1	960	2020-03-30 17:58:22.622012+03
21673	72	-1	620	2020-03-30 18:10:18.225396+03
21674	24	-1	950	2020-03-30 18:11:29.265262+03
21675	29	-1	1940	2020-03-30 18:29:16.7554+03
21676	13	-2	460	2020-03-30 18:42:12.174346+03
21677	75	-1	830	2020-03-30 18:51:38.906207+03
21678	83	-1	1230	2020-03-30 18:54:34.969238+03
21679	42	-1	1790	2020-03-30 19:05:41.599607+03
21680	45	-1	1590	2020-03-30 19:15:02.468126+03
21681	4	-1	1420	2020-03-30 19:27:18.572736+03
21682	11	-1	830	2020-03-30 19:30:44.371188+03
21683	50	-1	1140	2020-03-30 20:33:54.816628+03
21684	70	-2	760	2020-03-30 20:52:22.345106+03
21685	93	-1	1620	2020-03-30 21:01:33.98748+03
21686	34	-1	1550	2020-03-30 21:09:17.049111+03
21687	71	-1	1030	2020-03-30 21:09:51.456601+03
21688	1	-1	640	2020-03-30 21:23:28.121155+03
21689	56	-1	2460	2020-03-30 21:26:19.166449+03
21690	73	-1	960	2020-03-30 21:28:20.222071+03
21691	77	-1	640	2020-03-30 21:33:02.505863+03
21692	87	-1	2320	2020-03-30 21:48:20.263778+03
21693	47	-1	1480	2020-03-30 22:11:09.157486+03
21694	41	-1	830	2020-03-30 22:35:18.629992+03
21695	22	-1	1070	2020-03-30 22:39:18.62122+03
21696	86	-1	910	2020-03-30 23:07:47.197055+03
21697	93	-1	1620	2020-03-30 23:30:44.738863+03
21698	29	-1	1940	2020-03-30 23:30:50.735184+03
21699	70	-1	760	2020-03-30 23:35:54.285416+03
21700	89	-1	1420	2020-03-30 23:51:31.65445+03
21701	63	-1	1780	2020-03-31 00:25:01.345324+03
21702	73	-1	960	2020-03-31 01:20:57.973982+03
21703	74	-1	1010	2020-03-31 01:23:25.654112+03
21704	69	-1	1100	2020-03-31 01:26:25.635973+03
21705	48	-1	640	2020-03-31 01:40:49.827122+03
21706	32	-2	710	2020-03-31 01:42:22.161174+03
21707	20	-1	830	2020-03-31 01:46:29.650794+03
21708	5	-1	1620	2020-03-31 02:12:36.916252+03
21709	2	-1	470	2020-03-31 02:22:39.883756+03
21710	72	-1	620	2020-03-31 02:30:35.476833+03
21711	18	-1	910	2020-03-31 03:13:11.639279+03
21712	17	-1	1500	2020-03-31 03:16:41.58783+03
21713	39	-1	910	2020-03-31 03:22:09.265967+03
21714	86	46	533	2020-03-31 03:51:56.599349+03
21715	19	-1	1220	2020-03-31 04:17:36.996804+03
21716	84	-1	2700	2020-03-31 04:24:57.288455+03
21717	11	-1	830	2020-03-31 04:51:13.995415+03
21718	74	22	523	2020-03-31 05:00:42.497599+03
21719	92	-1	630	2020-03-31 05:12:05.299984+03
21720	8	-1	1920	2020-03-31 05:49:35.680393+03
21721	40	-1	1430	2020-03-31 06:29:02.792611+03
21722	20	-1	830	2020-03-31 06:37:16.588235+03
21723	77	-1	640	2020-03-31 06:53:07.004127+03
21724	96	-1	1570	2020-03-31 07:05:37.284074+03
21725	55	-1	3480	2020-03-31 08:14:10.074178+03
21726	14	-1	1350	2020-03-31 08:15:17.389864+03
21727	50	-1	1140	2020-03-31 08:19:34.580804+03
21728	94	-1	1230	2020-03-31 08:43:19.408114+03
21729	78	-1	900	2020-03-31 08:52:53.239689+03
21730	88	-1	1270	2020-03-31 08:55:11.185162+03
21731	96	-1	1570	2020-03-31 09:03:59.185001+03
21732	84	-1	2700	2020-03-31 09:06:30.440985+03
21733	82	-1	560	2020-03-31 09:10:19.016129+03
21734	3	-1	660	2020-03-31 09:12:57.911126+03
21735	14	-1	1350	2020-03-31 09:27:01.391406+03
21736	25	-1	1100	2020-03-31 09:28:52.342898+03
21737	81	-2	1620	2020-03-31 09:37:43.723164+03
21738	83	-1	1230	2020-03-31 09:58:49.524481+03
21739	81	-1	1620	2020-03-31 10:04:50.473133+03
21740	44	-1	500	2020-03-31 10:16:46.634014+03
21741	67	-1	350	2020-03-31 10:20:07.137781+03
21742	40	37	754	2020-03-31 10:26:57.28589+03
21743	6	-1	980	2020-03-31 10:40:11.096606+03
21744	48	-1	640	2020-03-31 10:50:35.248059+03
21745	38	-1	1100	2020-03-31 11:05:19.986869+03
21746	46	-1	1270	2020-03-31 11:17:00.779627+03
21747	78	-1	900	2020-03-31 11:21:44.870043+03
21748	60	-1	2700	2020-03-31 11:26:20.004194+03
21749	44	-1	500	2020-03-31 11:26:36.749544+03
21750	47	-1	1480	2020-03-31 11:40:54.77644+03
21751	52	-1	1090	2020-03-31 11:52:20.850269+03
21752	35	-2	670	2020-03-31 12:11:50.886867+03
21753	3	-1	660	2020-03-31 12:32:39.027097+03
21754	43	-1	380	2020-03-31 12:42:09.234583+03
21755	33	-1	900	2020-03-31 13:22:07.017669+03
21756	88	-1	1270	2020-03-31 13:24:50.663295+03
21757	72	-1	620	2020-03-31 13:55:34.932902+03
21758	94	-1	1230	2020-03-31 14:13:47.979973+03
21759	84	-1	2700	2020-03-31 14:24:00.754149+03
21760	17	40	712	2020-03-31 14:25:07.916669+03
21761	9	-1	2090	2020-03-31 14:35:19.682527+03
21762	82	-1	560	2020-03-31 14:37:11.991366+03
21763	22	-1	1070	2020-03-31 14:51:02.257106+03
21764	36	-1	630	2020-03-31 14:52:26.418313+03
21765	94	-1	1230	2020-03-31 15:27:11.185853+03
21766	74	-1	1010	2020-03-31 15:36:37.807354+03
21767	8	-1	1920	2020-03-31 15:43:54.333293+03
21768	16	-1	1380	2020-03-31 16:01:16.567952+03
21769	31	-2	1190	2020-03-31 16:13:41.790913+03
21770	63	-1	1780	2020-03-31 16:18:47.406657+03
21771	95	-1	480	2020-03-31 16:31:55.454563+03
21772	33	-1	900	2020-03-31 17:08:11.568376+03
21773	45	29	766	2020-03-31 17:22:49.725493+03
21774	41	-1	830	2020-03-31 17:23:39.276076+03
21775	70	-1	760	2020-03-31 17:34:55.396064+03
21776	73	-2	960	2020-03-31 17:38:57.669523+03
21777	26	-1	390	2020-03-31 18:05:07.935392+03
21778	46	-1	1270	2020-03-31 18:50:52.164155+03
21779	4	-1	1420	2020-03-31 19:09:02.555677+03
21780	14	-1	1350	2020-03-31 19:48:03.84096+03
21781	19	-1	1220	2020-03-31 20:34:43.740754+03
21782	2	-2	470	2020-03-31 20:51:20.254857+03
21783	22	-1	1070	2020-03-31 21:19:01.272225+03
21784	64	-1	970	2020-03-31 21:23:19.584925+03
21785	52	-1	1090	2020-03-31 21:38:34.482992+03
21786	15	-1	2830	2020-03-31 21:46:52.325609+03
21787	7	-2	810	2020-03-31 21:52:36.32665+03
21788	96	-2	1570	2020-03-31 21:54:50.452512+03
21789	58	-1	2830	2020-03-31 22:06:01.169587+03
21790	20	-1	830	2020-03-31 22:07:59.538307+03
21791	84	-1	2700	2020-03-31 22:32:42.125749+03
21792	29	-1	1940	2020-03-31 22:59:58.354882+03
21793	71	-1	1030	2020-03-31 23:34:22.830566+03
21794	43	-1	380	2020-03-31 23:52:34.733797+03
21795	93	-1	1620	2020-03-31 23:52:58.985117+03
21796	63	-1	1780	2020-03-31 23:53:22.270582+03
21797	35	-1	670	2020-03-31 23:54:59.706829+03
21798	75	-1	830	2020-04-01 00:26:06.874767+03
21799	9	-1	2090	2020-04-01 00:38:27.71544+03
21800	46	-1	1270	2020-04-01 01:13:03.86702+03
21801	9	-2	2090	2020-04-01 01:30:48.237623+03
21802	12	-1	1650	2020-04-01 01:35:40.566718+03
21803	21	-1	960	2020-04-01 01:40:53.805499+03
21804	46	-1	1270	2020-04-01 02:17:07.160743+03
21805	56	-1	2460	2020-04-01 02:35:30.669072+03
21806	47	-1	1480	2020-04-01 02:36:13.204314+03
21807	35	-1	670	2020-04-01 02:49:31.139409+03
21808	30	-1	1140	2020-04-01 02:56:21.742352+03
21809	27	-1	880	2020-04-01 02:56:55.093215+03
21810	53	-1	3120	2020-04-01 03:18:13.75743+03
21811	6	-2	980	2020-04-01 03:21:00.813255+03
21812	91	-1	1620	2020-04-01 03:29:39.63689+03
21813	87	-1	2320	2020-04-01 03:32:46.263319+03
21814	37	-1	1290	2020-04-01 03:35:11.074545+03
21815	77	-1	640	2020-04-01 03:40:43.074498+03
21816	54	-2	3470	2020-04-01 03:55:14.964415+03
21817	30	-1	1140	2020-04-01 03:57:06.977795+03
21818	19	-1	1220	2020-04-01 03:59:10.156995+03
21819	71	-1	1030	2020-04-01 04:01:39.284186+03
21820	71	-2	1030	2020-04-01 04:32:19.56762+03
21821	38	-1	1100	2020-04-01 04:42:23.682553+03
21822	11	-2	830	2020-04-01 04:44:04.956105+03
21823	23	-2	4390	2020-04-01 04:44:42.167752+03
21824	46	-1	1270	2020-04-01 04:51:52.435011+03
21825	9	-2	2090	2020-04-01 05:11:09.714047+03
21826	43	-1	380	2020-04-01 05:38:42.305445+03
21827	96	-1	1570	2020-04-01 05:52:31.013958+03
21828	75	-1	830	2020-04-01 05:54:19.812663+03
21829	76	-1	1070	2020-04-01 05:55:36.106362+03
21830	94	-1	1230	2020-04-01 07:27:24.294721+03
21831	76	-1	1070	2020-04-01 07:50:50.949689+03
21832	57	-2	1900	2020-04-01 08:28:57.610995+03
21833	56	-2	2460	2020-04-01 08:31:34.824396+03
21834	25	-2	1100	2020-04-01 09:02:27.843787+03
21835	90	-2	1780	2020-04-01 09:13:37.099811+03
21836	51	-1	1310	2020-04-01 09:13:41.345882+03
21837	51	-1	1310	2020-04-01 09:24:25.480677+03
21838	90	-1	1780	2020-04-01 09:31:36.165036+03
21839	77	-1	640	2020-04-01 09:49:56.310299+03
21840	37	-1	1290	2020-04-01 10:06:55.382514+03
21841	59	-1	1030	2020-04-01 11:14:20.701966+03
21842	25	-1	1100	2020-04-01 11:40:20.072943+03
21843	86	-1	910	2020-04-01 11:42:52.842435+03
21844	9	-1	2090	2020-04-01 11:44:48.1866+03
21845	83	-1	1230	2020-04-01 11:52:10.48957+03
21846	23	-1	4390	2020-04-01 12:07:48.624833+03
21847	88	-1	1270	2020-04-01 12:13:55.462474+03
21848	44	-1	500	2020-04-01 12:14:48.060737+03
21849	44	-2	500	2020-04-01 12:35:50.936282+03
21850	90	-1	1780	2020-04-01 12:41:25.513733+03
21851	80	-1	1120	2020-04-01 12:44:48.1574+03
21852	8	-1	1920	2020-04-01 12:48:39.241333+03
21853	10	-1	2080	2020-04-01 12:51:59.580342+03
21854	18	-1	910	2020-04-01 13:02:32.718893+03
21855	69	-1	1100	2020-04-01 13:11:49.812275+03
21856	38	-1	1100	2020-04-01 13:16:15.354947+03
21857	60	-1	2700	2020-04-01 13:41:16.646533+03
21858	35	-1	670	2020-04-01 13:43:17.205734+03
21859	67	-1	350	2020-04-01 13:48:08.790666+03
21860	81	-1	1620	2020-04-01 14:49:10.608476+03
21861	68	-1	490	2020-04-01 15:11:51.321213+03
21862	5	-1	1620	2020-04-01 15:44:57.668642+03
21863	95	-1	480	2020-04-01 15:48:24.217264+03
21864	58	-2	2830	2020-04-01 16:10:29.01278+03
21865	16	-1	1380	2020-04-01 16:14:50.984205+03
21866	84	-1	2700	2020-04-01 16:31:56.554817+03
21867	54	-1	3470	2020-04-01 16:32:55.006388+03
21868	96	-1	1570	2020-04-01 17:10:09.770011+03
21869	22	-1	1070	2020-04-01 17:30:45.133158+03
21870	63	-1	1780	2020-04-01 17:30:50.480452+03
21871	81	-1	1620	2020-04-01 17:45:50.783297+03
21872	77	-1	640	2020-04-01 17:46:07.252912+03
21873	28	-1	1860	2020-04-01 17:50:46.412501+03
21874	92	-1	630	2020-04-01 17:52:16.454672+03
21875	10	-1	2080	2020-04-01 17:53:19.633986+03
21876	8	-2	1920	2020-04-01 17:57:38.155412+03
21877	46	-2	1270	2020-04-01 18:10:56.472497+03
21878	48	-1	640	2020-04-01 18:23:06.877643+03
21879	67	-1	350	2020-04-01 18:45:25.436933+03
21880	4	-1	1420	2020-04-01 18:48:20.10813+03
21881	78	27	473	2020-04-01 19:00:54.267927+03
21882	87	-1	2320	2020-04-01 19:02:49.279331+03
21883	12	-2	1650	2020-04-01 19:25:32.109252+03
21884	95	-1	480	2020-04-01 19:28:43.862359+03
21885	20	-2	830	2020-04-01 19:43:32.928521+03
21886	56	-2	2460	2020-04-01 20:26:19.258872+03
21887	17	-2	1500	2020-04-01 20:51:02.1396+03
21888	29	-1	1940	2020-04-01 21:40:39.435681+03
21889	2	-1	470	2020-04-01 22:18:09.165428+03
21890	63	-1	1780	2020-04-01 22:26:55.926434+03
21891	36	-1	630	2020-04-01 22:52:23.134725+03
21892	19	-1	1220	2020-04-01 23:01:48.749966+03
21893	28	-2	1860	2020-04-01 23:28:50.699578+03
21894	80	-1	1120	2020-04-01 23:48:05.888559+03
21895	29	-1	1940	2020-04-02 00:02:33.530183+03
21896	1	-1	640	2020-04-02 00:22:36.98219+03
21897	79	-1	550	2020-04-02 00:24:19.897026+03
21898	70	26	422	2020-04-02 00:34:31.706094+03
21899	96	35	864	2020-04-02 00:46:26.189088+03
21900	35	-1	670	2020-04-02 01:08:32.16825+03
21901	52	-1	1090	2020-04-02 01:22:06.378049+03
21902	52	-1	1090	2020-04-02 01:24:14.626304+03
21903	38	-1	1100	2020-04-02 01:38:59.670402+03
21904	68	-2	490	2020-04-02 01:41:32.830601+03
21905	11	-2	830	2020-04-02 02:02:16.509583+03
21906	1	-1	640	2020-04-02 02:02:57.967325+03
21907	41	-2	830	2020-04-02 02:10:40.979245+03
21908	83	-2	1230	2020-04-02 02:28:21.332494+03
21909	88	-1	1270	2020-04-02 02:32:58.804249+03
21910	68	-1	490	2020-04-02 02:39:23.641399+03
21911	61	-1	1510	2020-04-02 02:46:01.148297+03
21912	39	-2	910	2020-04-02 03:07:53.523682+03
21913	26	-2	390	2020-04-02 03:14:57.061114+03
21914	44	28	229	2020-04-02 03:27:15.14096+03
21915	24	-1	950	2020-04-02 03:32:46.239287+03
21916	50	-1	1140	2020-04-02 03:42:21.356185+03
21917	61	-1	1510	2020-04-02 03:44:02.648666+03
21918	93	-1	1620	2020-04-02 04:23:54.428857+03
21919	25	-1	1100	2020-04-02 04:26:57.399866+03
21920	40	-1	1430	2020-04-02 04:35:19.267906+03
21921	23	-1	4390	2020-04-02 04:41:20.367194+03
21922	37	-1	1290	2020-04-02 04:59:53.301307+03
21923	31	-2	1190	2020-04-02 05:11:34.322809+03
21924	47	-1	1480	2020-04-02 05:17:36.205743+03
21925	75	-1	830	2020-04-02 05:26:38.616413+03
21926	48	24	276	2020-04-02 05:30:24.275403+03
21927	8	-1	1920	2020-04-02 05:37:26.434099+03
21928	15	-1	2830	2020-04-02 05:47:50.015565+03
21929	48	-2	640	2020-04-02 06:06:45.909408+03
21930	57	-2	1900	2020-04-02 06:47:31.644899+03
21931	26	-1	390	2020-04-02 06:47:47.017799+03
21932	14	-1	1350	2020-04-02 07:14:34.019513+03
21933	56	-2	2460	2020-04-02 07:17:38.004647+03
21934	67	-1	350	2020-04-02 07:57:34.923074+03
21935	56	-1	2460	2020-04-02 08:33:38.48158+03
21936	16	-1	1380	2020-04-02 08:42:07.152165+03
21937	47	-1	1480	2020-04-02 09:13:35.070147+03
21938	31	-1	1190	2020-04-02 09:48:23.459839+03
21939	66	-1	690	2020-04-02 10:10:50.401405+03
21940	40	-1	1430	2020-04-02 10:11:07.032341+03
21941	54	-1	3470	2020-04-02 10:26:06.683267+03
21942	12	-1	1650	2020-04-02 11:08:14.037603+03
21943	6	-1	980	2020-04-02 11:12:24.833933+03
21944	96	-1	1570	2020-04-02 11:28:20.93922+03
21945	8	-2	1920	2020-04-02 11:34:49.157417+03
21946	41	-1	830	2020-04-02 11:54:37.903839+03
21947	30	-1	1140	2020-04-02 12:06:33.278547+03
21948	9	-1	2090	2020-04-02 12:09:17.759206+03
21949	86	-1	910	2020-04-02 12:13:11.682773+03
21950	95	-1	480	2020-04-02 12:24:58.945457+03
21951	77	-1	640	2020-04-02 13:20:59.715022+03
21952	4	-2	1420	2020-04-02 13:31:41.015727+03
21953	8	-2	1920	2020-04-02 13:45:44.564686+03
21954	60	-1	2700	2020-04-02 13:47:17.278853+03
21955	77	-1	640	2020-04-02 13:50:18.466574+03
21956	90	-1	1780	2020-04-02 13:56:51.241988+03
21957	96	-1	1570	2020-04-02 14:01:42.627791+03
21958	78	-1	900	2020-04-02 14:06:27.972956+03
21959	67	-1	350	2020-04-02 14:08:31.123692+03
21960	57	-1	1900	2020-04-02 14:12:08.833942+03
21961	54	-1	3470	2020-04-02 14:29:56.497052+03
21962	50	-1	1140	2020-04-02 14:45:04.786771+03
21963	88	-1	1270	2020-04-02 14:47:02.875671+03
21964	67	-1	350	2020-04-02 14:50:46.669826+03
21965	87	-1	2320	2020-04-02 14:56:02.447034+03
21966	80	-1	1120	2020-04-02 15:08:14.493739+03
21967	57	-1	1900	2020-04-02 15:12:12.99702+03
21968	73	-1	960	2020-04-02 16:00:16.259011+03
21969	86	-1	910	2020-04-02 16:14:41.021293+03
21970	21	-1	960	2020-04-02 17:06:08.555405+03
21971	23	-1	4390	2020-04-02 17:14:17.810307+03
21972	94	-1	1230	2020-04-02 17:22:00.669179+03
21973	39	29	498	2020-04-02 17:33:16.310154+03
21974	62	-1	1220	2020-04-02 17:39:54.296242+03
21975	6	-1	980	2020-04-02 17:50:12.828319+03
21976	95	-1	480	2020-04-02 17:52:14.801269+03
21977	70	-2	760	2020-04-02 18:25:46.977131+03
21978	8	-1	1920	2020-04-02 18:38:13.969794+03
21979	29	-1	1940	2020-04-02 18:45:47.203486+03
21980	71	-1	1030	2020-04-02 18:46:56.256187+03
21981	86	-1	910	2020-04-02 18:50:06.537741+03
21982	30	-1	1140	2020-04-02 19:05:53.585899+03
21983	60	-1	2700	2020-04-02 19:07:11.77023+03
21984	91	17	757	2020-04-02 19:12:14.190151+03
21985	23	-1	4390	2020-04-02 19:38:27.629521+03
21986	70	-2	760	2020-04-02 19:59:54.072774+03
21987	23	-1	4390	2020-04-02 20:14:42.153329+03
21988	7	-1	810	2020-04-02 21:22:30.906216+03
21989	21	-1	960	2020-04-02 21:45:39.653547+03
21990	52	-1	1090	2020-04-02 21:53:19.134354+03
21991	51	-1	1310	2020-04-02 22:31:15.962305+03
21992	79	-1	550	2020-04-02 22:54:15.351074+03
21993	32	-2	710	2020-04-02 23:08:14.856888+03
21994	13	-1	460	2020-04-02 23:09:01.144775+03
21995	58	-2	2830	2020-04-02 23:11:43.03479+03
21996	29	-2	1940	2020-04-02 23:52:51.009044+03
21997	4	-1	1420	2020-04-03 00:04:03.241368+03
21998	49	-1	970	2020-04-03 00:40:10.593363+03
21999	81	-1	1620	2020-04-03 01:01:04.17356+03
22000	93	-1	1620	2020-04-03 01:28:43.828381+03
22001	39	-2	910	2020-04-03 01:58:06.557431+03
22002	49	-1	970	2020-04-03 02:24:46.627535+03
22003	28	-1	1860	2020-04-03 02:26:11.194832+03
22004	88	20	743	2020-04-03 02:54:25.263367+03
22005	32	33	349	2020-04-03 02:54:45.037781+03
22006	5	-2	1620	2020-04-03 02:55:53.252692+03
22007	21	-1	960	2020-04-03 03:10:07.532111+03
22008	92	-1	630	2020-04-03 03:47:07.130884+03
22009	79	-1	550	2020-04-03 04:02:20.148357+03
22010	48	-2	640	2020-04-03 04:18:06.29147+03
22011	85	-1	730	2020-04-03 04:21:42.844196+03
22012	15	-1	2830	2020-04-03 04:37:35.536919+03
22013	39	-2	910	2020-04-03 04:57:31.742397+03
22014	12	-2	1650	2020-04-03 05:10:08.216028+03
22015	59	-1	1030	2020-04-03 05:46:15.401994+03
22016	58	-2	2830	2020-04-03 06:26:44.560156+03
22017	19	-2	1220	2020-04-03 06:41:20.483471+03
22018	2	-2	470	2020-04-03 06:59:15.091299+03
22019	44	-1	500	2020-04-03 07:18:48.506098+03
22020	96	-1	1570	2020-04-03 07:25:06.998783+03
22021	87	-2	2320	2020-04-03 07:32:33.958781+03
22022	58	-1	2830	2020-04-03 07:35:48.153849+03
22023	57	-1	1900	2020-04-03 08:19:47.77311+03
22024	39	-1	910	2020-04-03 08:25:26.339943+03
22025	65	-1	490	2020-04-03 08:52:32.091904+03
22026	6	-1	980	2020-04-03 08:58:44.350855+03
22027	67	-1	350	2020-04-03 09:05:42.360126+03
22028	35	-1	670	2020-04-03 09:06:50.836132+03
22029	6	-1	980	2020-04-03 09:16:15.229214+03
22030	4	-1	1420	2020-04-03 09:23:16.87148+03
22031	76	-2	1070	2020-04-03 09:41:07.886011+03
22032	64	-2	970	2020-04-03 10:26:36.268848+03
22033	91	-2	1620	2020-04-03 11:24:19.708817+03
22034	40	-2	1430	2020-04-03 11:50:23.747184+03
22035	22	-1	1070	2020-04-03 12:00:51.98551+03
22036	46	-1	1270	2020-04-03 12:09:28.169329+03
22037	13	-1	460	2020-04-03 12:14:57.745651+03
22038	43	10	213	2020-04-03 12:32:13.893091+03
22039	74	-1	1010	2020-04-03 12:40:51.091894+03
22040	44	-1	500	2020-04-03 12:56:17.89343+03
22041	96	-1	1570	2020-04-03 13:21:36.616363+03
22042	53	31	1309	2020-04-03 13:21:38.744024+03
22043	56	-1	2460	2020-04-03 13:40:26.214304+03
22044	93	-2	1620	2020-04-03 13:46:52.061318+03
22045	54	-1	3470	2020-04-03 13:54:56.412494+03
22046	6	-1	980	2020-04-03 14:05:19.624891+03
22047	71	-2	1030	2020-04-03 14:18:21.399612+03
22048	10	-1	2080	2020-04-03 14:51:43.747652+03
22049	54	-1	3470	2020-04-03 15:10:46.529357+03
22050	69	-2	1100	2020-04-03 15:13:24.373932+03
22051	95	-2	480	2020-04-03 15:17:56.880951+03
22052	26	-1	390	2020-04-03 15:40:09.645384+03
22053	18	-1	910	2020-04-03 15:49:22.640484+03
22054	18	-1	910	2020-04-03 16:08:33.799447+03
22055	33	31	484	2020-04-03 16:10:48.898332+03
22056	35	-2	670	2020-04-03 16:24:40.402166+03
22057	41	-2	830	2020-04-03 16:26:42.117716+03
22058	31	-1	1190	2020-04-03 16:45:53.054887+03
22059	67	-1	350	2020-04-03 16:47:49.395124+03
22060	26	-1	390	2020-04-03 16:48:04.813643+03
22061	39	-2	910	2020-04-03 17:03:37.421607+03
22062	56	-1	2460	2020-04-03 17:05:01.33784+03
22063	54	-1	3470	2020-04-03 17:21:57.339765+03
22064	48	-1	640	2020-04-03 17:55:04.841814+03
22065	49	-1	970	2020-04-03 18:06:32.267464+03
22066	46	-1	1270	2020-04-03 18:22:36.067777+03
22067	70	-1	760	2020-04-03 19:05:05.144357+03
22068	92	-2	630	2020-04-03 19:12:14.064427+03
22069	14	-1	1350	2020-04-03 20:28:32.727216+03
22070	81	-1	1620	2020-04-03 20:43:55.044929+03
22071	13	-1	460	2020-04-03 21:02:30.705947+03
22072	38	-1	1100	2020-04-03 21:18:07.390667+03
22073	74	-1	1010	2020-04-03 21:42:03.567628+03
22074	24	-2	950	2020-04-03 21:53:22.657392+03
22075	76	-1	1070	2020-04-03 22:03:36.491656+03
22076	31	-1	1190	2020-04-03 22:26:27.759423+03
22077	92	-2	630	2020-04-03 22:28:43.011508+03
22078	74	-1	1010	2020-04-03 23:15:28.195352+03
22079	7	-1	810	2020-04-03 23:30:25.856647+03
22080	52	31	498	2020-04-03 23:39:00.853956+03
22081	66	-1	690	2020-04-03 23:40:47.890938+03
22082	22	-2	1070	2020-04-04 00:10:30.849274+03
22083	69	-2	1100	2020-04-04 00:49:07.248549+03
22084	87	-1	2320	2020-04-04 00:51:45.314951+03
22085	46	-1	1270	2020-04-04 00:57:53.550172+03
22086	19	-1	1220	2020-04-04 01:03:19.702546+03
22087	75	-1	830	2020-04-04 01:15:48.291172+03
22088	90	-1	1780	2020-04-04 01:17:41.393388+03
22089	1	-1	640	2020-04-04 01:27:04.092985+03
22090	60	-1	2700	2020-04-04 02:02:49.48884+03
22091	32	-1	710	2020-04-04 02:48:26.345088+03
22092	91	-1	1620	2020-04-04 03:20:28.47072+03
22093	29	-1	1940	2020-04-04 03:21:06.468609+03
22094	68	-1	490	2020-04-04 03:26:35.805158+03
22095	70	-1	760	2020-04-04 04:23:19.773632+03
22096	57	-2	1900	2020-04-04 04:35:25.329525+03
22097	40	-1	1430	2020-04-04 05:20:05.369616+03
22098	87	-2	2320	2020-04-04 05:24:12.83448+03
22099	32	-1	710	2020-04-04 05:31:49.66655+03
22100	70	-1	760	2020-04-04 05:35:32.840526+03
22101	18	-1	910	2020-04-04 06:42:22.161037+03
22102	6	-1	980	2020-04-04 06:43:38.394963+03
22103	71	33	608	2020-04-04 06:45:00.313673+03
22104	88	-1	1270	2020-04-04 06:54:15.542774+03
22105	27	-2	880	2020-04-04 06:56:17.319503+03
22106	31	-1	1190	2020-04-04 07:21:41.413495+03
22107	55	-1	3480	2020-04-04 07:24:18.473686+03
22108	66	-1	690	2020-04-04 07:51:55.515852+03
22109	47	-2	1480	2020-04-04 09:27:02.512197+03
22110	44	-1	500	2020-04-04 09:48:42.004176+03
22111	67	-1	350	2020-04-04 09:49:58.096104+03
22112	83	-1	1230	2020-04-04 09:58:41.365832+03
22113	14	-1	1350	2020-04-04 10:07:26.506862+03
22114	60	-1	2700	2020-04-04 10:36:28.290967+03
22115	66	-1	690	2020-04-04 10:59:29.908915+03
22116	4	38	598	2020-04-04 11:13:24.77881+03
22117	29	-1	1940	2020-04-04 12:10:02.683064+03
22118	2	19	195	2020-04-04 12:32:37.395969+03
22119	24	-2	950	2020-04-04 13:24:09.977067+03
22120	18	-1	910	2020-04-04 13:45:26.915999+03
22121	22	-2	1070	2020-04-04 13:50:29.278198+03
22122	63	-1	1780	2020-04-04 14:20:21.674898+03
22123	79	-1	550	2020-04-04 14:24:24.945839+03
22124	96	-1	1570	2020-04-04 15:14:54.070249+03
22125	10	-1	2080	2020-04-04 15:29:45.391853+03
22126	46	-1	1270	2020-04-04 15:45:30.405711+03
22127	56	-1	2460	2020-04-04 16:02:59.684944+03
22128	9	-1	2090	2020-04-04 16:22:41.577098+03
22129	78	-1	900	2020-04-04 16:40:55.304678+03
22130	10	-1	2080	2020-04-04 16:51:51.122062+03
22131	31	-3	1190	2020-04-04 17:05:02.364715+03
22132	34	-1	1550	2020-04-04 17:44:45.57122+03
22133	18	25	472	2020-04-04 17:56:32.605078+03
22134	7	-1	810	2020-04-04 17:57:50.030284+03
22135	73	-1	960	2020-04-04 18:05:48.267278+03
22136	75	-1	830	2020-04-04 18:08:20.339352+03
22137	82	-2	560	2020-04-04 18:08:43.236994+03
22138	65	-1	490	2020-04-04 19:04:11.75402+03
22139	50	-1	1140	2020-04-04 19:14:38.864765+03
22140	77	-1	640	2020-04-04 19:21:00.971972+03
22141	71	-1	1030	2020-04-04 19:30:39.364088+03
22142	69	-1	1100	2020-04-04 19:32:11.149635+03
22143	78	-1	900	2020-04-04 19:33:41.84617+03
22144	55	-2	3480	2020-04-04 20:22:45.455406+03
22145	71	-1	1030	2020-04-04 20:26:11.461683+03
22146	94	-1	1230	2020-04-04 20:34:42.790794+03
22147	24	-1	950	2020-04-04 20:50:02.032635+03
22148	95	-2	480	2020-04-04 21:00:09.103606+03
22149	40	-1	1430	2020-04-04 21:07:40.23117+03
22150	52	-1	1090	2020-04-04 21:47:04.43516+03
22151	5	-1	1620	2020-04-04 22:27:43.848031+03
22152	42	-1	1790	2020-04-04 22:50:23.44071+03
22153	50	-1	1140	2020-04-04 23:02:26.867191+03
22154	9	-1	2090	2020-04-04 23:18:00.365192+03
22155	30	-1	1140	2020-04-04 23:29:29.897679+03
22156	29	-2	1940	2020-04-04 23:37:23.361681+03
22157	89	-2	1420	2020-04-05 01:01:15.111987+03
22158	20	-1	830	2020-04-05 01:23:06.520071+03
22159	45	-1	1590	2020-04-05 01:25:00.573743+03
22160	67	-1	350	2020-04-05 01:31:47.322501+03
22161	31	28	634	2020-04-05 01:44:37.152226+03
22162	6	-1	980	2020-04-05 01:46:19.687688+03
22163	67	-1	350	2020-04-05 01:48:17.572381+03
22164	88	-1	1270	2020-04-05 02:03:26.856131+03
22165	14	-1	1350	2020-04-05 02:29:47.799275+03
22166	40	-1	1430	2020-04-05 02:34:06.10513+03
22167	49	-1	970	2020-04-05 02:53:04.807529+03
22168	81	-1	1620	2020-04-05 03:12:47.410916+03
22169	37	-2	1290	2020-04-05 03:28:40.071835+03
22170	47	-2	1480	2020-04-05 03:43:58.693594+03
22171	31	-1	1190	2020-04-05 04:31:33.602133+03
22172	64	-1	970	2020-04-05 04:41:36.074989+03
22173	17	-1	1500	2020-04-05 05:04:09.376583+03
22174	63	-1	1780	2020-04-05 05:25:54.13078+03
22175	88	-1	1270	2020-04-05 05:37:54.153335+03
22176	89	-1	1420	2020-04-05 05:54:50.564939+03
22177	42	-2	1790	2020-04-05 06:08:17.183341+03
22178	30	-1	1140	2020-04-05 06:36:29.212357+03
22179	37	-1	1290	2020-04-05 06:37:32.579067+03
22180	45	-2	1590	2020-04-05 06:59:09.481979+03
22181	93	-1	1620	2020-04-05 07:03:56.50219+03
22182	8	-2	1920	2020-04-05 07:04:36.161815+03
22183	51	-1	1310	2020-04-05 07:06:22.34722+03
22184	47	-1	1480	2020-04-05 07:08:13.76066+03
22185	64	-1	970	2020-04-05 07:18:48.313142+03
22186	80	-1	1120	2020-04-05 07:20:01.230505+03
22187	26	-2	390	2020-04-05 07:39:55.284555+03
22188	21	-1	960	2020-04-05 07:50:17.659843+03
22189	37	-2	1290	2020-04-05 07:51:11.159264+03
22190	75	31	391	2020-04-05 07:55:43.679591+03
22191	96	-1	1570	2020-04-05 08:10:42.308856+03
22192	37	-1	1290	2020-04-05 08:31:43.766588+03
22193	66	-1	690	2020-04-05 08:33:57.860093+03
22194	21	-1	960	2020-04-05 08:36:13.059261+03
22195	7	-1	810	2020-04-05 08:53:24.540479+03
22196	14	-2	1350	2020-04-05 09:22:24.815495+03
22197	35	-2	670	2020-04-05 09:30:01.131699+03
22198	20	-1	830	2020-04-05 09:59:14.50803+03
22199	55	-1	3480	2020-04-05 10:19:11.09161+03
22200	27	-1	880	2020-04-05 12:39:54.523551+03
22201	90	-1	1780	2020-04-05 12:49:48.023422+03
22202	45	-1	1590	2020-04-05 13:12:54.03655+03
22203	78	-1	900	2020-04-05 13:28:05.530593+03
22204	46	-1	1270	2020-04-05 13:28:09.317098+03
22205	31	-1	1190	2020-04-05 14:05:00.812966+03
22206	69	17	600	2020-04-05 14:05:06.242215+03
22207	13	-1	460	2020-04-05 14:07:47.140698+03
22208	43	-1	380	2020-04-05 14:08:08.247509+03
22209	87	-1	2320	2020-04-05 14:12:21.417984+03
22210	94	-1	1230	2020-04-05 14:25:57.761223+03
22211	62	-1	1220	2020-04-05 14:42:57.595251+03
22212	78	-1	900	2020-04-05 14:45:53.481213+03
22213	10	-1	2080	2020-04-05 15:23:15.858243+03
22214	35	-1	670	2020-04-05 15:34:46.553215+03
22215	3	-1	660	2020-04-05 16:29:58.84109+03
22216	80	-3	1120	2020-04-05 17:01:26.242473+03
22217	94	-1	1230	2020-04-05 17:04:26.773144+03
22218	13	-1	460	2020-04-05 17:14:38.865162+03
22219	63	-1	1780	2020-04-05 17:29:32.894925+03
22220	95	-1	480	2020-04-05 17:40:02.15551+03
22221	1	-1	640	2020-04-05 18:01:54.041564+03
22222	1	-1	640	2020-04-05 18:20:54.989227+03
22223	30	-2	1140	2020-04-05 18:29:16.958757+03
22224	37	-2	1290	2020-04-05 18:41:24.049426+03
22225	23	-1	4390	2020-04-05 18:55:16.61223+03
22226	81	30	899	2020-04-05 19:16:52.895564+03
22227	23	-1	4390	2020-04-05 19:25:53.220102+03
22228	67	-1	350	2020-04-05 19:26:28.062925+03
22229	37	-2	1290	2020-04-05 19:37:02.58225+03
22230	10	-1	2080	2020-04-05 19:49:58.044984+03
22231	58	-1	2830	2020-04-05 20:07:05.666158+03
22232	23	-2	4390	2020-04-05 20:10:21.052123+03
22233	22	-1	1070	2020-04-05 20:11:53.983721+03
22234	34	-1	1550	2020-04-05 20:35:55.906959+03
22235	30	-2	1140	2020-04-05 20:48:20.686658+03
22236	50	-1	1140	2020-04-05 21:33:23.7502+03
22237	60	23	1178	2020-04-05 21:33:28.13991+03
22238	78	-1	900	2020-04-05 21:40:44.38723+03
22239	42	-1	1790	2020-04-05 22:16:21.356349+03
22240	45	-1	1590	2020-04-05 22:18:15.616234+03
22241	18	-2	910	2020-04-05 22:23:31.706703+03
22242	38	-1	1100	2020-04-05 22:27:32.757611+03
22243	16	-1	1380	2020-04-05 22:47:12.936136+03
22244	52	-2	1090	2020-04-05 22:51:11.477553+03
22245	37	-1	1290	2020-04-05 22:51:24.917711+03
22246	35	-1	670	2020-04-05 23:06:16.400381+03
22247	33	-1	900	2020-04-05 23:43:09.703251+03
22248	42	-2	1790	2020-04-06 00:08:38.035861+03
22249	44	-1	500	2020-04-06 00:16:07.269957+03
22250	19	-1	1220	2020-04-06 00:26:21.731368+03
22251	56	-3	2460	2020-04-06 00:33:20.569063+03
22252	89	-1	1420	2020-04-06 00:34:30.212437+03
22253	3	-2	660	2020-04-06 01:40:54.375409+03
22254	38	-1	1100	2020-04-06 01:55:42.917271+03
22255	21	-1	960	2020-04-06 02:24:30.34174+03
22256	93	-1	1620	2020-04-06 02:49:30.384472+03
22257	12	-1	1650	2020-04-06 03:27:41.443307+03
22258	21	-1	960	2020-04-06 03:38:11.915591+03
22259	63	-1	1780	2020-04-06 03:56:23.522659+03
22260	46	-1	1270	2020-04-06 04:02:43.794998+03
22261	50	-1	1140	2020-04-06 04:26:18.757613+03
22262	93	-1	1620	2020-04-06 04:43:42.972591+03
22263	57	-1	1900	2020-04-06 04:46:51.53408+03
22264	18	-1	910	2020-04-06 04:48:37.73071+03
22265	29	-2	1940	2020-04-06 04:54:07.778256+03
22266	54	-1	3470	2020-04-06 04:56:15.429359+03
22267	23	-1	4390	2020-04-06 05:09:17.801542+03
22268	14	-1	1350	2020-04-06 05:17:10.458149+03
22269	22	-2	1070	2020-04-06 05:44:18.441347+03
22270	13	-1	460	2020-04-06 05:53:36.766864+03
22271	17	-1	1500	2020-04-06 06:01:14.821011+03
22272	50	-1	1140	2020-04-06 06:18:44.288994+03
22273	68	-1	490	2020-04-06 06:37:57.57798+03
22274	14	-1	1350	2020-04-06 06:40:29.033836+03
22275	39	-2	910	2020-04-06 06:43:24.607487+03
22276	40	-1	1430	2020-04-06 06:51:21.816482+03
22277	32	-2	710	2020-04-06 07:17:28.136296+03
22278	73	-1	960	2020-04-06 07:42:36.887418+03
22279	11	-1	830	2020-04-06 08:12:15.070328+03
22280	49	-2	970	2020-04-06 08:55:39.73339+03
22281	37	-3	1290	2020-04-06 09:03:33.831682+03
22282	37	31	739	2020-04-06 09:27:08.698971+03
22283	3	-1	660	2020-04-06 09:38:06.336587+03
22284	49	-1	970	2020-04-06 10:17:07.952661+03
22285	8	-2	1920	2020-04-06 11:00:02.393775+03
22286	4	-1	1420	2020-04-06 11:11:02.983322+03
22287	20	-1	830	2020-04-06 11:13:05.263876+03
22288	35	-1	670	2020-04-06 11:14:16.898259+03
22289	41	23	350	2020-04-06 11:38:42.844682+03
22290	84	-1	2700	2020-04-06 11:43:27.792197+03
22291	29	-1	1940	2020-04-06 11:47:30.051744+03
22292	86	-1	910	2020-04-06 11:49:57.393843+03
22293	12	-2	1650	2020-04-06 12:31:49.110986+03
22294	51	-1	1310	2020-04-06 13:08:00.909629+03
22295	83	-1	1230	2020-04-06 13:40:42.104309+03
22296	36	-1	630	2020-04-06 13:43:08.001835+03
22297	86	-1	910	2020-04-06 13:46:49.069633+03
22298	36	-1	630	2020-04-06 13:46:58.954166+03
22299	71	-1	1030	2020-04-06 13:51:59.202335+03
22300	1	-2	640	2020-04-06 13:58:32.174587+03
22301	1	-2	640	2020-04-06 14:03:03.252282+03
22302	95	-1	480	2020-04-06 14:03:20.262204+03
22303	35	-1	670	2020-04-06 14:17:07.415862+03
22304	88	-1	1270	2020-04-06 14:26:15.685122+03
22305	91	-1	1620	2020-04-06 14:28:29.337848+03
22306	47	-1	1480	2020-04-06 14:30:13.56631+03
22307	12	-1	1650	2020-04-06 14:40:13.98892+03
22308	10	-1	2080	2020-04-06 14:56:06.957855+03
22309	26	-1	390	2020-04-06 15:02:06.690611+03
22310	43	-1	380	2020-04-06 15:20:45.505585+03
22311	18	-2	910	2020-04-06 16:13:36.787293+03
22312	50	-1	1140	2020-04-06 16:59:06.73775+03
22313	78	-1	900	2020-04-06 17:15:55.858311+03
22314	67	-1	350	2020-04-06 17:18:05.37419+03
22315	4	-2	1420	2020-04-06 17:50:32.347741+03
22316	90	-1	1780	2020-04-06 17:57:43.078325+03
22317	93	-1	1620	2020-04-06 17:58:08.873189+03
22318	66	-1	690	2020-04-06 17:58:29.632107+03
22319	65	-1	490	2020-04-06 18:00:46.839893+03
22320	51	-1	1310	2020-04-06 18:22:26.835593+03
22321	31	-1	1190	2020-04-06 19:36:42.660576+03
22322	45	-1	1590	2020-04-06 19:42:27.144506+03
22323	45	-1	1590	2020-04-06 20:03:04.108455+03
22324	94	-2	1230	2020-04-06 20:04:42.13925+03
22325	86	-1	910	2020-04-06 20:14:57.218408+03
22326	48	-1	640	2020-04-06 20:17:41.324515+03
22327	77	-1	640	2020-04-06 20:31:47.929101+03
22328	46	-1	1270	2020-04-06 20:36:34.567961+03
22329	59	-2	1030	2020-04-06 20:57:01.95885+03
22330	60	-1	2700	2020-04-06 21:18:40.054039+03
22331	59	27	467	2020-04-06 21:52:06.846642+03
22332	90	-1	1780	2020-04-06 21:58:21.209041+03
22333	61	-1	1510	2020-04-06 22:21:23.537666+03
22334	94	-2	1230	2020-04-06 22:26:37.293737+03
22335	18	-1	910	2020-04-06 22:50:57.922063+03
22336	20	-1	830	2020-04-06 22:55:22.898357+03
22337	29	-1	1940	2020-04-06 23:08:29.070746+03
22338	17	-1	1500	2020-04-06 23:14:16.665027+03
22339	50	-1	1140	2020-04-06 23:35:04.379145+03
22340	4	-2	1420	2020-04-06 23:43:47.84532+03
22341	30	-1	1140	2020-04-06 23:58:18.216188+03
22342	67	-1	350	2020-04-07 00:00:03.290611+03
22343	83	-1	1230	2020-04-07 00:27:14.097882+03
22344	30	-1	1140	2020-04-07 00:51:50.408205+03
22345	57	-1	1900	2020-04-07 01:33:43.761374+03
22346	76	-1	1070	2020-04-07 01:59:56.676424+03
22347	34	-1	1550	2020-04-07 02:48:43.226668+03
22348	27	-2	880	2020-04-07 02:57:50.996275+03
22349	86	-1	910	2020-04-07 03:02:49.197258+03
22350	54	-1	3470	2020-04-07 03:06:51.08956+03
22351	74	-1	1010	2020-04-07 03:15:22.252647+03
22352	19	-1	1220	2020-04-07 03:24:51.614625+03
22353	85	-1	730	2020-04-07 03:40:03.75844+03
22354	39	-1	910	2020-04-07 03:45:22.624528+03
22355	60	-1	2700	2020-04-07 03:48:27.959899+03
22356	59	-1	1030	2020-04-07 04:08:42.547459+03
22357	10	-2	2080	2020-04-07 04:58:55.988541+03
22358	73	23	399	2020-04-07 05:39:15.534497+03
22359	39	-1	910	2020-04-07 05:39:29.776617+03
22360	17	-1	1500	2020-04-07 05:40:46.852723+03
22361	64	-2	970	2020-04-07 05:56:47.735647+03
22362	30	-2	1140	2020-04-07 05:58:54.367933+03
22363	46	-1	1270	2020-04-07 06:06:28.405512+03
22364	17	-1	1500	2020-04-07 06:38:11.058296+03
22365	60	-1	2700	2020-04-07 07:15:58.134572+03
22366	33	-2	900	2020-04-07 07:25:04.233958+03
22367	63	-1	1780	2020-04-07 07:47:53.97399+03
22368	71	-1	1030	2020-04-07 08:27:04.847883+03
22369	6	-2	980	2020-04-07 08:33:19.491197+03
22370	39	-1	910	2020-04-07 09:02:54.972607+03
22371	22	-1	1070	2020-04-07 09:39:47.043913+03
22372	96	-1	1570	2020-04-07 09:49:09.733486+03
22373	12	-1	1650	2020-04-07 10:09:05.032312+03
22374	9	-1	2090	2020-04-07 10:36:12.472413+03
22375	31	-1	1190	2020-04-07 11:04:55.930577+03
22376	82	-1	560	2020-04-07 11:09:15.205108+03
22377	65	-1	490	2020-04-07 11:19:08.569696+03
22378	46	-1	1270	2020-04-07 11:21:51.278299+03
22379	91	-1	1620	2020-04-07 11:28:42.292919+03
22380	81	-1	1620	2020-04-07 12:04:22.183001+03
22381	47	38	742	2020-04-07 12:14:10.989356+03
22382	89	-1	1420	2020-04-07 12:21:31.368846+03
22383	35	-1	670	2020-04-07 12:22:11.634343+03
22384	51	-2	1310	2020-04-07 12:23:20.784612+03
22385	32	-1	710	2020-04-07 12:38:35.668312+03
22386	8	-1	1920	2020-04-07 13:07:17.879089+03
22387	83	-1	1230	2020-04-07 13:10:55.91852+03
22388	95	24	225	2020-04-07 13:16:18.053017+03
22389	64	-2	970	2020-04-07 13:41:45.553914+03
22390	90	-1	1780	2020-04-07 13:48:30.36793+03
22391	94	-1	1230	2020-04-07 13:59:00.180636+03
22392	94	-1	1230	2020-04-07 14:09:22.84646+03
22393	11	-1	830	2020-04-07 14:17:33.318865+03
22394	29	-1	1940	2020-04-07 14:30:27.286421+03
22395	58	-1	2830	2020-04-07 14:45:45.988729+03
22396	79	-1	550	2020-04-07 14:46:38.672469+03
22397	88	-1	1270	2020-04-07 14:51:53.205447+03
22398	49	-1	970	2020-04-07 15:00:39.007017+03
22399	89	-1	1420	2020-04-07 15:04:40.383005+03
22400	95	-2	480	2020-04-07 15:21:01.81668+03
22401	96	-1	1570	2020-04-07 15:29:53.5434+03
22402	41	-1	830	2020-04-07 15:31:06.248504+03
22403	75	-1	830	2020-04-07 15:41:08.156414+03
22404	32	-2	710	2020-04-07 16:16:59.153351+03
22405	35	-1	670	2020-04-07 16:22:06.949134+03
22406	37	-2	1290	2020-04-07 16:30:44.664855+03
22407	74	-1	1010	2020-04-07 16:33:41.352088+03
22408	21	-1	960	2020-04-07 16:36:19.188893+03
22409	4	-2	1420	2020-04-07 16:53:29.451726+03
22410	29	-1	1940	2020-04-07 17:28:09.407381+03
22411	96	-1	1570	2020-04-07 17:34:27.252953+03
22412	12	-1	1650	2020-04-07 17:39:23.940855+03
22413	55	-1	3480	2020-04-07 17:45:50.150973+03
22414	29	-1	1940	2020-04-07 18:19:31.390666+03
22415	87	-1	2320	2020-04-07 18:26:28.575373+03
22416	22	-1	1070	2020-04-07 18:36:06.052543+03
22417	76	-1	1070	2020-04-07 18:37:24.224887+03
22418	88	-1	1270	2020-04-07 18:47:20.822538+03
22419	63	-1	1780	2020-04-07 19:00:15.836552+03
22420	60	-1	2700	2020-04-07 19:03:23.374649+03
22421	5	-1	1620	2020-04-07 19:03:44.806467+03
22422	31	-2	1190	2020-04-07 19:07:25.213705+03
22423	5	-1	1620	2020-04-07 19:41:11.196347+03
22424	13	-1	460	2020-04-07 19:47:54.620127+03
22425	6	-1	980	2020-04-07 20:11:44.897603+03
22426	10	-2	2080	2020-04-07 20:17:33.370442+03
22427	38	-1	1100	2020-04-07 20:22:45.453806+03
22428	77	-1	640	2020-04-07 20:28:10.535328+03
22429	60	-1	2700	2020-04-07 21:07:03.019308+03
22430	85	-1	730	2020-04-07 21:33:41.152306+03
22431	63	35	909	2020-04-07 21:59:31.758071+03
22432	48	-2	640	2020-04-07 22:01:46.072209+03
22433	17	-2	1500	2020-04-07 22:01:56.812559+03
22434	93	-1	1620	2020-04-07 22:49:29.140541+03
22435	53	-1	3120	2020-04-07 23:19:06.404851+03
22436	3	-1	660	2020-04-07 23:35:12.906043+03
22437	7	-1	810	2020-04-08 00:02:49.24064+03
22438	7	-1	810	2020-04-08 00:15:00.862489+03
22439	42	-1	1790	2020-04-08 00:17:24.625051+03
22440	77	-1	640	2020-04-08 00:32:27.166685+03
22441	75	-1	830	2020-04-08 01:26:58.195072+03
22442	38	-1	1100	2020-04-08 02:51:23.624523+03
22443	22	-1	1070	2020-04-08 02:58:14.116876+03
22444	20	-1	830	2020-04-08 03:10:55.982099+03
22445	40	-1	1430	2020-04-08 03:33:47.209169+03
22446	9	-2	2090	2020-04-08 03:59:50.41097+03
22447	14	-2	1350	2020-04-08 04:17:24.420669+03
22448	63	-1	1780	2020-04-08 04:31:46.39509+03
22449	6	-1	980	2020-04-08 04:43:55.709949+03
22450	8	-1	1920	2020-04-08 05:16:23.249965+03
22451	46	-1	1270	2020-04-08 05:21:03.550801+03
22452	15	-1	2830	2020-04-08 05:45:17.824693+03
22453	95	-1	480	2020-04-08 06:11:06.217156+03
22454	46	-2	1270	2020-04-08 06:17:16.235433+03
22455	90	-1	1780	2020-04-08 06:27:28.265087+03
22456	42	-1	1790	2020-04-08 06:28:40.853371+03
22457	60	-2	2700	2020-04-08 06:58:43.044585+03
22458	19	-2	1220	2020-04-08 07:22:07.897015+03
22459	42	-1	1790	2020-04-08 07:25:00.804645+03
22460	78	-1	900	2020-04-08 07:39:25.526099+03
22461	74	-2	1010	2020-04-08 07:49:17.753312+03
22462	7	-2	810	2020-04-08 07:52:41.841606+03
22463	52	-1	1090	2020-04-08 08:55:44.564569+03
22464	6	-1	980	2020-04-08 09:16:22.866551+03
22465	5	-1	1620	2020-04-08 09:23:44.846237+03
22466	7	-1	810	2020-04-08 09:24:05.299409+03
22467	87	-2	2320	2020-04-08 09:46:12.227581+03
22468	12	-1	1650	2020-04-08 09:54:36.007936+03
22469	93	-2	1620	2020-04-08 10:00:38.393257+03
22470	92	-2	630	2020-04-08 10:18:03.922601+03
22471	12	-2	1650	2020-04-08 10:32:33.01025+03
22472	95	-1	480	2020-04-08 10:45:33.316282+03
22473	73	-1	960	2020-04-08 10:48:16.145189+03
22474	22	-1	1070	2020-04-08 10:48:52.153132+03
22475	33	-1	900	2020-04-08 11:05:36.026885+03
22476	87	-1	2320	2020-04-08 11:13:19.387646+03
22477	48	-1	640	2020-04-08 11:13:35.20096+03
22478	91	-2	1620	2020-04-08 11:42:00.097687+03
22479	67	-2	350	2020-04-08 11:49:26.908348+03
22480	39	-1	910	2020-04-08 12:03:19.482099+03
22481	13	-1	460	2020-04-08 12:18:45.291528+03
22482	18	-1	910	2020-04-08 12:30:37.460367+03
22483	12	-1	1650	2020-04-08 12:47:07.55471+03
22484	39	-2	910	2020-04-08 12:52:59.928864+03
22485	63	-1	1780	2020-04-08 12:53:54.639057+03
22486	47	-2	1480	2020-04-08 13:02:12.181806+03
22487	93	-1	1620	2020-04-08 13:05:14.042867+03
22488	22	-2	1070	2020-04-08 13:17:10.052361+03
22489	76	-1	1070	2020-04-08 13:28:07.180982+03
22490	15	16	1329	2020-04-08 13:48:27.199453+03
22491	77	-2	640	2020-04-08 13:57:25.579794+03
22492	8	-1	1920	2020-04-08 14:40:49.760574+03
22493	30	-1	1140	2020-04-08 14:41:38.929551+03
22494	60	-1	2700	2020-04-08 14:43:15.646465+03
22495	86	-1	910	2020-04-08 15:44:52.295424+03
22496	73	-1	960	2020-04-08 16:18:32.990921+03
22497	92	-1	630	2020-04-08 16:25:27.659563+03
22498	35	24	387	2020-04-08 16:26:39.839903+03
22499	71	-1	1030	2020-04-08 16:49:09.731366+03
22500	68	-1	490	2020-04-08 17:07:51.786712+03
22501	84	-1	2700	2020-04-08 17:33:10.308704+03
22502	82	-1	560	2020-04-08 18:51:27.385234+03
22503	56	-1	2460	2020-04-08 18:51:30.362036+03
22504	75	-1	830	2020-04-08 19:06:03.440398+03
22505	90	-1	1780	2020-04-08 19:35:42.625541+03
22506	89	-1	1420	2020-04-08 19:37:29.554825+03
22507	92	-1	630	2020-04-08 19:41:07.851061+03
22508	22	-1	1070	2020-04-08 20:00:49.374531+03
22509	47	-1	1480	2020-04-08 20:01:30.780555+03
22510	10	-2	2080	2020-04-08 20:03:52.591239+03
22511	73	-2	960	2020-04-08 20:25:15.867149+03
22512	88	-1	1270	2020-04-08 20:38:05.36523+03
22513	61	-1	1510	2020-04-08 20:44:26.63821+03
22514	57	-1	1900	2020-04-08 20:52:00.695624+03
22515	63	-1	1780	2020-04-08 21:07:24.526791+03
22516	16	-1	1380	2020-04-08 21:18:53.18073+03
22517	15	-1	2830	2020-04-08 21:34:53.085164+03
22518	67	22	156	2020-04-08 21:42:26.048402+03
22519	56	-1	2460	2020-04-08 21:51:09.982112+03
22520	96	-3	1570	2020-04-08 22:23:22.627547+03
22521	15	-1	2830	2020-04-08 22:47:55.72478+03
22522	10	-1	2080	2020-04-08 23:06:23.119007+03
22523	85	24	359	2020-04-08 23:23:03.539436+03
22524	8	-1	1920	2020-04-08 23:25:04.10001+03
22525	58	-1	2830	2020-04-08 23:35:28.736484+03
22526	4	-1	1420	2020-04-08 23:44:41.777506+03
22527	96	-2	1570	2020-04-08 23:46:54.751442+03
22528	59	-1	1030	2020-04-08 23:55:05.073146+03
22529	86	-1	910	2020-04-09 00:07:03.039664+03
22530	42	-1	1790	2020-04-09 00:26:40.639589+03
22531	4	-1	1420	2020-04-09 00:35:09.845179+03
22532	7	-2	810	2020-04-09 00:38:54.159415+03
22533	20	20	427	2020-04-09 01:12:26.514289+03
22534	4	-2	1420	2020-04-09 01:12:36.789082+03
22535	50	-1	1140	2020-04-09 01:32:30.263332+03
22536	40	-1	1430	2020-04-09 01:34:23.247342+03
22537	33	-1	900	2020-04-09 01:55:28.005587+03
22538	37	-1	1290	2020-04-09 01:55:36.325155+03
22539	87	-1	2320	2020-04-09 02:24:28.109509+03
22540	77	-1	640	2020-04-09 02:45:33.57512+03
22541	22	-1	1070	2020-04-09 03:00:23.299472+03
22542	70	-1	760	2020-04-09 03:30:00.980891+03
22543	48	-1	640	2020-04-09 03:50:55.28869+03
22544	28	-2	1860	2020-04-09 04:00:41.110612+03
22545	27	-1	880	2020-04-09 04:07:24.942962+03
22546	25	-1	1100	2020-04-09 04:12:35.084568+03
22547	1	-1	640	2020-04-09 04:12:55.969715+03
22548	50	-1	1140	2020-04-09 04:34:22.140387+03
22549	47	-1	1480	2020-04-09 04:37:12.857375+03
22550	4	-1	1420	2020-04-09 04:49:32.970196+03
22551	84	-1	2700	2020-04-09 05:04:41.933287+03
22552	22	-1	1070	2020-04-09 05:11:04.011782+03
22553	47	-1	1480	2020-04-09 05:17:19.702569+03
22554	87	-3	2320	2020-04-09 05:42:58.756068+03
22555	16	-1	1380	2020-04-09 06:09:00.174369+03
22556	38	-1	1100	2020-04-09 06:16:39.035793+03
22557	77	-1	640	2020-04-09 06:36:04.82061+03
22558	82	-1	560	2020-04-09 06:43:57.852859+03
22559	49	-1	970	2020-04-09 07:42:17.483114+03
22560	64	-1	970	2020-04-09 07:46:52.016309+03
22561	18	-1	910	2020-04-09 07:47:49.278438+03
22562	34	-2	1550	2020-04-09 07:51:50.387379+03
22563	71	-1	1030	2020-04-09 08:07:19.426794+03
22564	7	-1	810	2020-04-09 08:20:28.257751+03
22565	81	-2	1620	2020-04-09 08:29:40.977198+03
22566	60	-2	2700	2020-04-09 08:37:00.473909+03
22567	3	26	323	2020-04-09 09:02:55.27844+03
22568	76	-1	1070	2020-04-09 09:07:15.855882+03
22569	63	-1	1780	2020-04-09 09:34:24.761876+03
22570	38	-1	1100	2020-04-09 09:44:48.474992+03
22571	60	-1	2700	2020-04-09 09:48:25.234663+03
22572	93	-1	1620	2020-04-09 10:05:16.380273+03
22573	29	-1	1940	2020-04-09 10:32:54.58391+03
22574	83	-1	1230	2020-04-09 10:35:13.055229+03
22575	88	-1	1270	2020-04-09 11:50:34.440616+03
22576	71	-1	1030	2020-04-09 12:04:14.145986+03
22577	10	-1	2080	2020-04-09 12:10:18.037419+03
22578	71	-1	1030	2020-04-09 12:22:55.344016+03
22579	77	-1	640	2020-04-09 12:25:04.055753+03
22580	59	-1	1030	2020-04-09 12:27:28.673037+03
22581	37	-1	1290	2020-04-09 12:28:37.817891+03
22582	82	-1	560	2020-04-09 12:38:00.639292+03
22583	90	-1	1780	2020-04-09 13:10:14.459186+03
22584	77	-1	640	2020-04-09 13:19:15.063846+03
22585	65	24	275	2020-04-09 13:25:51.462352+03
22586	29	-1	1940	2020-04-09 13:57:45.126629+03
22587	83	-1	1230	2020-04-09 14:07:24.288775+03
22588	2	-1	470	2020-04-09 14:13:14.217101+03
22589	76	-1	1070	2020-04-09 14:20:12.771836+03
22590	34	-2	1550	2020-04-09 14:31:39.749228+03
22591	27	-1	880	2020-04-09 14:46:49.57849+03
22592	20	-1	830	2020-04-09 14:46:55.760363+03
22593	58	-1	2830	2020-04-09 15:11:12.062702+03
22594	95	-1	480	2020-04-09 15:46:50.273781+03
22595	10	-1	2080	2020-04-09 15:58:59.100082+03
22596	64	-1	970	2020-04-09 16:04:23.06653+03
22597	75	-1	830	2020-04-09 16:04:27.949732+03
22598	38	-2	1100	2020-04-09 16:11:35.971166+03
22599	6	-1	980	2020-04-09 16:41:13.542857+03
22600	54	-2	3470	2020-04-09 17:20:56.941979+03
22601	96	-1	1570	2020-04-09 17:21:47.429933+03
22602	80	-1	1120	2020-04-09 17:53:42.375394+03
22603	55	-1	3480	2020-04-09 18:08:59.280569+03
22604	38	-1	1100	2020-04-09 18:09:44.350848+03
22605	91	-1	1620	2020-04-09 18:09:56.120794+03
22606	57	-1	1900	2020-04-09 18:15:44.838534+03
22607	93	-1	1620	2020-04-09 18:51:30.726614+03
22608	94	-1	1230	2020-04-09 18:56:35.586304+03
22609	88	-1	1270	2020-04-09 19:22:52.514996+03
22610	73	-1	960	2020-04-09 19:55:55.444245+03
22611	87	-1	2320	2020-04-09 19:57:43.659073+03
22612	95	-1	480	2020-04-09 20:14:02.451032+03
22613	78	-2	900	2020-04-09 20:24:17.406824+03
22614	46	-1	1270	2020-04-09 20:27:33.375431+03
22615	95	-1	480	2020-04-09 21:08:47.243175+03
22616	12	-1	1650	2020-04-09 22:28:41.543919+03
22617	89	-1	1420	2020-04-09 22:31:59.609827+03
22618	77	-1	640	2020-04-09 22:48:35.309741+03
22619	49	-1	970	2020-04-09 22:50:37.866302+03
22620	18	-1	910	2020-04-09 23:09:22.288227+03
22621	28	-1	1860	2020-04-09 23:21:04.106913+03
22622	59	-1	1030	2020-04-09 23:26:57.570004+03
22623	64	-2	970	2020-04-09 23:32:59.122798+03
22624	93	-2	1620	2020-04-09 23:51:16.582659+03
22625	73	-1	960	2020-04-09 23:56:17.863658+03
22626	83	-1	1230	2020-04-10 00:06:04.671006+03
22627	89	-1	1420	2020-04-10 00:09:52.216741+03
22628	71	-2	1030	2020-04-10 00:45:27.858659+03
22629	12	-3	1650	2020-04-10 00:45:31.432206+03
22630	95	-1	480	2020-04-10 00:48:51.16845+03
22631	81	-1	1620	2020-04-10 01:21:53.797531+03
22632	2	-3	470	2020-04-10 01:25:49.183756+03
22633	95	-2	480	2020-04-10 01:55:11.143006+03
22634	71	-1	1030	2020-04-10 02:10:14.159362+03
22635	49	31	456	2020-04-10 02:31:00.198871+03
22636	87	-2	2320	2020-04-10 02:50:29.184286+03
22637	24	-2	950	2020-04-10 02:57:59.321592+03
22638	58	-1	2830	2020-04-10 04:31:17.809198+03
22639	38	-1	1100	2020-04-10 04:34:22.777649+03
22640	57	-1	1900	2020-04-10 04:50:42.636192+03
22641	88	-1	1270	2020-04-10 05:32:00.70201+03
22642	48	-1	640	2020-04-10 05:37:49.145536+03
22643	2	-1	470	2020-04-10 05:49:35.933905+03
22644	28	-1	1860	2020-04-10 06:09:29.07179+03
22645	90	-1	1780	2020-04-10 06:22:13.643666+03
22646	62	-3	1220	2020-04-10 06:34:46.319956+03
22647	55	-1	3480	2020-04-10 06:36:48.665103+03
22648	49	-1	970	2020-04-10 07:10:55.746559+03
22649	76	-1	1070	2020-04-10 07:59:16.231596+03
22650	27	-1	880	2020-04-10 08:19:42.942911+03
22651	67	-1	350	2020-04-10 08:38:09.313608+03
22652	13	-1	460	2020-04-10 08:44:29.074149+03
22653	48	-1	640	2020-04-10 08:50:35.57286+03
22654	4	-1	1420	2020-04-10 08:51:35.124591+03
22655	22	-1	1070	2020-04-10 08:55:52.182806+03
22656	69	-2	1100	2020-04-10 09:12:20.503549+03
22657	22	-1	1070	2020-04-10 09:43:54.130671+03
22658	75	-1	830	2020-04-10 09:45:30.111463+03
22659	64	-2	970	2020-04-10 10:15:20.628767+03
22660	49	-2	970	2020-04-10 10:32:55.387892+03
22661	81	-1	1620	2020-04-10 10:41:08.70631+03
22662	2	-1	470	2020-04-10 10:48:47.083381+03
22663	72	-2	620	2020-04-10 10:53:25.181387+03
22664	76	-2	1070	2020-04-10 11:10:58.412662+03
22665	49	-1	970	2020-04-10 11:40:42.39334+03
22666	72	-1	620	2020-04-10 12:31:12.451244+03
22667	77	-1	640	2020-04-10 12:40:40.877752+03
22668	73	-1	960	2020-04-10 12:41:14.599+03
22669	84	-1	2700	2020-04-10 12:43:30.327739+03
22670	38	-1	1100	2020-04-10 12:46:18.770923+03
22671	77	-1	640	2020-04-10 12:55:01.986683+03
22672	77	-1	640	2020-04-10 13:06:49.481709+03
22673	81	-1	1620	2020-04-10 13:08:27.321868+03
22674	71	-2	1030	2020-04-10 13:18:52.481898+03
22675	18	-2	910	2020-04-10 13:37:30.612364+03
22676	21	-1	960	2020-04-10 13:40:42.818593+03
22677	54	-1	3470	2020-04-10 13:40:49.545621+03
22678	80	-1	1120	2020-04-10 13:56:31.35939+03
22679	62	-1	1220	2020-04-10 14:00:44.947459+03
22680	49	-1	970	2020-04-10 14:40:52.727552+03
22681	86	-1	910	2020-04-10 14:44:26.441612+03
22682	17	-1	1500	2020-04-10 14:48:55.588734+03
22683	55	-1	3480	2020-04-10 15:02:35.513298+03
22684	20	-1	830	2020-04-10 15:20:09.324714+03
22685	58	-2	2830	2020-04-10 15:37:27.434342+03
22686	50	-1	1140	2020-04-10 15:51:41.025508+03
22687	27	-2	880	2020-04-10 15:55:03.16055+03
22688	4	-2	1420	2020-04-10 16:17:45.390435+03
22689	55	-1	3480	2020-04-10 16:23:23.394506+03
22690	89	-1	1420	2020-04-10 16:53:25.573147+03
22691	71	-1	1030	2020-04-10 17:01:48.594738+03
22692	30	-1	1140	2020-04-10 17:27:26.588708+03
22693	67	-1	350	2020-04-10 17:31:05.870441+03
22694	94	21	608	2020-04-10 18:57:00.683654+03
22695	20	-1	830	2020-04-10 19:22:09.06493+03
22696	38	-2	1100	2020-04-10 19:27:57.112014+03
22697	54	-1	3470	2020-04-10 19:56:25.053521+03
22698	41	-1	830	2020-04-10 20:10:20.579175+03
22699	15	-1	2830	2020-04-10 20:28:13.200963+03
22700	80	-1	1120	2020-04-10 20:32:26.02333+03
22701	13	-1	460	2020-04-10 20:51:33.062971+03
22702	56	-1	2460	2020-04-10 21:17:53.406487+03
22703	75	-1	830	2020-04-10 21:21:10.302513+03
22704	70	-1	760	2020-04-10 22:38:41.972936+03
22705	43	-1	380	2020-04-10 23:38:00.144782+03
22706	34	-1	1550	2020-04-10 23:58:08.988488+03
22707	67	-1	350	2020-04-11 00:01:38.118617+03
22708	12	-1	1650	2020-04-11 00:10:45.765096+03
22709	26	-1	390	2020-04-11 00:25:01.844281+03
22710	28	-1	1860	2020-04-11 00:59:48.47961+03
22711	24	-1	950	2020-04-11 01:22:41.692965+03
22712	37	-1	1290	2020-04-11 01:49:19.34568+03
22713	36	-1	630	2020-04-11 02:00:03.046476+03
22714	20	-1	830	2020-04-11 02:31:25.91193+03
22715	83	-1	1230	2020-04-11 02:37:13.879529+03
22716	6	-1	980	2020-04-11 02:49:54.759172+03
22717	4	-2	1420	2020-04-11 03:06:58.898212+03
22718	32	-2	710	2020-04-11 03:34:22.529638+03
22719	93	-1	1620	2020-04-11 04:24:14.228863+03
22720	15	-2	2830	2020-04-11 04:28:03.312093+03
22721	14	-2	1350	2020-04-11 04:54:41.612897+03
22722	17	-1	1500	2020-04-11 04:56:12.778201+03
22723	9	-1	2090	2020-04-11 05:16:08.799155+03
22724	88	-1	1270	2020-04-11 05:23:01.40165+03
22725	27	-1	880	2020-04-11 05:25:13.339707+03
22726	74	-1	1010	2020-04-11 05:58:34.877836+03
22727	65	-1	490	2020-04-11 06:39:01.76824+03
22728	73	-1	960	2020-04-11 06:49:18.738353+03
22729	78	-1	900	2020-04-11 07:17:48.530066+03
22730	89	-1	1420	2020-04-11 07:25:02.976472+03
22731	24	-1	950	2020-04-11 08:07:11.615205+03
22732	71	-2	1030	2020-04-11 08:29:46.418793+03
22733	64	-2	970	2020-04-11 08:41:20.847035+03
22734	57	-1	1900	2020-04-11 08:46:56.704945+03
22735	6	-1	980	2020-04-11 08:53:13.800313+03
22736	11	-1	830	2020-04-11 09:07:40.115027+03
22737	40	-2	1430	2020-04-11 09:11:21.156511+03
22738	42	35	794	2020-04-11 09:34:35.291143+03
22739	90	-1	1780	2020-04-11 09:43:11.287665+03
22740	45	-1	1590	2020-04-11 09:52:08.217948+03
22741	17	-3	1500	2020-04-11 09:53:36.73166+03
22742	59	-1	1030	2020-04-11 09:56:59.730214+03
22743	22	-1	1070	2020-04-11 10:24:37.467692+03
22744	35	-1	670	2020-04-11 10:26:27.825481+03
22745	83	-1	1230	2020-04-11 11:05:38.959901+03
22746	15	-1	2830	2020-04-11 11:32:10.800662+03
22747	38	-2	1100	2020-04-11 11:45:07.943953+03
22748	86	-2	910	2020-04-11 12:17:48.878483+03
22749	79	25	311	2020-04-11 12:31:34.232547+03
22750	43	-1	380	2020-04-11 12:42:35.111018+03
22751	90	-1	1780	2020-04-11 12:48:12.960041+03
22752	84	-1	2700	2020-04-11 13:02:59.588945+03
22753	53	-1	3120	2020-04-11 13:30:14.157049+03
22754	58	-2	2830	2020-04-11 13:31:54.021149+03
22755	17	-1	1500	2020-04-11 13:55:35.419607+03
22756	55	-1	3480	2020-04-11 14:03:28.997147+03
22757	86	-1	910	2020-04-11 14:18:28.074576+03
22758	44	-1	500	2020-04-11 15:12:51.585229+03
22759	84	-1	2700	2020-04-11 15:24:22.25615+03
22760	8	-2	1920	2020-04-11 15:43:20.195746+03
22761	76	-1	1070	2020-04-11 16:11:25.470001+03
22762	22	-1	1070	2020-04-11 16:16:59.456753+03
22763	64	-1	970	2020-04-11 16:18:55.859136+03
22764	69	-1	1100	2020-04-11 16:21:34.956766+03
22765	64	-1	970	2020-04-11 16:29:09.300633+03
22766	83	-2	1230	2020-04-11 16:45:10.482162+03
22767	71	-1	1030	2020-04-11 16:53:46.403005+03
22768	12	-1	1650	2020-04-11 17:16:54.436672+03
22769	95	-1	480	2020-04-11 17:23:52.804095+03
22770	23	-1	4390	2020-04-11 17:42:22.211355+03
22771	44	-1	500	2020-04-11 18:23:36.678143+03
22772	33	-1	900	2020-04-11 18:29:29.52685+03
22773	35	-1	670	2020-04-11 18:34:18.692415+03
22774	74	-1	1010	2020-04-11 18:42:12.643169+03
22775	24	-1	950	2020-04-11 18:42:41.108014+03
22776	46	40	696	2020-04-11 18:53:49.968865+03
22777	29	-1	1940	2020-04-11 18:54:12.177286+03
22778	43	-1	380	2020-04-11 19:02:37.470167+03
22779	7	-1	810	2020-04-11 19:23:58.747292+03
22780	20	-1	830	2020-04-11 19:32:30.155332+03
22781	89	-1	1420	2020-04-11 19:41:11.9783+03
22782	20	-1	830	2020-04-11 19:46:11.590061+03
22783	84	-1	2700	2020-04-11 19:49:40.325974+03
22784	36	-1	630	2020-04-11 20:09:49.034324+03
22785	85	-1	730	2020-04-11 20:16:14.563022+03
22786	40	-1	1430	2020-04-11 20:17:09.389882+03
22787	12	-1	1650	2020-04-11 20:29:24.987839+03
22788	92	-1	630	2020-04-11 20:31:56.571035+03
22789	84	-1	2700	2020-04-11 20:55:03.932198+03
22790	55	-1	3480	2020-04-11 21:08:53.189674+03
22791	37	-2	1290	2020-04-11 21:12:31.744641+03
22792	17	-1	1500	2020-04-11 21:14:42.83518+03
22793	26	-1	390	2020-04-11 21:43:09.01293+03
22794	58	-1	2830	2020-04-11 21:57:02.851498+03
22795	91	-1	1620	2020-04-11 22:00:43.832811+03
22796	45	-1	1590	2020-04-11 22:04:48.320606+03
22797	86	-1	910	2020-04-11 22:26:53.905547+03
22798	31	-1	1190	2020-04-11 22:28:27.138031+03
22799	34	-1	1550	2020-04-11 22:32:25.039064+03
22800	68	-1	490	2020-04-11 22:53:14.52278+03
22801	55	-1	3480	2020-04-11 22:54:10.832326+03
22802	73	-1	960	2020-04-11 22:57:32.829856+03
22803	39	-1	910	2020-04-11 23:26:27.878354+03
22804	17	-2	1500	2020-04-11 23:59:45.292507+03
22805	47	-1	1480	2020-04-12 00:05:49.306997+03
22806	56	-2	2460	2020-04-12 00:12:12.589294+03
22807	91	-2	1620	2020-04-12 00:22:05.096369+03
22808	48	-2	640	2020-04-12 00:27:35.652334+03
22809	32	-1	710	2020-04-12 00:29:42.951161+03
22810	47	-1	1480	2020-04-12 00:33:29.722082+03
22811	45	-1	1590	2020-04-12 00:52:28.011174+03
22812	53	-1	3120	2020-04-12 01:08:50.2921+03
22813	13	-2	460	2020-04-12 02:11:50.093835+03
22814	36	-1	630	2020-04-12 02:11:54.888023+03
22815	90	-1	1780	2020-04-12 02:22:50.895188+03
22816	89	32	836	2020-04-12 02:28:37.219859+03
22817	4	-1	1420	2020-04-12 02:29:38.005368+03
22818	63	-1	1780	2020-04-12 02:41:20.313289+03
22819	71	-1	1030	2020-04-12 02:50:11.377761+03
22820	51	-1	1310	2020-04-12 03:16:35.369021+03
22821	21	-1	960	2020-04-12 03:32:30.179902+03
22822	76	37	527	2020-04-12 03:51:06.732958+03
22823	37	-1	1290	2020-04-12 03:57:25.729164+03
22824	5	-1	1620	2020-04-12 04:45:27.101905+03
22825	36	-1	630	2020-04-12 04:48:16.145431+03
22826	70	-2	760	2020-04-12 04:51:36.469723+03
22827	82	-1	560	2020-04-12 05:17:48.092628+03
22828	29	-1	1940	2020-04-12 05:28:43.812126+03
22829	15	-1	2830	2020-04-12 05:31:04.173346+03
22830	54	-1	3470	2020-04-12 05:38:11.25269+03
22831	27	-1	880	2020-04-12 05:57:24.086168+03
22832	76	-1	1070	2020-04-12 06:03:08.115998+03
22833	87	-1	2320	2020-04-12 06:39:37.189103+03
22834	87	-1	2320	2020-04-12 06:49:43.375613+03
22835	37	-1	1290	2020-04-12 07:03:24.608499+03
22836	37	-1	1290	2020-04-12 07:10:00.301261+03
22837	4	-1	1420	2020-04-12 07:11:10.205979+03
22838	13	-1	460	2020-04-12 07:34:39.01238+03
22839	68	25	197	2020-04-12 07:42:05.018448+03
22840	47	-1	1480	2020-04-12 07:54:59.631797+03
22841	20	-1	830	2020-04-12 08:21:51.103039+03
22842	19	-1	1220	2020-04-12 08:42:43.867488+03
22843	77	-1	640	2020-04-12 08:54:16.498707+03
22844	37	-1	1290	2020-04-12 09:08:45.396442+03
22845	52	-2	1090	2020-04-12 09:15:37.893876+03
22846	48	-1	640	2020-04-12 09:41:27.444362+03
22847	6	-2	980	2020-04-12 09:44:52.370082+03
22848	53	-2	3120	2020-04-12 09:51:53.078667+03
22849	71	-1	1030	2020-04-12 10:00:32.99204+03
22850	95	-1	480	2020-04-12 10:03:56.980599+03
22851	42	-1	1790	2020-04-12 10:05:51.819954+03
22852	50	-2	1140	2020-04-12 10:08:45.745923+03
22853	63	-1	1780	2020-04-12 10:39:09.106311+03
22854	36	-1	630	2020-04-12 10:40:30.329583+03
22855	3	-1	660	2020-04-12 10:41:33.878982+03
22856	81	-2	1620	2020-04-12 10:49:12.00215+03
22857	33	-1	900	2020-04-12 10:57:42.765956+03
22858	40	-1	1430	2020-04-12 11:07:29.388708+03
22859	77	-1	640	2020-04-12 11:08:39.873938+03
22860	1	-1	640	2020-04-12 11:19:42.863597+03
22861	3	-1	660	2020-04-12 11:20:19.270265+03
22862	40	-1	1430	2020-04-12 11:20:24.588412+03
22863	3	-1	660	2020-04-12 11:20:59.954386+03
22864	42	-2	1790	2020-04-12 11:36:59.766149+03
22865	33	-1	900	2020-04-12 11:38:54.394531+03
22866	5	-1	1620	2020-04-12 11:51:02.745557+03
22867	23	-1	4390	2020-04-12 12:04:47.179904+03
22868	27	-1	880	2020-04-12 12:21:41.008757+03
22869	37	-1	1290	2020-04-12 12:30:27.933919+03
22870	92	-1	630	2020-04-12 13:28:57.470184+03
22871	67	-2	350	2020-04-12 13:43:20.315695+03
22872	6	-1	980	2020-04-12 13:49:54.625423+03
22873	86	-1	910	2020-04-12 13:57:53.912325+03
22874	62	-3	1220	2020-04-12 14:00:20.350227+03
22875	46	-1	1270	2020-04-12 14:19:44.90087+03
22876	84	-1	2700	2020-04-12 14:24:46.023706+03
22877	3	-2	660	2020-04-12 14:27:13.573888+03
22878	70	-1	760	2020-04-12 14:28:02.12438+03
22879	12	-1	1650	2020-04-12 14:35:56.518879+03
22880	71	-1	1030	2020-04-12 14:47:55.297543+03
22881	86	-2	910	2020-04-12 15:19:50.480753+03
22882	71	-1	1030	2020-04-12 15:46:12.244775+03
22883	3	-2	660	2020-04-12 15:51:50.478972+03
22884	4	-1	1420	2020-04-12 16:08:41.443146+03
22885	90	-1	1780	2020-04-12 16:39:03.617263+03
22886	37	-1	1290	2020-04-12 16:39:52.556179+03
22887	70	-1	760	2020-04-12 17:26:18.126151+03
22888	18	-1	910	2020-04-12 17:30:41.362444+03
22889	23	-1	4390	2020-04-12 17:36:52.530054+03
22890	93	-1	1620	2020-04-12 17:42:54.844747+03
22891	24	-1	950	2020-04-12 17:45:56.492617+03
22892	12	-1	1650	2020-04-12 18:52:08.729194+03
22893	33	-2	900	2020-04-12 18:55:05.979214+03
22894	37	-1	1290	2020-04-12 19:07:58.908622+03
22895	42	-1	1790	2020-04-12 19:15:54.826835+03
22896	32	-1	710	2020-04-12 19:30:57.679222+03
22897	71	-1	1030	2020-04-12 20:06:52.040864+03
22898	34	-1	1550	2020-04-12 20:39:10.930447+03
22899	44	-1	500	2020-04-12 20:51:11.843546+03
22900	57	-1	1900	2020-04-12 21:05:13.762344+03
22901	41	-1	830	2020-04-12 21:07:56.456912+03
22902	79	-1	550	2020-04-12 21:11:26.83576+03
22903	39	-1	910	2020-04-12 21:36:34.566646+03
22904	57	-1	1900	2020-04-12 22:35:20.687014+03
22905	13	-1	460	2020-04-12 22:46:12.592383+03
22906	4	-3	1420	2020-04-12 22:47:36.9431+03
22907	90	-1	1780	2020-04-12 23:07:13.976235+03
22908	32	-1	710	2020-04-12 23:09:45.54907+03
22909	12	-1	1650	2020-04-12 23:12:23.280893+03
22910	61	-1	1510	2020-04-13 00:13:58.030869+03
22911	47	-1	1480	2020-04-13 00:17:57.620969+03
22912	42	-1	1790	2020-04-13 00:36:41.713833+03
22913	37	-1	1290	2020-04-13 00:46:38.638823+03
22914	25	-1	1100	2020-04-13 00:57:31.078679+03
22915	67	-1	350	2020-04-13 01:12:53.320106+03
22916	93	-1	1620	2020-04-13 01:15:27.0064+03
22917	76	-1	1070	2020-04-13 01:28:25.619583+03
22918	29	-2	1940	2020-04-13 01:48:15.270965+03
22919	13	-1	460	2020-04-13 01:56:53.708563+03
22920	89	-1	1420	2020-04-13 02:11:40.040125+03
22921	91	-1	1620	2020-04-13 02:18:12.607188+03
22922	89	-1	1420	2020-04-13 02:49:00.311255+03
22923	14	-1	1350	2020-04-13 03:04:21.846506+03
22924	50	-2	1140	2020-04-13 03:30:37.15919+03
22925	46	-2	1270	2020-04-13 04:50:20.038712+03
22926	51	-1	1310	2020-04-13 05:36:10.91726+03
22927	86	-1	910	2020-04-13 05:49:07.789294+03
22928	95	-1	480	2020-04-13 05:51:25.317899+03
22929	37	-1	1290	2020-04-13 05:56:48.673603+03
22930	55	-1	3480	2020-04-13 06:54:45.816964+03
22931	63	-1	1780	2020-04-13 07:13:18.422427+03
22932	12	-1	1650	2020-04-13 07:31:57.896518+03
22933	60	-2	2700	2020-04-13 07:32:04.784437+03
22934	68	-2	490	2020-04-13 07:37:03.621958+03
22935	56	-1	2460	2020-04-13 07:42:29.877867+03
22936	93	-1	1620	2020-04-13 07:49:09.398072+03
22937	30	-1	1140	2020-04-13 08:25:16.447105+03
22938	32	-3	710	2020-04-13 08:49:45.289794+03
22939	96	-2	1570	2020-04-13 09:16:38.149131+03
22940	35	-1	670	2020-04-13 09:33:07.768375+03
22941	4	-1	1420	2020-04-13 09:47:11.941268+03
22942	10	-2	2080	2020-04-13 09:58:57.736275+03
22943	87	-1	2320	2020-04-13 10:39:40.2502+03
22944	70	-2	760	2020-04-13 10:42:30.483979+03
22945	75	-2	830	2020-04-13 10:47:08.303767+03
22946	1	25	257	2020-04-13 10:53:43.84801+03
22947	9	-1	2090	2020-04-13 11:25:20.281637+03
22948	77	-1	640	2020-04-13 11:25:45.344208+03
22949	47	-1	1480	2020-04-13 11:30:12.398703+03
22950	22	-2	1070	2020-04-13 11:49:45.511634+03
22951	53	-2	3120	2020-04-13 11:50:16.969212+03
22952	30	-1	1140	2020-04-13 11:50:26.806332+03
22953	57	-1	1900	2020-04-13 12:23:24.387716+03
22954	10	37	1216	2020-04-13 12:31:16.634691+03
22955	94	-1	1230	2020-04-13 13:14:27.534059+03
22956	5	-1	1620	2020-04-13 13:21:06.935135+03
22957	37	-1	1290	2020-04-13 13:35:29.272913+03
22958	4	-1	1420	2020-04-13 13:54:26.082378+03
22959	83	-1	1230	2020-04-13 13:56:18.174413+03
22960	17	-1	1500	2020-04-13 13:57:10.296159+03
22961	50	-1	1140	2020-04-13 14:00:01.78399+03
22962	41	-1	830	2020-04-13 14:10:01.722354+03
22963	85	-1	730	2020-04-13 14:20:50.114823+03
22964	26	-1	390	2020-04-13 14:38:52.672707+03
22965	4	-1	1420	2020-04-13 14:42:33.505008+03
22966	17	-1	1500	2020-04-13 14:50:59.186766+03
22967	60	-1	2700	2020-04-13 15:23:12.856616+03
22968	18	-2	910	2020-04-13 15:39:54.109115+03
22969	17	-1	1500	2020-04-13 16:43:27.256988+03
22970	92	-1	630	2020-04-13 17:49:55.584877+03
22971	74	-1	1010	2020-04-13 17:57:01.288614+03
22972	81	-1	1620	2020-04-13 18:04:07.232747+03
22973	61	-1	1510	2020-04-13 18:20:13.443183+03
22974	35	-2	670	2020-04-13 18:20:17.067862+03
22975	64	-1	970	2020-04-13 18:42:43.732249+03
22976	41	-1	830	2020-04-13 18:48:02.058029+03
22977	70	-2	760	2020-04-13 18:48:32.710574+03
22978	44	-1	500	2020-04-13 19:12:31.115581+03
22979	29	41	819	2020-04-13 19:42:28.318375+03
22980	87	-1	2320	2020-04-13 19:57:14.55792+03
22981	85	-1	730	2020-04-13 20:06:51.905879+03
22982	23	-1	4390	2020-04-13 20:29:17.322374+03
22983	92	-1	630	2020-04-13 20:48:25.792576+03
22984	34	33	667	2020-04-13 21:02:18.871192+03
22985	35	-2	670	2020-04-13 21:28:42.446178+03
22986	48	-1	640	2020-04-13 21:35:20.660049+03
22987	71	-1	1030	2020-04-13 21:44:31.332385+03
22988	4	-1	1420	2020-04-13 22:41:21.809718+03
22989	1	-1	640	2020-04-13 22:41:46.476731+03
22990	54	-1	3470	2020-04-13 23:18:58.199763+03
22991	68	-1	490	2020-04-14 00:17:41.196655+03
22992	40	-1	1430	2020-04-14 00:17:46.557824+03
22993	40	-1	1430	2020-04-14 00:25:47.03449+03
22994	9	20	1174	2020-04-14 00:26:46.446269+03
22995	44	-1	500	2020-04-14 00:29:23.667847+03
22996	33	-1	900	2020-04-14 00:33:49.253657+03
22997	70	-1	760	2020-04-14 00:36:14.943087+03
22998	96	-1	1570	2020-04-14 01:04:50.939058+03
22999	90	-1	1780	2020-04-14 01:18:04.459638+03
23000	65	-3	490	2020-04-14 01:31:54.889954+03
23001	44	-1	500	2020-04-14 01:53:31.034057+03
23002	14	-2	1350	2020-04-14 01:54:33.707248+03
23003	42	-1	1790	2020-04-14 01:58:35.908785+03
23004	78	-2	900	2020-04-14 02:10:16.959463+03
23005	54	-1	3470	2020-04-14 02:27:01.082775+03
23006	12	-1	1650	2020-04-14 02:39:23.871163+03
23007	55	-2	3480	2020-04-14 03:09:52.178374+03
23008	17	-1	1500	2020-04-14 03:17:54.102301+03
23009	12	-1	1650	2020-04-14 03:38:03.771368+03
23010	96	-2	1570	2020-04-14 04:16:35.54554+03
23011	11	-1	830	2020-04-14 04:20:59.478197+03
23012	32	-1	710	2020-04-14 04:21:35.219172+03
23013	13	-1	460	2020-04-14 04:46:03.190811+03
23014	7	-1	810	2020-04-14 05:01:35.658422+03
23015	18	-2	910	2020-04-14 05:05:03.000399+03
23016	30	-1	1140	2020-04-14 05:14:36.089405+03
23017	73	-1	960	2020-04-14 05:15:21.8353+03
23018	10	-1	2080	2020-04-14 05:23:25.725431+03
23019	77	-1	640	2020-04-14 05:34:45.528073+03
23020	32	-2	710	2020-04-14 05:45:28.501106+03
23021	7	-1	810	2020-04-14 06:04:51.977612+03
23022	35	-1	670	2020-04-14 06:27:38.763214+03
23023	78	-1	900	2020-04-14 06:33:39.180523+03
23024	18	-1	910	2020-04-14 06:36:08.30745+03
23025	75	-1	830	2020-04-14 06:56:48.429803+03
23026	89	-1	1420	2020-04-14 08:10:11.908413+03
23027	37	-1	1290	2020-04-14 08:20:37.302061+03
23028	6	-1	980	2020-04-14 08:42:57.226694+03
23029	29	-1	1940	2020-04-14 08:50:35.62707+03
23030	6	-1	980	2020-04-14 09:15:36.130845+03
23031	18	-2	910	2020-04-14 09:46:40.247902+03
23032	90	-2	1780	2020-04-14 09:48:10.095554+03
23033	89	-2	1420	2020-04-14 09:51:25.841013+03
23034	75	-2	830	2020-04-14 09:59:47.942511+03
23035	59	-1	1030	2020-04-14 10:00:00.258617+03
23036	32	-1	710	2020-04-14 10:01:00.483064+03
23037	20	-1	830	2020-04-14 10:42:41.172084+03
23038	57	-1	1900	2020-04-14 10:44:17.196619+03
23039	81	-1	1620	2020-04-14 10:48:16.790809+03
23040	81	-2	1620	2020-04-14 11:18:50.572262+03
23041	56	-1	2460	2020-04-14 11:23:50.494181+03
23042	14	-1	1350	2020-04-14 11:25:37.519797+03
23043	26	-1	390	2020-04-14 11:25:54.342652+03
23044	64	23	520	2020-04-14 12:29:19.350525+03
23045	24	-1	950	2020-04-14 12:31:51.875722+03
23046	1	-1	640	2020-04-14 13:04:04.468115+03
23047	70	-1	760	2020-04-14 13:40:30.960109+03
23048	17	-1	1500	2020-04-14 14:28:01.108306+03
23049	73	-1	960	2020-04-14 14:51:13.84768+03
23050	96	-1	1570	2020-04-14 15:20:29.45986+03
23051	27	-1	880	2020-04-14 15:29:17.547173+03
23052	39	-1	910	2020-04-14 15:50:03.810177+03
23053	76	-1	1070	2020-04-14 16:09:15.612092+03
23054	20	-1	830	2020-04-14 17:09:04.687009+03
23055	96	-1	1570	2020-04-14 17:27:16.354591+03
23056	42	-2	1790	2020-04-14 17:55:16.236938+03
23057	29	-1	1940	2020-04-14 18:26:41.722304+03
23058	2	-1	470	2020-04-14 18:30:12.751507+03
23059	46	-2	1270	2020-04-14 18:34:57.277941+03
23060	95	-1	480	2020-04-14 18:35:50.310258+03
23061	12	-2	1650	2020-04-14 18:36:38.423607+03
23062	3	-1	660	2020-04-14 18:36:58.529553+03
23063	55	-2	3480	2020-04-14 18:43:45.789949+03
23064	32	-1	710	2020-04-14 19:07:10.456684+03
23065	61	-1	1510	2020-04-14 19:39:32.355299+03
23066	87	-1	2320	2020-04-14 19:44:33.258919+03
23067	66	-1	690	2020-04-14 19:45:37.104568+03
23068	4	-1	1420	2020-04-14 20:22:29.866495+03
23069	7	-1	810	2020-04-14 20:30:14.509713+03
23070	76	-1	1070	2020-04-14 20:30:57.370071+03
23071	43	-2	380	2020-04-14 20:38:07.924063+03
23072	95	-2	480	2020-04-14 20:52:29.524836+03
23073	28	-1	1860	2020-04-14 21:53:23.38278+03
23074	8	-1	1920	2020-04-14 22:05:04.689981+03
23075	8	-1	1920	2020-04-14 22:17:48.841017+03
23076	79	-1	550	2020-04-14 22:29:40.131183+03
23077	42	-1	1790	2020-04-14 22:37:16.890384+03
23078	18	-1	910	2020-04-14 22:50:13.750931+03
23079	74	-1	1010	2020-04-14 23:00:26.328561+03
23080	57	-1	1900	2020-04-14 23:23:04.417901+03
23081	20	-1	830	2020-04-14 23:31:01.730584+03
23082	95	-2	480	2020-04-14 23:47:58.267127+03
23083	44	-1	500	2020-04-15 00:03:39.561859+03
23084	66	-1	690	2020-04-15 00:19:43.031791+03
23085	53	-1	3120	2020-04-15 00:20:49.171577+03
23086	42	-1	1790	2020-04-15 00:26:42.029742+03
23087	36	-1	630	2020-04-15 00:41:32.000825+03
23088	41	-1	830	2020-04-15 00:53:54.977272+03
23089	42	-2	1790	2020-04-15 00:59:47.426124+03
23090	34	-1	1550	2020-04-15 01:53:19.051233+03
23091	55	32	1883	2020-04-15 02:00:56.033102+03
23092	88	-1	1270	2020-04-15 02:35:55.89914+03
23093	65	-1	490	2020-04-15 02:40:31.067228+03
23094	55	-2	3480	2020-04-15 03:02:09.240882+03
23095	71	-1	1030	2020-04-15 03:12:21.687781+03
23096	60	-2	2700	2020-04-15 03:42:07.772509+03
23097	33	-1	900	2020-04-15 03:59:13.869146+03
23098	1	-1	640	2020-04-15 04:03:15.821069+03
23099	28	-1	1860	2020-04-15 04:11:49.195375+03
23100	79	-1	550	2020-04-15 05:14:00.988242+03
23101	49	-2	970	2020-04-15 05:18:05.232082+03
23102	34	-2	1550	2020-04-15 05:31:48.24164+03
23103	82	-1	560	2020-04-15 05:33:37.612663+03
23104	44	-2	500	2020-04-15 05:51:27.696226+03
23105	82	-2	560	2020-04-15 05:56:04.453221+03
23106	41	-1	830	2020-04-15 06:06:21.998238+03
23107	91	-2	1620	2020-04-15 06:20:07.875777+03
23108	27	20	371	2020-04-15 06:25:03.759018+03
23109	60	-1	2700	2020-04-15 06:33:21.938448+03
23110	28	-2	1860	2020-04-15 06:35:34.022553+03
23111	55	-1	3480	2020-04-15 06:51:22.68691+03
23112	39	-1	910	2020-04-15 06:57:12.377452+03
23113	84	-2	2700	2020-04-15 07:19:45.52548+03
23114	20	-1	830	2020-04-15 07:41:14.863816+03
23115	6	-1	980	2020-04-15 07:47:43.097428+03
23116	34	-1	1550	2020-04-15 08:04:59.602985+03
23117	59	-1	1030	2020-04-15 08:06:16.424546+03
23118	28	-1	1860	2020-04-15 08:16:30.892662+03
23119	5	24	884	2020-04-15 08:17:29.223803+03
23120	73	-3	960	2020-04-15 08:24:00.456153+03
23121	13	-1	460	2020-04-15 08:36:19.980281+03
23122	17	-1	1500	2020-04-15 08:40:57.002573+03
23123	96	-1	1570	2020-04-15 08:51:47.636693+03
23124	70	-1	760	2020-04-15 08:53:19.137435+03
23125	43	-1	380	2020-04-15 09:11:38.157305+03
23126	13	-1	460	2020-04-15 09:48:02.700911+03
23127	35	-1	670	2020-04-15 09:48:15.116403+03
23128	14	32	627	2020-04-15 10:11:34.542856+03
23129	10	-1	2080	2020-04-15 10:27:36.301364+03
23130	26	-1	390	2020-04-15 10:32:33.708565+03
23131	67	-1	350	2020-04-15 10:46:37.696548+03
23132	95	-1	480	2020-04-15 10:59:41.952449+03
23133	43	-1	380	2020-04-15 11:49:03.428242+03
23134	81	-1	1620	2020-04-15 11:49:24.628659+03
23135	88	-1	1270	2020-04-15 11:55:15.048712+03
23136	23	-2	4390	2020-04-15 12:00:25.708278+03
23137	20	-1	830	2020-04-15 12:28:25.787011+03
23138	75	-1	830	2020-04-15 12:29:04.308884+03
23139	53	-1	3120	2020-04-15 12:39:14.596986+03
23140	27	-1	880	2020-04-15 12:52:38.475579+03
23141	33	-1	900	2020-04-15 13:03:55.917836+03
23142	83	-1	1230	2020-04-15 13:03:59.294789+03
23143	49	-1	970	2020-04-15 13:30:59.41663+03
23144	30	-1	1140	2020-04-15 14:03:48.624053+03
23145	7	-1	810	2020-04-15 14:37:55.763775+03
23146	4	-2	1420	2020-04-15 14:52:09.431522+03
23147	1	-1	640	2020-04-15 15:14:45.154724+03
23148	95	-1	480	2020-04-15 15:18:47.667871+03
23149	95	-1	480	2020-04-15 15:22:41.202581+03
23150	20	-1	830	2020-04-15 15:40:20.728727+03
23151	9	-1	2090	2020-04-15 16:03:54.37911+03
23152	63	-1	1780	2020-04-15 17:02:09.797791+03
23153	87	-1	2320	2020-04-15 17:12:10.576701+03
23154	91	-1	1620	2020-04-15 18:12:50.608864+03
23155	29	-1	1940	2020-04-15 18:24:14.92673+03
23156	76	-2	1070	2020-04-15 18:44:45.959022+03
23157	69	-1	1100	2020-04-15 18:52:17.913253+03
23158	73	-2	960	2020-04-15 19:13:59.149174+03
23159	5	-1	1620	2020-04-15 19:36:02.425639+03
23160	74	-2	1010	2020-04-15 19:54:56.539552+03
23161	86	-1	910	2020-04-15 20:00:22.722197+03
23162	34	-1	1550	2020-04-15 20:04:25.040932+03
23163	34	-1	1550	2020-04-15 20:05:54.0938+03
23164	17	-1	1500	2020-04-15 20:15:55.826718+03
23165	88	-1	1270	2020-04-15 20:39:00.763104+03
23166	31	-1	1190	2020-04-15 20:41:25.018277+03
23167	61	-1	1510	2020-04-15 20:49:56.076791+03
23168	73	-2	960	2020-04-15 20:52:03.504092+03
23169	33	-1	900	2020-04-15 21:01:56.506536+03
23170	32	-2	710	2020-04-15 21:01:56.612073+03
23171	4	-2	1420	2020-04-15 21:35:50.904259+03
23172	86	-1	910	2020-04-15 22:06:18.381768+03
23173	81	-1	1620	2020-04-15 22:08:00.379429+03
23174	74	-1	1010	2020-04-15 22:09:16.993424+03
23175	8	-1	1920	2020-04-15 22:17:23.278288+03
23176	5	-1	1620	2020-04-15 22:55:26.132282+03
23177	70	-1	760	2020-04-15 22:56:20.183894+03
23178	87	-1	2320	2020-04-15 23:03:10.928219+03
23179	60	-2	2700	2020-04-15 23:08:20.913613+03
23180	87	-1	2320	2020-04-15 23:19:31.42547+03
23181	68	-2	490	2020-04-16 00:37:53.218126+03
23182	45	-1	1590	2020-04-16 00:41:18.966322+03
23183	75	-1	830	2020-04-16 00:43:08.813402+03
23184	24	-1	950	2020-04-16 00:45:54.074595+03
23185	45	-1	1590	2020-04-16 00:49:19.548537+03
23186	66	11	405	2020-04-16 00:55:09.660736+03
23187	10	-3	2080	2020-04-16 01:18:19.818203+03
23188	84	-1	2700	2020-04-16 01:19:34.652917+03
23189	75	-1	830	2020-04-16 02:40:34.913695+03
23190	95	-1	480	2020-04-16 04:02:54.346037+03
23191	58	18	1455	2020-04-16 04:40:24.265211+03
23192	13	-1	460	2020-04-16 04:43:07.655469+03
23193	92	-1	630	2020-04-16 05:17:36.451158+03
23194	5	-1	1620	2020-04-16 05:27:22.928788+03
23195	92	-1	630	2020-04-16 05:39:40.270026+03
23196	41	-1	830	2020-04-16 06:23:10.667132+03
23197	6	-1	980	2020-04-16 06:24:56.561545+03
23198	4	-2	1420	2020-04-16 06:26:32.880965+03
23199	13	-1	460	2020-04-16 06:28:43.468975+03
23200	44	-1	500	2020-04-16 07:00:57.18317+03
23201	49	-1	970	2020-04-16 07:48:57.674576+03
23202	89	-1	1420	2020-04-16 07:51:00.062247+03
23203	17	-1	1500	2020-04-16 08:09:31.58382+03
23204	52	-1	1090	2020-04-16 08:45:51.624479+03
23205	42	-1	1790	2020-04-16 08:47:39.056075+03
23206	52	-1	1090	2020-04-16 08:58:36.550658+03
23207	21	-1	960	2020-04-16 09:28:57.918911+03
23208	85	-2	730	2020-04-16 09:29:48.357672+03
23209	94	-1	1230	2020-04-16 09:35:08.873065+03
23210	38	-1	1100	2020-04-16 09:43:02.210548+03
23211	90	-1	1780	2020-04-16 09:49:16.868733+03
23212	54	-1	3470	2020-04-16 10:42:14.131403+03
23213	47	-1	1480	2020-04-16 10:59:14.962911+03
23214	88	-1	1270	2020-04-16 11:06:16.501517+03
23215	91	-1	1620	2020-04-16 11:19:23.978896+03
23216	20	-1	830	2020-04-16 11:32:49.445869+03
23217	22	-2	1070	2020-04-16 11:37:04.236736+03
23218	21	31	521	2020-04-16 11:40:03.407882+03
23219	60	-1	2700	2020-04-16 11:46:25.665796+03
23220	38	-1	1100	2020-04-16 12:10:29.997579+03
23221	71	-1	1030	2020-04-16 12:16:50.854588+03
23222	49	-1	970	2020-04-16 12:57:41.489882+03
23223	18	-1	910	2020-04-16 13:04:38.067269+03
23224	61	-1	1510	2020-04-16 13:50:50.977626+03
23225	19	-2	1220	2020-04-16 13:54:07.146948+03
23226	68	-1	490	2020-04-16 13:59:50.679831+03
23227	96	-1	1570	2020-04-16 14:11:59.992772+03
23228	76	-1	1070	2020-04-16 14:32:47.083602+03
23229	29	-1	1940	2020-04-16 14:45:02.351577+03
23230	93	-1	1620	2020-04-16 15:37:47.02157+03
23231	50	-1	1140	2020-04-16 15:49:45.631498+03
23232	23	-1	4390	2020-04-16 16:55:05.558275+03
23233	3	-1	660	2020-04-16 17:05:45.839369+03
23234	87	39	1112	2020-04-16 17:13:52.109305+03
23235	13	-1	460	2020-04-16 17:16:26.82128+03
23236	19	-1	1220	2020-04-16 17:19:42.345612+03
23237	41	-1	830	2020-04-16 17:41:45.822481+03
23238	7	-2	810	2020-04-16 17:56:01.156263+03
23239	76	-2	1070	2020-04-16 17:59:57.087156+03
23240	56	-1	2460	2020-04-16 18:07:51.328873+03
23241	3	-1	660	2020-04-16 19:15:26.943615+03
23242	38	-1	1100	2020-04-16 19:53:43.823602+03
23243	53	-2	3120	2020-04-16 20:04:52.458959+03
23244	19	-1	1220	2020-04-16 20:16:02.735855+03
23245	74	-1	1010	2020-04-16 20:20:44.270946+03
23246	79	-2	550	2020-04-16 21:35:39.503447+03
23247	60	-1	2700	2020-04-16 21:38:25.138494+03
23248	12	-1	1650	2020-04-16 21:58:58.122186+03
23249	83	38	650	2020-04-16 22:22:40.701163+03
23250	94	-1	1230	2020-04-16 22:23:15.43408+03
23251	67	-1	350	2020-04-16 23:12:53.204401+03
23252	47	-2	1480	2020-04-16 23:22:30.054809+03
23253	64	-1	970	2020-04-16 23:24:09.805218+03
23254	86	-1	910	2020-04-16 23:41:52.211338+03
23255	83	-1	1230	2020-04-16 23:53:43.174555+03
23256	4	-2	1420	2020-04-17 00:10:16.025701+03
23257	75	-1	830	2020-04-17 00:39:50.556035+03
23258	67	-1	350	2020-04-17 00:47:56.309808+03
23259	46	-1	1270	2020-04-17 01:01:21.454176+03
23260	95	-1	480	2020-04-17 01:04:13.25169+03
23261	83	-2	1230	2020-04-17 01:46:34.299045+03
23262	19	-1	1220	2020-04-17 01:49:29.202772+03
23263	79	-1	550	2020-04-17 02:03:23.033172+03
23264	61	-1	1510	2020-04-17 02:09:52.943764+03
23265	39	-1	910	2020-04-17 02:14:25.95382+03
23266	85	-2	730	2020-04-17 02:58:22.096081+03
23267	39	-1	910	2020-04-17 03:40:26.897018+03
23268	44	-2	500	2020-04-17 04:10:23.502759+03
23269	45	-1	1590	2020-04-17 04:17:44.774881+03
23270	57	-1	1900	2020-04-17 04:18:06.203303+03
23271	18	-1	910	2020-04-17 04:24:11.408017+03
23272	4	-1	1420	2020-04-17 04:34:47.597052+03
23273	23	-1	4390	2020-04-17 04:38:07.987469+03
23274	81	-1	1620	2020-04-17 04:43:33.179084+03
23275	55	-1	3480	2020-04-17 04:49:56.328322+03
23276	69	-3	1100	2020-04-17 05:22:09.148326+03
23277	4	45	596	2020-04-17 06:10:22.719134+03
23278	58	-2	2830	2020-04-17 06:10:59.279257+03
23279	88	-2	1270	2020-04-17 06:14:32.624501+03
23280	18	-1	910	2020-04-17 06:23:50.845159+03
23281	67	-1	350	2020-04-17 07:14:08.500025+03
23282	39	-2	910	2020-04-17 07:14:12.679558+03
23283	25	-1	1100	2020-04-17 07:25:33.144298+03
23284	45	-1	1590	2020-04-17 07:35:45.39073+03
23285	42	-1	1790	2020-04-17 07:36:25.806951+03
23286	4	-1	1420	2020-04-17 07:42:37.496186+03
23287	4	-1	1420	2020-04-17 07:47:43.754554+03
23288	21	-2	960	2020-04-17 08:22:13.780309+03
23289	80	-1	1120	2020-04-17 08:35:09.84707+03
23290	35	-1	670	2020-04-17 09:13:36.010907+03
23291	41	-1	830	2020-04-17 09:25:17.819657+03
23292	87	-1	2320	2020-04-17 09:26:35.615111+03
23293	17	-1	1500	2020-04-17 10:16:54.164703+03
23294	69	-1	1100	2020-04-17 10:23:26.801963+03
23295	41	-1	830	2020-04-17 10:25:48.352262+03
23296	73	-1	960	2020-04-17 10:41:59.035881+03
23297	5	-1	1620	2020-04-17 11:12:07.179377+03
23298	67	-1	350	2020-04-17 11:16:59.556074+03
23299	29	-1	1940	2020-04-17 11:26:00.084163+03
23300	40	-1	1430	2020-04-17 11:41:09.273851+03
23301	35	-2	670	2020-04-17 11:54:09.157884+03
23302	5	-1	1620	2020-04-17 12:10:58.541761+03
23303	71	-1	1030	2020-04-17 12:34:56.044295+03
23304	94	-1	1230	2020-04-17 12:41:25.909111+03
23305	86	-1	910	2020-04-17 12:56:57.629036+03
23306	73	-1	960	2020-04-17 13:03:37.074807+03
23307	47	-1	1480	2020-04-17 13:25:45.998095+03
23308	1	-2	640	2020-04-17 13:36:41.706523+03
23309	96	-1	1570	2020-04-17 13:43:20.740812+03
23310	43	-1	380	2020-04-17 14:16:23.238862+03
23311	7	-1	810	2020-04-17 14:29:07.398712+03
23312	14	-2	1350	2020-04-17 14:30:31.207554+03
23313	35	-1	670	2020-04-17 15:06:21.360883+03
23314	14	-1	1350	2020-04-17 15:32:45.035766+03
23315	46	-1	1270	2020-04-17 15:43:08.107376+03
23316	60	-1	2700	2020-04-17 15:44:14.805686+03
23317	96	-1	1570	2020-04-17 16:29:59.20047+03
23318	6	-1	980	2020-04-17 17:00:40.703552+03
23319	54	-1	3470	2020-04-17 17:03:30.723304+03
23320	14	-1	1350	2020-04-17 17:18:01.01199+03
23321	64	-2	970	2020-04-17 17:39:00.50391+03
23322	42	-1	1790	2020-04-17 18:10:36.722783+03
23323	84	-1	2700	2020-04-17 18:12:02.287259+03
23324	68	-1	490	2020-04-17 18:27:01.353139+03
23325	93	-1	1620	2020-04-17 18:52:09.898085+03
23326	71	-1	1030	2020-04-17 18:56:50.741378+03
23327	41	-1	830	2020-04-17 18:57:29.067378+03
23328	42	-1	1790	2020-04-17 19:29:50.602395+03
23329	49	-2	970	2020-04-17 19:34:57.590557+03
23330	67	-1	350	2020-04-17 19:35:29.472766+03
23331	20	-1	830	2020-04-17 19:52:00.354529+03
23332	79	-1	550	2020-04-17 20:20:31.706986+03
23333	84	-1	2700	2020-04-17 20:55:00.699018+03
23334	87	-2	2320	2020-04-17 20:57:35.645507+03
23335	81	-2	1620	2020-04-17 21:19:05.397186+03
23336	32	-1	710	2020-04-17 21:27:47.247803+03
23337	70	-2	760	2020-04-17 21:39:10.75664+03
23338	26	-1	390	2020-04-17 21:48:32.501299+03
23339	40	-1	1430	2020-04-17 22:24:07.783029+03
23340	67	-2	350	2020-04-17 22:48:26.605533+03
23341	32	-2	710	2020-04-17 23:28:38.042589+03
23342	53	-1	3120	2020-04-17 23:56:17.242719+03
23343	78	-1	900	2020-04-17 23:57:36.131857+03
23344	70	-1	760	2020-04-18 00:10:02.296129+03
23345	20	-1	830	2020-04-18 01:07:14.792101+03
23346	63	-1	1780	2020-04-18 01:10:12.091427+03
23347	47	-1	1480	2020-04-18 01:20:47.790121+03
23348	5	-1	1620	2020-04-18 01:25:56.669319+03
23349	34	-1	1550	2020-04-18 01:32:09.463632+03
23350	18	-1	910	2020-04-18 01:44:40.592715+03
23351	90	-1	1780	2020-04-18 01:47:02.92205+03
23352	45	-1	1590	2020-04-18 01:54:16.35463+03
23353	9	-1	2090	2020-04-18 02:32:56.740836+03
23354	10	-1	2080	2020-04-18 02:59:06.189991+03
23355	35	-1	670	2020-04-18 03:14:24.39141+03
23356	61	-1	1510	2020-04-18 03:31:41.032002+03
23357	86	-1	910	2020-04-18 03:41:18.258423+03
23358	65	-1	490	2020-04-18 03:49:52.831016+03
23359	73	-1	960	2020-04-18 03:51:33.7741+03
23360	23	-1	4390	2020-04-18 04:01:50.4532+03
23361	33	-1	900	2020-04-18 04:10:58.806529+03
23362	48	-1	640	2020-04-18 04:57:17.5173+03
23363	21	-1	960	2020-04-18 05:26:11.172178+03
23364	42	-1	1790	2020-04-18 05:56:14.847547+03
23365	94	-1	1230	2020-04-18 06:40:42.095567+03
23366	73	-1	960	2020-04-18 06:42:17.217283+03
23367	46	-1	1270	2020-04-18 06:43:59.869601+03
23368	90	-2	1780	2020-04-18 06:53:04.837419+03
23369	33	-1	900	2020-04-18 07:01:08.250034+03
23370	65	-1	490	2020-04-18 07:18:01.534088+03
23371	12	-1	1650	2020-04-18 07:37:05.565479+03
23372	54	-1	3470	2020-04-18 07:41:49.357399+03
23373	4	-2	1420	2020-04-18 07:49:43.371034+03
23374	9	-1	2090	2020-04-18 07:51:55.629799+03
23375	80	-1	1120	2020-04-18 08:05:30.175533+03
23376	39	-1	910	2020-04-18 08:36:43.689365+03
23377	43	18	165	2020-04-18 08:47:51.336842+03
23378	45	-1	1590	2020-04-18 08:49:57.308894+03
23379	91	-1	1620	2020-04-18 08:55:10.31999+03
23380	90	-2	1780	2020-04-18 09:17:55.389243+03
23381	14	-1	1350	2020-04-18 09:44:38.590604+03
23382	54	-1	3470	2020-04-18 09:51:00.190976+03
23383	80	-1	1120	2020-04-18 09:53:17.676134+03
23384	95	-1	480	2020-04-18 10:00:34.305537+03
23385	46	-1	1270	2020-04-18 10:25:41.961839+03
23386	83	-1	1230	2020-04-18 10:37:06.293256+03
23387	14	-1	1350	2020-04-18 10:48:59.37197+03
23388	48	-1	640	2020-04-18 10:54:30.284677+03
23389	20	-1	830	2020-04-18 10:58:12.812614+03
23390	36	-2	630	2020-04-18 11:27:42.195009+03
23391	23	-1	4390	2020-04-18 11:31:49.277626+03
23392	56	-1	2460	2020-04-18 11:32:02.348326+03
23393	79	-1	550	2020-04-18 11:34:01.086942+03
23394	56	-1	2460	2020-04-18 12:10:59.386949+03
23395	5	-1	1620	2020-04-18 12:32:42.189947+03
23396	32	-1	710	2020-04-18 12:32:46.597128+03
23397	40	-1	1430	2020-04-18 12:43:45.469138+03
23398	35	-1	670	2020-04-18 12:45:55.705445+03
23399	83	-2	1230	2020-04-18 12:47:45.075635+03
23400	30	-1	1140	2020-04-18 12:54:36.618456+03
23401	27	-1	880	2020-04-18 13:52:30.744998+03
23402	81	-1	1620	2020-04-18 13:58:50.474887+03
23403	74	-1	1010	2020-04-18 14:07:12.982361+03
23404	96	-1	1570	2020-04-18 14:18:33.394844+03
23405	23	-1	4390	2020-04-18 14:29:21.715246+03
23406	4	-1	1420	2020-04-18 14:34:51.036072+03
23407	52	-2	1090	2020-04-18 14:38:46.951378+03
23408	37	-3	1290	2020-04-18 14:50:25.009574+03
23409	71	-1	1030	2020-04-18 15:01:56.61724+03
23410	26	-1	390	2020-04-18 15:20:19.918081+03
23411	70	-2	760	2020-04-18 15:25:06.435055+03
23412	46	-1	1270	2020-04-18 15:25:22.226211+03
23413	60	-1	2700	2020-04-18 15:25:59.690252+03
23414	4	-1	1420	2020-04-18 15:37:13.0341+03
23415	87	-1	2320	2020-04-18 15:43:23.951345+03
23416	61	-1	1510	2020-04-18 15:58:16.345776+03
23417	71	-1	1030	2020-04-18 16:28:56.137899+03
23418	91	30	899	2020-04-18 16:34:46.075942+03
23419	33	-1	900	2020-04-18 16:35:27.669965+03
23420	25	-1	1100	2020-04-18 16:38:00.295686+03
23421	35	-1	670	2020-04-18 16:42:54.377411+03
23422	22	-1	1070	2020-04-18 17:00:20.012917+03
23423	1	-1	640	2020-04-18 17:04:37.447126+03
23424	46	-1	1270	2020-04-18 17:07:25.941627+03
23425	44	-1	500	2020-04-18 17:22:52.140906+03
23426	51	-1	1310	2020-04-18 17:46:58.263136+03
23427	1	-1	640	2020-04-18 17:56:47.170872+03
23428	47	-1	1480	2020-04-18 18:09:16.962778+03
23429	60	29	1501	2020-04-18 18:24:42.370333+03
23430	36	-1	630	2020-04-18 18:28:03.620618+03
23431	20	-1	830	2020-04-18 18:46:20.590112+03
23432	3	-1	660	2020-04-18 18:55:46.368216+03
23433	69	-1	1100	2020-04-18 20:07:49.541861+03
23434	28	-1	1860	2020-04-18 20:54:33.810137+03
23435	68	-1	490	2020-04-18 21:17:01.612512+03
23436	46	-1	1270	2020-04-18 21:17:12.748696+03
23437	52	-1	1090	2020-04-18 21:25:09.44679+03
23438	57	-1	1900	2020-04-18 21:27:19.623921+03
23439	21	-2	960	2020-04-18 21:40:19.387892+03
23440	9	-1	2090	2020-04-18 22:43:30.979791+03
23441	83	-1	1230	2020-04-18 22:47:30.349867+03
23442	39	-1	910	2020-04-18 23:08:46.696528+03
23443	37	-1	1290	2020-04-18 23:09:26.685998+03
23444	64	-1	970	2020-04-18 23:30:48.442491+03
23445	90	-1	1780	2020-04-18 23:34:32.347307+03
23446	58	-1	2830	2020-04-19 00:04:32.225464+03
23447	52	-2	1090	2020-04-19 00:35:51.457452+03
23448	14	-1	1350	2020-04-19 00:41:46.267972+03
23449	13	-1	460	2020-04-19 00:42:19.83772+03
23450	5	-2	1620	2020-04-19 00:47:53.024096+03
23451	32	-1	710	2020-04-19 01:18:06.885479+03
23452	44	-1	500	2020-04-19 02:05:27.533813+03
23453	16	-1	1380	2020-04-19 02:06:34.730526+03
23454	94	-1	1230	2020-04-19 02:42:54.781433+03
23455	40	-1	1430	2020-04-19 03:36:48.65911+03
23456	88	-1	1270	2020-04-19 03:45:06.576243+03
23457	73	-1	960	2020-04-19 04:14:46.05062+03
23458	34	-1	1550	2020-04-19 05:07:37.432352+03
23459	14	-1	1350	2020-04-19 05:27:26.145224+03
23460	5	-1	1620	2020-04-19 05:30:36.66242+03
23461	75	-1	830	2020-04-19 05:39:46.476486+03
23462	80	-2	1120	2020-04-19 05:40:32.360782+03
23463	3	-1	660	2020-04-19 05:42:02.288048+03
23464	87	-2	2320	2020-04-19 06:03:43.802834+03
23465	53	-2	3120	2020-04-19 06:50:35.087358+03
23466	17	-1	1500	2020-04-19 06:56:59.162685+03
23467	61	-1	1510	2020-04-19 07:09:51.209442+03
23468	31	-1	1190	2020-04-19 07:33:47.375269+03
23469	74	-1	1010	2020-04-19 07:59:36.799209+03
23470	3	-1	660	2020-04-19 09:30:02.710897+03
23471	78	-2	900	2020-04-19 10:20:34.916941+03
23472	33	-2	900	2020-04-19 10:30:00.527907+03
23473	17	-2	1500	2020-04-19 10:41:59.883112+03
23474	92	-1	630	2020-04-19 10:48:05.96814+03
23475	62	11	621	2020-04-19 10:53:58.638098+03
23476	29	-1	1940	2020-04-19 11:08:35.650205+03
23477	42	-1	1790	2020-04-19 11:36:26.083229+03
23478	21	-1	960	2020-04-19 11:43:53.045582+03
23479	23	-1	4390	2020-04-19 11:50:09.384462+03
23480	26	-1	390	2020-04-19 11:58:16.603407+03
23481	96	-1	1570	2020-04-19 12:01:59.859975+03
23482	29	-1	1940	2020-04-19 12:17:27.36262+03
23483	6	-1	980	2020-04-19 12:35:16.589368+03
23484	12	-1	1650	2020-04-19 12:44:57.546004+03
23485	78	-2	900	2020-04-19 13:01:28.231494+03
23486	93	-1	1620	2020-04-19 13:15:11.79728+03
23487	25	-2	1100	2020-04-19 13:32:38.338363+03
23488	25	-1	1100	2020-04-19 13:35:03.415138+03
23489	77	-1	640	2020-04-19 13:36:58.878465+03
23490	64	-1	970	2020-04-19 13:49:50.382899+03
23491	22	-2	1070	2020-04-19 14:08:36.729556+03
23492	81	-2	1620	2020-04-19 14:20:28.072933+03
23493	88	-1	1270	2020-04-19 14:28:50.444523+03
23494	66	-1	690	2020-04-19 14:30:46.09484+03
23495	44	-1	500	2020-04-19 14:35:23.319606+03
23496	29	-1	1940	2020-04-19 14:40:47.804823+03
23497	31	-1	1190	2020-04-19 14:54:45.662938+03
23498	55	-1	3480	2020-04-19 15:08:14.592806+03
23499	43	-1	380	2020-04-19 15:11:31.782524+03
23500	8	-1	1920	2020-04-19 15:13:07.223356+03
23501	63	-1	1780	2020-04-19 15:18:57.139339+03
23502	10	-1	2080	2020-04-19 15:23:20.998762+03
23503	62	-2	1220	2020-04-19 15:28:37.201293+03
23504	51	-2	1310	2020-04-19 15:54:46.145089+03
23505	47	-1	1480	2020-04-19 16:02:09.836518+03
23506	10	-1	2080	2020-04-19 16:17:45.979961+03
23507	29	-1	1940	2020-04-19 17:07:00.438675+03
23508	25	15	641	2020-04-19 17:23:31.818116+03
23509	78	-1	900	2020-04-19 17:25:08.401779+03
23510	53	-2	3120	2020-04-19 17:37:34.39482+03
23511	39	-1	910	2020-04-19 17:47:01.991065+03
23512	54	-1	3470	2020-04-19 17:47:36.186562+03
23513	82	-1	560	2020-04-19 17:59:15.580949+03
23514	74	-1	1010	2020-04-19 18:09:25.031878+03
23515	19	-1	1220	2020-04-19 18:17:38.441058+03
23516	55	-2	3480	2020-04-19 18:22:21.432903+03
23517	60	-1	2700	2020-04-19 18:51:24.184605+03
23518	18	-1	910	2020-04-19 18:55:27.313309+03
23519	22	-1	1070	2020-04-19 19:29:27.59495+03
23520	8	-1	1920	2020-04-19 20:07:30.61761+03
23521	22	-1	1070	2020-04-19 20:17:24.205039+03
23522	75	-1	830	2020-04-19 20:27:33.903105+03
23523	4	-1	1420	2020-04-19 20:40:54.01212+03
23524	71	-1	1030	2020-04-19 20:46:31.684766+03
23525	77	-1	640	2020-04-19 21:08:16.365186+03
23526	80	23	511	2020-04-19 21:09:36.719944+03
23527	90	-1	1780	2020-04-19 21:15:30.386403+03
23528	81	-1	1620	2020-04-19 21:34:10.816597+03
23529	79	-1	550	2020-04-19 21:45:19.150214+03
23530	83	-1	1230	2020-04-19 22:15:22.37663+03
23531	47	-1	1480	2020-04-19 22:23:31.075121+03
23532	74	-1	1010	2020-04-19 22:39:04.079134+03
23533	15	-1	2830	2020-04-19 23:06:49.311229+03
23534	13	-2	460	2020-04-19 23:14:44.645047+03
23535	19	-1	1220	2020-04-19 23:40:49.276855+03
23536	12	-1	1650	2020-04-19 23:57:51.940481+03
23537	29	-1	1940	2020-04-20 00:12:37.11702+03
23538	5	-1	1620	2020-04-20 00:22:21.822803+03
23539	5	-1	1620	2020-04-20 00:24:29.531826+03
23540	3	-2	660	2020-04-20 00:28:55.322747+03
23541	67	-1	350	2020-04-20 00:42:07.582211+03
23542	84	30	1391	2020-04-20 00:53:12.117354+03
23543	10	-1	2080	2020-04-20 00:56:26.873444+03
23544	84	-1	2700	2020-04-20 01:08:50.628753+03
23545	64	-1	970	2020-04-20 01:24:35.928444+03
23546	41	-1	830	2020-04-20 01:25:12.811883+03
23547	25	-1	1100	2020-04-20 01:30:39.832044+03
23548	33	-2	900	2020-04-20 01:54:16.345915+03
23549	73	26	455	2020-04-20 01:55:41.674934+03
23550	18	30	498	2020-04-20 02:00:10.349497+03
23551	53	-2	3120	2020-04-20 02:26:05.110159+03
23552	52	-1	1090	2020-04-20 02:53:31.858958+03
23553	45	-1	1590	2020-04-20 03:33:01.551315+03
23554	48	-1	640	2020-04-20 03:39:26.713941+03
23555	81	-1	1620	2020-04-20 04:05:28.082696+03
23556	46	-3	1270	2020-04-20 04:28:59.709823+03
23557	85	-1	730	2020-04-20 04:33:47.802147+03
23558	55	-2	3480	2020-04-20 04:34:58.215896+03
23559	29	-1	1940	2020-04-20 04:50:48.834425+03
23560	37	-1	1290	2020-04-20 04:55:26.744792+03
23561	1	-1	640	2020-04-20 05:14:51.827739+03
23562	36	-1	630	2020-04-20 06:33:25.670838+03
23563	71	-1	1030	2020-04-20 07:57:14.602597+03
23564	78	-1	900	2020-04-20 08:05:24.603072+03
23565	10	-1	2080	2020-04-20 08:14:26.002574+03
23566	27	-1	880	2020-04-20 08:45:24.535977+03
23567	78	-2	900	2020-04-20 08:46:27.335441+03
23568	9	-2	2090	2020-04-20 09:12:52.136765+03
23569	2	-2	470	2020-04-20 09:12:53.29483+03
23570	39	-1	910	2020-04-20 09:12:57.721035+03
23571	14	-1	1350	2020-04-20 09:15:03.620752+03
23572	58	-2	2830	2020-04-20 09:41:27.747505+03
23573	81	-2	1620	2020-04-20 09:55:52.100094+03
23574	30	-1	1140	2020-04-20 10:38:42.173657+03
23575	29	-1	1940	2020-04-20 10:53:42.799479+03
23576	20	-1	830	2020-04-20 11:44:22.287483+03
23577	31	-1	1190	2020-04-20 11:52:11.919426+03
23578	31	-2	1190	2020-04-20 11:57:19.16385+03
23579	28	-1	1860	2020-04-20 12:14:13.723187+03
23580	24	-1	950	2020-04-20 12:20:52.803792+03
23581	88	32	613	2020-04-20 12:20:54.648523+03
23582	26	-2	390	2020-04-20 12:39:44.613862+03
23583	60	-1	2700	2020-04-20 13:40:14.760099+03
23584	19	-1	1220	2020-04-20 14:03:38.130824+03
23585	53	-1	3120	2020-04-20 14:26:17.310572+03
23586	21	-1	960	2020-04-20 14:31:46.716824+03
23587	69	-1	1100	2020-04-20 14:34:22.055238+03
23588	5	-1	1620	2020-04-20 14:42:56.069499+03
23589	11	-2	830	2020-04-20 14:50:46.244619+03
23590	54	-1	3470	2020-04-20 14:53:44.892341+03
23591	78	-1	900	2020-04-20 15:26:16.488115+03
23592	93	-1	1620	2020-04-20 15:42:02.238108+03
23593	30	23	487	2020-04-20 15:45:14.729867+03
23594	64	-1	970	2020-04-20 16:15:10.988062+03
23595	73	-1	960	2020-04-20 16:25:55.223221+03
23596	20	-1	830	2020-04-20 16:38:26.862137+03
23597	5	-1	1620	2020-04-20 16:58:06.269046+03
23598	70	26	406	2020-04-20 17:22:04.822932+03
23599	32	-1	710	2020-04-20 17:29:52.182875+03
23600	25	-2	1100	2020-04-20 17:36:51.548065+03
23601	10	-1	2080	2020-04-20 17:37:13.078533+03
23602	87	-1	2320	2020-04-20 17:48:18.411541+03
23603	45	-2	1590	2020-04-20 17:50:00.36289+03
23604	34	-1	1550	2020-04-20 17:51:48.333503+03
23605	69	-1	1100	2020-04-20 17:59:16.834917+03
23606	54	25	1574	2020-04-20 18:41:57.593295+03
23607	78	-1	900	2020-04-20 19:21:49.119323+03
23608	77	-1	640	2020-04-20 20:16:20.99082+03
23609	52	-1	1090	2020-04-20 20:54:49.627137+03
23610	89	-1	1420	2020-04-20 20:55:12.292279+03
23611	61	-1	1510	2020-04-20 20:59:52.746078+03
23612	4	-1	1420	2020-04-20 21:40:32.739307+03
23613	13	-2	460	2020-04-20 21:49:52.095243+03
23614	24	-1	950	2020-04-20 22:04:29.387292+03
23615	26	-1	390	2020-04-20 22:09:09.46024+03
23616	20	25	423	2020-04-20 22:55:51.134001+03
23617	59	-1	1030	2020-04-20 23:06:05.20615+03
23618	67	-1	350	2020-04-20 23:44:53.546766+03
23619	32	-1	710	2020-04-20 23:48:01.886057+03
23620	95	24	217	2020-04-20 23:58:56.801098+03
23621	1	-1	640	2020-04-21 00:21:43.889258+03
23622	67	-1	350	2020-04-21 00:37:48.378838+03
23623	53	-1	3120	2020-04-21 01:36:57.865388+03
23624	68	-2	490	2020-04-21 01:48:29.047273+03
23625	51	-1	1310	2020-04-21 01:51:34.550949+03
23626	78	-1	900	2020-04-21 01:53:37.087324+03
23627	24	-1	950	2020-04-21 03:11:50.378041+03
23628	51	-1	1310	2020-04-21 03:20:10.879273+03
23629	23	-1	4390	2020-04-21 03:24:37.964471+03
23630	28	-1	1860	2020-04-21 03:28:34.025208+03
23631	31	-2	1190	2020-04-21 03:49:47.885747+03
23632	12	-1	1650	2020-04-21 03:54:24.5596+03
23633	81	-1	1620	2020-04-21 04:27:40.715228+03
23634	62	-1	1220	2020-04-21 04:27:45.693744+03
23635	76	-2	1070	2020-04-21 04:45:48.348144+03
23636	1	-1	640	2020-04-21 04:49:49.474146+03
23637	82	-1	560	2020-04-21 05:04:13.227127+03
23638	63	-1	1780	2020-04-21 05:15:10.49749+03
23639	60	-1	2700	2020-04-21 05:21:57.920087+03
23640	85	-1	730	2020-04-21 05:42:38.674996+03
23641	95	-1	480	2020-04-21 06:10:15.605386+03
23642	80	-1	1120	2020-04-21 06:28:13.032024+03
23643	95	-1	480	2020-04-21 06:46:59.771092+03
23644	5	-1	1620	2020-04-21 06:47:51.406125+03
23645	38	-1	1100	2020-04-21 06:49:00.985325+03
23646	46	-1	1270	2020-04-21 06:55:59.473292+03
23647	29	-2	1940	2020-04-21 07:00:15.267938+03
23648	17	-1	1500	2020-04-21 07:01:24.485291+03
23649	12	-1	1650	2020-04-21 07:07:16.088821+03
23650	32	-2	710	2020-04-21 07:07:27.255245+03
23651	78	-1	900	2020-04-21 07:39:43.028227+03
23652	63	-1	1780	2020-04-21 08:02:14.20283+03
23653	7	-2	810	2020-04-21 08:40:42.345296+03
23654	14	-1	1350	2020-04-21 08:55:25.300066+03
23655	46	-1	1270	2020-04-21 09:11:49.229877+03
23656	78	24	400	2020-04-21 09:51:03.96954+03
23657	15	-1	2830	2020-04-21 10:27:43.712393+03
23658	42	-1	1790	2020-04-21 10:31:15.623756+03
23659	38	-1	1100	2020-04-21 10:46:37.414323+03
23660	83	-1	1230	2020-04-21 10:48:55.739737+03
23661	87	-2	2320	2020-04-21 11:12:03.274885+03
23662	54	-2	3470	2020-04-21 11:22:02.640107+03
23663	95	-1	480	2020-04-21 11:26:40.354799+03
23664	26	23	231	2020-04-21 11:26:47.233996+03
23665	68	-3	490	2020-04-21 11:27:00.480942+03
23666	60	-1	2700	2020-04-21 11:30:17.75055+03
23667	2	-2	470	2020-04-21 11:35:04.039582+03
23668	24	-1	950	2020-04-21 11:40:17.47653+03
23669	95	-1	480	2020-04-21 11:42:06.572524+03
23670	30	-1	1140	2020-04-21 12:14:53.181558+03
23671	37	-1	1290	2020-04-21 12:15:22.1083+03
23672	46	-1	1270	2020-04-21 12:49:13.959402+03
23673	68	-1	490	2020-04-21 12:55:49.638403+03
23674	21	-1	960	2020-04-21 13:19:37.244741+03
23675	1	-1	640	2020-04-21 13:38:23.502037+03
23676	12	-1	1650	2020-04-21 13:41:09.612471+03
23677	41	-1	830	2020-04-21 13:53:08.75124+03
23678	35	-1	670	2020-04-21 14:08:38.889027+03
23679	46	-2	1270	2020-04-21 15:07:14.912728+03
23680	46	-1	1270	2020-04-21 15:07:28.666976+03
23681	18	-1	910	2020-04-21 15:08:12.554735+03
23682	73	-1	960	2020-04-21 15:10:43.791592+03
23683	22	-1	1070	2020-04-21 15:54:13.963461+03
23684	34	-1	1550	2020-04-21 15:58:20.330086+03
23685	37	-1	1290	2020-04-21 16:09:33.306137+03
23686	77	39	354	2020-04-21 16:23:54.226915+03
23687	66	-1	690	2020-04-21 16:25:49.173107+03
23688	88	-2	1270	2020-04-21 16:51:42.986981+03
23689	1	-1	640	2020-04-21 17:27:54.712288+03
23690	47	-1	1480	2020-04-21 17:53:29.337515+03
23691	78	-2	900	2020-04-21 18:27:03.513397+03
23692	20	-1	830	2020-04-21 18:29:00.073715+03
23693	47	-1	1480	2020-04-21 18:42:41.488685+03
23694	47	-1	1480	2020-04-21 18:46:05.652629+03
23695	93	-1	1620	2020-04-21 18:47:43.195288+03
23696	57	-1	1900	2020-04-21 18:56:40.377292+03
23697	27	-1	880	2020-04-21 19:05:53.239995+03
23698	49	-1	970	2020-04-21 19:10:39.940306+03
23699	93	21	811	2020-04-21 19:11:50.67574+03
23700	77	-2	640	2020-04-21 19:15:12.367432+03
23701	56	-1	2460	2020-04-21 19:21:34.630106+03
23702	35	-1	670	2020-04-21 19:27:19.033639+03
23703	27	-1	880	2020-04-21 19:46:56.252214+03
23704	10	-1	2080	2020-04-21 19:48:01.375505+03
23705	47	-1	1480	2020-04-21 20:08:02.199467+03
23706	46	-1	1270	2020-04-21 20:13:32.265087+03
23707	60	-2	2700	2020-04-21 20:57:04.226576+03
23708	12	-1	1650	2020-04-21 21:00:46.899009+03
23709	50	-1	1140	2020-04-21 21:17:49.207337+03
23710	52	-1	1090	2020-04-21 21:42:28.950549+03
23711	29	-1	1940	2020-04-21 21:45:37.687242+03
23712	19	-1	1220	2020-04-21 21:55:09.463431+03
23713	89	-2	1420	2020-04-21 22:29:35.554256+03
23714	45	-3	1590	2020-04-21 22:45:10.106533+03
23715	9	-1	2090	2020-04-21 23:06:15.095429+03
23716	41	-1	830	2020-04-21 23:49:38.518597+03
23717	78	-1	900	2020-04-21 23:57:55.480601+03
23718	86	-1	910	2020-04-22 00:21:54.434336+03
23719	13	-1	460	2020-04-22 01:07:49.963581+03
23720	20	-1	830	2020-04-22 01:11:55.023117+03
23721	55	-1	3480	2020-04-22 01:29:40.827045+03
23722	42	-1	1790	2020-04-22 01:45:13.245089+03
23723	6	-1	980	2020-04-22 01:53:27.425024+03
23724	84	-2	2700	2020-04-22 01:57:57.197917+03
23725	46	-1	1270	2020-04-22 02:07:53.960132+03
23726	65	-1	490	2020-04-22 02:35:31.845434+03
23727	24	-1	950	2020-04-22 02:46:24.357512+03
23728	64	-1	970	2020-04-22 03:14:57.01394+03
23729	57	-1	1900	2020-04-22 03:21:04.662291+03
23730	56	-1	2460	2020-04-22 03:27:05.789913+03
23731	90	33	872	2020-04-22 03:39:17.170688+03
23732	14	-2	1350	2020-04-22 04:21:49.99738+03
23733	86	-1	910	2020-04-22 04:27:48.402207+03
23734	86	-1	910	2020-04-22 04:59:24.057012+03
23735	28	-1	1860	2020-04-22 05:07:38.398834+03
23736	14	-1	1350	2020-04-22 06:07:21.956944+03
23737	87	-1	2320	2020-04-22 06:57:54.9972+03
23738	63	-1	1780	2020-04-22 08:47:22.620941+03
23739	64	-1	970	2020-04-22 08:53:57.071589+03
23740	22	-1	1070	2020-04-22 09:08:01.131862+03
23741	24	-1	950	2020-04-22 09:46:22.332161+03
23742	11	-1	830	2020-04-22 09:55:06.647078+03
23743	13	-1	460	2020-04-22 09:56:33.198308+03
23744	76	-1	1070	2020-04-22 10:34:54.564115+03
23745	5	-1	1620	2020-04-22 10:50:05.247266+03
23746	77	-1	640	2020-04-22 10:56:11.217009+03
23747	33	-1	900	2020-04-22 11:01:45.95459+03
23748	59	-1	1030	2020-04-22 11:06:25.883811+03
23749	57	-2	1900	2020-04-22 11:10:45.556846+03
23750	47	-1	1480	2020-04-22 11:15:46.231042+03
23751	21	-1	960	2020-04-22 11:19:57.976348+03
23752	49	-1	970	2020-04-22 11:48:20.000649+03
23753	21	-1	960	2020-04-22 12:24:00.966805+03
23754	49	-1	970	2020-04-22 12:39:08.457193+03
23755	64	-1	970	2020-04-22 12:40:59.668938+03
23756	6	-1	980	2020-04-22 12:58:45.605654+03
23757	86	-1	910	2020-04-22 13:03:44.964403+03
23758	81	-1	1620	2020-04-22 13:31:09.716152+03
23759	46	-1	1270	2020-04-22 13:54:46.09414+03
23760	62	-1	1220	2020-04-22 14:07:27.198964+03
23761	29	-1	1940	2020-04-22 14:23:50.227074+03
23762	91	-1	1620	2020-04-22 14:43:15.782282+03
23763	1	-1	640	2020-04-22 14:45:20.119803+03
23764	19	-1	1220	2020-04-22 14:53:43.318194+03
23765	57	-1	1900	2020-04-22 15:53:18.079507+03
23766	61	27	845	2020-04-22 15:56:41.27607+03
23767	23	-2	4390	2020-04-22 16:12:16.317434+03
23768	4	-1	1420	2020-04-22 16:25:24.41189+03
23769	40	-2	1430	2020-04-22 16:40:36.551008+03
23770	87	-1	2320	2020-04-22 17:40:55.061417+03
23771	71	-1	1030	2020-04-22 17:48:13.275283+03
23772	50	-1	1140	2020-04-22 17:59:36.829578+03
23773	5	-2	1620	2020-04-22 18:06:31.33381+03
23774	42	-1	1790	2020-04-22 18:50:13.765514+03
23775	88	-1	1270	2020-04-22 19:10:03.800381+03
23776	23	-2	4390	2020-04-22 19:12:10.201809+03
23777	52	-1	1090	2020-04-22 19:21:10.076599+03
23778	77	-1	640	2020-04-22 19:39:02.267984+03
23779	5	-1	1620	2020-04-22 20:02:04.084053+03
23780	38	-1	1100	2020-04-22 20:03:17.673614+03
23781	5	-1	1620	2020-04-22 20:12:08.111691+03
23782	10	-1	2080	2020-04-22 20:19:23.53301+03
23783	31	-1	1190	2020-04-22 20:50:59.704449+03
23784	38	-1	1100	2020-04-22 20:56:51.350149+03
23785	56	-1	2460	2020-04-22 21:28:03.299146+03
23786	86	-1	910	2020-04-22 22:02:15.302741+03
23787	51	-1	1310	2020-04-22 22:11:44.026076+03
23788	26	-1	390	2020-04-22 22:19:36.948466+03
23789	25	-2	1100	2020-04-22 22:24:08.480908+03
23790	68	-2	490	2020-04-22 22:30:59.913147+03
23791	44	-1	500	2020-04-22 22:45:18.8898+03
23792	29	-1	1940	2020-04-22 22:59:03.579469+03
23793	73	-1	960	2020-04-23 00:28:26.299916+03
23794	84	-1	2700	2020-04-23 00:30:28.415271+03
23795	28	-1	1860	2020-04-23 00:34:30.293577+03
23796	34	-1	1550	2020-04-23 01:10:35.565742+03
23797	17	-1	1500	2020-04-23 01:17:57.016597+03
23798	60	-1	2700	2020-04-23 01:48:40.197432+03
23799	10	-1	2080	2020-04-23 01:51:14.914902+03
23800	10	-1	2080	2020-04-23 02:49:57.084962+03
23801	34	-1	1550	2020-04-23 03:07:09.490731+03
23802	17	-2	1500	2020-04-23 03:28:38.173559+03
23803	47	-1	1480	2020-04-23 03:32:10.920909+03
23804	12	-1	1650	2020-04-23 03:34:32.146254+03
23805	84	-2	2700	2020-04-23 04:44:11.493499+03
23806	37	-1	1290	2020-04-23 05:07:18.982896+03
23807	21	-1	960	2020-04-23 05:11:23.894557+03
23808	68	-3	490	2020-04-23 05:20:28.045636+03
23809	46	-1	1270	2020-04-23 05:27:49.145478+03
23810	35	-1	670	2020-04-23 05:30:18.604418+03
23811	63	-1	1780	2020-04-23 06:15:57.439292+03
23812	61	-2	1510	2020-04-23 06:51:16.624661+03
23813	31	-1	1190	2020-04-23 06:51:44.111686+03
23814	70	-1	760	2020-04-23 07:10:25.046914+03
23815	52	-1	1090	2020-04-23 07:19:37.312319+03
23816	59	-1	1030	2020-04-23 07:31:26.987324+03
23817	7	-1	810	2020-04-23 07:55:38.491992+03
23818	81	-1	1620	2020-04-23 07:56:10.73985+03
23819	11	-1	830	2020-04-23 08:05:20.176608+03
23820	27	-1	880	2020-04-23 08:07:09.264117+03
23821	10	-1	2080	2020-04-23 08:21:44.402911+03
23822	21	-2	960	2020-04-23 09:11:23.956881+03
23823	43	-1	380	2020-04-23 09:31:08.138574+03
23824	89	-1	1420	2020-04-23 09:32:14.654397+03
23825	37	-1	1290	2020-04-23 09:41:47.616254+03
23826	77	-1	640	2020-04-23 09:45:10.779112+03
23827	40	-1	1430	2020-04-23 09:47:02.036832+03
23828	1	-1	640	2020-04-23 10:18:45.343226+03
23829	35	-1	670	2020-04-23 10:21:18.38182+03
23830	94	-2	1230	2020-04-23 10:34:03.837247+03
23831	42	-1	1790	2020-04-23 10:53:32.449342+03
23832	47	-1	1480	2020-04-23 10:56:29.446339+03
23833	35	-2	670	2020-04-23 11:10:37.70164+03
23834	44	-1	500	2020-04-23 11:16:18.224659+03
23835	60	-1	2700	2020-04-23 11:19:50.155548+03
23836	18	-1	910	2020-04-23 11:30:28.64172+03
23837	45	-1	1590	2020-04-23 12:05:01.842435+03
23838	95	-1	480	2020-04-23 13:02:04.703826+03
23839	95	-1	480	2020-04-23 13:07:48.723254+03
23840	87	-1	2320	2020-04-23 13:11:43.626904+03
23841	91	-1	1620	2020-04-23 13:11:49.2931+03
23842	21	-2	960	2020-04-23 13:19:48.215601+03
23843	87	-1	2320	2020-04-23 13:20:10.435852+03
23844	22	-2	1070	2020-04-23 13:21:58.461461+03
23845	60	-1	2700	2020-04-23 13:28:15.718015+03
23846	91	-1	1620	2020-04-23 13:48:53.689648+03
23847	4	-1	1420	2020-04-23 13:49:43.974319+03
23848	17	-1	1500	2020-04-23 13:50:45.89937+03
23849	24	-1	950	2020-04-23 13:59:13.010194+03
23850	91	-1	1620	2020-04-23 13:59:57.285288+03
23851	8	-1	1920	2020-04-23 14:13:03.99115+03
23852	46	-2	1270	2020-04-23 14:17:16.234725+03
23853	34	-1	1550	2020-04-23 15:29:45.145449+03
23854	63	-1	1780	2020-04-23 15:32:52.830231+03
23855	76	-1	1070	2020-04-23 16:01:31.01542+03
23856	52	-1	1090	2020-04-23 16:03:14.554691+03
23857	85	-1	730	2020-04-23 16:16:40.721162+03
23858	45	-1	1590	2020-04-23 16:38:53.416083+03
23859	40	-1	1430	2020-04-23 16:42:48.684899+03
23860	37	-1	1290	2020-04-23 16:43:46.91509+03
23861	48	-1	640	2020-04-23 17:52:58.246421+03
23862	33	-2	900	2020-04-23 18:17:14.057898+03
23863	38	31	550	2020-04-23 18:25:12.403201+03
23864	76	-1	1070	2020-04-23 18:36:43.668842+03
23865	33	-1	900	2020-04-23 19:22:14.508535+03
23866	82	-1	560	2020-04-23 19:28:36.216328+03
23867	13	-1	460	2020-04-23 20:42:59.56044+03
23868	34	-2	1550	2020-04-23 21:44:11.761223+03
23869	44	-1	500	2020-04-23 22:09:18.230401+03
23870	53	-2	3120	2020-04-23 22:16:34.982966+03
23871	43	-1	380	2020-04-23 22:29:15.541364+03
23872	96	-1	1570	2020-04-23 22:35:30.753819+03
23873	54	-1	3470	2020-04-23 22:49:01.167597+03
23874	12	-1	1650	2020-04-23 23:02:40.543517+03
23875	29	-1	1940	2020-04-23 23:06:08.992333+03
23876	47	-1	1480	2020-04-23 23:57:57.922295+03
23877	65	-1	490	2020-04-24 00:04:36.997522+03
23878	75	-1	830	2020-04-24 00:11:34.981684+03
23879	58	-1	2830	2020-04-24 00:23:02.406881+03
23880	23	-1	4390	2020-04-24 00:34:16.395143+03
23881	89	-1	1420	2020-04-24 00:40:28.842188+03
23882	59	-1	1030	2020-04-24 01:01:41.416993+03
23883	68	-2	490	2020-04-24 01:18:02.12525+03
23884	94	-1	1230	2020-04-24 02:11:01.190367+03
23885	46	-1	1270	2020-04-24 02:21:00.718669+03
23886	95	-1	480	2020-04-24 02:22:17.20178+03
23887	8	-1	1920	2020-04-24 02:31:35.506568+03
23888	25	-1	1100	2020-04-24 02:50:07.520915+03
23889	51	-1	1310	2020-04-24 03:34:10.258294+03
23890	53	-1	3120	2020-04-24 04:13:53.95396+03
23891	94	-1	1230	2020-04-24 04:15:17.302771+03
23892	55	-2	3480	2020-04-24 04:34:44.918978+03
23893	6	-1	980	2020-04-24 04:53:50.943942+03
23894	72	-1	620	2020-04-24 05:41:37.135662+03
23895	8	31	1137	2020-04-24 06:01:10.726863+03
23896	73	-1	960	2020-04-24 06:29:41.20703+03
23897	39	-1	910	2020-04-24 06:30:52.096647+03
23898	55	-1	3480	2020-04-24 06:38:27.055371+03
23899	83	-1	1230	2020-04-24 06:52:13.50286+03
23900	45	-1	1590	2020-04-24 07:25:52.269129+03
23901	95	-1	480	2020-04-24 07:36:59.948861+03
23902	35	-1	670	2020-04-24 07:51:24.583318+03
23903	49	-1	970	2020-04-24 08:03:26.257309+03
23904	94	-1	1230	2020-04-24 08:33:59.174724+03
23905	48	-1	640	2020-04-24 08:49:40.663905+03
23906	39	34	547	2020-04-24 08:54:44.305557+03
23907	36	-1	630	2020-04-24 09:12:54.484167+03
23908	79	-1	550	2020-04-24 09:33:47.247199+03
23909	8	-2	1920	2020-04-24 09:38:48.210417+03
23910	18	-1	910	2020-04-24 09:46:03.579786+03
23911	43	-1	380	2020-04-24 09:55:17.66082+03
23912	76	-2	1070	2020-04-24 10:07:39.25115+03
23913	20	-1	830	2020-04-24 10:25:29.762822+03
23914	39	-1	910	2020-04-24 10:46:04.912847+03
23915	42	-1	1790	2020-04-24 10:48:38.938621+03
23916	83	-2	1230	2020-04-24 10:49:29.299974+03
23917	33	-1	900	2020-04-24 10:53:57.035781+03
23918	17	-1	1500	2020-04-24 11:04:52.03206+03
23919	54	-1	3470	2020-04-24 11:23:13.678573+03
23920	78	-2	900	2020-04-24 11:31:40.11038+03
23921	46	-1	1270	2020-04-24 11:38:39.03089+03
23922	19	-1	1220	2020-04-24 12:11:26.177596+03
23923	32	-1	710	2020-04-24 12:23:08.867058+03
23924	38	-1	1100	2020-04-24 12:36:30.813455+03
23925	88	-1	1270	2020-04-24 12:49:07.564864+03
23926	75	-1	830	2020-04-24 12:52:47.837977+03
23927	26	-1	390	2020-04-24 13:02:08.686427+03
23928	16	-1	1380	2020-04-24 13:04:35.17352+03
23929	12	39	917	2020-04-24 13:08:45.592353+03
23930	78	-2	900	2020-04-24 13:21:58.812218+03
23931	39	-1	910	2020-04-24 13:27:34.279707+03
23932	34	-1	1550	2020-04-24 13:29:08.783839+03
23933	25	-1	1100	2020-04-24 13:29:44.605199+03
23934	71	-1	1030	2020-04-24 13:40:04.981315+03
23935	18	-1	910	2020-04-24 13:41:38.088947+03
23936	92	-1	630	2020-04-24 13:49:36.067199+03
23937	36	-1	630	2020-04-24 13:56:34.790014+03
23938	9	-1	2090	2020-04-24 14:04:02.275668+03
23939	81	-1	1620	2020-04-24 14:09:11.834564+03
23940	77	-2	640	2020-04-24 14:09:32.399131+03
23941	58	-1	2830	2020-04-24 14:23:01.778127+03
23942	3	-2	660	2020-04-24 14:35:40.530705+03
23943	64	-1	970	2020-04-24 14:48:03.354207+03
23944	56	-1	2460	2020-04-24 14:58:24.78885+03
23945	1	-2	640	2020-04-24 15:07:06.590597+03
23946	53	-2	3120	2020-04-24 16:06:17.664183+03
23947	96	-1	1570	2020-04-24 16:27:35.328049+03
23948	18	-1	910	2020-04-24 16:35:41.273495+03
23949	5	-2	1620	2020-04-24 16:37:20.222019+03
23950	90	-1	1780	2020-04-24 16:46:10.248651+03
23951	90	-1	1780	2020-04-24 16:46:34.617605+03
23952	78	-3	900	2020-04-24 17:16:06.422516+03
23953	36	-2	630	2020-04-24 17:39:02.664759+03
23954	74	-2	1010	2020-04-24 18:05:11.871278+03
23955	15	-1	2830	2020-04-24 18:06:47.715496+03
23956	22	-1	1070	2020-04-24 18:13:25.431824+03
23957	51	-1	1310	2020-04-24 18:29:05.012032+03
23958	91	-1	1620	2020-04-24 19:24:32.795945+03
23959	72	9	335	2020-04-24 19:38:03.520854+03
23960	18	-1	910	2020-04-24 19:46:35.454362+03
23961	39	-1	910	2020-04-24 19:54:22.381313+03
23962	42	-1	1790	2020-04-24 20:14:31.690805+03
23963	71	30	464	2020-04-24 20:41:38.623572+03
23964	37	-1	1290	2020-04-24 20:43:59.935602+03
23965	64	-1	970	2020-04-24 20:47:04.759198+03
23966	79	-1	550	2020-04-24 21:06:08.696791+03
23967	69	-1	1100	2020-04-24 21:39:05.274849+03
23968	85	-1	730	2020-04-24 21:41:08.861788+03
23969	96	-1	1570	2020-04-24 21:46:20.988562+03
23970	1	-1	640	2020-04-24 21:56:05.120113+03
23971	41	-1	830	2020-04-24 22:16:06.528828+03
23972	95	-1	480	2020-04-24 22:44:11.568059+03
23973	29	-2	1940	2020-04-24 22:44:14.199797+03
23974	75	-2	830	2020-04-24 23:10:32.547218+03
23975	58	-1	2830	2020-04-24 23:16:29.986531+03
23976	85	-1	730	2020-04-24 23:58:24.295566+03
23977	40	-1	1430	2020-04-25 00:07:37.120408+03
23978	3	-1	660	2020-04-25 00:20:47.654282+03
23979	37	-2	1290	2020-04-25 00:22:39.356868+03
23980	95	-1	480	2020-04-25 01:20:18.384492+03
23981	77	-1	640	2020-04-25 01:20:50.542041+03
23982	16	-1	1380	2020-04-25 02:26:26.566186+03
23983	59	-1	1030	2020-04-25 02:34:19.852695+03
23984	55	-1	3480	2020-04-25 02:41:47.499363+03
23985	43	-2	380	2020-04-25 02:49:49.16794+03
23986	31	-1	1190	2020-04-25 03:03:38.582009+03
23987	87	-1	2320	2020-04-25 03:03:56.336529+03
23988	42	-1	1790	2020-04-25 03:16:13.998059+03
23989	94	-1	1230	2020-04-25 04:32:08.301026+03
23990	52	-1	1090	2020-04-25 04:35:30.283456+03
23991	84	-1	2700	2020-04-25 04:43:59.255097+03
23992	47	-1	1480	2020-04-25 04:51:29.2996+03
23993	22	-1	1070	2020-04-25 04:58:46.313437+03
23994	77	-1	640	2020-04-25 05:06:18.268664+03
23995	58	-2	2830	2020-04-25 05:17:53.851741+03
23996	62	-1	1220	2020-04-25 05:51:58.771355+03
23997	1	-1	640	2020-04-25 06:41:55.037915+03
23998	40	-1	1430	2020-04-25 06:44:10.332629+03
23999	77	-2	640	2020-04-25 06:49:12.215809+03
24000	21	-1	960	2020-04-25 06:49:52.605578+03
24001	32	-2	710	2020-04-25 06:56:46.304507+03
24002	10	-1	2080	2020-04-25 06:57:17.603446+03
24003	91	-1	1620	2020-04-25 07:00:21.265624+03
24004	75	-2	830	2020-04-25 07:06:05.043837+03
24005	49	-1	970	2020-04-25 07:08:15.873096+03
24006	85	-2	730	2020-04-25 07:54:57.022128+03
24007	36	-1	630	2020-04-25 07:58:18.59899+03
24008	39	-1	910	2020-04-25 08:16:20.425899+03
24009	90	-1	1780	2020-04-25 08:22:55.83489+03
24010	46	-1	1270	2020-04-25 08:24:09.1925+03
24011	6	-1	980	2020-04-25 08:28:50.504998+03
24012	49	-1	970	2020-04-25 08:37:08.646625+03
24013	14	-2	1350	2020-04-25 09:12:13.46582+03
24014	74	24	425	2020-04-25 09:19:14.812519+03
24015	7	-1	810	2020-04-25 10:16:51.101285+03
24016	62	-1	1220	2020-04-25 10:22:29.290509+03
24017	57	-1	1900	2020-04-25 10:22:55.008861+03
24018	92	-1	630	2020-04-25 10:28:20.690401+03
24019	19	32	705	2020-04-25 11:04:49.522664+03
24020	88	-2	1270	2020-04-25 11:05:16.348192+03
24021	84	-2	2700	2020-04-25 11:05:37.927369+03
24022	27	-1	880	2020-04-25 11:16:50.985778+03
24023	93	-1	1620	2020-04-25 11:44:50.823894+03
24024	83	-1	1230	2020-04-25 11:56:47.126853+03
24025	54	-1	3470	2020-04-25 12:26:19.526006+03
24026	31	-1	1190	2020-04-25 13:07:01.344162+03
24027	71	-1	1030	2020-04-25 13:29:36.837432+03
24028	67	-1	350	2020-04-25 13:48:22.690668+03
24029	80	-1	1120	2020-04-25 14:22:22.535415+03
24030	38	-1	1100	2020-04-25 14:30:58.327561+03
24031	69	-1	1100	2020-04-25 14:32:55.235439+03
24032	2	-1	470	2020-04-25 14:34:39.731624+03
24033	85	-1	730	2020-04-25 14:44:07.099714+03
24034	76	-1	1070	2020-04-25 14:47:59.943051+03
24035	78	-2	900	2020-04-25 14:48:33.933758+03
24036	10	-1	2080	2020-04-25 15:25:20.344601+03
24037	53	-1	3120	2020-04-25 15:34:10.484412+03
24038	41	-1	830	2020-04-25 15:34:54.557103+03
24039	43	-1	380	2020-04-25 15:41:29.074132+03
24040	29	-1	1940	2020-04-25 15:46:36.515433+03
24041	53	-1	3120	2020-04-25 16:13:28.217838+03
24042	61	-1	1510	2020-04-25 16:47:41.32455+03
24043	26	-1	390	2020-04-25 16:50:21.833029+03
24044	16	-1	1380	2020-04-25 16:53:09.127388+03
24045	46	-1	1270	2020-04-25 16:58:24.809433+03
24046	89	-1	1420	2020-04-25 17:00:28.553707+03
24047	52	-1	1090	2020-04-25 17:05:52.103515+03
24048	53	-1	3120	2020-04-25 17:29:16.636241+03
24049	44	-1	500	2020-04-25 17:46:12.993264+03
24050	84	-1	2700	2020-04-25 17:48:25.685088+03
24051	67	-1	350	2020-04-25 18:00:59.404637+03
24052	83	-2	1230	2020-04-25 18:09:01.413838+03
24053	2	-1	470	2020-04-25 18:19:55.010411+03
24054	5	-1	1620	2020-04-25 18:33:51.311633+03
24055	88	-1	1270	2020-04-25 18:39:39.42656+03
24056	89	-1	1420	2020-04-25 18:44:26.641622+03
24057	27	-1	880	2020-04-25 18:56:13.525755+03
24058	94	-1	1230	2020-04-25 19:48:17.302951+03
24059	84	-1	2700	2020-04-25 19:59:30.373344+03
24060	91	-1	1620	2020-04-25 20:21:19.761471+03
24061	1	-2	640	2020-04-25 20:23:38.656069+03
24062	74	-1	1010	2020-04-25 20:25:27.884099+03
24063	80	-1	1120	2020-04-25 20:26:46.703473+03
24064	45	-1	1590	2020-04-25 20:56:18.112751+03
24065	77	-1	640	2020-04-25 20:57:15.516452+03
24066	58	-1	2830	2020-04-25 21:02:28.292429+03
24067	5	-1	1620	2020-04-25 21:32:21.211179+03
24068	89	-1	1420	2020-04-25 21:35:23.50884+03
24069	19	-1	1220	2020-04-25 21:36:05.837982+03
24070	59	-1	1030	2020-04-25 21:36:29.80418+03
24071	48	-1	640	2020-04-25 21:41:25.58405+03
24072	37	39	736	2020-04-25 21:50:19.617437+03
24073	37	-1	1290	2020-04-25 22:05:04.597517+03
24074	46	-1	1270	2020-04-25 22:09:38.526708+03
24075	81	-2	1620	2020-04-25 22:20:24.882581+03
24076	46	-1	1270	2020-04-25 22:26:18.8088+03
24077	49	-1	970	2020-04-25 22:26:46.866362+03
24078	63	-1	1780	2020-04-25 22:27:57.748716+03
24079	76	-2	1070	2020-04-25 22:45:10.081222+03
24080	71	-1	1030	2020-04-25 23:11:24.28612+03
24081	61	-1	1510	2020-04-25 23:23:03.594094+03
24082	83	-2	1230	2020-04-25 23:55:15.411347+03
24083	37	-2	1290	2020-04-26 00:23:51.116513+03
24084	19	-1	1220	2020-04-26 00:41:02.387471+03
24085	73	-1	960	2020-04-26 01:01:16.658207+03
24086	7	-1	810	2020-04-26 01:05:59.370927+03
24087	83	-1	1230	2020-04-26 01:06:11.943912+03
24088	76	-1	1070	2020-04-26 01:22:14.589573+03
24089	51	-2	1310	2020-04-26 01:51:54.771727+03
24090	41	-1	830	2020-04-26 02:16:49.232318+03
24091	68	-1	490	2020-04-26 02:26:53.488749+03
24092	78	-2	900	2020-04-26 02:36:46.32882+03
24093	96	-1	1570	2020-04-26 04:11:54.250525+03
24094	30	-1	1140	2020-04-26 04:13:21.869993+03
24095	22	-1	1070	2020-04-26 04:15:17.742532+03
24096	29	-1	1940	2020-04-26 04:16:11.353569+03
24097	15	-1	2830	2020-04-26 04:18:07.858088+03
24098	12	-1	1650	2020-04-26 04:59:55.828012+03
24099	55	-2	3480	2020-04-26 05:06:21.910052+03
24100	15	-1	2830	2020-04-26 05:23:15.872436+03
24101	26	-1	390	2020-04-26 06:02:29.838502+03
24102	57	-1	1900	2020-04-26 06:06:13.39441+03
24103	34	-2	1550	2020-04-26 06:16:26.130748+03
24104	88	-1	1270	2020-04-26 06:53:27.571299+03
24105	11	26	480	2020-04-26 07:27:50.946911+03
24106	14	-1	1350	2020-04-26 07:28:19.573919+03
24107	12	-1	1650	2020-04-26 07:28:30.37113+03
24108	79	-1	550	2020-04-26 07:51:19.177308+03
24109	10	-1	2080	2020-04-26 07:53:32.62582+03
24110	60	-1	2700	2020-04-26 08:08:19.859686+03
24111	13	-3	460	2020-04-26 08:57:02.990262+03
24112	37	-1	1290	2020-04-26 09:14:17.090571+03
24113	56	-2	2460	2020-04-26 09:18:03.647278+03
24114	46	-1	1270	2020-04-26 09:20:03.44454+03
24115	26	-1	390	2020-04-26 09:34:28.922856+03
24116	88	-1	1270	2020-04-26 09:55:32.471548+03
24117	26	-1	390	2020-04-26 10:12:40.492177+03
24118	80	-2	1120	2020-04-26 10:24:35.54917+03
24119	83	-1	1230	2020-04-26 10:34:07.834209+03
24120	31	-2	1190	2020-04-26 10:38:35.388528+03
24121	88	-1	1270	2020-04-26 10:38:54.315341+03
24122	47	-1	1480	2020-04-26 10:58:41.341696+03
24123	27	-1	880	2020-04-26 11:17:24.789691+03
24124	32	25	338	2020-04-26 11:29:48.679054+03
24125	52	-1	1090	2020-04-26 11:40:33.100573+03
24126	55	-1	3480	2020-04-26 11:42:39.170336+03
24127	58	-1	2830	2020-04-26 12:13:32.957409+03
24128	3	-1	660	2020-04-26 12:23:15.097086+03
24129	10	-1	2080	2020-04-26 12:25:13.113368+03
24130	40	-1	1430	2020-04-26 12:43:56.637057+03
24131	52	-1	1090	2020-04-26 12:59:32.455906+03
24132	11	-2	830	2020-04-26 13:26:55.65995+03
24133	47	-1	1480	2020-04-26 13:41:44.683584+03
24134	5	29	954	2020-04-26 14:05:14.357727+03
24135	37	-1	1290	2020-04-26 14:22:26.40064+03
24136	48	-1	640	2020-04-26 14:24:40.218414+03
24137	4	-2	1420	2020-04-26 14:37:40.205628+03
24138	83	-1	1230	2020-04-26 14:53:33.06337+03
24139	42	-2	1790	2020-04-26 15:04:54.956661+03
24140	13	-1	460	2020-04-26 15:13:20.232232+03
24141	67	-1	350	2020-04-26 15:13:28.428428+03
24142	1	-1	640	2020-04-26 15:16:38.751799+03
24143	37	-2	1290	2020-04-26 16:03:54.056582+03
24144	45	-1	1590	2020-04-26 16:14:41.204956+03
24145	30	-1	1140	2020-04-26 16:36:26.588328+03
24146	10	-1	2080	2020-04-26 16:51:06.326599+03
24147	36	-2	630	2020-04-26 16:52:50.371875+03
24148	37	-1	1290	2020-04-26 16:59:41.312127+03
24149	71	-1	1030	2020-04-26 17:00:40.784437+03
24150	59	-2	1030	2020-04-26 17:28:43.241529+03
24151	15	-1	2830	2020-04-26 17:50:14.366667+03
24152	40	-1	1430	2020-04-26 17:50:35.378843+03
24153	29	-2	1940	2020-04-26 17:50:54.690313+03
24154	26	-1	390	2020-04-26 17:55:01.321142+03
24155	5	-1	1620	2020-04-26 18:06:33.659283+03
24156	66	-1	690	2020-04-26 18:20:01.6612+03
24157	13	-1	460	2020-04-26 18:28:23.363085+03
24158	79	-1	550	2020-04-26 18:30:51.547698+03
24159	10	-1	2080	2020-04-26 18:43:55.961683+03
24160	93	-1	1620	2020-04-26 18:47:44.56801+03
24161	70	-1	760	2020-04-26 18:59:51.859475+03
24162	3	-1	660	2020-04-26 19:48:19.836194+03
24163	83	-2	1230	2020-04-26 20:05:21.822238+03
24164	3	-1	660	2020-04-26 20:49:58.384288+03
24165	8	-1	1920	2020-04-26 21:10:03.507144+03
24166	63	-1	1780	2020-04-26 21:37:09.399655+03
24167	32	-1	710	2020-04-26 21:54:28.858687+03
24168	37	-1	1290	2020-04-26 22:09:54.11176+03
24169	51	-1	1310	2020-04-26 22:10:59.835325+03
24170	89	-1	1420	2020-04-26 22:27:18.151423+03
24171	84	-1	2700	2020-04-26 22:28:47.240184+03
24172	91	-1	1620	2020-04-26 22:36:02.678672+03
24173	19	-1	1220	2020-04-26 22:38:45.085421+03
24174	5	-2	1620	2020-04-26 23:01:53.119283+03
24175	17	-2	1500	2020-04-26 23:35:11.958642+03
24176	80	-2	1120	2020-04-26 23:48:57.872621+03
24177	94	-1	1230	2020-04-26 23:55:01.737618+03
24178	52	-1	1090	2020-04-27 00:10:54.638139+03
24179	63	-1	1780	2020-04-27 00:18:33.286719+03
24180	23	-1	4390	2020-04-27 00:34:30.008113+03
24181	64	-1	970	2020-04-27 00:41:48.217873+03
24182	57	-1	1900	2020-04-27 01:51:23.705219+03
24183	84	-1	2700	2020-04-27 02:09:00.195621+03
24184	96	-1	1570	2020-04-27 02:28:44.294945+03
24185	40	-1	1430	2020-04-27 02:29:09.838381+03
24186	39	-1	910	2020-04-27 02:34:14.437908+03
24187	22	-1	1070	2020-04-27 02:56:14.755104+03
24188	56	-1	2460	2020-04-27 03:02:14.916081+03
24189	37	-2	1290	2020-04-27 03:05:19.220819+03
24190	59	-1	1030	2020-04-27 03:50:49.846971+03
24191	64	-2	970	2020-04-27 04:05:44.200105+03
24192	69	-1	1100	2020-04-27 04:12:58.463029+03
24193	69	-1	1100	2020-04-27 04:20:24.448723+03
24194	20	-1	830	2020-04-27 04:26:34.998763+03
24195	18	-1	910	2020-04-27 04:56:14.622589+03
24196	25	-1	1100	2020-04-27 05:10:59.883042+03
24197	41	-2	830	2020-04-27 05:38:05.843954+03
24198	86	-1	910	2020-04-27 05:43:27.907348+03
24199	93	-1	1620	2020-04-27 06:29:59.082899+03
24200	90	-3	1780	2020-04-27 06:32:36.777534+03
24201	46	-1	1270	2020-04-27 06:34:29.507988+03
24202	13	-2	460	2020-04-27 06:38:13.419699+03
24203	1	-1	640	2020-04-27 06:53:38.966715+03
24204	42	-1	1790	2020-04-27 07:04:01.008536+03
24205	8	-1	1920	2020-04-27 07:26:33.0237+03
24206	6	47	451	2020-04-27 08:14:36.782879+03
24207	68	-1	490	2020-04-27 08:30:33.548097+03
24208	34	-1	1550	2020-04-27 08:32:47.951924+03
24209	21	-2	960	2020-04-27 08:44:16.177617+03
24210	39	-2	910	2020-04-27 08:46:03.770086+03
24211	77	-1	640	2020-04-27 08:52:54.396686+03
24212	87	-2	2320	2020-04-27 08:57:11.293503+03
24213	22	-1	1070	2020-04-27 09:23:12.05318+03
24214	49	-2	970	2020-04-27 09:31:42.418097+03
24215	89	-1	1420	2020-04-27 10:11:47.828993+03
24216	44	-1	500	2020-04-27 10:16:42.67594+03
24217	42	-1	1790	2020-04-27 10:56:04.117535+03
24218	60	-1	2700	2020-04-27 11:05:19.150493+03
24219	11	-1	830	2020-04-27 11:11:51.748662+03
24220	78	-1	900	2020-04-27 11:24:56.020898+03
24221	37	-1	1290	2020-04-27 12:14:06.771886+03
24222	70	-1	760	2020-04-27 12:31:47.307123+03
24223	25	-2	1100	2020-04-27 12:42:46.375826+03
24224	95	-1	480	2020-04-27 13:18:23.053806+03
24225	25	-1	1100	2020-04-27 13:53:09.496744+03
24226	68	-1	490	2020-04-27 14:07:02.461721+03
24227	38	-1	1100	2020-04-27 14:07:40.473577+03
24228	56	-2	2460	2020-04-27 14:19:26.30076+03
24229	2	-1	470	2020-04-27 14:27:58.373548+03
24230	62	-1	1220	2020-04-27 14:34:22.440037+03
24231	36	-1	630	2020-04-27 15:01:01.68466+03
24232	73	-1	960	2020-04-27 15:23:24.548515+03
24233	85	-1	730	2020-04-27 15:32:45.053674+03
24234	65	-1	490	2020-04-27 16:02:30.551024+03
24235	37	-1	1290	2020-04-27 16:19:09.867308+03
24236	32	-1	710	2020-04-27 16:47:21.785118+03
24237	94	-1	1230	2020-04-27 16:48:47.618464+03
24238	86	-1	910	2020-04-27 16:49:08.918298+03
24239	64	-1	970	2020-04-27 17:06:12.95698+03
24240	49	-1	970	2020-04-27 17:22:07.48922+03
24241	39	-2	910	2020-04-27 17:26:09.648995+03
24242	86	-1	910	2020-04-27 17:30:32.302466+03
24243	53	-1	3120	2020-04-27 17:41:09.520532+03
24244	73	-1	960	2020-04-27 17:47:16.134169+03
24245	76	-2	1070	2020-04-27 18:04:04.318722+03
24246	19	-1	1220	2020-04-27 18:04:37.284773+03
24247	49	-1	970	2020-04-27 18:19:09.337822+03
24248	35	-1	670	2020-04-27 18:45:47.370161+03
24249	61	-1	1510	2020-04-27 19:47:36.369316+03
24250	67	-1	350	2020-04-27 19:50:34.786083+03
24251	33	-1	900	2020-04-27 20:02:56.552137+03
24252	77	-1	640	2020-04-27 20:12:54.407296+03
24253	51	-2	1310	2020-04-27 20:24:30.891717+03
24254	38	-1	1100	2020-04-27 20:25:57.163998+03
24255	65	-2	490	2020-04-27 20:31:24.172345+03
24256	17	-2	1500	2020-04-27 20:32:00.406559+03
24257	20	-1	830	2020-04-27 20:34:05.005255+03
24258	90	-1	1780	2020-04-27 20:54:35.081985+03
24259	80	-1	1120	2020-04-27 21:33:34.937322+03
24260	7	-1	810	2020-04-27 21:37:05.337595+03
24261	24	-1	950	2020-04-27 21:54:09.008772+03
24262	46	-2	1270	2020-04-27 22:22:59.537147+03
24263	26	-1	390	2020-04-27 22:26:27.152983+03
24264	49	-2	970	2020-04-27 22:40:07.134729+03
24265	74	-1	1010	2020-04-27 22:47:58.293826+03
24266	30	-1	1140	2020-04-27 23:12:53.141899+03
24267	88	-1	1270	2020-04-27 23:20:18.874208+03
24268	77	-1	640	2020-04-27 23:21:48.58809+03
24269	74	-1	1010	2020-04-27 23:58:48.501575+03
24270	59	-1	1030	2020-04-27 23:59:14.138083+03
24271	49	-1	970	2020-04-28 00:44:44.247021+03
24272	39	-1	910	2020-04-28 00:53:09.037861+03
24273	36	-1	630	2020-04-28 01:07:33.217774+03
24274	72	-2	620	2020-04-28 01:08:23.772399+03
24275	17	29	844	2020-04-28 01:32:03.804419+03
24276	76	-2	1070	2020-04-28 01:36:42.746231+03
24277	84	-1	2700	2020-04-28 02:08:24.694225+03
24278	31	-1	1190	2020-04-28 02:09:10.88873+03
24279	46	-1	1270	2020-04-28 02:26:08.91974+03
24280	20	-1	830	2020-04-28 03:08:31.512967+03
24281	63	-2	1780	2020-04-28 03:12:52.809015+03
24282	81	27	694	2020-04-28 03:13:59.627884+03
24283	83	-1	1230	2020-04-28 03:19:37.409997+03
24284	46	-1	1270	2020-04-28 03:38:11.26061+03
24285	64	-1	970	2020-04-28 03:50:37.216847+03
24286	71	-2	1030	2020-04-28 04:15:23.253205+03
24287	27	-1	880	2020-04-28 04:32:31.655007+03
24288	18	-1	910	2020-04-28 04:34:37.934809+03
24289	42	-1	1790	2020-04-28 04:37:59.317328+03
24290	34	-1	1550	2020-04-28 04:43:04.451913+03
24291	64	-1	970	2020-04-28 04:49:03.106003+03
24292	69	-1	1100	2020-04-28 05:33:02.632943+03
24293	1	-1	640	2020-04-28 05:45:01.44196+03
24294	13	-1	460	2020-04-28 06:05:13.336259+03
24295	87	-1	2320	2020-04-28 06:27:52.179279+03
24296	39	-1	910	2020-04-28 08:02:44.199832+03
24297	75	-1	830	2020-04-28 08:18:39.879187+03
24298	77	-1	640	2020-04-28 09:01:04.204824+03
24299	51	-2	1310	2020-04-28 09:12:26.394054+03
24300	15	-1	2830	2020-04-28 09:27:44.71061+03
24301	76	-1	1070	2020-04-28 09:39:14.317146+03
24302	71	-1	1030	2020-04-28 09:44:30.428386+03
24303	16	12	795	2020-04-28 09:45:47.999882+03
24304	11	-1	830	2020-04-28 11:29:31.04807+03
24305	57	-1	1900	2020-04-28 11:30:03.507825+03
24306	90	-1	1780	2020-04-28 11:35:37.576924+03
24307	47	-1	1480	2020-04-28 11:48:28.441099+03
24308	38	-1	1100	2020-04-28 11:51:49.132218+03
24309	13	-1	460	2020-04-28 12:46:24.514727+03
24310	86	-1	910	2020-04-28 13:07:27.98621+03
24311	59	-1	1030	2020-04-28 13:11:54.522749+03
24312	60	-1	2700	2020-04-28 14:10:28.29062+03
24313	94	-1	1230	2020-04-28 14:25:14.305984+03
24314	34	-2	1550	2020-04-28 14:32:31.588818+03
24315	33	-2	900	2020-04-28 14:53:37.72631+03
24316	13	-2	460	2020-04-28 15:35:18.279156+03
24317	70	-2	760	2020-04-28 15:36:06.053653+03
24318	39	-1	910	2020-04-28 16:03:41.767584+03
24319	63	-1	1780	2020-04-28 16:27:45.526098+03
24320	12	-1	1650	2020-04-28 16:54:01.765804+03
24321	13	30	194	2020-04-28 16:59:49.35203+03
24322	22	41	620	2020-04-28 17:06:28.397172+03
24323	82	-1	560	2020-04-28 17:28:15.729676+03
24324	94	-2	1230	2020-04-28 17:40:28.969351+03
24325	7	-2	810	2020-04-28 18:26:01.042634+03
24326	39	-2	910	2020-04-28 18:47:16.839328+03
24327	58	-1	2830	2020-04-28 18:54:38.750471+03
24328	34	-1	1550	2020-04-28 19:24:49.444231+03
24329	77	-2	640	2020-04-28 19:42:39.873271+03
24330	32	-1	710	2020-04-28 19:56:37.73567+03
24331	52	-1	1090	2020-04-28 20:31:25.117599+03
24332	7	24	367	2020-04-28 20:39:57.760215+03
24333	44	-2	500	2020-04-28 21:32:04.13644+03
24334	56	-2	2460	2020-04-28 21:40:23.666891+03
24335	96	-1	1570	2020-04-28 21:41:43.950894+03
24336	47	-1	1480	2020-04-28 22:09:05.518352+03
24337	70	-2	760	2020-04-28 22:40:22.940786+03
24338	77	-1	640	2020-04-28 22:54:31.99942+03
24339	48	-1	640	2020-04-28 23:01:41.69451+03
24340	57	-1	1900	2020-04-28 23:17:34.166936+03
24341	4	-1	1420	2020-04-28 23:21:55.285973+03
24342	23	-1	4390	2020-04-29 00:00:04.828489+03
24343	44	-2	500	2020-04-29 00:13:13.344848+03
24344	93	-1	1620	2020-04-29 00:22:04.882413+03
24345	44	-1	500	2020-04-29 00:24:15.927239+03
24346	34	-1	1550	2020-04-29 01:00:44.211575+03
24347	76	-1	1070	2020-04-29 01:19:11.200348+03
24348	75	-1	830	2020-04-29 01:20:52.457366+03
24349	75	-1	830	2020-04-29 01:30:27.386177+03
24350	6	-1	980	2020-04-29 02:43:40.395403+03
24351	67	-1	350	2020-04-29 03:05:34.399972+03
24352	35	26	340	2020-04-29 03:23:54.424086+03
24353	8	-1	1920	2020-04-29 03:31:06.061734+03
24354	12	-1	1650	2020-04-29 03:34:17.411841+03
24355	76	-2	1070	2020-04-29 03:36:26.577165+03
24356	4	-1	1420	2020-04-29 03:40:03.147273+03
24357	10	-1	2080	2020-04-29 03:50:53.121275+03
24358	35	-2	670	2020-04-29 04:09:05.843645+03
24359	37	-1	1290	2020-04-29 04:37:39.118195+03
24360	80	-1	1120	2020-04-29 05:03:21.457507+03
24361	50	27	511	2020-04-29 05:11:09.214211+03
24362	28	16	924	2020-04-29 05:26:14.629414+03
24363	41	-1	830	2020-04-29 05:26:59.676253+03
24364	84	-1	2700	2020-04-29 05:28:03.936289+03
24365	37	-1	1290	2020-04-29 05:32:02.237832+03
24366	53	-1	3120	2020-04-29 05:36:16.477906+03
24367	32	-1	710	2020-04-29 05:53:38.769175+03
24368	48	26	262	2020-04-29 06:02:09.358969+03
24369	66	-1	690	2020-04-29 06:06:11.657655+03
24370	41	-1	830	2020-04-29 07:13:03.219141+03
24371	36	-2	630	2020-04-29 07:21:26.6399+03
24372	74	-1	1010	2020-04-29 07:46:07.020533+03
24373	46	-1	1270	2020-04-29 08:12:21.829046+03
24374	54	-3	3470	2020-04-29 08:33:17.383011+03
24375	92	22	350	2020-04-29 08:57:54.205976+03
24376	80	-1	1120	2020-04-29 09:12:00.471134+03
24377	39	-1	910	2020-04-29 09:14:55.671403+03
24378	65	-1	490	2020-04-29 09:45:49.235503+03
24379	7	-1	810	2020-04-29 10:26:58.980763+03
24380	43	-1	380	2020-04-29 10:32:02.961637+03
24381	94	-1	1230	2020-04-29 10:42:46.993172+03
24382	42	-1	1790	2020-04-29 10:53:54.491862+03
24383	59	-1	1030	2020-04-29 11:09:30.342807+03
24384	63	-1	1780	2020-04-29 11:15:29.284163+03
24385	10	-1	2080	2020-04-29 11:22:01.110658+03
24386	66	-1	690	2020-04-29 11:24:30.223243+03
24387	57	-1	1900	2020-04-29 11:29:39.858397+03
24388	40	-1	1430	2020-04-29 11:34:32.447822+03
24389	39	-1	910	2020-04-29 11:50:49.874029+03
24390	89	-1	1420	2020-04-29 12:25:26.383157+03
24391	67	33	185	2020-04-29 12:27:47.359034+03
24392	6	-2	980	2020-04-29 12:32:20.224584+03
24393	94	-2	1230	2020-04-29 12:36:12.637485+03
24394	59	-1	1030	2020-04-29 12:56:10.379908+03
24395	21	-1	960	2020-04-29 13:08:42.042833+03
24396	64	-1	970	2020-04-29 13:51:55.847586+03
24397	87	-2	2320	2020-04-29 14:11:05.641866+03
24398	85	-1	730	2020-04-29 14:23:03.077198+03
24399	27	-2	880	2020-04-29 14:36:21.369974+03
24400	8	-1	1920	2020-04-29 15:14:25.20997+03
24401	84	-1	2700	2020-04-29 15:15:04.893253+03
24402	92	-1	630	2020-04-29 15:36:02.056774+03
24403	81	-1	1620	2020-04-29 15:56:51.530627+03
24404	81	-1	1620	2020-04-29 16:07:12.130663+03
24405	70	-1	760	2020-04-29 16:18:14.094139+03
24406	76	-1	1070	2020-04-29 16:44:35.037817+03
24407	27	-2	880	2020-04-29 17:11:35.534505+03
24408	10	-1	2080	2020-04-29 17:28:22.885792+03
24409	86	-1	910	2020-04-29 17:44:49.256964+03
24410	59	-1	1030	2020-04-29 17:54:00.942043+03
24411	94	25	512	2020-04-29 18:19:04.196264+03
24412	50	-1	1140	2020-04-29 18:29:26.810608+03
24413	29	-1	1940	2020-04-29 18:33:11.476332+03
24414	87	-1	2320	2020-04-29 18:38:00.617899+03
24415	33	-1	900	2020-04-29 18:39:10.172711+03
24416	57	-2	1900	2020-04-29 18:58:51.437689+03
24417	90	-2	1780	2020-04-29 19:03:59.126266+03
24418	61	-2	1510	2020-04-29 19:25:39.167448+03
24419	13	-1	460	2020-04-29 19:39:42.874547+03
24420	2	-1	470	2020-04-29 19:54:22.303031+03
24421	9	-1	2090	2020-04-29 19:57:43.625017+03
24422	84	-1	2700	2020-04-29 20:27:29.429732+03
24423	67	-2	350	2020-04-29 20:28:41.705302+03
24424	70	-1	760	2020-04-29 20:35:43.502945+03
24425	56	-1	2460	2020-04-29 20:36:16.286606+03
24426	90	-1	1780	2020-04-29 20:45:47.255622+03
24427	58	-1	2830	2020-04-29 20:56:25.032539+03
24428	49	-1	970	2020-04-29 20:58:17.198528+03
24429	58	-1	2830	2020-04-29 21:08:27.684352+03
24430	88	-1	1270	2020-04-29 21:14:57.257269+03
24431	13	-2	460	2020-04-29 21:28:01.924763+03
24432	41	25	471	2020-04-29 21:40:04.383614+03
24433	1	-1	640	2020-04-29 21:53:45.822451+03
24434	50	-1	1140	2020-04-29 21:54:45.620414+03
24435	63	-1	1780	2020-04-29 21:57:56.736119+03
24436	83	-3	1230	2020-04-29 22:39:00.978215+03
24437	24	14	521	2020-04-29 22:41:05.314558+03
24438	33	-1	900	2020-04-29 22:53:01.757826+03
24439	18	-1	910	2020-04-29 22:58:57.263824+03
24440	36	-2	630	2020-04-29 23:23:10.128462+03
24441	37	-1	1290	2020-04-29 23:31:09.350864+03
24442	42	-1	1790	2020-04-29 23:36:03.096132+03
24443	79	-1	550	2020-04-29 23:37:19.471078+03
24444	29	-1	1940	2020-04-29 23:52:07.532543+03
24445	71	-1	1030	2020-04-29 23:54:26.857426+03
24446	76	-2	1070	2020-04-29 23:55:58.069684+03
24447	57	-1	1900	2020-04-30 00:28:33.30714+03
24448	52	-1	1090	2020-04-30 00:31:34.404506+03
24449	60	-1	2700	2020-04-30 00:40:33.031428+03
24450	33	-1	900	2020-04-30 00:48:31.431619+03
24451	59	-1	1030	2020-04-30 01:08:58.942819+03
24452	36	-1	630	2020-04-30 01:11:09.986113+03
24453	95	-1	480	2020-04-30 01:21:57.432693+03
24454	23	31	2161	2020-04-30 01:23:03.563089+03
24455	80	-1	1120	2020-04-30 01:36:54.070282+03
24456	36	-2	630	2020-04-30 02:35:35.309074+03
24457	72	-1	620	2020-04-30 02:42:18.260282+03
24458	13	-1	460	2020-04-30 02:54:19.889586+03
24459	76	-1	1070	2020-04-30 03:03:05.338498+03
24460	67	-1	350	2020-04-30 03:13:58.538114+03
24461	57	-1	1900	2020-04-30 03:19:38.460479+03
24462	24	-1	950	2020-04-30 03:26:10.102888+03
24463	66	-1	690	2020-04-30 04:03:39.073574+03
24464	88	-1	1270	2020-04-30 04:08:37.202987+03
24465	96	-1	1570	2020-04-30 04:44:28.595655+03
24466	71	-1	1030	2020-04-30 05:18:18.412566+03
24467	87	-1	2320	2020-04-30 05:40:15.061851+03
24468	91	-1	1620	2020-04-30 06:31:46.857326+03
24469	80	-1	1120	2020-04-30 07:01:38.01846+03
24470	32	-1	710	2020-04-30 07:05:56.667158+03
24471	68	18	249	2020-04-30 07:22:52.940331+03
24472	91	-1	1620	2020-04-30 07:34:37.555357+03
24473	32	-2	710	2020-04-30 08:01:16.047431+03
24474	63	-1	1780	2020-04-30 08:03:06.187371+03
24475	79	-1	550	2020-04-30 08:07:58.522804+03
24476	35	-1	670	2020-04-30 08:18:12.813356+03
24477	81	-1	1620	2020-04-30 08:19:12.649706+03
24478	10	-1	2080	2020-04-30 08:24:35.069562+03
24479	33	29	441	2020-04-30 08:51:25.909567+03
24480	29	-3	1940	2020-04-30 08:59:15.501787+03
24481	15	-1	2830	2020-04-30 09:00:29.652206+03
24482	58	-1	2830	2020-04-30 09:10:48.465728+03
24483	79	-1	550	2020-04-30 10:19:41.220134+03
24484	3	-2	660	2020-04-30 10:21:09.543861+03
24485	89	-1	1420	2020-04-30 10:35:53.231797+03
24486	17	-1	1500	2020-04-30 10:37:11.045878+03
24487	30	-1	1140	2020-04-30 11:47:52.00839+03
24488	89	-2	1420	2020-04-30 12:12:51.886275+03
24489	42	-1	1790	2020-04-30 12:49:09.544834+03
24490	61	-2	1510	2020-04-30 13:08:54.212732+03
24491	5	-2	1620	2020-04-30 13:09:27.666274+03
24492	86	-1	910	2020-04-30 14:00:20.998325+03
24493	61	-1	1510	2020-04-30 14:04:31.436254+03
24494	37	-2	1290	2020-04-30 14:12:58.392533+03
24495	46	40	723	2020-04-30 14:27:37.266199+03
24496	8	-1	1920	2020-04-30 14:44:33.00958+03
24497	89	-1	1420	2020-04-30 15:19:10.5702+03
24498	46	-2	1270	2020-04-30 16:08:37.692917+03
24499	70	-1	760	2020-04-30 16:21:51.638516+03
24500	10	-1	2080	2020-04-30 16:32:41.391897+03
24501	88	-2	1270	2020-04-30 16:41:20.717202+03
24502	94	-1	1230	2020-04-30 16:56:09.571367+03
24503	3	-1	660	2020-04-30 17:17:42.808003+03
24504	66	-1	690	2020-04-30 17:31:08.21336+03
24505	82	-1	560	2020-04-30 17:37:26.623933+03
24506	22	-2	1070	2020-04-30 17:45:02.797864+03
24507	68	-1	490	2020-04-30 17:55:33.027301+03
24508	64	-1	970	2020-04-30 18:06:18.035537+03
24509	12	-1	1650	2020-04-30 18:09:56.925826+03
24510	74	-3	1010	2020-04-30 18:23:33.38902+03
24511	33	-1	900	2020-04-30 19:12:45.395496+03
24512	46	-1	1270	2020-04-30 19:15:49.17268+03
24513	81	-1	1620	2020-04-30 19:44:40.246975+03
24514	30	-1	1140	2020-04-30 19:49:10.326538+03
24515	35	-1	670	2020-04-30 20:04:58.922208+03
24516	29	-2	1940	2020-04-30 21:07:13.674759+03
24517	13	-1	460	2020-04-30 21:26:22.117919+03
24518	76	-1	1070	2020-04-30 21:26:37.19422+03
24519	27	-2	880	2020-04-30 21:33:17.01409+03
24520	91	-2	1620	2020-04-30 21:42:04.294884+03
24521	75	-1	830	2020-04-30 21:44:40.88072+03
24522	2	-1	470	2020-04-30 21:47:47.434611+03
24523	58	-1	2830	2020-04-30 21:48:31.190593+03
24524	59	-1	1030	2020-04-30 21:49:12.823135+03
24525	22	-2	1070	2020-04-30 22:01:12.032207+03
24526	32	-1	710	2020-04-30 22:02:53.746+03
24527	6	-1	980	2020-04-30 22:19:11.586152+03
24528	28	-1	1860	2020-04-30 22:38:59.59296+03
24529	88	-1	1270	2020-04-30 22:39:30.846953+03
24530	28	-1	1860	2020-04-30 22:40:18.019561+03
24531	47	-3	1480	2020-04-30 22:50:49.601378+03
24532	40	-1	1430	2020-04-30 22:57:57.818196+03
24533	77	-1	640	2020-04-30 22:59:51.007627+03
24534	86	-1	910	2020-04-30 23:05:28.153164+03
24535	31	-1	1190	2020-04-30 23:22:15.919266+03
24536	4	-1	1420	2020-04-30 23:49:30.207324+03
24537	21	-2	960	2020-05-01 00:02:27.112702+03
24538	88	-1	1270	2020-05-01 00:26:32.625678+03
24539	64	-2	970	2020-05-01 00:29:12.084969+03
24540	83	-1	1230	2020-05-01 00:37:02.204297+03
24541	90	-2	1780	2020-05-01 01:06:20.221246+03
24542	96	37	912	2020-05-01 01:14:49.833935+03
24543	37	-2	1290	2020-05-01 01:44:26.192702+03
24544	38	-2	1100	2020-05-01 01:53:09.752347+03
24545	94	-2	1230	2020-05-01 02:05:49.085149+03
24546	60	-1	2700	2020-05-01 02:11:07.887388+03
24547	61	-1	1510	2020-05-01 02:30:09.47629+03
24548	64	-1	970	2020-05-01 02:37:51.825365+03
24549	10	-1	2080	2020-05-01 02:38:37.674145+03
24550	46	-1	1270	2020-05-01 02:44:05.139103+03
24551	56	-1	2460	2020-05-01 03:34:16.825958+03
24552	46	-1	1270	2020-05-01 03:35:09.800727+03
24553	20	-1	830	2020-05-01 03:45:05.325605+03
24554	42	-1	1790	2020-05-01 03:54:39.447419+03
24555	82	-1	560	2020-05-01 04:08:02.76001+03
24556	44	27	206	2020-05-01 04:08:51.016262+03
24557	73	-1	960	2020-05-01 04:23:57.292535+03
24558	88	-3	1270	2020-05-01 04:27:13.174662+03
24559	59	-1	1030	2020-05-01 04:43:15.342176+03
24560	12	-1	1650	2020-05-01 04:45:37.311492+03
24561	83	-1	1230	2020-05-01 04:55:43.820641+03
24562	90	-2	1780	2020-05-01 05:41:58.607116+03
24563	74	-1	1010	2020-05-01 06:01:06.073146+03
24564	54	-1	3470	2020-05-01 06:09:32.973507+03
24565	2	-1	470	2020-05-01 06:15:36.239633+03
24566	7	-1	810	2020-05-01 06:30:20.341679+03
24567	76	-1	1070	2020-05-01 07:42:00.856649+03
24568	57	-1	1900	2020-05-01 08:06:51.059193+03
24569	53	-1	3120	2020-05-01 08:10:51.082622+03
24570	8	-2	1920	2020-05-01 08:17:51.08946+03
24571	90	-1	1780	2020-05-01 08:44:43.268017+03
24572	55	-1	3480	2020-05-01 08:48:52.924724+03
24573	79	-1	550	2020-05-01 09:53:17.781699+03
24574	89	-1	1420	2020-05-01 09:57:27.245273+03
24575	52	-2	1090	2020-05-01 10:29:27.035218+03
24576	23	-1	4390	2020-05-01 10:31:01.428478+03
24577	14	-1	1350	2020-05-01 10:31:38.891469+03
24578	33	-1	900	2020-05-01 10:52:18.227136+03
24579	55	-2	3480	2020-05-01 11:24:25.612961+03
24580	47	-2	1480	2020-05-01 11:25:17.621928+03
24581	20	-2	830	2020-05-01 11:44:33.890356+03
24582	58	-1	2830	2020-05-01 11:59:31.529125+03
24583	8	-1	1920	2020-05-01 12:24:34.94321+03
24584	5	-2	1620	2020-05-01 13:28:03.226718+03
24585	94	-2	1230	2020-05-01 13:34:53.955505+03
24586	38	-1	1100	2020-05-01 13:44:58.816863+03
24587	74	-1	1010	2020-05-01 14:09:29.867469+03
24588	20	-1	830	2020-05-01 14:13:56.593123+03
24589	70	-1	760	2020-05-01 14:43:27.26362+03
24590	9	-1	2090	2020-05-01 14:54:54.813466+03
24591	40	-1	1430	2020-05-01 14:57:45.293722+03
24592	17	-1	1500	2020-05-01 15:10:14.847573+03
24593	93	-1	1620	2020-05-01 15:10:34.111519+03
24594	85	-1	730	2020-05-01 15:19:43.213379+03
24595	6	-1	980	2020-05-01 15:30:52.390712+03
24596	47	-1	1480	2020-05-01 15:43:59.393374+03
24597	17	-1	1500	2020-05-01 16:22:53.723495+03
24598	85	-1	730	2020-05-01 16:36:04.706041+03
24599	28	-1	1860	2020-05-01 16:52:35.800477+03
24600	32	-1	710	2020-05-01 17:43:21.497532+03
24601	4	-1	1420	2020-05-01 17:49:37.271206+03
24602	35	-1	670	2020-05-01 17:56:03.690419+03
24603	23	-1	4390	2020-05-01 18:45:40.755717+03
24604	1	25	257	2020-05-01 18:59:27.355607+03
24605	71	-1	1030	2020-05-01 19:12:37.090854+03
24606	80	-1	1120	2020-05-01 19:29:45.139745+03
24607	44	-1	500	2020-05-01 19:35:07.774294+03
24608	36	-1	630	2020-05-01 19:38:42.695742+03
24609	54	-1	3470	2020-05-01 19:41:27.87356+03
24610	2	-1	470	2020-05-01 19:47:30.052173+03
24611	34	-1	1550	2020-05-01 19:54:39.608872+03
24612	43	-1	380	2020-05-01 20:03:48.36646+03
24613	22	-1	1070	2020-05-01 20:04:45.34039+03
24614	66	-1	690	2020-05-01 20:12:59.55063+03
24615	95	-1	480	2020-05-01 20:18:28.700108+03
24616	34	-1	1550	2020-05-01 20:19:51.506332+03
24617	56	-2	2460	2020-05-01 20:29:38.663248+03
24618	85	-1	730	2020-05-01 20:30:31.418537+03
24619	94	-1	1230	2020-05-01 20:35:45.920423+03
24620	47	40	790	2020-05-01 20:46:40.884989+03
24621	9	-1	2090	2020-05-01 20:50:20.439289+03
24622	14	-2	1350	2020-05-01 20:55:56.891289+03
24623	93	-1	1620	2020-05-01 21:04:53.490077+03
24624	3	-1	660	2020-05-01 21:13:35.979604+03
24625	87	-1	2320	2020-05-01 21:58:37.40061+03
24626	92	-1	630	2020-05-01 22:37:17.430885+03
24627	76	-1	1070	2020-05-01 22:46:03.126713+03
24628	19	-1	1220	2020-05-01 23:00:36.656366+03
24629	54	-1	3470	2020-05-01 23:08:51.292013+03
24630	89	-2	1420	2020-05-01 23:32:24.007802+03
24631	29	-2	1940	2020-05-01 23:34:08.757753+03
24632	70	-1	760	2020-05-01 23:51:52.292669+03
24633	45	-1	1590	2020-05-01 23:56:42.019404+03
24634	8	-1	1920	2020-05-02 00:10:15.013815+03
24635	41	-1	830	2020-05-02 00:33:12.011151+03
24636	64	-1	970	2020-05-02 00:59:43.70439+03
24637	58	18	1327	2020-05-02 01:10:48.866517+03
24638	85	-1	730	2020-05-02 01:25:04.078999+03
24639	2	-1	470	2020-05-02 01:26:43.981051+03
24640	71	-1	1030	2020-05-02 01:35:41.909294+03
24641	11	-1	830	2020-05-02 01:37:12.566953+03
24642	53	25	1840	2020-05-02 01:57:20.0166+03
24643	18	-1	910	2020-05-02 02:05:23.508567+03
24644	73	-1	960	2020-05-02 02:05:27.177599+03
24645	90	-1	1780	2020-05-02 02:07:42.751827+03
24646	14	-2	1350	2020-05-02 02:29:26.352119+03
24647	83	-1	1230	2020-05-02 02:41:03.29492+03
24648	84	-1	2700	2020-05-02 02:43:24.45852+03
24649	66	-2	690	2020-05-02 02:46:48.836772+03
24650	84	-2	2700	2020-05-02 02:50:34.939318+03
24651	33	-1	900	2020-05-02 02:54:27.017121+03
24652	78	-1	900	2020-05-02 02:56:32.939976+03
24653	9	-1	2090	2020-05-02 03:15:13.407214+03
24654	12	-1	1650	2020-05-02 03:24:46.329655+03
24655	32	-1	710	2020-05-02 03:27:08.951189+03
24656	68	-1	490	2020-05-02 03:46:44.756046+03
24657	20	-1	830	2020-05-02 03:57:09.069777+03
24658	38	-1	1100	2020-05-02 03:59:35.068256+03
24659	31	-1	1190	2020-05-02 04:17:07.669016+03
24660	96	-1	1570	2020-05-02 04:38:14.433899+03
24661	39	-1	910	2020-05-02 04:41:48.569005+03
24662	10	-1	2080	2020-05-02 04:54:28.924573+03
24663	75	-1	830	2020-05-02 05:05:39.530951+03
24664	31	-1	1190	2020-05-02 05:19:35.439785+03
24665	42	-1	1790	2020-05-02 05:31:26.346213+03
24666	58	-2	2830	2020-05-02 05:43:18.558207+03
24667	96	-2	1570	2020-05-02 05:50:32.832416+03
24668	54	-2	3470	2020-05-02 06:01:05.615208+03
24669	5	-1	1620	2020-05-02 06:08:58.701432+03
24670	30	-1	1140	2020-05-02 06:18:09.758+03
24671	89	-1	1420	2020-05-02 06:26:54.898008+03
24672	60	-1	2700	2020-05-02 07:32:27.519414+03
24673	40	-1	1430	2020-05-02 07:35:26.911669+03
24674	24	-1	950	2020-05-02 07:58:24.473044+03
24675	44	-2	500	2020-05-02 08:29:12.236477+03
24676	64	-1	970	2020-05-02 08:41:59.503382+03
24677	90	-1	1780	2020-05-02 09:01:01.609712+03
24678	71	-1	1030	2020-05-02 09:18:33.887738+03
24679	9	-1	2090	2020-05-02 09:26:31.454095+03
24680	36	-1	630	2020-05-02 09:31:50.553961+03
24681	93	-1	1620	2020-05-02 09:52:47.952362+03
24682	42	-1	1790	2020-05-02 10:04:19.636784+03
24683	87	-2	2320	2020-05-02 10:06:35.169082+03
24684	28	-1	1860	2020-05-02 10:10:25.657791+03
24685	92	-2	630	2020-05-02 10:12:48.52092+03
24686	39	-1	910	2020-05-02 10:14:36.032002+03
24687	23	-2	4390	2020-05-02 10:15:32.801354+03
24688	54	-1	3470	2020-05-02 10:28:13.870828+03
24689	91	-2	1620	2020-05-02 10:42:35.746386+03
24690	70	-1	760	2020-05-02 10:43:44.174813+03
24691	39	-2	910	2020-05-02 11:11:14.640936+03
24692	95	-1	480	2020-05-02 11:33:08.702609+03
24693	96	-1	1570	2020-05-02 11:33:39.424554+03
24694	57	38	936	2020-05-02 11:57:03.090716+03
24695	48	-1	640	2020-05-02 12:10:25.613519+03
24696	95	-1	480	2020-05-02 12:11:46.819926+03
24697	78	-1	900	2020-05-02 12:12:09.14254+03
24698	1	-1	640	2020-05-02 12:20:01.681941+03
24699	71	-1	1030	2020-05-02 12:59:23.253088+03
24700	6	-1	980	2020-05-02 13:08:17.245767+03
24701	83	-2	1230	2020-05-02 13:10:41.526118+03
24702	52	-1	1090	2020-05-02 13:15:04.241234+03
24703	12	-2	1650	2020-05-02 13:22:33.562285+03
24704	70	-1	760	2020-05-02 13:29:57.011718+03
24705	88	-1	1270	2020-05-02 13:35:03.211469+03
24706	47	-1	1480	2020-05-02 14:02:51.866519+03
24707	86	-1	910	2020-05-02 14:20:43.124206+03
24708	87	-1	2320	2020-05-02 14:22:57.953061+03
24709	87	-2	2320	2020-05-02 14:30:04.670048+03
24710	41	-1	830	2020-05-02 14:33:01.849815+03
24711	12	-2	1650	2020-05-02 14:50:20.850984+03
24712	63	-1	1780	2020-05-02 15:01:53.62606+03
24713	24	-1	950	2020-05-02 16:02:48.597725+03
24714	94	-1	1230	2020-05-02 16:09:47.758493+03
24715	2	14	249	2020-05-02 16:16:17.58389+03
24716	67	-2	350	2020-05-02 16:50:04.710788+03
24717	37	-1	1290	2020-05-02 17:06:02.675952+03
24718	2	-1	470	2020-05-02 19:13:05.646499+03
24719	38	-1	1100	2020-05-02 19:36:21.694706+03
24720	89	-1	1420	2020-05-02 19:52:40.624516+03
24721	20	-2	830	2020-05-02 19:59:16.246369+03
24722	89	-1	1420	2020-05-02 19:59:59.974479+03
24723	83	-1	1230	2020-05-02 20:20:08.950267+03
24724	95	-2	480	2020-05-02 20:24:02.11439+03
24725	71	-2	1030	2020-05-02 20:59:30.877353+03
24726	57	-1	1900	2020-05-02 21:00:50.388781+03
24727	26	-1	390	2020-05-02 21:02:22.945685+03
24728	88	-1	1270	2020-05-02 21:05:54.418495+03
24729	50	-1	1140	2020-05-02 21:07:24.997098+03
24730	63	-2	1780	2020-05-02 21:27:52.626315+03
24731	18	-1	910	2020-05-02 22:04:14.984921+03
24732	29	-1	1940	2020-05-02 22:29:55.210406+03
24733	77	-1	640	2020-05-02 22:46:35.337707+03
24734	38	-1	1100	2020-05-02 23:20:58.972247+03
24735	54	-1	3470	2020-05-02 23:39:53.201001+03
24736	8	-1	1920	2020-05-02 23:48:57.021027+03
24737	36	26	287	2020-05-03 00:14:21.753441+03
24738	66	-1	690	2020-05-03 00:19:59.805965+03
24739	57	-1	1900	2020-05-03 00:42:07.12958+03
24740	6	-1	980	2020-05-03 00:53:55.591545+03
24741	65	-1	490	2020-05-03 01:05:24.115341+03
24742	31	-1	1190	2020-05-03 01:41:20.745238+03
24743	39	-1	910	2020-05-03 01:42:22.537376+03
24744	17	-1	1500	2020-05-03 01:58:33.221276+03
24745	2	-1	470	2020-05-03 02:32:55.078491+03
24746	69	-1	1100	2020-05-03 02:38:19.754401+03
24747	68	-1	490	2020-05-03 02:39:18.322255+03
24748	10	-1	2080	2020-05-03 02:44:07.235608+03
24749	51	-1	1310	2020-05-03 02:46:37.115934+03
24750	76	-1	1070	2020-05-03 03:02:19.811102+03
24751	52	-1	1090	2020-05-03 03:17:02.300101+03
24752	4	-1	1420	2020-05-03 03:30:06.3235+03
24753	40	-2	1430	2020-05-03 04:09:37.933389+03
24754	5	-1	1620	2020-05-03 04:20:07.331153+03
24755	17	-1	1500	2020-05-03 04:42:20.111985+03
24756	36	-1	630	2020-05-03 04:47:51.579726+03
24757	73	-2	960	2020-05-03 05:00:42.43859+03
24758	8	-2	1920	2020-05-03 05:01:23.257512+03
24759	6	-2	980	2020-05-03 05:01:41.651642+03
24760	38	-1	1100	2020-05-03 05:08:28.129514+03
24761	49	-1	970	2020-05-03 05:17:49.740846+03
24762	4	-1	1420	2020-05-03 05:51:12.843943+03
24763	27	-1	880	2020-05-03 06:05:33.816837+03
24764	60	-1	2700	2020-05-03 06:07:38.498096+03
24765	47	-1	1480	2020-05-03 06:07:57.610747+03
24766	25	-1	1100	2020-05-03 06:30:12.79411+03
24767	72	-1	620	2020-05-03 06:30:45.252158+03
24768	76	39	562	2020-05-03 07:10:34.584311+03
24769	13	-2	460	2020-05-03 07:26:37.840953+03
24770	89	-1	1420	2020-05-03 07:30:47.66516+03
24771	49	-1	970	2020-05-03 07:59:19.680955+03
24772	60	-1	2700	2020-05-03 08:00:46.129795+03
24773	9	-1	2090	2020-05-03 08:14:24.526634+03
24774	59	-1	1030	2020-05-03 08:46:57.235507+03
24775	60	-2	2700	2020-05-03 08:47:44.513029+03
24776	76	-1	1070	2020-05-03 08:53:11.445501+03
24777	18	-1	910	2020-05-03 09:11:46.538764+03
24778	64	27	401	2020-05-03 09:17:07.626479+03
24779	20	-2	830	2020-05-03 09:26:13.609654+03
24780	51	28	708	2020-05-03 09:37:51.511896+03
24781	12	-1	1650	2020-05-03 09:54:23.655341+03
24782	87	-1	2320	2020-05-03 10:23:26.408849+03
24783	7	-1	810	2020-05-03 10:29:34.165711+03
24784	49	-1	970	2020-05-03 10:40:35.273839+03
24785	22	-1	1070	2020-05-03 10:41:39.467095+03
24786	63	-1	1780	2020-05-03 10:57:03.295945+03
24787	61	-1	1510	2020-05-03 11:05:41.968835+03
24788	16	-1	1380	2020-05-03 11:11:49.544907+03
24789	33	-1	900	2020-05-03 11:19:20.077224+03
24790	39	-1	910	2020-05-03 11:34:11.352738+03
24791	12	-1	1650	2020-05-03 11:35:24.668157+03
24792	54	-1	3470	2020-05-03 11:35:55.673533+03
24793	90	-1	1780	2020-05-03 12:49:17.509441+03
24794	22	-1	1070	2020-05-03 13:04:34.695159+03
24795	52	-1	1090	2020-05-03 13:33:07.292931+03
24796	55	-1	3480	2020-05-03 13:48:20.107919+03
24797	36	-2	630	2020-05-03 14:03:48.947932+03
24798	34	-2	1550	2020-05-03 15:21:35.961301+03
24799	20	-2	830	2020-05-03 15:25:40.86853+03
24800	30	-1	1140	2020-05-03 15:48:16.519957+03
24801	90	-1	1780	2020-05-03 16:15:32.308712+03
24802	46	-1	1270	2020-05-03 16:17:23.369808+03
24803	67	-1	350	2020-05-03 16:47:09.72646+03
24804	35	-1	670	2020-05-03 16:59:26.063592+03
24805	85	-1	730	2020-05-03 17:39:32.43233+03
24806	6	-1	980	2020-05-03 17:41:13.590181+03
24807	40	40	748	2020-05-03 18:03:06.412758+03
24808	86	-1	910	2020-05-03 18:19:18.80932+03
24809	22	-1	1070	2020-05-03 18:58:16.567752+03
24810	18	-1	910	2020-05-03 19:25:44.341347+03
24811	46	-1	1270	2020-05-03 19:33:58.392579+03
24812	87	-1	2320	2020-05-03 19:37:03.615696+03
24813	21	-1	960	2020-05-03 20:16:27.387313+03
24814	4	-2	1420	2020-05-03 20:21:58.693825+03
24815	59	-1	1030	2020-05-03 20:27:11.417232+03
24816	70	-1	760	2020-05-03 20:34:44.614678+03
24817	13	-1	460	2020-05-03 20:37:09.797111+03
24818	76	-1	1070	2020-05-03 20:38:51.387546+03
24819	71	-1	1030	2020-05-03 20:40:36.758784+03
24820	67	-1	350	2020-05-03 21:00:18.302085+03
24821	67	-2	350	2020-05-03 21:11:47.944206+03
24822	32	-1	710	2020-05-03 21:19:19.513319+03
24823	26	-1	390	2020-05-03 21:32:52.19729+03
24824	90	-1	1780	2020-05-03 21:39:21.644501+03
24825	17	-1	1500	2020-05-03 22:10:24.960466+03
24826	43	-1	380	2020-05-03 22:12:13.905587+03
24827	43	-2	380	2020-05-03 22:49:27.573362+03
24828	89	-1	1420	2020-05-03 22:52:04.630199+03
24829	53	-1	3120	2020-05-03 23:14:23.845594+03
24830	9	-2	2090	2020-05-03 23:20:09.525512+03
24831	39	-1	910	2020-05-03 23:32:10.838304+03
24832	31	-2	1190	2020-05-03 23:36:24.589394+03
24833	20	-1	830	2020-05-04 00:33:37.499963+03
24834	90	-2	1780	2020-05-04 00:43:09.869766+03
24835	10	-1	2080	2020-05-04 01:03:47.440389+03
24836	79	-1	550	2020-05-04 01:17:24.211496+03
24837	28	-1	1860	2020-05-04 01:31:48.65236+03
24838	56	-1	2460	2020-05-04 01:53:27.390107+03
24839	95	-1	480	2020-05-04 02:15:44.658307+03
24840	14	-1	1350	2020-05-04 02:17:16.8814+03
24841	1	-1	640	2020-05-04 02:33:47.353331+03
24842	4	-1	1420	2020-05-04 02:46:03.135837+03
24843	6	-2	980	2020-05-04 02:47:55.56037+03
24844	21	-1	960	2020-05-04 02:58:57.137495+03
24845	59	-1	1030	2020-05-04 03:16:52.417426+03
24846	88	-1	1270	2020-05-04 03:22:16.230314+03
24847	90	-1	1780	2020-05-04 03:24:57.138695+03
24848	51	-1	1310	2020-05-04 03:47:44.739475+03
24849	68	-1	490	2020-05-04 03:53:23.449438+03
24850	4	-2	1420	2020-05-04 03:56:36.729769+03
24851	27	-1	880	2020-05-04 04:02:43.699917+03
24852	2	-1	470	2020-05-04 04:22:44.762821+03
24853	14	-1	1350	2020-05-04 05:04:54.483755+03
24854	13	-1	460	2020-05-04 05:27:16.894623+03
24855	21	-1	960	2020-05-04 05:56:35.315697+03
24856	49	-1	970	2020-05-04 06:11:28.369696+03
24857	29	-2	1940	2020-05-04 06:21:39.485081+03
24858	42	39	743	2020-05-04 06:34:35.49453+03
24859	46	-1	1270	2020-05-04 06:39:35.90899+03
24860	96	-1	1570	2020-05-04 06:55:21.911649+03
24861	76	-1	1070	2020-05-04 07:03:48.967819+03
24862	70	-1	760	2020-05-04 07:11:09.666773+03
24863	57	-2	1900	2020-05-04 08:00:12.205195+03
24864	31	27	586	2020-05-04 08:22:13.199863+03
24865	51	-1	1310	2020-05-04 08:38:34.424502+03
24866	18	-1	910	2020-05-04 09:17:13.244019+03
24867	53	-2	3120	2020-05-04 09:21:12.061518+03
24868	57	-1	1900	2020-05-04 09:30:12.906319+03
24869	95	-1	480	2020-05-04 09:46:47.750365+03
24870	4	-1	1420	2020-05-04 09:56:54.656166+03
24871	53	-2	3120	2020-05-04 10:32:02.527069+03
24872	80	-1	1120	2020-05-04 10:47:41.62957+03
24873	53	-1	3120	2020-05-04 10:48:13.242322+03
24874	23	-1	4390	2020-05-04 11:02:37.841615+03
24875	47	-1	1480	2020-05-04 11:25:22.883226+03
24876	83	-1	1230	2020-05-04 11:26:04.322962+03
24877	45	-1	1590	2020-05-04 11:38:18.083892+03
24878	63	-1	1780	2020-05-04 11:46:09.510459+03
24879	41	-1	830	2020-05-04 11:59:43.75056+03
24880	92	-1	630	2020-05-04 12:05:21.235991+03
24881	15	-1	2830	2020-05-04 12:05:46.331183+03
24882	48	-1	640	2020-05-04 12:12:50.687471+03
24883	37	-1	1290	2020-05-04 12:26:37.466502+03
24884	3	23	386	2020-05-04 12:28:25.585509+03
24885	90	-1	1780	2020-05-04 12:28:27.685853+03
24886	12	-1	1650	2020-05-04 12:31:19.665324+03
24887	93	-2	1620	2020-05-04 12:59:42.991405+03
24888	57	-1	1900	2020-05-04 13:12:38.175866+03
24889	5	-2	1620	2020-05-04 13:13:25.479286+03
24890	30	-2	1140	2020-05-04 13:23:22.733588+03
24891	17	-1	1500	2020-05-04 13:36:32.072435+03
24892	37	-1	1290	2020-05-04 13:52:38.957819+03
24893	37	-1	1290	2020-05-04 14:06:59.659665+03
24894	91	-1	1620	2020-05-04 14:13:15.796668+03
24895	44	-1	500	2020-05-04 14:42:59.10248+03
24896	92	-1	630	2020-05-04 14:54:57.86867+03
24897	89	-3	1420	2020-05-04 15:35:59.532723+03
24898	56	-1	2460	2020-05-04 15:51:36.605421+03
24899	9	-1	2090	2020-05-04 16:00:48.39482+03
24900	40	-2	1430	2020-05-04 16:19:44.6422+03
24901	48	-1	640	2020-05-04 16:21:40.401129+03
24902	50	-1	1140	2020-05-04 16:42:11.937084+03
24903	48	-1	640	2020-05-04 16:59:08.284927+03
24904	89	26	740	2020-05-04 17:02:56.064752+03
24905	18	-1	910	2020-05-04 17:11:10.582922+03
24906	20	-1	830	2020-05-04 17:21:53.525829+03
24907	71	-1	1030	2020-05-04 18:02:17.93555+03
24908	14	-1	1350	2020-05-04 18:08:01.792549+03
24909	14	-1	1350	2020-05-04 18:16:32.986195+03
24910	51	-1	1310	2020-05-04 18:47:03.17152+03
24911	87	-1	2320	2020-05-04 18:57:09.888354+03
24912	7	-3	810	2020-05-04 19:20:08.625775+03
24913	26	-1	390	2020-05-04 19:39:25.006971+03
24914	45	25	838	2020-05-04 19:49:20.903513+03
24915	72	-1	620	2020-05-04 19:58:19.956487+03
24916	68	-1	490	2020-05-04 20:01:09.62176+03
24917	6	-1	980	2020-05-04 20:06:29.847744+03
24918	89	-1	1420	2020-05-04 21:06:09.820452+03
24919	35	-1	670	2020-05-04 21:26:38.881551+03
24920	56	34	1101	2020-05-04 21:33:13.174389+03
24921	74	-1	1010	2020-05-04 21:36:45.967151+03
24922	34	-2	1550	2020-05-04 22:07:23.984154+03
24923	63	-2	1780	2020-05-04 22:09:08.099722+03
24924	18	-1	910	2020-05-04 22:17:09.024771+03
24925	85	-1	730	2020-05-04 22:21:20.403955+03
24926	75	-1	830	2020-05-04 22:31:39.442946+03
24927	22	-1	1070	2020-05-04 22:35:04.405479+03
24928	50	-1	1140	2020-05-04 22:42:29.708849+03
24929	24	-1	950	2020-05-04 22:56:17.730101+03
24930	5	-1	1620	2020-05-04 23:03:34.356829+03
24931	91	-1	1620	2020-05-04 23:10:54.194453+03
24932	59	27	589	2020-05-04 23:52:03.545754+03
24933	56	-2	2460	2020-05-05 00:04:40.716089+03
24934	58	-1	2830	2020-05-05 00:09:06.963415+03
24935	80	-2	1120	2020-05-05 00:12:17.008341+03
24936	73	-2	960	2020-05-05 00:17:42.970642+03
24937	6	-1	980	2020-05-05 00:18:17.480099+03
24938	4	-2	1420	2020-05-05 00:20:26.601614+03
24939	50	-1	1140	2020-05-05 00:40:55.348011+03
24940	8	-1	1920	2020-05-05 00:50:44.948773+03
24941	69	-1	1100	2020-05-05 01:06:15.75193+03
24942	12	-1	1650	2020-05-05 01:08:34.20724+03
24943	74	-1	1010	2020-05-05 01:48:24.758252+03
24944	4	-2	1420	2020-05-05 01:58:58.214145+03
24945	20	-1	830	2020-05-05 02:01:19.366297+03
24946	93	-1	1620	2020-05-05 02:12:03.043946+03
24947	78	-2	900	2020-05-05 02:32:37.297468+03
24948	89	-1	1420	2020-05-05 02:44:25.344843+03
24949	18	-1	910	2020-05-05 02:58:25.449694+03
24950	46	-1	1270	2020-05-05 03:02:54.313197+03
24951	30	-2	1140	2020-05-05 03:05:31.283539+03
24952	54	-1	3470	2020-05-05 03:06:25.374321+03
24953	65	-1	490	2020-05-05 03:08:46.99575+03
24954	37	-1	1290	2020-05-05 03:27:12.472349+03
24955	22	-1	1070	2020-05-05 03:35:56.685812+03
24956	39	-1	910	2020-05-05 03:48:51.706046+03
24957	30	-1	1140	2020-05-05 03:52:52.900325+03
24958	55	-1	3480	2020-05-05 04:14:37.825812+03
24959	56	-1	2460	2020-05-05 04:29:15.58202+03
24960	12	-1	1650	2020-05-05 04:54:08.770532+03
24961	17	-1	1500	2020-05-05 05:25:23.743941+03
24962	90	-1	1780	2020-05-05 05:32:24.277506+03
24963	4	-1	1420	2020-05-05 05:33:09.662374+03
24964	54	-2	3470	2020-05-05 05:39:05.805489+03
24965	56	-1	2460	2020-05-05 06:04:32.657037+03
24966	41	-1	830	2020-05-05 06:08:02.986055+03
24967	43	-1	380	2020-05-05 06:16:01.689093+03
24968	95	-1	480	2020-05-05 06:41:46.419804+03
24969	29	-1	1940	2020-05-05 07:00:44.295521+03
24970	21	-1	960	2020-05-05 07:27:42.117407+03
24971	61	-1	1510	2020-05-05 07:30:13.359865+03
24972	63	-1	1780	2020-05-05 08:01:20.35444+03
24973	53	-1	3120	2020-05-05 08:17:26.949347+03
24974	92	-1	630	2020-05-05 08:23:48.014596+03
24975	47	-1	1480	2020-05-05 08:27:17.398777+03
24976	70	-1	760	2020-05-05 08:57:11.870632+03
24977	13	-1	460	2020-05-05 09:12:50.95626+03
24978	90	-1	1780	2020-05-05 09:16:49.943825+03
24979	37	-2	1290	2020-05-05 09:27:38.327987+03
24980	82	-1	560	2020-05-05 09:41:07.064816+03
24981	89	-1	1420	2020-05-05 09:55:24.800858+03
24982	8	-1	1920	2020-05-05 10:05:12.267909+03
24983	13	-2	460	2020-05-05 10:23:55.770597+03
24984	49	33	407	2020-05-05 10:41:52.027201+03
24985	19	-1	1220	2020-05-05 10:47:04.323822+03
24986	87	-2	2320	2020-05-05 10:47:20.077545+03
24987	62	-2	1220	2020-05-05 10:55:38.521064+03
24988	37	-1	1290	2020-05-05 11:18:36.297272+03
24989	1	-1	640	2020-05-05 11:20:07.632357+03
24990	59	-1	1030	2020-05-05 11:49:04.842727+03
24991	12	-1	1650	2020-05-05 11:54:04.702636+03
24992	67	-2	350	2020-05-05 12:04:02.170206+03
24993	13	-1	460	2020-05-05 12:13:07.317001+03
24994	71	-1	1030	2020-05-05 12:22:58.422853+03
24995	35	-1	670	2020-05-05 12:58:03.154319+03
24996	6	-1	980	2020-05-05 13:04:00.649772+03
24997	34	-1	1550	2020-05-05 13:37:07.540947+03
24998	47	-1	1480	2020-05-05 13:51:00.647403+03
24999	54	-1	3470	2020-05-05 14:35:12.834488+03
25000	37	-1	1290	2020-05-05 14:39:36.361121+03
25001	64	-2	970	2020-05-05 14:42:24.862282+03
25002	17	-2	1500	2020-05-05 14:42:30.217789+03
25003	90	-2	1780	2020-05-05 14:46:23.882591+03
25004	27	-2	880	2020-05-05 15:03:38.136106+03
25005	76	-1	1070	2020-05-05 15:21:19.839289+03
25006	18	-1	910	2020-05-05 15:27:50.645536+03
25007	17	-1	1500	2020-05-05 15:32:01.896979+03
25008	34	-1	1550	2020-05-05 15:39:01.558649+03
25009	82	19	269	2020-05-05 16:08:55.258433+03
25010	52	29	484	2020-05-05 16:14:58.965138+03
25011	91	-1	1620	2020-05-05 16:18:49.198189+03
25012	34	-1	1550	2020-05-05 16:39:48.86808+03
25013	86	-1	910	2020-05-05 16:41:43.726717+03
25014	11	-1	830	2020-05-05 16:57:34.669262+03
25015	77	-1	640	2020-05-05 17:03:02.071954+03
25016	28	-1	1860	2020-05-05 17:17:35.027781+03
25017	52	-1	1090	2020-05-05 17:32:43.542762+03
25018	84	-2	2700	2020-05-05 17:33:45.875263+03
25019	24	-1	950	2020-05-05 17:48:19.607436+03
25020	63	-1	1780	2020-05-05 17:54:12.860631+03
25021	12	-1	1650	2020-05-05 17:59:53.396982+03
25022	26	-1	390	2020-05-05 18:01:52.331897+03
25023	13	-1	460	2020-05-05 18:30:08.29305+03
25024	42	-1	1790	2020-05-05 19:12:43.55612+03
25025	81	-2	1620	2020-05-05 19:22:19.36341+03
25026	95	-1	480	2020-05-05 19:51:24.71074+03
25027	53	-1	3120	2020-05-05 20:06:02.858852+03
25028	66	-1	690	2020-05-05 20:07:08.45159+03
25029	22	-1	1070	2020-05-05 20:16:52.708249+03
25030	96	-1	1570	2020-05-05 20:17:49.714929+03
25031	7	-1	810	2020-05-05 20:26:22.557668+03
25032	45	-1	1590	2020-05-05 20:37:01.386065+03
25033	18	-1	910	2020-05-05 20:51:38.652404+03
25034	94	-1	1230	2020-05-05 21:02:52.104647+03
25035	11	-1	830	2020-05-05 21:03:09.339033+03
25036	85	21	382	2020-05-05 21:24:40.843997+03
25037	46	-2	1270	2020-05-05 21:28:47.815819+03
25038	35	-1	670	2020-05-05 21:29:17.409838+03
25039	68	-1	490	2020-05-05 21:42:28.800247+03
25040	58	-1	2830	2020-05-05 22:16:52.919143+03
25041	36	-2	630	2020-05-05 22:39:13.57049+03
25042	92	-2	630	2020-05-05 22:53:04.358389+03
25043	33	-1	900	2020-05-05 23:13:18.667989+03
25044	33	-1	900	2020-05-05 23:43:49.288246+03
25045	95	-1	480	2020-05-05 23:54:20.736753+03
25046	88	-1	1270	2020-05-06 00:10:31.114753+03
25047	59	-1	1030	2020-05-06 01:38:14.271723+03
25048	6	-1	980	2020-05-06 01:40:07.294305+03
25049	94	-1	1230	2020-05-06 01:50:35.303617+03
25050	10	-1	2080	2020-05-06 02:07:36.635854+03
25051	86	-1	910	2020-05-06 02:08:25.829101+03
25052	67	-1	350	2020-05-06 02:11:32.906933+03
25053	12	-1	1650	2020-05-06 03:49:35.451963+03
25054	64	-1	970	2020-05-06 04:18:02.747504+03
25055	66	10	280	2020-05-06 04:23:12.652402+03
25056	59	-1	1030	2020-05-06 04:34:13.96433+03
25057	57	-1	1900	2020-05-06 05:29:28.663671+03
25058	87	-1	2320	2020-05-06 05:30:51.047179+03
25059	73	-1	960	2020-05-06 05:44:57.029586+03
25060	33	-2	900	2020-05-06 06:13:49.22221+03
25061	44	-1	500	2020-05-06 06:51:20.671204+03
25062	47	-1	1480	2020-05-06 07:11:17.008433+03
25063	45	-1	1590	2020-05-06 07:26:13.678654+03
25064	54	-1	3470	2020-05-06 08:12:40.006548+03
25065	89	-1	1420	2020-05-06 08:47:46.362545+03
25066	31	-1	1190	2020-05-06 09:02:37.600975+03
25067	56	-1	2460	2020-05-06 09:21:05.155609+03
25068	48	-2	640	2020-05-06 09:41:47.848367+03
25069	37	-1	1290	2020-05-06 09:45:47.03855+03
25070	55	-2	3480	2020-05-06 09:50:07.99026+03
25071	3	-2	660	2020-05-06 10:24:10.16231+03
25072	69	20	491	2020-05-06 11:33:24.737809+03
25073	13	-1	460	2020-05-06 11:35:51.512942+03
25074	86	-1	910	2020-05-06 11:50:37.739711+03
25075	14	-1	1350	2020-05-06 11:58:26.399396+03
25076	26	-2	390	2020-05-06 12:21:57.23969+03
25077	35	-1	670	2020-05-06 12:52:14.288312+03
25078	21	-1	960	2020-05-06 13:07:40.170616+03
25079	6	-1	980	2020-05-06 13:19:17.867778+03
25080	71	-1	1030	2020-05-06 13:29:57.072843+03
25081	74	-2	1010	2020-05-06 13:44:16.106377+03
25082	20	-1	830	2020-05-06 13:52:29.181014+03
25083	50	-1	1140	2020-05-06 14:47:49.880239+03
25084	96	-2	1570	2020-05-06 15:04:00.294356+03
25085	71	-1	1030	2020-05-06 15:23:00.673287+03
25086	13	-2	460	2020-05-06 15:27:05.0015+03
25087	81	-1	1620	2020-05-06 15:32:53.917063+03
25088	57	-1	1900	2020-05-06 15:35:28.015163+03
25089	70	-1	760	2020-05-06 15:36:46.477855+03
25090	94	-2	1230	2020-05-06 15:40:15.40593+03
25091	9	-1	2090	2020-05-06 15:42:34.971063+03
25092	93	-1	1620	2020-05-06 16:15:01.17947+03
25093	13	-1	460	2020-05-06 16:35:21.290158+03
25094	80	-1	1120	2020-05-06 16:36:28.455412+03
25095	14	-1	1350	2020-05-06 16:45:59.461882+03
25096	31	-2	1190	2020-05-06 16:51:28.933287+03
25097	74	-1	1010	2020-05-06 17:00:05.128394+03
25098	7	-1	810	2020-05-06 17:05:29.925714+03
25099	70	-2	760	2020-05-06 17:28:05.191111+03
25100	52	-1	1090	2020-05-06 17:56:50.593706+03
25101	69	-2	1100	2020-05-06 18:48:36.268441+03
25102	10	-1	2080	2020-05-06 19:06:27.689839+03
25103	77	-1	640	2020-05-06 19:30:04.530187+03
25104	4	-2	1420	2020-05-06 19:45:27.924277+03
25105	63	-1	1780	2020-05-06 19:45:54.506269+03
25106	4	-1	1420	2020-05-06 20:09:26.816443+03
25107	10	-1	2080	2020-05-06 20:36:37.438173+03
25108	36	-1	630	2020-05-06 20:37:31.009844+03
25109	88	-1	1270	2020-05-06 21:09:13.53871+03
25110	85	-1	730	2020-05-06 21:10:28.589309+03
25111	96	-2	1570	2020-05-06 21:50:00.158745+03
25112	14	-1	1350	2020-05-06 22:00:33.052134+03
25113	19	-1	1220	2020-05-06 22:08:46.722628+03
25114	4	-1	1420	2020-05-06 22:37:34.188677+03
25115	95	-1	480	2020-05-06 22:54:00.716816+03
25116	47	-1	1480	2020-05-06 23:19:34.281949+03
25117	52	-1	1090	2020-05-07 00:09:07.182662+03
25118	32	-2	710	2020-05-07 00:34:24.695277+03
25119	76	-1	1070	2020-05-07 00:56:02.89838+03
25120	47	-1	1480	2020-05-07 01:21:27.556713+03
25121	32	-1	710	2020-05-07 02:34:04.374643+03
25122	93	-1	1620	2020-05-07 02:34:05.033572+03
25123	29	-2	1940	2020-05-07 02:34:13.07587+03
25124	48	-2	640	2020-05-07 02:36:32.003725+03
25125	56	-2	2460	2020-05-07 02:40:53.943007+03
25126	52	-1	1090	2020-05-07 02:50:05.990785+03
25127	35	-1	670	2020-05-07 03:01:13.765754+03
25128	57	-1	1900	2020-05-07 03:07:33.360142+03
25129	52	-1	1090	2020-05-07 03:27:46.454597+03
25130	58	-1	2830	2020-05-07 03:37:20.209933+03
25131	49	-1	970	2020-05-07 04:01:47.137074+03
25132	36	-1	630	2020-05-07 04:32:19.9087+03
25133	11	-1	830	2020-05-07 05:02:06.13836+03
25134	43	-1	380	2020-05-07 05:10:06.916604+03
25135	84	-1	2700	2020-05-07 05:18:02.283961+03
25136	20	-1	830	2020-05-07 05:30:37.891056+03
25137	50	-1	1140	2020-05-07 06:35:49.516139+03
25138	7	-1	810	2020-05-07 06:53:37.795837+03
25139	51	-1	1310	2020-05-07 06:59:55.314415+03
25140	63	-1	1780	2020-05-07 07:22:47.938097+03
25141	67	-1	350	2020-05-07 07:39:10.286555+03
25142	18	-2	910	2020-05-07 07:46:47.234449+03
25143	83	-1	1230	2020-05-07 07:49:21.959414+03
25144	38	-2	1100	2020-05-07 08:13:21.257185+03
25145	63	30	842	2020-05-07 08:25:14.381308+03
25146	30	-1	1140	2020-05-07 08:28:03.444027+03
25147	61	-2	1510	2020-05-07 09:05:09.922336+03
25148	31	-2	1190	2020-05-07 09:06:52.22735+03
25149	30	-1	1140	2020-05-07 09:15:16.211095+03
25150	33	-1	900	2020-05-07 09:50:50.23114+03
25151	6	-1	980	2020-05-07 09:52:10.886886+03
25152	39	-1	910	2020-05-07 10:29:12.026063+03
25153	48	-1	640	2020-05-07 10:41:04.139215+03
25154	4	-1	1420	2020-05-07 10:47:24.789563+03
25155	49	-1	970	2020-05-07 10:53:30.73039+03
25156	61	-2	1510	2020-05-07 11:25:03.494168+03
25157	40	-1	1430	2020-05-07 11:30:58.78093+03
25158	4	-1	1420	2020-05-07 11:32:52.796152+03
25159	15	18	1393	2020-05-07 11:33:40.451421+03
25160	8	-1	1920	2020-05-07 11:47:02.071838+03
25161	61	-1	1510	2020-05-07 11:56:21.19412+03
25162	8	-1	1920	2020-05-07 12:00:04.610939+03
25163	86	-1	910	2020-05-07 12:16:57.749621+03
25164	30	-1	1140	2020-05-07 12:41:28.214108+03
25165	45	-2	1590	2020-05-07 12:47:40.786621+03
25166	10	-2	2080	2020-05-07 12:53:54.427572+03
25167	85	-1	730	2020-05-07 13:03:48.937028+03
25168	31	-1	1190	2020-05-07 13:07:23.084489+03
25169	93	-1	1620	2020-05-07 13:13:56.678921+03
25170	56	-1	2460	2020-05-07 13:15:28.934514+03
25171	50	-1	1140	2020-05-07 13:21:44.56335+03
25172	7	-2	810	2020-05-07 13:30:21.490882+03
25173	84	-1	2700	2020-05-07 14:00:29.303789+03
25174	71	-1	1030	2020-05-07 14:38:25.96724+03
25175	21	-1	960	2020-05-07 15:07:21.779746+03
25176	49	-2	970	2020-05-07 15:18:03.2474+03
25177	15	-2	2830	2020-05-07 15:26:45.191007+03
25178	66	-2	690	2020-05-07 15:32:00.196003+03
25179	14	-1	1350	2020-05-07 15:38:16.820707+03
25180	41	-1	830	2020-05-07 15:58:11.692122+03
25181	82	-1	560	2020-05-07 16:24:31.608901+03
25182	13	-1	460	2020-05-07 16:31:45.993528+03
25183	3	-1	660	2020-05-07 17:07:03.579805+03
25184	46	-1	1270	2020-05-07 17:35:49.217427+03
25185	14	-1	1350	2020-05-07 17:42:33.300632+03
25186	89	-1	1420	2020-05-07 17:58:21.151193+03
25187	29	-1	1940	2020-05-07 17:59:09.457959+03
25188	5	-1	1620	2020-05-07 18:02:25.153015+03
25189	37	-1	1290	2020-05-07 18:08:40.048449+03
25190	33	-2	900	2020-05-07 18:11:22.43047+03
25191	80	-1	1120	2020-05-07 18:25:01.940452+03
25192	67	-1	350	2020-05-07 18:30:57.194099+03
25193	32	-1	710	2020-05-07 18:37:34.385085+03
25194	8	-2	1920	2020-05-07 18:38:06.144753+03
25195	24	-1	950	2020-05-07 19:28:14.155978+03
25196	32	-1	710	2020-05-07 19:30:43.547608+03
25197	96	-1	1570	2020-05-07 19:33:40.008633+03
25198	27	22	439	2020-05-07 20:53:11.920167+03
25199	57	-1	1900	2020-05-07 20:56:20.617802+03
25200	96	-1	1570	2020-05-07 21:21:09.741705+03
25201	11	-1	830	2020-05-07 21:23:02.102098+03
25202	69	-1	1100	2020-05-07 21:35:12.122804+03
25203	9	-1	2090	2020-05-07 21:42:28.205222+03
25204	86	-1	910	2020-05-07 22:14:23.429934+03
25205	53	-2	3120	2020-05-07 22:17:08.159011+03
25206	6	-1	980	2020-05-07 22:43:09.875041+03
25207	21	-1	960	2020-05-07 22:57:01.089391+03
25208	30	-1	1140	2020-05-07 23:10:58.232516+03
25209	33	-1	900	2020-05-07 23:36:56.692049+03
25210	14	-1	1350	2020-05-07 23:51:57.602123+03
25211	12	-2	1650	2020-05-08 00:01:44.191232+03
25212	80	-1	1120	2020-05-08 00:16:20.316555+03
25213	41	-1	830	2020-05-08 00:18:14.40228+03
25214	14	-1	1350	2020-05-08 00:57:09.616826+03
25215	94	-1	1230	2020-05-08 01:22:19.55394+03
25216	63	-3	1780	2020-05-08 01:33:03.811607+03
25217	52	-1	1090	2020-05-08 01:38:24.689602+03
25218	36	-1	630	2020-05-08 01:44:58.121558+03
25219	39	-1	910	2020-05-08 02:18:18.662104+03
25220	14	44	654	2020-05-08 02:18:23.800152+03
25221	82	-1	560	2020-05-08 02:28:15.266017+03
25222	14	-1	1350	2020-05-08 02:30:50.241991+03
25223	13	-2	460	2020-05-08 02:56:50.202474+03
25224	57	-2	1900	2020-05-08 03:01:36.188361+03
25225	76	-2	1070	2020-05-08 03:22:01.370959+03
25226	74	-1	1010	2020-05-08 03:28:30.328907+03
25227	5	-1	1620	2020-05-08 03:29:11.086236+03
25228	83	-2	1230	2020-05-08 04:09:38.433706+03
25229	77	-1	640	2020-05-08 04:15:46.436234+03
25230	48	-1	640	2020-05-08 04:21:18.500327+03
25231	88	-1	1270	2020-05-08 04:28:23.572906+03
25232	19	-1	1220	2020-05-08 04:46:50.677424+03
25233	63	-1	1780	2020-05-08 04:48:02.891873+03
25234	20	-1	830	2020-05-08 04:57:35.911932+03
25235	27	-1	880	2020-05-08 05:34:14.704424+03
25236	11	-2	830	2020-05-08 05:44:57.325311+03
25237	7	-1	810	2020-05-08 05:53:22.762428+03
25238	20	-2	830	2020-05-08 06:14:15.406627+03
25239	31	-1	1190	2020-05-08 06:21:37.512989+03
25240	77	-1	640	2020-05-08 06:24:19.368496+03
25241	44	-1	500	2020-05-08 06:27:14.891154+03
25242	39	-1	910	2020-05-08 06:35:10.325533+03
25243	25	-1	1100	2020-05-08 06:40:45.150752+03
25244	32	-1	710	2020-05-08 06:45:30.308304+03
25245	48	-1	640	2020-05-08 07:12:39.334664+03
25246	36	-1	630	2020-05-08 07:18:16.247983+03
25247	41	-1	830	2020-05-08 07:24:38.18572+03
25248	71	-1	1030	2020-05-08 07:28:58.936098+03
25249	36	-1	630	2020-05-08 08:02:12.173812+03
25250	91	-1	1620	2020-05-08 08:04:14.022216+03
25251	53	-1	3120	2020-05-08 08:04:53.712373+03
25252	65	-1	490	2020-05-08 08:11:03.230282+03
25253	40	-2	1430	2020-05-08 08:17:38.476978+03
25254	11	-1	830	2020-05-08 08:18:32.14095+03
25255	25	-1	1100	2020-05-08 08:20:56.676165+03
25256	31	-1	1190	2020-05-08 08:34:24.014213+03
25257	64	-2	970	2020-05-08 08:47:14.239369+03
25258	14	-2	1350	2020-05-08 08:56:27.745929+03
25259	3	-1	660	2020-05-08 09:13:37.985117+03
25260	44	-2	500	2020-05-08 09:24:04.240283+03
25261	76	-1	1070	2020-05-08 10:00:50.120399+03
25262	49	-1	970	2020-05-08 11:14:06.599192+03
25263	58	-1	2830	2020-05-08 11:21:18.108273+03
25264	17	-2	1500	2020-05-08 11:27:19.410554+03
25265	67	-1	350	2020-05-08 11:30:00.820731+03
25266	2	-2	470	2020-05-08 11:35:16.292935+03
25267	69	-1	1100	2020-05-08 12:03:30.529883+03
25268	28	-2	1860	2020-05-08 12:05:48.861414+03
25269	54	-1	3470	2020-05-08 12:10:42.817848+03
25270	23	-1	4390	2020-05-08 12:17:12.292163+03
25271	18	-1	910	2020-05-08 12:38:58.345885+03
25272	76	-2	1070	2020-05-08 13:45:31.983218+03
25273	2	-2	470	2020-05-08 14:44:03.397936+03
25274	65	-2	490	2020-05-08 15:14:40.135566+03
25275	22	-1	1070	2020-05-08 15:20:14.122774+03
25276	43	-2	380	2020-05-08 15:32:19.415721+03
25277	88	-2	1270	2020-05-08 15:58:37.977098+03
25278	82	-1	560	2020-05-08 16:00:37.060308+03
25279	18	-1	910	2020-05-08 16:05:18.173348+03
25280	59	-1	1030	2020-05-08 16:27:29.357915+03
25281	22	-1	1070	2020-05-08 16:30:33.576706+03
25282	14	-2	1350	2020-05-08 16:33:04.915731+03
25283	22	-1	1070	2020-05-08 16:35:11.679606+03
25284	36	-1	630	2020-05-08 16:47:36.018803+03
25285	77	-2	640	2020-05-08 16:52:34.91821+03
25286	1	-2	640	2020-05-08 17:08:14.700361+03
25287	46	-1	1270	2020-05-08 17:09:30.422121+03
25288	39	-1	910	2020-05-08 17:20:41.916169+03
25289	70	-2	760	2020-05-08 17:26:39.227913+03
25290	64	-1	970	2020-05-08 17:30:51.316468+03
25291	80	-2	1120	2020-05-08 17:45:29.123085+03
25292	17	-1	1500	2020-05-08 18:07:11.910535+03
25293	12	-1	1650	2020-05-08 18:07:37.599121+03
25294	84	-1	2700	2020-05-08 18:32:24.63584+03
25295	4	-1	1420	2020-05-08 19:11:01.992967+03
25296	4	-1	1420	2020-05-08 19:26:29.143539+03
25297	22	-1	1070	2020-05-08 19:31:17.163906+03
25298	56	-1	2460	2020-05-08 20:05:25.567535+03
25299	20	32	364	2020-05-08 20:12:47.317306+03
25300	41	-1	830	2020-05-08 20:30:04.141175+03
25301	76	-1	1070	2020-05-08 21:04:19.263515+03
25302	29	-1	1940	2020-05-08 21:07:18.342833+03
25303	93	-1	1620	2020-05-08 21:23:41.34062+03
25304	50	-1	1140	2020-05-08 21:38:30.617092+03
25305	86	-1	910	2020-05-08 22:09:55.361158+03
25306	94	-1	1230	2020-05-08 22:18:28.59756+03
25307	90	-1	1780	2020-05-08 22:21:37.295214+03
25308	87	-1	2320	2020-05-08 22:23:58.149566+03
25309	88	-2	1270	2020-05-08 22:34:41.884348+03
25310	83	-2	1230	2020-05-08 22:59:15.363491+03
25311	76	-2	1070	2020-05-08 23:00:51.564693+03
25312	30	-1	1140	2020-05-08 23:07:47.78426+03
25313	6	-1	980	2020-05-08 23:11:53.305689+03
25314	51	-1	1310	2020-05-08 23:23:40.351867+03
25315	34	39	854	2020-05-08 23:28:25.975758+03
25316	59	-1	1030	2020-05-08 23:33:46.064451+03
25317	22	-2	1070	2020-05-08 23:41:45.552351+03
25318	8	-1	1920	2020-05-08 23:44:32.199283+03
25319	47	-2	1480	2020-05-08 23:58:02.64784+03
25320	13	-1	460	2020-05-09 00:03:40.370732+03
25321	61	-2	1510	2020-05-09 00:03:59.778455+03
25322	89	-2	1420	2020-05-09 00:06:16.014722+03
25323	90	-1	1780	2020-05-09 01:01:50.821156+03
25324	63	-1	1780	2020-05-09 01:09:00.279469+03
25325	60	-1	2700	2020-05-09 02:37:31.968951+03
25326	4	-2	1420	2020-05-09 03:09:05.986809+03
25327	79	-1	550	2020-05-09 03:11:28.260951+03
25328	89	-1	1420	2020-05-09 03:13:36.133956+03
25329	54	-1	3470	2020-05-09 03:27:57.9625+03
25330	63	-1	1780	2020-05-09 04:00:05.226236+03
25331	14	-1	1350	2020-05-09 05:17:47.334796+03
25332	53	-1	3120	2020-05-09 05:23:01.967216+03
25333	83	42	607	2020-05-09 06:33:26.054831+03
25334	39	-1	910	2020-05-09 06:46:00.258377+03
25335	11	-1	830	2020-05-09 06:55:12.310957+03
25336	87	-1	2320	2020-05-09 07:14:27.903106+03
25337	12	-1	1650	2020-05-09 07:33:49.694528+03
25338	14	-1	1350	2020-05-09 08:32:56.966453+03
25339	88	-1	1270	2020-05-09 08:50:35.368668+03
25340	54	-1	3470	2020-05-09 08:59:37.732831+03
25341	42	-1	1790	2020-05-09 09:07:06.332854+03
25342	91	-1	1620	2020-05-09 09:48:12.867416+03
25343	71	-2	1030	2020-05-09 09:56:44.090271+03
25344	48	-1	640	2020-05-09 10:16:10.55861+03
25345	50	-2	1140	2020-05-09 10:17:01.035699+03
25346	42	-1	1790	2020-05-09 10:35:01.247798+03
25347	44	-1	500	2020-05-09 11:04:16.834795+03
25348	29	36	1114	2020-05-09 11:36:39.951663+03
25349	90	-1	1780	2020-05-09 12:01:46.344016+03
25350	21	-1	960	2020-05-09 12:22:30.40934+03
25351	50	-1	1140	2020-05-09 12:24:43.203633+03
25352	48	-1	640	2020-05-09 12:27:03.081806+03
25353	63	-1	1780	2020-05-09 13:01:31.58853+03
25354	5	-1	1620	2020-05-09 13:24:21.488805+03
25355	82	-1	560	2020-05-09 13:36:24.005264+03
25356	67	-1	350	2020-05-09 13:37:46.38295+03
25357	40	-1	1430	2020-05-09 14:16:03.179726+03
25358	14	-1	1350	2020-05-09 14:19:53.782734+03
25359	12	-1	1650	2020-05-09 15:09:09.639794+03
25360	50	-1	1140	2020-05-09 15:52:46.425213+03
25361	40	-1	1430	2020-05-09 15:55:50.874086+03
25362	57	-1	1900	2020-05-09 16:00:17.94598+03
25363	55	-1	3480	2020-05-09 16:01:46.242603+03
25364	54	22	1674	2020-05-09 16:09:52.731566+03
25365	7	-1	810	2020-05-09 16:46:39.733302+03
25366	40	-2	1430	2020-05-09 16:58:32.329154+03
25367	20	-3	830	2020-05-09 17:16:11.484842+03
25368	43	-1	380	2020-05-09 17:22:17.74314+03
25369	10	-1	2080	2020-05-09 17:27:38.537163+03
25370	52	-1	1090	2020-05-09 17:36:57.108963+03
25371	52	-1	1090	2020-05-09 17:47:30.263514+03
25372	47	-1	1480	2020-05-09 17:54:52.610906+03
25373	47	-1	1480	2020-05-09 18:09:28.100712+03
25374	13	-1	460	2020-05-09 18:31:17.961769+03
25375	22	-1	1070	2020-05-09 18:31:47.816555+03
25376	52	-3	1090	2020-05-09 18:42:33.324414+03
25377	10	34	926	2020-05-09 18:52:38.072747+03
25378	84	-1	2700	2020-05-09 19:17:44.771347+03
25379	87	-1	2320	2020-05-09 19:48:57.231151+03
25380	76	-1	1070	2020-05-09 19:54:43.559426+03
25381	46	-2	1270	2020-05-09 20:29:48.743304+03
25382	10	-1	2080	2020-05-09 20:34:15.617191+03
25383	37	-1	1290	2020-05-09 21:03:52.796582+03
25384	4	-1	1420	2020-05-09 21:10:33.832386+03
25385	81	-1	1620	2020-05-09 21:10:40.387449+03
25386	32	-1	710	2020-05-09 21:23:48.59974+03
25387	92	-1	630	2020-05-09 21:36:32.849204+03
25388	52	-1	1090	2020-05-09 21:49:51.888888+03
25389	83	-2	1230	2020-05-09 21:51:19.760611+03
25390	77	-1	640	2020-05-09 22:19:37.226723+03
25391	51	-1	1310	2020-05-09 22:39:28.599059+03
25392	61	-1	1510	2020-05-09 22:39:45.034839+03
25393	1	-1	640	2020-05-09 22:43:48.278829+03
25394	68	-1	490	2020-05-09 22:49:55.281718+03
25395	22	-1	1070	2020-05-09 22:55:39.357606+03
25396	30	-2	1140	2020-05-09 22:58:02.627619+03
25397	16	-1	1380	2020-05-09 23:05:54.814249+03
25398	22	-1	1070	2020-05-10 00:59:12.917893+03
25399	22	-1	1070	2020-05-10 01:18:52.570529+03
25400	25	-1	1100	2020-05-10 01:21:53.422604+03
25401	76	-1	1070	2020-05-10 01:21:55.182288+03
25402	80	-1	1120	2020-05-10 01:31:42.07403+03
25403	31	-2	1190	2020-05-10 01:32:14.175527+03
25404	86	-1	910	2020-05-10 02:30:06.841223+03
25405	17	-1	1500	2020-05-10 02:33:19.322875+03
25406	91	-1	1620	2020-05-10 03:08:53.759403+03
25407	22	-1	1070	2020-05-10 03:23:49.957337+03
25408	47	-1	1480	2020-05-10 04:15:25.069147+03
25409	33	-1	900	2020-05-10 04:43:17.426135+03
25410	42	-1	1790	2020-05-10 05:33:29.195313+03
25411	75	-1	830	2020-05-10 05:44:52.565239+03
25412	33	-1	900	2020-05-10 06:03:10.35082+03
25413	36	-1	630	2020-05-10 06:29:43.567199+03
25414	70	-1	760	2020-05-10 06:47:59.972394+03
25415	66	-1	690	2020-05-10 06:49:23.590544+03
25416	55	-1	3480	2020-05-10 07:12:12.586734+03
25417	83	-2	1230	2020-05-10 07:14:18.043828+03
25418	22	-2	1070	2020-05-10 07:33:03.122803+03
25419	60	-1	2700	2020-05-10 07:46:19.618029+03
25420	27	-2	880	2020-05-10 08:28:37.738022+03
25421	8	-1	1920	2020-05-10 08:29:39.339932+03
25422	60	-1	2700	2020-05-10 08:43:46.98526+03
25423	64	-1	970	2020-05-10 08:48:32.007854+03
25424	54	-1	3470	2020-05-10 09:22:22.062919+03
25425	70	-1	760	2020-05-10 09:26:54.560801+03
25426	28	-2	1860	2020-05-10 09:29:10.757056+03
25427	96	-2	1570	2020-05-10 09:44:02.787516+03
25428	45	-1	1590	2020-05-10 09:47:00.933841+03
25429	33	-1	900	2020-05-10 10:04:36.691969+03
25430	58	-1	2830	2020-05-10 10:10:02.335051+03
25431	93	-1	1620	2020-05-10 10:22:56.505073+03
25432	28	-1	1860	2020-05-10 10:29:54.088683+03
25433	6	-1	980	2020-05-10 10:30:12.592519+03
25434	41	-1	830	2020-05-10 11:18:47.415605+03
25435	29	-1	1940	2020-05-10 11:33:15.689374+03
25436	54	-1	3470	2020-05-10 11:47:13.932842+03
25437	67	-1	350	2020-05-10 12:11:31.08915+03
25438	79	-1	550	2020-05-10 12:14:21.88061+03
25439	12	-2	1650	2020-05-10 12:20:58.835596+03
25440	23	-1	4390	2020-05-10 12:41:12.577121+03
25441	37	-1	1290	2020-05-10 12:47:29.103802+03
25442	37	-1	1290	2020-05-10 13:00:03.196143+03
25443	47	-2	1480	2020-05-10 13:08:22.874737+03
25444	12	-1	1650	2020-05-10 13:11:31.515938+03
25445	51	-1	1310	2020-05-10 13:16:29.123837+03
25446	6	-2	980	2020-05-10 13:20:07.929474+03
25447	58	-1	2830	2020-05-10 13:38:29.549723+03
25448	28	-1	1860	2020-05-10 13:40:40.691231+03
25449	57	-1	1900	2020-05-10 13:58:09.136024+03
25450	23	-1	4390	2020-05-10 14:03:08.766779+03
25451	9	-1	2090	2020-05-10 14:21:16.081573+03
25452	51	-1	1310	2020-05-10 14:25:35.624567+03
25453	79	-1	550	2020-05-10 14:26:47.005601+03
25454	81	-1	1620	2020-05-10 14:38:01.232242+03
25455	17	-1	1500	2020-05-10 14:48:36.975674+03
25456	78	-1	900	2020-05-10 15:00:16.495153+03
25457	37	-1	1290	2020-05-10 15:21:46.608621+03
25458	53	-2	3120	2020-05-10 15:57:49.303023+03
25459	29	-1	1940	2020-05-10 15:58:27.248852+03
25460	38	-1	1100	2020-05-10 16:05:34.446102+03
25461	5	-1	1620	2020-05-10 16:08:56.29984+03
25462	14	-1	1350	2020-05-10 16:52:17.17252+03
25463	50	-1	1140	2020-05-10 17:20:49.244907+03
25464	86	-1	910	2020-05-10 18:15:11.960179+03
25465	54	-1	3470	2020-05-10 18:35:01.202729+03
25466	33	-2	900	2020-05-10 18:50:33.412935+03
25467	19	-1	1220	2020-05-10 19:12:56.232848+03
25468	92	-1	630	2020-05-10 20:13:10.678219+03
25469	22	-1	1070	2020-05-10 20:48:53.091717+03
25470	35	-2	670	2020-05-10 20:57:43.317813+03
25471	94	-1	1230	2020-05-10 21:30:38.116353+03
25472	88	-1	1270	2020-05-10 21:46:05.294034+03
25473	12	-1	1650	2020-05-10 21:47:37.659855+03
25474	74	-1	1010	2020-05-10 22:00:17.369674+03
25475	63	-1	1780	2020-05-10 22:13:17.018907+03
25476	80	-1	1120	2020-05-10 22:29:37.060209+03
25477	83	-1	1230	2020-05-10 22:36:38.87589+03
25478	55	-1	3480	2020-05-10 22:48:04.549888+03
25479	42	-2	1790	2020-05-10 22:59:17.382827+03
25480	23	-1	4390	2020-05-10 23:06:03.98675+03
25481	19	-1	1220	2020-05-10 23:10:14.837805+03
25482	91	-1	1620	2020-05-11 00:00:18.227644+03
25483	57	-1	1900	2020-05-11 00:13:44.470168+03
25484	90	-1	1780	2020-05-11 00:16:16.591942+03
25485	23	-1	4390	2020-05-11 00:23:25.458439+03
25486	94	-1	1230	2020-05-11 00:32:48.349267+03
25487	8	-1	1920	2020-05-11 01:11:18.662127+03
25488	28	-1	1860	2020-05-11 01:19:11.200141+03
25489	30	-2	1140	2020-05-11 01:19:54.523067+03
25490	38	-1	1100	2020-05-11 01:36:12.272771+03
25491	49	-2	970	2020-05-11 01:47:30.20459+03
25492	88	32	586	2020-05-11 01:59:58.928575+03
25493	85	-1	730	2020-05-11 02:15:33.333705+03
25494	63	-1	1780	2020-05-11 02:43:27.268096+03
25495	65	-2	490	2020-05-11 02:43:43.310269+03
25496	48	-1	640	2020-05-11 02:48:56.132351+03
25497	62	-1	1220	2020-05-11 02:53:58.6882+03
25498	45	-1	1590	2020-05-11 03:23:26.993474+03
25499	5	-2	1620	2020-05-11 03:33:44.328106+03
25500	66	-1	690	2020-05-11 03:35:34.758205+03
25501	24	-1	950	2020-05-11 03:38:24.114808+03
25502	87	-1	2320	2020-05-11 03:42:38.938433+03
25503	30	-1	1140	2020-05-11 03:57:28.140994+03
25504	62	-1	1220	2020-05-11 04:19:29.482779+03
25505	47	-1	1480	2020-05-11 04:36:18.630184+03
25506	46	-1	1270	2020-05-11 04:51:18.696964+03
25507	94	-1	1230	2020-05-11 05:36:08.257486+03
25508	55	-1	3480	2020-05-11 05:37:31.713651+03
25509	89	-1	1420	2020-05-11 05:53:00.011648+03
25510	91	-1	1620	2020-05-11 06:13:55.623697+03
25511	14	-1	1350	2020-05-11 06:20:51.52743+03
25512	69	-1	1100	2020-05-11 06:36:05.827206+03
25513	5	-1	1620	2020-05-11 07:07:19.002764+03
25514	86	22	410	2020-05-11 07:08:44.320759+03
25515	4	-1	1420	2020-05-11 07:09:34.418948+03
25516	36	-2	630	2020-05-11 07:24:08.7192+03
25517	9	22	979	2020-05-11 07:35:10.450934+03
25518	10	-1	2080	2020-05-11 08:36:21.441963+03
25519	17	-1	1500	2020-05-11 09:40:01.361616+03
25520	47	-1	1480	2020-05-11 09:42:53.710692+03
25521	71	-1	1030	2020-05-11 09:58:13.466934+03
25522	50	-1	1140	2020-05-11 10:01:55.367698+03
25523	86	-1	910	2020-05-11 10:07:17.333604+03
25524	45	-2	1590	2020-05-11 10:10:02.210288+03
25525	34	-1	1550	2020-05-11 10:20:50.748367+03
25526	32	-1	710	2020-05-11 10:25:41.350097+03
25527	53	-1	3120	2020-05-11 10:38:44.906065+03
25528	92	-1	630	2020-05-11 10:41:16.302651+03
25529	70	-2	760	2020-05-11 10:41:45.238251+03
25530	19	-1	1220	2020-05-11 11:01:12.455238+03
25531	11	-1	830	2020-05-11 11:08:31.706084+03
25532	22	-1	1070	2020-05-11 11:15:36.953516+03
25533	38	-1	1100	2020-05-11 11:20:41.556155+03
25534	8	-1	1920	2020-05-11 11:35:22.638389+03
25535	56	-1	2460	2020-05-11 12:13:21.264934+03
25536	8	-1	1920	2020-05-11 12:23:43.246106+03
25537	4	-2	1420	2020-05-11 12:26:23.122593+03
25538	69	-1	1100	2020-05-11 12:43:41.810898+03
25539	92	-1	630	2020-05-11 12:59:58.733221+03
25540	92	-1	630	2020-05-11 13:08:00.842995+03
25541	23	-1	4390	2020-05-11 13:43:48.929408+03
25542	76	-1	1070	2020-05-11 14:06:18.686491+03
25543	10	-1	2080	2020-05-11 14:12:19.716122+03
25544	86	-1	910	2020-05-11 14:33:00.375169+03
25545	67	-2	350	2020-05-11 14:51:52.320637+03
25546	18	-1	910	2020-05-11 15:21:09.456322+03
25547	3	-1	660	2020-05-11 15:49:08.559985+03
25548	7	-1	810	2020-05-11 16:03:39.214567+03
25549	89	-1	1420	2020-05-11 16:16:39.286202+03
25550	43	-1	380	2020-05-11 16:51:28.8611+03
25551	62	13	557	2020-05-11 17:33:41.384342+03
25552	89	-1	1420	2020-05-11 17:35:02.07961+03
25553	21	-1	960	2020-05-11 17:38:21.397212+03
25554	33	-2	900	2020-05-11 18:01:00.533849+03
25555	3	-1	660	2020-05-11 18:14:22.464352+03
25556	42	-1	1790	2020-05-11 18:51:21.819175+03
25557	24	-2	950	2020-05-11 18:57:49.070051+03
25558	55	-1	3480	2020-05-11 19:13:35.546213+03
25559	77	-1	640	2020-05-11 19:39:06.602212+03
25560	60	-1	2700	2020-05-11 19:44:46.518381+03
25561	1	-1	640	2020-05-11 19:48:05.251955+03
25562	57	-2	1900	2020-05-11 19:51:40.807242+03
25563	24	-1	950	2020-05-11 20:23:48.854515+03
25564	14	-1	1350	2020-05-11 21:37:34.473089+03
25565	7	-2	810	2020-05-11 21:48:21.589978+03
25566	69	-1	1100	2020-05-11 21:58:58.475819+03
25567	13	-1	460	2020-05-11 21:59:47.021595+03
25568	88	-1	1270	2020-05-11 22:11:04.871662+03
25569	87	-1	2320	2020-05-11 22:33:33.130041+03
25570	61	-1	1510	2020-05-11 23:01:29.520565+03
25571	81	-2	1620	2020-05-11 23:30:16.217794+03
25572	46	-1	1270	2020-05-11 23:42:40.584998+03
25573	30	34	585	2020-05-11 23:45:08.621698+03
25574	48	-1	640	2020-05-12 00:14:10.514815+03
25575	47	-1	1480	2020-05-12 00:33:54.576468+03
25576	42	-2	1790	2020-05-12 00:36:13.575104+03
25577	35	-1	670	2020-05-12 00:36:26.510267+03
25578	14	-1	1350	2020-05-12 00:44:59.311711+03
25579	17	-1	1500	2020-05-12 00:45:01.649357+03
25580	48	-1	640	2020-05-12 00:47:13.441553+03
25581	87	-1	2320	2020-05-12 01:03:36.863844+03
25582	79	-2	550	2020-05-12 01:40:38.512386+03
25583	5	-1	1620	2020-05-12 01:51:55.438938+03
25584	54	-1	3470	2020-05-12 02:30:01.71786+03
25585	16	-1	1380	2020-05-12 02:48:41.256228+03
25586	59	-1	1030	2020-05-12 03:40:51.104492+03
25587	83	-1	1230	2020-05-12 04:22:07.627035+03
25588	81	-1	1620	2020-05-12 04:39:57.803198+03
25589	9	-1	2090	2020-05-12 05:14:19.678607+03
25590	42	-1	1790	2020-05-12 06:08:35.22159+03
25591	14	-1	1350	2020-05-12 06:12:06.61855+03
25592	23	-1	4390	2020-05-12 06:33:27.812957+03
25593	17	-1	1500	2020-05-12 06:53:07.822616+03
25594	72	-1	620	2020-05-12 07:11:12.019202+03
25595	80	25	559	2020-05-12 07:39:22.643734+03
25596	94	-2	1230	2020-05-12 07:55:07.517949+03
25597	79	-1	550	2020-05-12 08:01:27.123084+03
25598	75	18	339	2020-05-12 08:16:01.088913+03
25599	46	-1	1270	2020-05-12 08:18:04.522533+03
25600	56	-1	2460	2020-05-12 08:33:39.518889+03
25601	1	-1	640	2020-05-12 08:50:57.161313+03
25602	13	-1	460	2020-05-12 08:51:17.535577+03
25603	54	-1	3470	2020-05-12 08:58:09.305646+03
25604	26	-2	390	2020-05-12 09:07:16.428507+03
25605	29	-1	1940	2020-05-12 09:08:01.926087+03
25606	53	-1	3120	2020-05-12 09:12:46.437064+03
25607	85	-1	730	2020-05-12 09:40:41.579024+03
25608	69	-2	1100	2020-05-12 09:41:43.55851+03
25609	42	-1	1790	2020-05-12 09:47:08.007259+03
25610	75	-1	830	2020-05-12 11:12:57.508748+03
25611	49	-2	970	2020-05-12 11:59:28.260776+03
25612	81	-1	1620	2020-05-12 11:59:57.631014+03
25613	16	-1	1380	2020-05-12 12:12:00.728537+03
25614	17	-2	1500	2020-05-12 12:19:19.214318+03
25615	54	-1	3470	2020-05-12 12:25:46.663393+03
25616	12	-1	1650	2020-05-12 12:48:14.812978+03
25617	1	-1	640	2020-05-12 12:48:21.219578+03
25618	57	-1	1900	2020-05-12 12:53:56.971738+03
25619	95	-1	480	2020-05-12 13:05:54.097081+03
25620	33	-2	900	2020-05-12 13:08:55.218313+03
25621	57	-2	1900	2020-05-12 13:19:34.707351+03
25622	36	-1	630	2020-05-12 14:14:08.06059+03
25623	88	-2	1270	2020-05-12 14:26:37.559143+03
25624	19	-1	1220	2020-05-12 14:29:45.540314+03
25625	15	-2	2830	2020-05-12 14:49:38.591916+03
25626	96	-2	1570	2020-05-12 15:34:49.683615+03
25627	29	-1	1940	2020-05-12 15:42:25.723059+03
25628	47	-2	1480	2020-05-12 15:42:36.447327+03
25629	4	-1	1420	2020-05-12 15:55:34.671332+03
25630	60	-1	2700	2020-05-12 15:57:55.268071+03
25631	26	-1	390	2020-05-12 16:18:40.314395+03
25632	65	-1	490	2020-05-12 16:34:30.073272+03
25633	23	-2	4390	2020-05-12 16:46:42.924651+03
25634	71	-1	1030	2020-05-12 17:13:24.615272+03
25635	84	-1	2700	2020-05-12 17:50:17.513712+03
25636	18	-1	910	2020-05-12 17:52:44.806401+03
25637	68	-1	490	2020-05-12 17:53:25.900409+03
25638	69	-1	1100	2020-05-12 17:54:13.855189+03
25639	61	-1	1510	2020-05-12 18:06:48.148736+03
25640	66	-1	690	2020-05-12 18:23:31.740694+03
25641	80	-1	1120	2020-05-12 18:29:05.545059+03
25642	88	-1	1270	2020-05-12 18:33:09.858871+03
25643	86	-2	910	2020-05-12 18:42:57.856009+03
25644	2	-2	470	2020-05-12 19:05:20.821891+03
25645	53	-2	3120	2020-05-12 19:20:45.68758+03
25646	26	-1	390	2020-05-12 19:37:43.693348+03
25647	94	-1	1230	2020-05-12 19:55:26.299618+03
25648	3	-2	660	2020-05-12 20:17:54.776823+03
25649	87	31	959	2020-05-12 21:07:47.217626+03
25650	69	-1	1100	2020-05-12 21:23:52.203953+03
25651	77	-2	640	2020-05-12 21:54:10.708022+03
25652	56	-1	2460	2020-05-12 21:54:30.520078+03
25653	44	-1	500	2020-05-12 22:05:16.836915+03
25654	63	-1	1780	2020-05-12 22:26:17.313075+03
25655	56	-1	2460	2020-05-12 22:32:00.638744+03
25656	46	-1	1270	2020-05-12 22:47:15.810224+03
25657	37	-1	1290	2020-05-12 22:55:45.45358+03
25658	89	-1	1420	2020-05-12 23:00:30.53223+03
25659	14	-1	1350	2020-05-12 23:29:55.915509+03
25660	50	-2	1140	2020-05-13 00:30:21.966935+03
25661	70	35	341	2020-05-13 00:59:52.369433+03
25662	13	-1	460	2020-05-13 01:12:12.176325+03
25663	91	-1	1620	2020-05-13 01:26:42.216608+03
25664	71	-1	1030	2020-05-13 01:45:12.260594+03
25665	64	-1	970	2020-05-13 01:47:55.505627+03
25666	10	-1	2080	2020-05-13 01:56:07.777841+03
25667	28	-1	1860	2020-05-13 02:07:43.936755+03
25668	37	-1	1290	2020-05-13 02:12:30.867655+03
25669	54	-1	3470	2020-05-13 02:13:44.302058+03
25670	94	-2	1230	2020-05-13 02:31:50.768748+03
25671	48	-2	640	2020-05-13 02:33:16.251113+03
25672	22	-1	1070	2020-05-13 02:54:00.050186+03
25673	33	-2	900	2020-05-13 02:57:30.154347+03
25674	30	-1	1140	2020-05-13 03:36:44.714857+03
25675	47	-1	1480	2020-05-13 03:46:30.272292+03
25676	51	-1	1310	2020-05-13 04:05:08.675609+03
25677	75	-1	830	2020-05-13 04:10:29.340569+03
25678	44	-2	500	2020-05-13 04:17:31.618084+03
25679	67	-1	350	2020-05-13 04:29:04.262087+03
25680	57	-1	1900	2020-05-13 04:33:59.479158+03
25681	21	-1	960	2020-05-13 04:43:21.346203+03
25682	40	-2	1430	2020-05-13 05:02:21.744534+03
25683	67	-1	350	2020-05-13 05:10:24.520647+03
25684	35	-2	670	2020-05-13 05:12:15.71344+03
25685	49	-1	970	2020-05-13 05:34:57.678851+03
25686	36	-1	630	2020-05-13 05:36:52.09888+03
25687	54	-1	3470	2020-05-13 05:47:29.192772+03
25688	91	-1	1620	2020-05-13 05:58:43.426163+03
25689	76	-1	1070	2020-05-13 05:59:48.347554+03
25690	77	-2	640	2020-05-13 06:20:43.577182+03
25691	63	-1	1780	2020-05-13 06:23:20.501087+03
25692	84	-1	2700	2020-05-13 06:32:40.328168+03
25693	76	-1	1070	2020-05-13 06:44:39.582503+03
25694	77	-1	640	2020-05-13 07:04:09.528122+03
25695	23	-1	4390	2020-05-13 07:21:14.859112+03
25696	94	-1	1230	2020-05-13 07:37:42.517177+03
25697	65	-1	490	2020-05-13 08:09:00.821665+03
25698	11	-1	830	2020-05-13 08:29:24.262228+03
25699	85	-1	730	2020-05-13 08:37:07.735832+03
25700	19	-1	1220	2020-05-13 09:20:34.476041+03
25701	47	-1	1480	2020-05-13 10:56:46.099923+03
25702	87	-1	2320	2020-05-13 11:01:31.081314+03
25703	46	-1	1270	2020-05-13 11:07:34.010394+03
25704	47	-1	1480	2020-05-13 11:32:34.049254+03
25705	8	-2	1920	2020-05-13 12:04:34.803426+03
25706	42	-1	1790	2020-05-13 12:19:44.214734+03
25707	40	-1	1430	2020-05-13 12:20:57.969266+03
25708	93	-1	1620	2020-05-13 12:29:45.434999+03
25709	51	-1	1310	2020-05-13 12:31:42.778706+03
25710	13	-1	460	2020-05-13 12:48:10.803154+03
25711	55	-1	3480	2020-05-13 13:25:24.725626+03
25712	10	-1	2080	2020-05-13 13:46:27.336646+03
25713	45	-2	1590	2020-05-13 13:49:33.499735+03
25714	27	-1	880	2020-05-13 13:49:41.54541+03
25715	89	-2	1420	2020-05-13 13:51:17.645029+03
25716	80	-1	1120	2020-05-13 14:42:53.862848+03
25717	4	31	676	2020-05-13 14:59:11.38394+03
25718	12	-1	1650	2020-05-13 15:08:48.306357+03
25719	47	-2	1480	2020-05-13 15:24:44.32674+03
25720	9	-2	2090	2020-05-13 15:31:21.097679+03
25721	18	-1	910	2020-05-13 16:13:26.59707+03
25722	37	-1	1290	2020-05-13 16:18:38.07886+03
25723	13	-1	460	2020-05-13 16:21:46.408632+03
25724	73	-1	960	2020-05-13 16:31:07.626974+03
25725	70	-1	760	2020-05-13 16:59:41.159221+03
25726	71	-1	1030	2020-05-13 17:42:51.817986+03
25727	52	-1	1090	2020-05-13 18:22:43.756805+03
25728	51	-1	1310	2020-05-13 18:22:46.075447+03
25729	95	27	282	2020-05-13 18:35:15.238199+03
25730	76	-1	1070	2020-05-13 19:07:57.108004+03
25731	72	-1	620	2020-05-13 19:23:48.203404+03
25732	41	-1	830	2020-05-13 19:40:56.069576+03
25733	22	-2	1070	2020-05-13 19:51:28.044006+03
25734	71	-2	1030	2020-05-13 19:56:25.585478+03
25735	90	26	943	2020-05-13 20:23:47.158474+03
25736	39	-2	910	2020-05-13 20:31:29.90694+03
25737	42	-1	1790	2020-05-13 21:05:28.287055+03
25738	4	-1	1420	2020-05-13 21:17:55.741412+03
25739	33	-1	900	2020-05-13 21:22:55.581399+03
25740	47	-1	1480	2020-05-13 21:31:17.638939+03
25741	25	16	479	2020-05-13 21:36:03.190122+03
25742	14	-1	1350	2020-05-13 21:41:05.929237+03
25743	8	-1	1920	2020-05-13 21:48:19.413724+03
25744	70	-1	760	2020-05-13 22:02:24.968997+03
25745	47	-1	1480	2020-05-13 22:06:42.50785+03
25746	40	-1	1430	2020-05-13 22:08:38.48077+03
25747	47	-1	1480	2020-05-13 22:12:52.787416+03
25748	33	-1	900	2020-05-13 22:26:46.114932+03
25749	42	-1	1790	2020-05-13 22:34:42.013532+03
25750	25	-1	1100	2020-05-13 22:51:04.809474+03
25751	8	-1	1920	2020-05-13 22:52:43.069954+03
25752	54	-1	3470	2020-05-13 23:24:09.455889+03
25753	48	-2	640	2020-05-13 23:33:12.189185+03
25754	32	-1	710	2020-05-13 23:55:01.162241+03
25755	1	-1	640	2020-05-14 00:07:58.673788+03
25756	67	-1	350	2020-05-14 00:21:10.060661+03
25757	85	-1	730	2020-05-14 00:53:52.679744+03
25758	93	-1	1620	2020-05-14 00:54:38.370741+03
25759	61	-1	1510	2020-05-14 01:10:03.416725+03
25760	43	18	214	2020-05-14 01:27:25.574356+03
25761	75	-1	830	2020-05-14 01:49:59.141042+03
25762	4	-1	1420	2020-05-14 02:12:05.379853+03
25763	96	-1	1570	2020-05-14 02:17:24.264017+03
25764	56	-1	2460	2020-05-14 02:30:35.600132+03
25765	96	-2	1570	2020-05-14 02:35:06.9021+03
25766	14	-2	1350	2020-05-14 02:55:08.698851+03
25767	22	-1	1070	2020-05-14 02:59:50.603974+03
25768	80	-1	1120	2020-05-14 03:13:56.830384+03
25769	67	-1	350	2020-05-14 03:16:09.173592+03
25770	6	-1	980	2020-05-14 04:02:50.705955+03
25771	33	-1	900	2020-05-14 04:04:01.156304+03
25772	46	-1	1270	2020-05-14 04:11:05.996425+03
25773	45	-1	1590	2020-05-14 04:25:39.625527+03
25774	59	-1	1030	2020-05-14 04:34:38.461097+03
25775	59	-1	1030	2020-05-14 04:39:51.344274+03
25776	54	-1	3470	2020-05-14 04:43:04.691573+03
25777	47	-1	1480	2020-05-14 05:28:13.090585+03
25778	96	-1	1570	2020-05-14 05:39:40.251109+03
25779	63	-1	1780	2020-05-14 05:44:41.251294+03
25780	35	-1	670	2020-05-14 05:44:42.222509+03
25781	11	-1	830	2020-05-14 06:00:32.916919+03
25782	60	-1	2700	2020-05-14 06:13:15.467437+03
25783	9	-1	2090	2020-05-14 06:21:04.946185+03
25784	52	-1	1090	2020-05-14 06:22:22.60549+03
25785	76	-1	1070	2020-05-14 06:38:41.006042+03
25786	23	-2	4390	2020-05-14 06:39:27.726889+03
25787	10	-1	2080	2020-05-14 06:41:43.968794+03
25788	32	-1	710	2020-05-14 07:27:39.546755+03
25789	1	-1	640	2020-05-14 07:27:41.99281+03
25790	10	-1	2080	2020-05-14 07:32:32.248921+03
25791	58	-1	2830	2020-05-14 07:51:10.153807+03
25792	89	-1	1420	2020-05-14 08:06:40.688279+03
25793	61	-1	1510	2020-05-14 08:09:49.065823+03
25794	17	-1	1500	2020-05-14 08:10:21.57321+03
25795	17	-1	1500	2020-05-14 08:15:15.110618+03
25796	38	-1	1100	2020-05-14 08:24:36.433382+03
25797	30	-1	1140	2020-05-14 08:32:10.119871+03
25798	79	15	295	2020-05-14 08:49:11.556725+03
25799	35	-1	670	2020-05-14 09:51:18.835422+03
25800	7	-1	810	2020-05-14 10:05:24.611938+03
25801	38	-2	1100	2020-05-14 10:56:54.505824+03
25802	19	-1	1220	2020-05-14 11:02:39.031236+03
25803	27	-2	880	2020-05-14 11:55:43.806155+03
25804	91	-1	1620	2020-05-14 12:00:13.160346+03
25805	92	-1	630	2020-05-14 12:00:20.055137+03
25806	35	-2	670	2020-05-14 12:06:41.239874+03
25807	47	-1	1480	2020-05-14 12:14:21.795245+03
25808	32	-1	710	2020-05-14 12:29:21.770099+03
25809	6	-1	980	2020-05-14 12:40:33.469701+03
25810	23	-1	4390	2020-05-14 12:50:35.77125+03
25811	95	-1	480	2020-05-14 13:07:18.199697+03
25812	43	-1	380	2020-05-14 13:11:06.515502+03
25813	25	-1	1100	2020-05-14 13:28:00.544074+03
25814	21	-1	960	2020-05-14 13:41:53.791048+03
25815	29	-1	1940	2020-05-14 13:54:45.369301+03
25816	59	-1	1030	2020-05-14 13:59:16.767017+03
25817	83	-1	1230	2020-05-14 15:08:25.87113+03
25818	4	-1	1420	2020-05-14 15:18:04.015743+03
25819	76	-1	1070	2020-05-14 15:47:46.712066+03
25820	47	-1	1480	2020-05-14 15:55:06.542908+03
25821	44	-1	500	2020-05-14 16:27:48.951771+03
25822	36	-1	630	2020-05-14 16:30:49.448191+03
25823	40	-1	1430	2020-05-14 16:33:24.330274+03
25824	12	-1	1650	2020-05-14 16:44:08.436563+03
25825	35	-1	670	2020-05-14 17:10:06.382737+03
25826	47	-1	1480	2020-05-14 17:23:09.429678+03
25827	89	-1	1420	2020-05-14 17:27:26.306446+03
25828	19	-1	1220	2020-05-14 17:27:31.885544+03
25829	59	-2	1030	2020-05-14 18:11:33.044112+03
25830	7	-1	810	2020-05-14 18:14:39.382797+03
25831	40	-2	1430	2020-05-14 18:17:47.717532+03
25832	30	-1	1140	2020-05-14 18:21:04.606702+03
25833	92	-1	630	2020-05-14 18:23:57.438658+03
25834	77	-1	640	2020-05-14 19:28:16.28561+03
25835	31	-1	1190	2020-05-14 19:44:57.172601+03
25836	55	-1	3480	2020-05-14 19:53:09.816159+03
25837	78	-1	900	2020-05-14 20:03:21.049635+03
25838	94	-1	1230	2020-05-14 20:41:34.692663+03
25839	13	-2	460	2020-05-14 20:47:51.134615+03
25840	49	-1	970	2020-05-14 20:53:36.715101+03
25841	63	-1	1780	2020-05-14 20:55:25.308669+03
25842	53	-1	3120	2020-05-14 21:00:53.301242+03
25843	68	-1	490	2020-05-14 21:02:55.070619+03
25844	64	-1	970	2020-05-14 22:09:05.974302+03
25845	73	-1	960	2020-05-14 22:19:44.721964+03
25846	13	33	193	2020-05-14 22:43:38.484326+03
25847	11	-3	830	2020-05-14 22:56:19.96038+03
25848	12	-1	1650	2020-05-14 23:52:54.749856+03
25849	76	-1	1070	2020-05-15 00:38:10.125123+03
25850	65	-2	490	2020-05-15 00:45:24.525449+03
25851	61	-2	1510	2020-05-15 00:47:15.713696+03
25852	91	-1	1620	2020-05-15 01:18:14.692834+03
25853	19	-1	1220	2020-05-15 01:28:31.233262+03
25854	44	-1	500	2020-05-15 01:43:44.365941+03
25855	52	-1	1090	2020-05-15 02:11:14.865395+03
25856	11	-1	830	2020-05-15 02:15:03.726494+03
25857	68	-1	490	2020-05-15 02:44:55.2481+03
25858	63	-1	1780	2020-05-15 03:05:28.569079+03
25859	64	-1	970	2020-05-15 03:16:31.160808+03
25860	90	-1	1780	2020-05-15 03:21:08.576085+03
25861	80	-1	1120	2020-05-15 03:48:56.314578+03
25862	4	-1	1420	2020-05-15 03:52:48.487459+03
25863	9	-3	2090	2020-05-15 04:08:14.789738+03
25864	43	-1	380	2020-05-15 04:34:36.134326+03
25865	37	-1	1290	2020-05-15 05:13:16.196684+03
25866	87	-1	2320	2020-05-15 05:24:14.911378+03
25867	59	-1	1030	2020-05-15 05:33:06.02521+03
25868	95	-2	480	2020-05-15 06:00:20.923262+03
25869	56	-1	2460	2020-05-15 06:04:42.840567+03
25870	89	-1	1420	2020-05-15 06:06:00.075451+03
25871	60	-1	2700	2020-05-15 06:33:42.586888+03
25872	35	-1	670	2020-05-15 06:33:43.992583+03
25873	88	-2	1270	2020-05-15 06:46:30.612951+03
25874	77	-1	640	2020-05-15 07:50:09.061047+03
25875	84	-1	2700	2020-05-15 08:28:26.824168+03
25876	1	-1	640	2020-05-15 08:30:02.573788+03
25877	20	-1	830	2020-05-15 08:36:53.770558+03
25878	59	-1	1030	2020-05-15 08:52:16.264998+03
25879	57	-2	1900	2020-05-15 09:21:09.999737+03
25880	21	16	518	2020-05-15 09:30:20.873908+03
25881	14	-1	1350	2020-05-15 09:36:58.424194+03
25882	53	-1	3120	2020-05-15 09:50:06.713277+03
25883	27	-1	880	2020-05-15 09:55:54.485118+03
25884	15	-1	2830	2020-05-15 10:17:27.949175+03
25885	6	-1	980	2020-05-15 10:23:33.050509+03
25886	41	-2	830	2020-05-15 10:26:09.968445+03
25887	83	-1	1230	2020-05-15 10:40:59.011454+03
25888	64	-1	970	2020-05-15 11:00:26.151399+03
25889	93	-2	1620	2020-05-15 11:03:41.937918+03
25890	6	-1	980	2020-05-15 11:22:39.475974+03
25891	75	-1	830	2020-05-15 11:39:31.259922+03
25892	93	-1	1620	2020-05-15 11:51:35.755659+03
25893	96	-1	1570	2020-05-15 11:58:25.997531+03
25894	26	-2	390	2020-05-15 12:15:44.55058+03
25895	89	-2	1420	2020-05-15 12:24:38.430155+03
25896	13	-1	460	2020-05-15 12:27:19.665012+03
25897	51	-1	1310	2020-05-15 12:34:41.140939+03
25898	71	-1	1030	2020-05-15 12:42:23.414316+03
25899	28	-1	1860	2020-05-15 13:01:03.952064+03
25900	92	-2	630	2020-05-15 13:06:13.868775+03
25901	75	-1	830	2020-05-15 13:52:07.872372+03
25902	42	-2	1790	2020-05-15 14:02:54.212642+03
25903	54	-1	3470	2020-05-15 14:31:29.743235+03
25904	69	-1	1100	2020-05-15 14:35:35.214614+03
25905	59	-2	1030	2020-05-15 15:16:52.221584+03
25906	29	-1	1940	2020-05-15 15:21:21.639349+03
25907	24	-1	950	2020-05-15 15:29:57.727307+03
25908	77	-1	640	2020-05-15 15:41:09.314979+03
25909	49	-1	970	2020-05-15 15:42:10.175471+03
25910	88	-1	1270	2020-05-15 16:15:04.820172+03
25911	7	-2	810	2020-05-15 16:18:53.577047+03
25912	43	-1	380	2020-05-15 16:41:54.049584+03
25913	76	-1	1070	2020-05-15 16:55:00.286232+03
25914	27	-1	880	2020-05-15 16:58:16.375883+03
25915	71	33	528	2020-05-15 17:07:07.215516+03
25916	1	-2	640	2020-05-15 17:33:14.79687+03
25917	52	-1	1090	2020-05-15 17:38:44.730519+03
25918	38	-1	1100	2020-05-15 18:01:15.03109+03
25919	56	-1	2460	2020-05-15 18:25:41.147596+03
25920	15	-1	2830	2020-05-15 19:13:33.041584+03
25921	86	-1	910	2020-05-15 20:18:13.204985+03
25922	42	-1	1790	2020-05-15 20:22:48.566766+03
25923	54	-1	3470	2020-05-15 20:29:21.052763+03
25924	69	-1	1100	2020-05-15 20:40:46.144559+03
25925	37	40	581	2020-05-15 20:57:52.217957+03
25926	14	-1	1350	2020-05-15 20:58:05.272862+03
25927	67	-2	350	2020-05-15 21:29:07.679692+03
25928	25	-1	1100	2020-05-15 21:39:16.975074+03
25929	54	-1	3470	2020-05-15 22:20:54.107363+03
25930	11	-1	830	2020-05-15 22:27:03.942854+03
25931	12	-1	1650	2020-05-15 22:51:16.008757+03
25932	17	-1	1500	2020-05-15 22:59:17.898147+03
25933	82	-1	560	2020-05-15 23:00:42.380007+03
25934	33	-1	900	2020-05-15 23:32:30.705568+03
25935	77	-1	640	2020-05-15 23:56:40.653205+03
25936	84	-1	2700	2020-05-16 00:32:38.415278+03
25937	77	-2	640	2020-05-16 00:44:35.094947+03
25938	20	-1	830	2020-05-16 00:58:17.655898+03
25939	23	-1	4390	2020-05-16 01:13:27.171384+03
25940	37	-1	1290	2020-05-16 01:40:13.139688+03
25941	46	-1	1270	2020-05-16 01:42:49.183523+03
25942	14	-1	1350	2020-05-16 01:57:46.049409+03
25943	24	-2	950	2020-05-16 02:12:28.492277+03
25944	46	-2	1270	2020-05-16 02:19:53.871221+03
25945	34	-2	1550	2020-05-16 02:24:24.727111+03
25946	17	-2	1500	2020-05-16 03:21:07.582573+03
25947	92	-1	630	2020-05-16 03:27:40.409362+03
25948	48	-1	640	2020-05-16 03:53:01.048702+03
25949	48	-1	640	2020-05-16 04:03:04.217948+03
25950	75	-2	830	2020-05-16 04:30:47.196871+03
25951	32	-2	710	2020-05-16 04:46:12.769222+03
25952	1	-1	640	2020-05-16 04:57:35.205778+03
25953	35	-2	670	2020-05-16 05:13:22.217059+03
25954	48	-1	640	2020-05-16 05:19:44.811327+03
25955	83	-1	1230	2020-05-16 05:37:14.029337+03
25956	17	-1	1500	2020-05-16 06:09:40.27175+03
25957	22	-1	1070	2020-05-16 06:23:08.812943+03
25958	76	-1	1070	2020-05-16 06:34:31.358542+03
25959	87	-1	2320	2020-05-16 06:58:44.776071+03
25960	51	-1	1310	2020-05-16 07:12:59.619961+03
25961	51	-2	1310	2020-05-16 07:26:29.595956+03
25962	86	-1	910	2020-05-16 07:36:57.410691+03
25963	22	-1	1070	2020-05-16 07:48:28.289055+03
25964	76	-2	1070	2020-05-16 08:22:45.98451+03
25965	13	-1	460	2020-05-16 08:26:00.744907+03
25966	84	20	1358	2020-05-16 08:33:00.688956+03
25967	26	-1	390	2020-05-16 08:40:14.976675+03
25968	70	-3	760	2020-05-16 08:56:02.84257+03
25969	18	-1	910	2020-05-16 09:35:57.861616+03
25970	52	-1	1090	2020-05-16 09:36:25.948073+03
25971	4	-1	1420	2020-05-16 09:47:42.803047+03
25972	49	-1	970	2020-05-16 09:58:28.691007+03
25973	79	-1	550	2020-05-16 10:14:25.323739+03
25974	35	-1	670	2020-05-16 10:33:33.923351+03
25975	58	-1	2830	2020-05-16 10:41:42.636462+03
25976	54	-1	3470	2020-05-16 11:09:14.259722+03
25977	69	-1	1100	2020-05-16 11:24:02.310429+03
25978	2	-1	470	2020-05-16 11:50:54.633787+03
25979	18	-1	910	2020-05-16 11:53:52.619653+03
25980	4	-1	1420	2020-05-16 12:16:40.532687+03
25981	82	-1	560	2020-05-16 12:33:31.267664+03
25982	67	-1	350	2020-05-16 12:44:50.895762+03
25983	69	-1	1100	2020-05-16 12:55:10.965173+03
25984	9	-2	2090	2020-05-16 13:20:09.622805+03
25985	67	-1	350	2020-05-16 13:20:30.680712+03
25986	39	-1	910	2020-05-16 13:35:25.933793+03
25987	23	-1	4390	2020-05-16 13:44:29.930857+03
25988	5	-1	1620	2020-05-16 14:41:08.984453+03
25989	33	-1	900	2020-05-16 15:14:49.353384+03
25990	67	-1	350	2020-05-16 15:14:57.446719+03
25991	70	-1	760	2020-05-16 15:30:04.362709+03
25992	96	-1	1570	2020-05-16 15:30:33.21152+03
25993	26	-2	390	2020-05-16 15:31:16.616313+03
25994	83	-1	1230	2020-05-16 16:17:36.094515+03
25995	1	-1	640	2020-05-16 16:18:39.322801+03
25996	36	-1	630	2020-05-16 16:20:28.177774+03
25997	92	-1	630	2020-05-16 16:36:26.525322+03
25998	61	31	827	2020-05-16 16:40:41.034847+03
25999	35	34	355	2020-05-16 16:58:47.320361+03
26000	15	-2	2830	2020-05-16 17:00:03.498756+03
26001	90	-1	1780	2020-05-16 17:20:49.389855+03
26002	95	-2	480	2020-05-16 17:25:34.425056+03
26003	84	-1	2700	2020-05-16 18:13:42.613833+03
26004	44	-1	500	2020-05-16 18:37:14.087174+03
26005	37	-1	1290	2020-05-16 18:45:58.991131+03
26006	88	-1	1270	2020-05-16 19:47:27.28593+03
26007	21	-1	960	2020-05-16 19:58:56.70966+03
26008	13	-2	460	2020-05-16 20:00:57.624649+03
26009	35	-1	670	2020-05-16 20:04:04.570294+03
26010	56	-1	2460	2020-05-16 20:06:17.666402+03
26011	64	-1	970	2020-05-16 20:44:25.140957+03
26012	44	-1	500	2020-05-16 21:04:33.69472+03
26013	95	-1	480	2020-05-16 21:06:37.850097+03
26014	3	-1	660	2020-05-16 21:13:33.175922+03
26015	83	-1	1230	2020-05-16 21:13:53.594384+03
26016	71	-2	1030	2020-05-16 21:31:14.030824+03
26017	52	-1	1090	2020-05-16 21:46:08.963684+03
26018	77	43	375	2020-05-16 22:03:14.28214+03
26019	84	-1	2700	2020-05-16 22:20:37.315488+03
26020	32	-1	710	2020-05-16 22:51:24.149931+03
26021	10	-1	2080	2020-05-16 23:08:19.557437+03
26022	31	-2	1190	2020-05-16 23:08:41.77299+03
26023	26	24	223	2020-05-16 23:37:49.225958+03
26024	37	-2	1290	2020-05-16 23:41:34.184384+03
26025	35	-1	670	2020-05-16 23:50:00.483427+03
26026	40	-1	1430	2020-05-17 00:11:16.202246+03
26027	32	23	406	2020-05-17 00:48:51.701209+03
26028	48	-1	640	2020-05-17 00:55:51.769171+03
26029	84	-1	2700	2020-05-17 01:09:45.973296+03
26030	56	-2	2460	2020-05-17 01:35:20.549121+03
26031	67	-1	350	2020-05-17 01:40:13.028455+03
26032	44	-1	500	2020-05-17 01:43:09.802368+03
26033	86	-1	910	2020-05-17 02:20:28.348117+03
26034	64	-1	970	2020-05-17 02:31:11.722662+03
26035	49	-1	970	2020-05-17 02:32:19.501229+03
26036	89	-1	1420	2020-05-17 02:43:35.691022+03
26037	13	-1	460	2020-05-17 03:01:03.541663+03
26038	90	-1	1780	2020-05-17 03:08:39.789219+03
26039	84	-1	2700	2020-05-17 03:09:04.845213+03
26040	40	-2	1430	2020-05-17 03:12:32.252162+03
26041	73	-1	960	2020-05-17 03:13:36.2319+03
26042	71	-1	1030	2020-05-17 03:16:13.383265+03
26043	85	-1	730	2020-05-17 03:34:26.728106+03
26044	71	-1	1030	2020-05-17 04:21:46.452546+03
26045	82	-1	560	2020-05-17 04:34:08.724245+03
26046	38	-1	1100	2020-05-17 04:45:04.073408+03
26047	85	-1	730	2020-05-17 04:50:09.64948+03
26048	33	40	407	2020-05-17 04:53:53.477578+03
26049	43	-1	380	2020-05-17 05:18:09.706417+03
26050	69	-1	1100	2020-05-17 06:05:21.955345+03
26051	55	-1	3480	2020-05-17 06:17:11.168705+03
26052	6	-1	980	2020-05-17 06:40:46.7492+03
26053	74	-1	1010	2020-05-17 06:45:52.024465+03
26054	64	-2	970	2020-05-17 06:50:01.151802+03
26055	77	-2	640	2020-05-17 06:56:24.31602+03
26056	27	-1	880	2020-05-17 07:09:39.646654+03
26057	89	-1	1420	2020-05-17 07:25:29.33128+03
26058	89	-2	1420	2020-05-17 07:28:33.793113+03
26059	47	-1	1480	2020-05-17 07:34:55.275939+03
26060	96	-1	1570	2020-05-17 07:47:16.318276+03
26061	32	-1	710	2020-05-17 07:51:16.181978+03
26062	73	-1	960	2020-05-17 07:57:23.768534+03
26063	55	30	1553	2020-05-17 08:21:10.107545+03
26064	63	-1	1780	2020-05-17 08:29:14.476949+03
26065	51	-1	1310	2020-05-17 08:46:13.939553+03
26066	64	-1	970	2020-05-17 09:08:39.0733+03
26067	41	-1	830	2020-05-17 09:24:33.540503+03
26068	85	-1	730	2020-05-17 09:26:41.596296+03
26069	96	-1	1570	2020-05-17 09:28:07.753956+03
26070	67	-1	350	2020-05-17 09:28:19.652481+03
26071	34	-1	1550	2020-05-17 09:45:07.661785+03
26072	93	-2	1620	2020-05-17 09:47:40.574454+03
26073	19	-2	1220	2020-05-17 09:58:56.465+03
26074	50	-2	1140	2020-05-17 10:42:11.928495+03
26075	69	-1	1100	2020-05-17 10:44:03.699042+03
26076	91	-1	1620	2020-05-17 11:09:55.097923+03
26077	96	-1	1570	2020-05-17 11:57:22.783641+03
26078	50	-1	1140	2020-05-17 12:14:05.181361+03
26079	6	-1	980	2020-05-17 12:25:28.001995+03
26080	51	-1	1310	2020-05-17 12:36:04.086331+03
26081	55	-1	3480	2020-05-17 13:01:35.221073+03
26082	47	-1	1480	2020-05-17 13:08:15.542234+03
26083	56	-1	2460	2020-05-17 13:31:41.690064+03
26084	38	-1	1100	2020-05-17 13:59:05.724598+03
26085	82	-2	560	2020-05-17 14:01:25.373995+03
26086	42	-1	1790	2020-05-17 14:05:07.21946+03
26087	15	-1	2830	2020-05-17 14:27:34.985835+03
26088	96	-1	1570	2020-05-17 15:00:54.321067+03
26089	39	-1	910	2020-05-17 15:10:14.978611+03
26090	41	-1	830	2020-05-17 15:36:44.708897+03
26091	76	-1	1070	2020-05-17 15:47:15.520668+03
26092	83	-2	1230	2020-05-17 15:55:48.396742+03
26093	83	-1	1230	2020-05-17 16:01:02.135472+03
26094	87	-1	2320	2020-05-17 16:43:05.91545+03
26095	31	-1	1190	2020-05-17 16:46:02.536423+03
26096	55	-1	3480	2020-05-17 17:03:03.941496+03
26097	72	-1	620	2020-05-17 17:15:43.0763+03
26098	61	-1	1510	2020-05-17 17:17:15.602365+03
26099	34	-1	1550	2020-05-17 17:28:20.645261+03
26100	5	-1	1620	2020-05-17 17:34:22.858425+03
26101	76	-1	1070	2020-05-17 18:25:59.665724+03
26102	15	-1	2830	2020-05-17 18:44:32.976878+03
26103	20	-2	830	2020-05-17 18:53:10.472262+03
26104	37	-2	1290	2020-05-17 18:57:47.495908+03
26105	28	-1	1860	2020-05-17 19:00:39.47909+03
26106	35	-1	670	2020-05-17 19:37:16.442674+03
26107	47	-1	1480	2020-05-17 19:49:20.31749+03
26108	49	-1	970	2020-05-17 19:50:09.220843+03
26109	21	-1	960	2020-05-17 19:56:51.032745+03
26110	40	-1	1430	2020-05-17 20:00:37.526224+03
26111	21	-1	960	2020-05-17 20:12:01.342876+03
26112	35	-1	670	2020-05-17 20:19:46.354452+03
26113	75	-1	830	2020-05-17 21:32:31.765155+03
26114	34	-1	1550	2020-05-17 21:52:33.32001+03
26115	53	-2	3120	2020-05-17 22:49:36.324574+03
26116	39	-2	910	2020-05-17 23:01:47.0927+03
26117	25	-1	1100	2020-05-17 23:17:46.040222+03
26118	68	-1	490	2020-05-17 23:21:13.518911+03
26119	24	-1	950	2020-05-17 23:41:27.44111+03
26120	42	-1	1790	2020-05-18 00:43:41.757021+03
26121	58	-1	2830	2020-05-18 00:48:25.793143+03
26122	44	-2	500	2020-05-18 00:53:25.216455+03
26123	24	23	417	2020-05-18 01:17:08.841467+03
26124	80	-1	1120	2020-05-18 01:19:41.004399+03
26125	4	-1	1420	2020-05-18 01:38:38.762407+03
26126	73	-1	960	2020-05-18 01:49:07.49416+03
26127	37	-1	1290	2020-05-18 02:01:54.186044+03
26128	62	-1	1220	2020-05-18 02:22:27.134639+03
26129	95	-1	480	2020-05-18 02:50:57.68241+03
26130	96	-1	1570	2020-05-18 02:55:23.221592+03
26131	85	-1	730	2020-05-18 03:12:34.072781+03
26132	42	-2	1790	2020-05-18 03:22:51.060266+03
26133	58	-1	2830	2020-05-18 03:35:26.977264+03
26134	79	-1	550	2020-05-18 03:36:13.401383+03
26135	57	-1	1900	2020-05-18 04:24:24.326399+03
26136	92	-2	630	2020-05-18 04:34:20.198817+03
26137	94	-1	1230	2020-05-18 04:37:08.507527+03
26138	18	-1	910	2020-05-18 04:45:32.626092+03
26139	63	-2	1780	2020-05-18 05:12:15.450769+03
26140	5	-1	1620	2020-05-18 05:14:58.419961+03
26141	45	-1	1590	2020-05-18 05:24:00.601235+03
26142	75	-1	830	2020-05-18 06:12:22.766319+03
26143	71	-1	1030	2020-05-18 07:00:10.992896+03
26144	44	-1	500	2020-05-18 07:18:14.558208+03
26145	64	-1	970	2020-05-18 07:24:33.618943+03
26146	87	-1	2320	2020-05-18 07:25:20.252637+03
26147	61	-1	1510	2020-05-18 07:33:37.808895+03
26148	93	24	766	2020-05-18 08:02:28.252233+03
26149	31	-1	1190	2020-05-18 08:38:42.561702+03
26150	46	-1	1270	2020-05-18 08:40:58.328869+03
26151	13	-1	460	2020-05-18 08:49:41.061717+03
26152	37	-1	1290	2020-05-18 08:51:35.655584+03
26153	83	-1	1230	2020-05-18 08:55:08.096588+03
26154	30	-1	1140	2020-05-18 09:01:48.937077+03
26155	45	-1	1590	2020-05-18 09:53:20.254393+03
26156	7	-1	810	2020-05-18 10:11:24.209131+03
26157	8	-1	1920	2020-05-18 10:31:27.638276+03
26158	10	-1	2080	2020-05-18 10:34:42.377931+03
26159	84	-1	2700	2020-05-18 10:48:23.38264+03
26160	38	-1	1100	2020-05-18 10:48:57.115249+03
26161	67	-2	350	2020-05-18 10:52:45.871036+03
26162	41	-2	830	2020-05-18 11:22:22.63914+03
26163	65	21	277	2020-05-18 11:25:51.018502+03
26164	63	-2	1780	2020-05-18 11:29:12.71922+03
26165	95	-1	480	2020-05-18 11:44:19.791732+03
26166	46	-2	1270	2020-05-18 11:46:27.98957+03
26167	35	-1	670	2020-05-18 11:47:01.35398+03
26168	46	-1	1270	2020-05-18 12:31:39.56667+03
26169	77	-1	640	2020-05-18 12:40:21.100064+03
26170	68	-1	490	2020-05-18 12:41:33.631379+03
26171	15	-1	2830	2020-05-18 13:24:46.8798+03
26172	52	-1	1090	2020-05-18 13:29:29.259878+03
26173	20	-1	830	2020-05-18 13:34:50.630813+03
26174	26	-1	390	2020-05-18 13:38:21.242521+03
26175	1	-1	640	2020-05-18 13:38:23.345213+03
26176	38	-2	1100	2020-05-18 13:55:38.424568+03
26177	55	-1	3480	2020-05-18 14:17:05.968579+03
26178	41	-2	830	2020-05-18 14:33:58.184794+03
26179	24	-2	950	2020-05-18 14:56:48.518025+03
26180	2	-2	470	2020-05-18 15:16:15.083814+03
26181	69	-1	1100	2020-05-18 15:21:34.681384+03
26182	37	-1	1290	2020-05-18 15:45:29.580324+03
26183	54	-2	3470	2020-05-18 15:58:40.611191+03
26184	18	-1	910	2020-05-18 17:00:03.127955+03
26185	96	-1	1570	2020-05-18 17:11:50.1251+03
26186	94	-1	1230	2020-05-18 17:12:41.704226+03
26187	79	-1	550	2020-05-18 17:55:12.342274+03
26188	6	-1	980	2020-05-18 18:03:36.090978+03
26189	86	-2	910	2020-05-18 18:23:08.015081+03
26190	52	-2	1090	2020-05-18 18:25:26.732396+03
26191	12	-2	1650	2020-05-18 18:28:35.539281+03
26192	14	-2	1350	2020-05-18 19:27:10.549098+03
26193	67	-1	350	2020-05-18 19:42:55.941296+03
26194	11	-1	830	2020-05-18 19:48:53.437511+03
26195	56	-1	2460	2020-05-18 19:52:08.662004+03
26196	85	-1	730	2020-05-18 19:54:28.028943+03
26197	51	-1	1310	2020-05-18 20:05:46.04295+03
26198	29	-1	1940	2020-05-18 20:17:02.091177+03
26199	57	-1	1900	2020-05-18 20:19:23.901332+03
26200	30	-1	1140	2020-05-18 20:21:27.465496+03
26201	14	-1	1350	2020-05-18 20:23:39.123852+03
26202	82	-1	560	2020-05-18 20:24:40.265435+03
26203	71	-1	1030	2020-05-18 20:27:01.197263+03
26204	35	-1	670	2020-05-18 20:43:50.691267+03
26205	29	-1	1940	2020-05-18 20:47:28.006204+03
26206	76	-1	1070	2020-05-18 20:58:24.420356+03
26207	64	-1	970	2020-05-18 21:10:56.298372+03
26208	86	-2	910	2020-05-18 21:15:41.299179+03
26209	56	-1	2460	2020-05-18 21:37:41.873676+03
26210	36	-1	630	2020-05-18 21:53:41.592658+03
26211	52	-2	1090	2020-05-18 22:05:24.048323+03
26212	7	-1	810	2020-05-18 22:07:41.365382+03
26213	73	-2	960	2020-05-18 22:13:50.350196+03
26214	58	-2	2830	2020-05-18 22:14:18.767381+03
26215	7	-1	810	2020-05-18 22:19:09.361912+03
26216	58	-1	2830	2020-05-18 22:37:47.35839+03
26217	84	-1	2700	2020-05-18 22:43:50.993366+03
26218	18	34	417	2020-05-18 22:45:48.600801+03
26219	70	-1	760	2020-05-18 22:54:28.091197+03
26220	4	-1	1420	2020-05-18 22:59:15.965374+03
26221	8	-1	1920	2020-05-18 23:09:26.078561+03
26222	58	-2	2830	2020-05-18 23:10:40.675855+03
26223	14	-2	1350	2020-05-18 23:20:36.036713+03
26224	40	-1	1430	2020-05-18 23:25:34.564143+03
26225	63	-1	1780	2020-05-18 23:27:24.855172+03
26226	93	-2	1620	2020-05-19 00:06:49.692576+03
26227	1	-1	640	2020-05-19 01:07:59.613006+03
26228	60	-2	2700	2020-05-19 01:08:35.646318+03
26229	21	-1	960	2020-05-19 01:10:40.653058+03
26230	67	34	154	2020-05-19 01:22:20.962267+03
26231	77	-1	640	2020-05-19 02:00:48.59614+03
26232	10	-1	2080	2020-05-19 02:05:15.988642+03
26233	33	-1	900	2020-05-19 02:28:16.576344+03
26234	22	-2	1070	2020-05-19 02:30:55.81347+03
26235	14	-1	1350	2020-05-19 02:45:08.071717+03
26236	42	-1	1790	2020-05-19 02:46:04.761524+03
26237	71	-1	1030	2020-05-19 03:13:24.812386+03
26238	20	-1	830	2020-05-19 03:41:48.121817+03
26239	93	-2	1620	2020-05-19 03:55:39.461454+03
26240	6	-1	980	2020-05-19 04:20:14.814399+03
26241	73	-2	960	2020-05-19 04:29:16.123391+03
26242	4	-1	1420	2020-05-19 04:55:57.15631+03
26243	49	-1	970	2020-05-19 04:58:40.259115+03
26244	77	-1	640	2020-05-19 05:04:27.500235+03
26245	69	-1	1100	2020-05-19 05:52:54.577+03
26246	56	-1	2460	2020-05-19 05:59:12.636608+03
26247	7	-1	810	2020-05-19 06:05:59.413161+03
26248	35	-1	670	2020-05-19 06:10:25.297949+03
26249	71	-1	1030	2020-05-19 06:33:00.547994+03
26250	65	-2	490	2020-05-19 06:56:04.590319+03
26251	28	18	878	2020-05-19 07:17:18.921973+03
26252	27	-1	880	2020-05-19 07:21:59.697872+03
26253	19	-1	1220	2020-05-19 07:43:48.123042+03
26254	70	-1	760	2020-05-19 07:53:43.820162+03
26255	57	-1	1900	2020-05-19 08:15:18.847823+03
26256	58	-1	2830	2020-05-19 08:19:51.926847+03
26257	20	-1	830	2020-05-19 08:22:33.254342+03
26258	79	-1	550	2020-05-19 08:39:10.956445+03
26259	76	-1	1070	2020-05-19 08:41:09.321669+03
26260	60	-1	2700	2020-05-19 08:54:38.883582+03
26261	78	-1	900	2020-05-19 09:01:58.391991+03
26262	84	-1	2700	2020-05-19 09:02:07.546654+03
26263	14	-1	1350	2020-05-19 09:04:33.378143+03
26264	79	-1	550	2020-05-19 09:10:46.184063+03
26265	19	-1	1220	2020-05-19 09:15:04.743725+03
26266	24	-1	950	2020-05-19 09:18:33.560649+03
26267	47	-2	1480	2020-05-19 09:27:29.266949+03
26268	5	-1	1620	2020-05-19 09:40:40.196408+03
26269	43	-1	380	2020-05-19 09:43:19.918963+03
26270	4	-1	1420	2020-05-19 09:58:52.774354+03
26271	17	-1	1500	2020-05-19 09:59:29.253448+03
26272	38	-1	1100	2020-05-19 10:13:03.116096+03
26273	33	-1	900	2020-05-19 10:22:00.253428+03
26274	77	-1	640	2020-05-19 10:46:29.36956+03
26275	46	-2	1270	2020-05-19 10:46:31.501456+03
26276	31	-1	1190	2020-05-19 10:48:45.024374+03
26277	8	30	943	2020-05-19 11:29:43.112317+03
26278	80	-1	1120	2020-05-19 12:20:36.369409+03
26279	5	-2	1620	2020-05-19 12:39:08.355942+03
26280	64	-1	970	2020-05-19 12:46:04.605044+03
26281	64	-1	970	2020-05-19 12:51:48.417485+03
26282	46	-1	1270	2020-05-19 12:56:15.323977+03
26283	57	-1	1900	2020-05-19 13:08:15.222367+03
26284	13	-1	460	2020-05-19 13:35:05.990384+03
26285	22	-1	1070	2020-05-19 13:38:42.721894+03
26286	13	-1	460	2020-05-19 14:14:48.105246+03
26287	4	-1	1420	2020-05-19 14:15:18.228579+03
26288	30	-1	1140	2020-05-19 14:58:06.770971+03
26289	57	-1	1900	2020-05-19 15:00:26.835581+03
26290	1	-1	640	2020-05-19 15:11:18.863793+03
26291	51	-1	1310	2020-05-19 15:34:57.212533+03
26292	12	-1	1650	2020-05-19 15:40:31.917801+03
26293	49	-1	970	2020-05-19 15:51:48.990256+03
26294	25	-1	1100	2020-05-19 15:54:31.45712+03
26295	14	-1	1350	2020-05-19 16:15:53.604493+03
26296	18	-1	910	2020-05-19 16:19:51.574159+03
26297	29	-1	1940	2020-05-19 16:47:09.385746+03
26298	76	-1	1070	2020-05-19 16:56:42.31297+03
26299	54	-1	3470	2020-05-19 17:05:55.204075+03
26300	61	-1	1510	2020-05-19 17:12:48.924497+03
26301	83	-1	1230	2020-05-19 17:13:48.718357+03
26302	58	26	1660	2020-05-19 17:19:15.388283+03
26303	32	-1	710	2020-05-19 18:04:10.427777+03
26304	49	-1	970	2020-05-19 18:26:32.805264+03
26305	82	-1	560	2020-05-19 18:44:20.205735+03
26306	66	-2	690	2020-05-19 18:50:30.140088+03
26307	22	-1	1070	2020-05-19 19:23:53.161329+03
26308	45	-1	1590	2020-05-19 19:32:08.241979+03
26309	9	-1	2090	2020-05-19 19:33:08.827094+03
26310	33	-1	900	2020-05-19 19:33:47.378231+03
26311	59	-1	1030	2020-05-19 19:40:08.698581+03
26312	64	-1	970	2020-05-19 20:10:18.314404+03
26313	70	-1	760	2020-05-19 20:40:47.316216+03
26314	32	-1	710	2020-05-19 20:47:38.29752+03
26315	37	-1	1290	2020-05-19 21:46:59.777081+03
26316	17	-1	1500	2020-05-19 21:57:13.909865+03
26317	16	-1	1380	2020-05-19 22:32:01.929601+03
26318	40	-1	1430	2020-05-19 22:48:05.442668+03
26319	5	-2	1620	2020-05-19 23:48:44.985332+03
26320	80	-1	1120	2020-05-20 00:03:09.074146+03
26321	22	-1	1070	2020-05-20 00:11:59.751414+03
26322	11	-1	830	2020-05-20 01:32:01.734628+03
26323	84	-2	2700	2020-05-20 01:43:25.476585+03
26324	82	-1	560	2020-05-20 01:53:40.482214+03
26325	81	-2	1620	2020-05-20 02:15:51.409802+03
26326	84	-1	2700	2020-05-20 02:16:54.503013+03
26327	6	-1	980	2020-05-20 02:22:28.281554+03
26328	58	-1	2830	2020-05-20 02:23:01.588744+03
26329	95	-1	480	2020-05-20 02:31:12.873364+03
26330	54	-2	3470	2020-05-20 02:50:08.337255+03
26331	32	-1	710	2020-05-20 03:04:18.138383+03
26332	17	29	852	2020-05-20 03:22:41.719356+03
26333	58	-1	2830	2020-05-20 03:51:29.328853+03
26334	56	-1	2460	2020-05-20 04:03:06.357462+03
26335	25	-2	1100	2020-05-20 04:06:20.523268+03
26336	78	-2	900	2020-05-20 04:12:22.951468+03
26337	2	-1	470	2020-05-20 04:45:35.476406+03
26338	9	-1	2090	2020-05-20 04:50:21.070312+03
26339	25	-1	1100	2020-05-20 05:23:22.066779+03
26340	96	-1	1570	2020-05-20 05:35:28.830121+03
26341	1	-1	640	2020-05-20 06:02:57.610074+03
26342	33	-1	900	2020-05-20 06:07:41.222872+03
26343	18	-1	910	2020-05-20 06:19:17.630455+03
26344	58	-2	2830	2020-05-20 06:43:20.842257+03
26345	11	-1	830	2020-05-20 07:34:31.023303+03
26346	21	-1	960	2020-05-20 08:20:15.43672+03
26347	33	-1	900	2020-05-20 08:39:33.061018+03
26348	18	-1	910	2020-05-20 08:44:40.161372+03
26349	36	-1	630	2020-05-20 09:17:19.991528+03
26350	83	-1	1230	2020-05-20 10:02:29.746083+03
26351	40	-1	1430	2020-05-20 10:14:30.789213+03
26352	22	-2	1070	2020-05-20 10:17:07.668822+03
26353	96	-1	1570	2020-05-20 10:21:40.759256+03
26354	11	-1	830	2020-05-20 10:36:06.708396+03
26355	39	36	532	2020-05-20 10:37:48.178727+03
26356	1	-1	640	2020-05-20 11:25:40.421915+03
26357	17	-2	1500	2020-05-20 11:33:24.728953+03
26358	47	-1	1480	2020-05-20 11:34:13.859666+03
26359	75	-1	830	2020-05-20 13:11:49.768177+03
26360	34	-1	1550	2020-05-20 13:23:13.293826+03
26361	64	-1	970	2020-05-20 13:43:48.594983+03
26362	19	-1	1220	2020-05-20 13:56:35.555803+03
26363	15	-1	2830	2020-05-20 14:00:40.868803+03
26364	22	-1	1070	2020-05-20 14:16:56.440212+03
26365	75	-1	830	2020-05-20 14:31:01.859187+03
26366	96	-2	1570	2020-05-20 14:47:48.043557+03
26367	46	-2	1270	2020-05-20 14:53:13.480368+03
26368	22	-1	1070	2020-05-20 15:00:28.647994+03
26369	49	-1	970	2020-05-20 15:04:50.812411+03
26370	72	-1	620	2020-05-20 15:22:42.713324+03
26371	80	-1	1120	2020-05-20 15:23:18.331736+03
26372	79	-1	550	2020-05-20 15:33:39.053702+03
26373	95	-1	480	2020-05-20 15:42:41.891677+03
26374	41	-1	830	2020-05-20 17:06:46.527349+03
26375	35	-1	670	2020-05-20 17:22:55.118123+03
26376	61	-2	1510	2020-05-20 17:39:46.015111+03
26377	56	-1	2460	2020-05-20 17:55:40.883944+03
26378	84	-1	2700	2020-05-20 18:05:58.860701+03
26379	42	-1	1790	2020-05-20 18:09:55.701101+03
26380	15	-1	2830	2020-05-20 18:13:22.137373+03
26381	52	-1	1090	2020-05-20 18:15:26.886331+03
26382	88	-1	1270	2020-05-20 18:40:41.837609+03
26383	30	-1	1140	2020-05-20 18:49:15.226182+03
26384	65	-1	490	2020-05-20 19:11:03.956907+03
26385	47	-1	1480	2020-05-20 19:16:29.341256+03
26386	30	-1	1140	2020-05-20 19:42:33.202347+03
26387	77	-2	640	2020-05-20 19:57:16.053599+03
26388	37	-2	1290	2020-05-20 20:13:08.597769+03
26389	31	-3	1190	2020-05-20 20:20:12.119251+03
26390	7	26	371	2020-05-20 20:43:49.022304+03
26391	36	-2	630	2020-05-20 20:50:36.564916+03
26392	14	-1	1350	2020-05-20 20:50:45.978656+03
26393	65	-1	490	2020-05-20 20:56:20.720707+03
26394	26	-1	390	2020-05-20 21:12:34.02864+03
26395	11	-1	830	2020-05-20 21:29:05.60364+03
26396	81	-2	1620	2020-05-20 21:30:23.692435+03
26397	79	-1	550	2020-05-20 21:38:41.891641+03
26398	54	-1	3470	2020-05-20 21:40:49.588348+03
26399	21	-2	960	2020-05-20 21:53:32.565648+03
26400	36	-2	630	2020-05-20 22:03:54.497048+03
26401	46	-2	1270	2020-05-20 22:22:42.601525+03
26402	31	-1	1190	2020-05-20 22:23:07.76693+03
26403	27	-1	880	2020-05-20 22:34:35.3852+03
26404	54	-1	3470	2020-05-20 22:41:08.901253+03
26405	53	-1	3120	2020-05-21 00:04:54.050876+03
26406	67	-1	350	2020-05-21 00:08:52.884425+03
26407	49	-1	970	2020-05-21 00:30:33.212512+03
26408	51	-2	1310	2020-05-21 00:30:43.647137+03
26409	96	-1	1570	2020-05-21 00:35:39.019146+03
26410	33	-1	900	2020-05-21 01:29:39.859596+03
26411	6	-1	980	2020-05-21 01:46:32.667351+03
26412	6	-1	980	2020-05-21 02:12:19.718876+03
26413	45	-1	1590	2020-05-21 02:19:48.462224+03
26414	37	-1	1290	2020-05-21 02:43:23.923354+03
26415	20	-1	830	2020-05-21 02:47:54.167634+03
26416	9	-2	2090	2020-05-21 03:02:45.787577+03
26417	88	-1	1270	2020-05-21 03:13:10.886289+03
26418	81	-1	1620	2020-05-21 03:54:33.152961+03
26419	78	24	393	2020-05-21 05:32:56.858844+03
26420	83	-2	1230	2020-05-21 05:33:44.552021+03
26421	8	-2	1920	2020-05-21 06:24:46.265002+03
26422	47	-1	1480	2020-05-21 06:46:41.239886+03
26423	76	-1	1070	2020-05-21 06:48:31.695763+03
26424	20	-2	830	2020-05-21 07:15:03.121662+03
26425	16	-1	1380	2020-05-21 07:25:25.029853+03
26426	19	-1	1220	2020-05-21 07:28:44.816799+03
26427	41	-1	830	2020-05-21 07:35:37.491446+03
26428	46	-1	1270	2020-05-21 07:37:31.206217+03
26429	55	-1	3480	2020-05-21 07:55:12.954541+03
26430	28	-1	1860	2020-05-21 07:56:12.81968+03
26431	32	-1	710	2020-05-21 08:21:16.14468+03
26432	41	-1	830	2020-05-21 08:27:25.501413+03
26433	52	-2	1090	2020-05-21 08:34:07.580929+03
26434	1	-1	640	2020-05-21 08:37:37.236668+03
26435	36	-1	630	2020-05-21 09:04:44.157661+03
26436	77	-1	640	2020-05-21 09:09:04.083379+03
26437	22	43	631	2020-05-21 09:21:37.535283+03
26438	9	-1	2090	2020-05-21 09:40:32.773554+03
26439	73	-1	960	2020-05-21 09:50:19.154416+03
26440	63	-1	1780	2020-05-21 09:52:23.628112+03
26441	20	-1	830	2020-05-21 10:24:25.383344+03
26442	21	-1	960	2020-05-21 11:01:13.468327+03
26443	57	-3	1900	2020-05-21 11:49:37.186084+03
26444	67	-1	350	2020-05-21 11:51:20.352368+03
26445	87	-1	2320	2020-05-21 12:42:52.851566+03
26446	60	27	1424	2020-05-21 12:52:09.904873+03
26447	72	9	274	2020-05-21 13:04:17.006472+03
26448	1	-1	640	2020-05-21 13:06:52.75611+03
26449	37	-1	1290	2020-05-21 13:31:02.756496+03
26450	58	-2	2830	2020-05-21 14:01:56.51288+03
26451	94	27	503	2020-05-21 14:18:02.529921+03
26452	95	-1	480	2020-05-21 14:22:09.432156+03
26453	60	-2	2700	2020-05-21 15:26:05.77453+03
26454	77	-1	640	2020-05-21 15:32:03.737717+03
26455	6	-1	980	2020-05-21 15:42:52.34386+03
26456	85	-1	730	2020-05-21 16:56:20.976725+03
26457	50	-1	1140	2020-05-21 17:03:54.871278+03
26458	28	-1	1860	2020-05-21 17:23:30.187594+03
26459	18	-1	910	2020-05-21 17:44:57.245981+03
26460	11	16	399	2020-05-21 17:53:00.203794+03
26461	83	-2	1230	2020-05-21 18:16:33.844509+03
26462	8	-2	1920	2020-05-21 18:33:00.323933+03
26463	3	-1	660	2020-05-21 19:02:42.840927+03
26464	60	-1	2700	2020-05-21 19:04:39.257792+03
26465	4	-1	1420	2020-05-21 19:21:40.832509+03
26466	53	-1	3120	2020-05-21 19:21:49.975124+03
26467	52	-1	1090	2020-05-21 19:38:05.893944+03
26468	39	-1	910	2020-05-21 19:42:29.914291+03
26469	43	-1	380	2020-05-21 19:44:29.892475+03
26470	13	-1	460	2020-05-21 20:08:36.672229+03
26471	39	-1	910	2020-05-21 20:12:21.287037+03
26472	85	-1	730	2020-05-21 20:18:39.43113+03
26473	75	-1	830	2020-05-21 20:25:12.640839+03
26474	57	-1	1900	2020-05-21 20:29:22.861687+03
26475	92	18	288	2020-05-21 20:31:44.77545+03
26476	38	-1	1100	2020-05-21 20:54:28.354666+03
26477	35	-1	670	2020-05-21 20:56:06.982437+03
26478	8	-2	1920	2020-05-21 21:03:08.158557+03
26479	71	-1	1030	2020-05-21 21:15:53.594705+03
26480	80	-1	1120	2020-05-21 21:34:05.021848+03
26481	29	-1	1940	2020-05-21 21:37:36.937706+03
26482	3	-2	660	2020-05-21 21:52:03.48034+03
26483	70	-1	760	2020-05-21 22:14:38.18451+03
26484	61	-1	1510	2020-05-21 22:18:14.77211+03
26485	52	-1	1090	2020-05-21 22:41:19.103557+03
26486	20	-2	830	2020-05-21 22:44:35.25391+03
26487	16	-1	1380	2020-05-21 22:55:55.051621+03
26488	8	-2	1920	2020-05-21 23:02:59.851331+03
26489	96	-2	1570	2020-05-21 23:49:43.895719+03
26490	81	-1	1620	2020-05-22 00:13:56.613725+03
26491	10	-2	2080	2020-05-22 00:56:54.773265+03
26492	36	-1	630	2020-05-22 01:00:38.010017+03
26493	4	-1	1420	2020-05-22 01:01:30.068987+03
26494	45	-1	1590	2020-05-22 01:07:22.672069+03
26495	35	-2	670	2020-05-22 01:26:59.8794+03
26496	26	-1	390	2020-05-22 01:29:34.524333+03
26497	11	-1	830	2020-05-22 01:32:11.644022+03
26498	82	-1	560	2020-05-22 02:00:48.951693+03
26499	35	-1	670	2020-05-22 02:09:10.6643+03
26500	17	-2	1500	2020-05-22 02:27:11.219923+03
26501	59	-1	1030	2020-05-22 03:10:02.133221+03
26502	12	-2	1650	2020-05-22 03:16:27.767544+03
26503	76	-2	1070	2020-05-22 03:18:47.67723+03
26504	76	-1	1070	2020-05-22 03:59:44.590473+03
26505	96	-1	1570	2020-05-22 04:09:23.787454+03
26506	78	-1	900	2020-05-22 04:16:42.397892+03
26507	64	-1	970	2020-05-22 04:36:10.464462+03
26508	90	-1	1780	2020-05-22 05:29:30.827827+03
26509	79	-1	550	2020-05-22 05:38:05.284913+03
26510	32	-1	710	2020-05-22 05:48:46.412567+03
26511	59	-1	1030	2020-05-22 05:59:30.07323+03
26512	94	-1	1230	2020-05-22 06:22:15.825282+03
26513	88	-2	1270	2020-05-22 06:38:30.430256+03
26514	37	-1	1290	2020-05-22 06:42:08.536208+03
26515	26	-2	390	2020-05-22 06:43:24.579399+03
26516	84	-1	2700	2020-05-22 07:03:12.411163+03
26517	4	-1	1420	2020-05-22 07:06:44.771201+03
26518	39	-1	910	2020-05-22 07:36:19.315366+03
26519	5	-1	1620	2020-05-22 07:57:25.851414+03
26520	78	-1	900	2020-05-22 08:02:12.331459+03
26521	7	-1	810	2020-05-22 08:38:04.417949+03
26522	55	-2	3480	2020-05-22 08:47:51.761444+03
26523	69	-1	1100	2020-05-22 08:56:41.143968+03
26524	17	-2	1500	2020-05-22 09:09:42.274582+03
26525	31	-1	1190	2020-05-22 09:22:00.491822+03
26526	14	-1	1350	2020-05-22 10:01:10.138968+03
26527	46	-2	1270	2020-05-22 10:02:29.28167+03
26528	76	-1	1070	2020-05-22 10:47:08.898712+03
26529	20	-1	830	2020-05-22 10:48:51.187345+03
26530	12	-1	1650	2020-05-22 11:03:43.504416+03
26531	71	-1	1030	2020-05-22 11:15:37.982223+03
26532	34	-1	1550	2020-05-22 11:19:29.264932+03
26533	95	-2	480	2020-05-22 12:06:08.262924+03
26534	38	-2	1100	2020-05-22 12:17:33.878177+03
26535	56	-1	2460	2020-05-22 12:31:29.727147+03
26536	67	-1	350	2020-05-22 12:49:06.448736+03
26537	23	-1	4390	2020-05-22 13:39:48.480348+03
26538	63	-1	1780	2020-05-22 14:11:31.291102+03
26539	55	-1	3480	2020-05-22 15:15:13.717628+03
26540	71	-1	1030	2020-05-22 15:28:48.952744+03
26541	42	-2	1790	2020-05-22 15:33:27.388012+03
26542	76	-2	1070	2020-05-22 15:36:52.283755+03
26543	15	-1	2830	2020-05-22 15:50:13.265085+03
26544	79	-1	550	2020-05-22 16:09:12.080302+03
26545	79	-1	550	2020-05-22 16:20:43.833236+03
26546	14	-2	1350	2020-05-22 16:28:20.05126+03
26547	50	-1	1140	2020-05-22 16:50:23.187023+03
26548	76	-1	1070	2020-05-22 16:59:09.448307+03
26549	4	-1	1420	2020-05-22 17:07:44.958741+03
26550	47	38	811	2020-05-22 17:58:00.658981+03
26551	6	-1	980	2020-05-22 18:11:16.206465+03
26552	25	-1	1100	2020-05-22 18:34:34.8249+03
26553	55	-1	3480	2020-05-22 18:43:09.605559+03
26554	40	-1	1430	2020-05-22 18:49:08.314292+03
26555	81	-1	1620	2020-05-22 19:10:42.908252+03
26556	81	-2	1620	2020-05-22 19:40:32.853313+03
26557	20	-1	830	2020-05-22 19:46:31.390724+03
26558	11	-1	830	2020-05-22 20:28:07.317922+03
26559	72	-2	620	2020-05-22 20:36:03.383507+03
26560	10	-1	2080	2020-05-22 20:44:29.206857+03
26561	60	-1	2700	2020-05-22 22:05:32.209225+03
26562	79	-1	550	2020-05-22 22:44:13.965386+03
26563	56	-3	2460	2020-05-22 22:51:21.703312+03
26564	28	-1	1860	2020-05-22 23:06:29.730301+03
26565	79	-2	550	2020-05-22 23:06:52.46593+03
26566	78	-1	900	2020-05-22 23:24:33.937372+03
26567	80	-2	1120	2020-05-22 23:28:35.274474+03
26568	39	-1	910	2020-05-22 23:37:28.262162+03
26569	69	19	626	2020-05-22 23:44:50.859371+03
26570	30	-1	1140	2020-05-22 23:54:36.949544+03
26571	7	-1	810	2020-05-23 00:25:34.4143+03
26572	76	34	623	2020-05-23 00:32:26.657241+03
26573	18	-1	910	2020-05-23 00:35:38.90275+03
26574	82	-1	560	2020-05-23 01:05:34.303171+03
26575	22	-1	1070	2020-05-23 01:10:49.432705+03
26576	27	-2	880	2020-05-23 01:17:21.522934+03
26577	94	-1	1230	2020-05-23 01:22:28.96479+03
26578	4	-1	1420	2020-05-23 01:23:22.884166+03
26579	54	-1	3470	2020-05-23 01:30:27.965566+03
26580	67	-2	350	2020-05-23 01:31:25.302965+03
26581	37	-1	1290	2020-05-23 01:44:45.647451+03
26582	86	-1	910	2020-05-23 01:48:34.885807+03
26583	95	-1	480	2020-05-23 01:53:35.023779+03
26584	86	-1	910	2020-05-23 02:05:46.142611+03
26585	54	-1	3470	2020-05-23 02:21:52.896744+03
26586	11	-1	830	2020-05-23 02:28:19.809991+03
26587	75	-2	830	2020-05-23 02:38:00.049946+03
26588	75	-1	830	2020-05-23 02:45:46.851151+03
26589	2	-1	470	2020-05-23 03:09:46.883514+03
26590	73	-2	960	2020-05-23 03:11:54.893821+03
26591	33	-1	900	2020-05-23 03:19:10.630324+03
26592	63	-2	1780	2020-05-23 03:52:14.931987+03
26593	72	-1	620	2020-05-23 04:20:14.307882+03
26594	88	-2	1270	2020-05-23 04:26:58.427307+03
26595	37	-1	1290	2020-05-23 04:32:19.298378+03
26596	64	-1	970	2020-05-23 04:42:15.210608+03
26597	20	-2	830	2020-05-23 04:50:24.776742+03
26598	11	-1	830	2020-05-23 05:03:51.988523+03
26599	90	-1	1780	2020-05-23 05:05:05.657736+03
26600	31	-1	1190	2020-05-23 05:38:09.220807+03
26601	84	-1	2700	2020-05-23 05:47:10.456796+03
26602	59	-1	1030	2020-05-23 06:21:56.016368+03
26603	5	32	674	2020-05-23 06:41:43.956634+03
26604	4	-1	1420	2020-05-23 06:57:13.735587+03
26605	41	-1	830	2020-05-23 07:03:53.364944+03
26606	58	-1	2830	2020-05-23 07:30:13.590786+03
26607	49	-1	970	2020-05-23 08:10:56.220044+03
26608	52	-1	1090	2020-05-23 08:31:27.675686+03
26609	18	-1	910	2020-05-23 08:48:28.613035+03
26610	63	-1	1780	2020-05-23 08:51:55.480175+03
26611	27	-2	880	2020-05-23 09:21:42.979323+03
26612	95	-2	480	2020-05-23 09:44:06.758427+03
26613	30	-1	1140	2020-05-23 10:01:24.990993+03
26614	68	-1	490	2020-05-23 10:19:09.679887+03
26615	93	-1	1620	2020-05-23 10:19:17.70917+03
26616	1	-1	640	2020-05-23 11:15:13.636625+03
26617	76	-1	1070	2020-05-23 11:16:08.665706+03
26618	29	-1	1940	2020-05-23 11:30:48.841067+03
26619	45	-1	1590	2020-05-23 11:42:49.236996+03
26620	47	-1	1480	2020-05-23 11:47:46.302763+03
26621	94	-1	1230	2020-05-23 11:56:28.051344+03
26622	77	-1	640	2020-05-23 12:08:12.843096+03
26623	30	-1	1140	2020-05-23 12:09:34.738191+03
26624	93	-2	1620	2020-05-23 12:21:10.70504+03
26625	63	-2	1780	2020-05-23 12:28:53.426345+03
26626	51	-1	1310	2020-05-23 12:35:56.157697+03
26627	44	-2	500	2020-05-23 13:11:50.755658+03
26628	4	-1	1420	2020-05-23 13:43:26.641373+03
26629	67	-2	350	2020-05-23 13:56:27.863535+03
26630	24	-2	950	2020-05-23 14:14:30.601119+03
26631	38	-1	1100	2020-05-23 14:20:04.114731+03
26632	94	-1	1230	2020-05-23 14:31:14.064857+03
26633	41	-1	830	2020-05-23 14:54:18.701447+03
26634	59	-1	1030	2020-05-23 14:56:28.136228+03
26635	83	-1	1230	2020-05-23 15:40:21.477783+03
26636	4	-1	1420	2020-05-23 16:15:15.825854+03
26637	73	-1	960	2020-05-23 16:39:50.895163+03
26638	4	-1	1420	2020-05-23 16:46:31.373638+03
26639	55	-2	3480	2020-05-23 16:47:42.091112+03
26640	12	36	730	2020-05-23 16:49:02.91443+03
26641	58	-1	2830	2020-05-23 17:38:34.338728+03
26642	93	-1	1620	2020-05-23 17:44:13.628334+03
26643	16	-1	1380	2020-05-23 17:48:57.266455+03
26644	9	-1	2090	2020-05-23 17:52:04.877792+03
26645	93	-1	1620	2020-05-23 18:16:56.392095+03
26646	93	-2	1620	2020-05-23 18:27:07.614396+03
26647	86	-1	910	2020-05-23 18:28:01.014031+03
26648	48	-1	640	2020-05-23 20:01:36.214866+03
26649	20	-1	830	2020-05-23 20:12:28.903208+03
26650	54	34	1536	2020-05-23 20:34:20.873427+03
26651	26	-1	390	2020-05-23 20:48:11.987479+03
26652	7	-1	810	2020-05-23 20:51:43.982257+03
26653	50	-1	1140	2020-05-23 20:57:35.191659+03
26654	89	-2	1420	2020-05-23 20:58:27.942398+03
26655	34	-1	1550	2020-05-23 21:02:22.017769+03
26656	82	-2	560	2020-05-23 21:03:32.229562+03
26657	70	-1	760	2020-05-23 21:36:26.483876+03
26658	47	-2	1480	2020-05-23 21:37:28.681888+03
26659	4	-1	1420	2020-05-23 21:44:09.018625+03
26660	30	-1	1140	2020-05-23 21:49:50.151762+03
26661	4	-2	1420	2020-05-23 21:51:15.818059+03
26662	63	-1	1780	2020-05-23 21:53:13.812733+03
26663	58	-1	2830	2020-05-23 22:10:51.652806+03
26664	10	-1	2080	2020-05-23 22:29:31.954937+03
26665	6	-1	980	2020-05-23 22:30:12.150159+03
26666	13	-1	460	2020-05-23 22:59:47.455794+03
26667	41	-1	830	2020-05-23 23:36:53.654987+03
26668	81	-1	1620	2020-05-23 23:54:46.546334+03
26669	38	28	557	2020-05-23 23:55:36.09438+03
26670	51	-1	1310	2020-05-24 00:17:49.340311+03
26671	18	-1	910	2020-05-24 00:25:10.239313+03
26672	91	-1	1620	2020-05-24 00:39:38.144466+03
26673	41	-1	830	2020-05-24 00:51:24.422927+03
26674	89	-1	1420	2020-05-24 00:59:04.720084+03
26675	47	-1	1480	2020-05-24 00:59:31.907705+03
26676	95	-2	480	2020-05-24 01:23:25.100756+03
26677	83	-1	1230	2020-05-24 01:43:17.657694+03
26678	53	-1	3120	2020-05-24 02:03:41.733729+03
26679	36	29	274	2020-05-24 02:09:35.483218+03
26680	6	-2	980	2020-05-24 02:35:06.25737+03
26681	7	-1	810	2020-05-24 02:43:35.83822+03
26682	35	-1	670	2020-05-24 02:50:54.502919+03
26683	23	-1	4390	2020-05-24 03:37:34.005817+03
26684	89	28	767	2020-05-24 04:12:35.206895+03
26685	87	-1	2320	2020-05-24 04:16:12.843531+03
26686	54	-1	3470	2020-05-24 04:17:34.798522+03
26687	39	-1	910	2020-05-24 04:31:53.061713+03
26688	43	-1	380	2020-05-24 04:53:00.407457+03
26689	48	-1	640	2020-05-24 05:03:15.822768+03
26690	84	-2	2700	2020-05-24 05:20:58.274681+03
26691	34	-3	1550	2020-05-24 05:21:08.530236+03
26692	3	-1	660	2020-05-24 05:21:25.957328+03
26693	30	-1	1140	2020-05-24 05:37:07.247775+03
26694	74	-1	1010	2020-05-24 05:58:15.293994+03
26695	60	-1	2700	2020-05-24 06:52:23.430971+03
26696	14	-1	1350	2020-05-24 06:59:41.006198+03
26697	63	-1	1780	2020-05-24 07:06:14.293817+03
26698	18	-1	910	2020-05-24 07:15:52.440263+03
26699	80	-1	1120	2020-05-24 07:30:27.167408+03
26700	63	23	892	2020-05-24 07:44:03.00439+03
26701	12	-2	1650	2020-05-24 07:51:49.845183+03
26702	55	-1	3480	2020-05-24 07:53:22.906852+03
26703	12	-1	1650	2020-05-24 07:57:21.970665+03
26704	59	-1	1030	2020-05-24 08:04:19.182238+03
26705	54	-2	3470	2020-05-24 08:13:16.533711+03
26706	23	-1	4390	2020-05-24 08:26:31.649327+03
26707	22	-2	1070	2020-05-24 09:00:47.058706+03
26708	71	-1	1030	2020-05-24 09:11:44.318504+03
26709	35	-1	670	2020-05-24 09:11:44.589319+03
26710	69	-2	1100	2020-05-24 10:02:15.090325+03
26711	96	27	644	2020-05-24 10:26:55.044095+03
26712	35	-1	670	2020-05-24 11:10:48.559187+03
26713	68	-1	490	2020-05-24 11:18:26.939112+03
26714	75	-1	830	2020-05-24 11:25:18.5807+03
26715	1	-1	640	2020-05-24 11:27:03.684937+03
26716	20	-1	830	2020-05-24 11:56:59.02038+03
26717	41	27	376	2020-05-24 12:16:21.853137+03
26718	33	-2	900	2020-05-24 12:32:37.237203+03
26719	47	-1	1480	2020-05-24 12:44:34.939556+03
26720	63	-1	1780	2020-05-24 12:48:04.622914+03
26721	24	-1	950	2020-05-24 12:50:03.621367+03
26722	81	-1	1620	2020-05-24 12:51:28.089382+03
26723	12	-1	1650	2020-05-24 13:25:46.227387+03
26724	30	-1	1140	2020-05-24 13:46:48.335927+03
26725	58	-1	2830	2020-05-24 13:47:11.126473+03
26726	55	-2	3480	2020-05-24 14:19:01.639939+03
26727	6	-1	980	2020-05-24 14:38:17.837585+03
26728	79	-1	550	2020-05-24 14:40:22.609761+03
26729	6	-1	980	2020-05-24 15:05:29.365272+03
26730	86	-1	910	2020-05-24 15:16:38.586699+03
26731	48	23	265	2020-05-24 15:20:06.128398+03
26732	13	-1	460	2020-05-24 15:36:22.953526+03
26733	21	-1	960	2020-05-24 16:15:11.148173+03
26734	80	-1	1120	2020-05-24 16:46:17.576122+03
26735	52	30	496	2020-05-24 16:55:28.621111+03
26736	33	-2	900	2020-05-24 16:56:47.142494+03
26737	7	-1	810	2020-05-24 16:57:28.330021+03
26738	63	-1	1780	2020-05-24 17:25:58.121814+03
26739	95	-1	480	2020-05-24 17:28:26.084749+03
26740	12	-1	1650	2020-05-24 17:39:26.610578+03
26741	58	-1	2830	2020-05-24 17:57:12.198038+03
26742	77	-1	640	2020-05-24 17:59:06.589139+03
26743	22	-2	1070	2020-05-24 18:06:41.032081+03
26744	4	-1	1420	2020-05-24 18:08:06.31263+03
26745	21	-1	960	2020-05-24 18:12:46.505755+03
26746	6	-1	980	2020-05-24 18:18:16.45654+03
26747	92	-2	630	2020-05-24 18:41:54.320155+03
26748	87	-2	2320	2020-05-24 18:46:06.803541+03
26749	67	-1	350	2020-05-24 18:58:53.353466+03
26750	49	-2	970	2020-05-24 19:30:02.627342+03
26751	82	-1	560	2020-05-24 19:42:11.877641+03
26752	2	20	219	2020-05-24 19:45:48.112662+03
26753	55	-2	3480	2020-05-24 19:47:45.925155+03
26754	15	-1	2830	2020-05-24 19:54:40.405348+03
26755	4	-2	1420	2020-05-24 20:32:09.17202+03
26756	31	-1	1190	2020-05-24 20:43:41.049105+03
26757	34	-1	1550	2020-05-24 21:16:50.376408+03
26758	37	-1	1290	2020-05-24 21:17:00.096754+03
26759	26	-1	390	2020-05-24 21:34:23.173588+03
26760	17	-1	1500	2020-05-24 22:09:03.755878+03
26761	54	-1	3470	2020-05-24 22:25:49.895542+03
26762	83	-1	1230	2020-05-24 22:37:44.9451+03
26763	80	-1	1120	2020-05-24 22:42:58.896184+03
26764	80	-1	1120	2020-05-24 22:58:03.558212+03
26765	95	-1	480	2020-05-24 23:06:07.290711+03
26766	48	-1	640	2020-05-24 23:35:28.106048+03
26767	22	-2	1070	2020-05-24 23:39:47.923014+03
26768	75	-1	830	2020-05-24 23:53:20.296181+03
26769	85	-1	730	2020-05-25 00:18:32.068034+03
26770	54	-1	3470	2020-05-25 00:20:15.450074+03
26771	5	-1	1620	2020-05-25 00:25:54.82079+03
26772	2	-1	470	2020-05-25 00:35:15.80813+03
26773	42	-1	1790	2020-05-25 00:43:47.425765+03
26774	37	-1	1290	2020-05-25 01:02:54.11097+03
26775	83	-1	1230	2020-05-25 01:07:23.410339+03
26776	38	-1	1100	2020-05-25 01:09:49.026042+03
26777	37	-2	1290	2020-05-25 01:19:33.426538+03
26778	47	-1	1480	2020-05-25 01:23:27.004923+03
26779	29	-1	1940	2020-05-25 02:01:51.19096+03
26780	1	31	321	2020-05-25 02:03:03.994993+03
26781	39	-1	910	2020-05-25 02:27:21.648736+03
26782	25	-2	1100	2020-05-25 03:05:17.059001+03
26783	31	-2	1190	2020-05-25 03:12:01.932916+03
26784	56	-2	2460	2020-05-25 03:23:48.172339+03
26785	77	-1	640	2020-05-25 04:17:24.664273+03
26786	9	-1	2090	2020-05-25 04:33:51.76483+03
26787	20	-2	830	2020-05-25 04:40:27.132676+03
26788	47	-1	1480	2020-05-25 04:56:56.814531+03
26789	29	-1	1940	2020-05-25 05:29:03.447287+03
26790	71	-1	1030	2020-05-25 05:29:51.257843+03
26791	44	-1	500	2020-05-25 05:35:35.992647+03
26792	23	-1	4390	2020-05-25 06:26:53.553248+03
26793	92	-1	630	2020-05-25 06:31:14.890608+03
26794	65	-2	490	2020-05-25 06:41:43.106594+03
26795	10	-1	2080	2020-05-25 06:42:08.130387+03
26796	82	-1	560	2020-05-25 06:45:48.00292+03
26797	88	-1	1270	2020-05-25 06:45:59.227658+03
26798	88	-1	1270	2020-05-25 06:46:37.946459+03
26799	75	-1	830	2020-05-25 06:52:56.9068+03
26800	18	-1	910	2020-05-25 07:06:43.131588+03
26801	88	-1	1270	2020-05-25 07:11:46.007204+03
26802	7	-1	810	2020-05-25 07:24:08.316262+03
26803	4	-1	1420	2020-05-25 07:42:43.487752+03
26804	14	-1	1350	2020-05-25 07:51:26.650931+03
26805	45	-1	1590	2020-05-25 07:52:06.185842+03
26806	55	-1	3480	2020-05-25 08:11:14.548259+03
26807	39	-2	910	2020-05-25 09:17:37.253738+03
26808	64	-1	970	2020-05-25 09:33:50.431837+03
26809	30	-1	1140	2020-05-25 10:25:22.99796+03
26810	4	-2	1420	2020-05-25 10:43:39.109639+03
26811	29	-1	1940	2020-05-25 10:58:49.212686+03
26812	26	-1	390	2020-05-25 11:06:06.044294+03
26813	76	-1	1070	2020-05-25 11:06:10.689524+03
26814	14	-1	1350	2020-05-25 11:15:04.787643+03
26815	64	-1	970	2020-05-25 11:33:48.919161+03
26816	60	-1	2700	2020-05-25 11:50:51.787043+03
26817	43	-1	380	2020-05-25 11:54:37.822167+03
26818	43	-2	380	2020-05-25 12:01:27.096231+03
26819	5	-2	1620	2020-05-25 12:11:14.963702+03
26820	84	-1	2700	2020-05-25 12:40:18.141455+03
26821	24	-1	950	2020-05-25 12:42:02.011852+03
26822	12	-1	1650	2020-05-25 12:44:06.683115+03
26823	10	-2	2080	2020-05-25 12:46:29.904243+03
26824	32	-1	710	2020-05-25 13:05:47.193574+03
26825	14	-1	1350	2020-05-25 13:12:24.218604+03
26826	69	-1	1100	2020-05-25 13:22:04.549981+03
26827	31	-1	1190	2020-05-25 13:26:32.367828+03
26828	89	-1	1420	2020-05-25 13:37:32.243292+03
26829	77	-1	640	2020-05-25 13:55:39.783173+03
26830	95	-1	480	2020-05-25 13:57:31.349783+03
26831	73	27	528	2020-05-25 14:15:09.188356+03
26832	61	-1	1510	2020-05-25 14:16:00.770735+03
26833	3	-1	660	2020-05-25 14:21:44.382791+03
26834	46	-2	1270	2020-05-25 14:25:32.087348+03
26835	41	-1	830	2020-05-25 14:30:04.731525+03
26836	83	-1	1230	2020-05-25 14:37:51.847965+03
26837	10	-1	2080	2020-05-25 14:45:13.581098+03
26838	90	-2	1780	2020-05-25 14:53:27.41329+03
26839	58	-1	2830	2020-05-25 14:54:14.249587+03
26840	27	-1	880	2020-05-25 14:58:23.630811+03
26841	24	-1	950	2020-05-25 15:18:44.717007+03
26842	47	-1	1480	2020-05-25 15:27:28.08179+03
26843	19	-1	1220	2020-05-25 15:30:25.734505+03
26844	95	-1	480	2020-05-25 15:36:08.772766+03
26845	6	-2	980	2020-05-25 15:42:58.373782+03
26846	21	-1	960	2020-05-25 16:18:57.497128+03
26847	23	-1	4390	2020-05-25 16:27:52.721521+03
26848	89	-1	1420	2020-05-25 17:00:49.862998+03
26849	67	-1	350	2020-05-25 17:24:12.900069+03
26850	49	-1	970	2020-05-25 17:25:33.352581+03
26851	86	-1	910	2020-05-25 17:55:24.98507+03
26852	13	-1	460	2020-05-25 18:03:29.891733+03
26853	10	-2	2080	2020-05-25 18:19:12.237869+03
26854	21	-1	960	2020-05-25 18:24:07.735756+03
26855	69	-2	1100	2020-05-25 18:31:10.385366+03
26856	82	-1	560	2020-05-25 18:37:57.458119+03
26857	93	-1	1620	2020-05-25 18:38:45.61078+03
26858	27	-1	880	2020-05-25 18:55:42.078095+03
26859	6	-1	980	2020-05-25 18:58:57.248563+03
26860	60	-1	2700	2020-05-25 19:12:25.658096+03
26861	54	-1	3470	2020-05-25 19:27:06.143437+03
26862	71	-2	1030	2020-05-25 19:29:44.035189+03
26863	36	-1	630	2020-05-25 19:36:49.501616+03
26864	47	-2	1480	2020-05-25 20:27:26.67997+03
26865	60	-1	2700	2020-05-25 20:45:34.11544+03
26866	57	-1	1900	2020-05-25 21:01:57.247288+03
26867	18	-1	910	2020-05-25 21:11:05.008474+03
26868	18	-1	910	2020-05-25 21:12:58.73717+03
26869	70	-1	760	2020-05-25 21:18:45.124808+03
26870	91	-1	1620	2020-05-25 21:28:20.374734+03
26871	91	-1	1620	2020-05-25 21:33:07.655413+03
26872	47	-1	1480	2020-05-25 21:38:05.234132+03
26873	95	-1	480	2020-05-25 22:00:34.621012+03
26874	47	-1	1480	2020-05-25 22:52:50.244472+03
26875	76	-1	1070	2020-05-25 23:25:06.901582+03
26876	1	-1	640	2020-05-25 23:58:38.432578+03
26877	70	-1	760	2020-05-26 00:02:40.58809+03
26878	4	-2	1420	2020-05-26 00:14:25.209026+03
26879	3	-1	660	2020-05-26 00:37:51.811394+03
26880	72	-2	620	2020-05-26 01:11:56.406171+03
26881	89	-1	1420	2020-05-26 01:34:16.539797+03
26882	87	-1	2320	2020-05-26 02:32:32.062859+03
26883	13	-1	460	2020-05-26 02:41:57.289437+03
26884	39	-1	910	2020-05-26 02:56:24.015163+03
26885	6	-1	980	2020-05-26 03:18:14.989613+03
26886	41	-2	830	2020-05-26 03:20:38.954473+03
26887	89	-1	1420	2020-05-26 03:32:41.20416+03
26888	34	-1	1550	2020-05-26 03:52:03.470766+03
26889	6	-1	980	2020-05-26 04:04:14.452684+03
26890	13	-1	460	2020-05-26 04:18:55.363449+03
26891	49	-1	970	2020-05-26 04:27:08.792923+03
26892	13	-1	460	2020-05-26 04:52:25.384267+03
26893	88	-2	1270	2020-05-26 05:33:05.351387+03
26894	74	-2	1010	2020-05-26 05:34:51.727497+03
26895	82	10	229	2020-05-26 05:48:55.507261+03
26896	89	-1	1420	2020-05-26 06:32:12.997358+03
26897	39	-1	910	2020-05-26 06:57:06.566785+03
26898	23	-2	4390	2020-05-26 07:04:02.703861+03
26899	22	-1	1070	2020-05-26 07:33:24.422956+03
26900	93	-1	1620	2020-05-26 07:58:31.817206+03
26901	88	-1	1270	2020-05-26 08:01:30.463149+03
26902	52	-1	1090	2020-05-26 08:22:31.846543+03
26903	68	-2	490	2020-05-26 08:23:38.007032+03
26904	91	23	947	2020-05-26 09:02:25.936215+03
26905	89	-1	1420	2020-05-26 09:06:30.452146+03
26906	4	-1	1420	2020-05-26 09:16:02.466812+03
26907	12	-1	1650	2020-05-26 09:34:45.965244+03
26908	57	-1	1900	2020-05-26 09:42:35.610056+03
26909	6	36	514	2020-05-26 09:59:30.971415+03
26910	33	-1	900	2020-05-26 10:17:19.617086+03
26911	38	-2	1100	2020-05-26 10:34:36.063208+03
26912	8	-1	1920	2020-05-26 11:04:18.76881+03
26913	57	-1	1900	2020-05-26 11:11:59.394187+03
26914	74	-1	1010	2020-05-26 11:15:41.908551+03
26915	26	-1	390	2020-05-26 11:23:53.49974+03
26916	17	-1	1500	2020-05-26 11:33:27.876211+03
26917	82	-1	560	2020-05-26 11:55:40.256582+03
26918	47	-1	1480	2020-05-26 12:02:10.037134+03
26919	17	-1	1500	2020-05-26 12:21:53.757193+03
26920	47	-2	1480	2020-05-26 12:54:05.139121+03
26921	38	-1	1100	2020-05-26 12:57:15.792481+03
26922	53	28	1390	2020-05-26 13:01:29.636086+03
26923	29	-1	1940	2020-05-26 13:07:41.724557+03
26924	38	-1	1100	2020-05-26 13:38:36.194039+03
26925	28	-1	1860	2020-05-26 13:56:26.592273+03
26926	86	-1	910	2020-05-26 14:01:19.042189+03
26927	33	-1	900	2020-05-26 14:13:17.974547+03
26928	3	-2	660	2020-05-26 14:13:22.629929+03
26929	8	-2	1920	2020-05-26 14:25:23.235156+03
26930	91	-1	1620	2020-05-26 14:37:11.029341+03
26931	7	-1	810	2020-05-26 15:06:09.105205+03
26932	71	-2	1030	2020-05-26 16:02:07.212718+03
26933	46	32	527	2020-05-26 16:05:41.775649+03
26934	38	-1	1100	2020-05-26 16:21:06.134211+03
26935	59	-1	1030	2020-05-26 16:43:47.523119+03
26936	47	-2	1480	2020-05-26 17:00:31.36987+03
26937	96	-1	1570	2020-05-26 17:07:20.770025+03
26938	92	-2	630	2020-05-26 17:12:31.185231+03
26939	47	-1	1480	2020-05-26 17:18:04.971994+03
26940	37	-1	1290	2020-05-26 17:25:24.863802+03
26941	61	-1	1510	2020-05-26 17:39:39.789202+03
26942	67	-1	350	2020-05-26 17:41:00.200928+03
26943	78	-2	900	2020-05-26 17:57:12.626663+03
26944	37	-2	1290	2020-05-26 18:22:39.946544+03
26945	7	-2	810	2020-05-26 18:56:21.193212+03
26946	53	-1	3120	2020-05-26 18:59:11.053054+03
26947	8	-1	1920	2020-05-26 19:02:32.104961+03
26948	37	-2	1290	2020-05-26 19:15:32.07443+03
26949	48	-1	640	2020-05-26 19:24:41.418765+03
26950	2	-1	470	2020-05-26 19:28:40.35097+03
26951	93	-1	1620	2020-05-26 19:34:56.174843+03
26952	11	-1	830	2020-05-26 20:48:14.133061+03
26953	94	-2	1230	2020-05-26 21:11:45.419948+03
26954	80	-1	1120	2020-05-26 21:11:55.103701+03
26955	62	-1	1220	2020-05-26 21:11:59.90682+03
26956	23	-1	4390	2020-05-26 21:18:41.499399+03
26957	67	-2	350	2020-05-26 22:28:53.714122+03
26958	76	-1	1070	2020-05-26 23:12:51.90543+03
26959	87	-1	2320	2020-05-26 23:17:07.989449+03
26960	64	-1	970	2020-05-27 00:09:08.565518+03
26961	76	-1	1070	2020-05-27 00:44:48.16019+03
26962	62	-1	1220	2020-05-27 00:54:37.980488+03
26963	12	-2	1650	2020-05-27 01:01:07.636287+03
26964	72	-1	620	2020-05-27 01:19:25.871768+03
26965	13	-1	460	2020-05-27 01:54:36.450355+03
26966	68	-2	490	2020-05-27 02:05:03.317638+03
26967	41	-1	830	2020-05-27 02:17:34.110226+03
26968	93	-1	1620	2020-05-27 02:25:42.862181+03
26969	33	-1	900	2020-05-27 02:31:59.154022+03
26970	2	-1	470	2020-05-27 03:16:22.962473+03
26971	80	-1	1120	2020-05-27 03:17:21.520769+03
26972	9	-1	2090	2020-05-27 03:31:07.539189+03
26973	29	-1	1940	2020-05-27 03:38:41.447171+03
26974	19	-2	1220	2020-05-27 04:08:42.36791+03
26975	49	-1	970	2020-05-27 04:36:51.574566+03
26976	5	-1	1620	2020-05-27 04:38:17.363297+03
26977	27	-1	880	2020-05-27 05:31:41.923529+03
26978	61	-2	1510	2020-05-27 05:40:28.33988+03
26979	75	-1	830	2020-05-27 06:28:45.77185+03
26980	22	-2	1070	2020-05-27 06:39:56.904918+03
26981	25	-1	1100	2020-05-27 06:48:57.313553+03
26982	46	-2	1270	2020-05-27 06:50:20.690197+03
26983	42	-1	1790	2020-05-27 07:40:39.900297+03
26984	4	-1	1420	2020-05-27 08:36:50.996693+03
26985	33	-2	900	2020-05-27 08:40:41.568446+03
26986	46	-1	1270	2020-05-27 10:19:53.630183+03
26987	82	-1	560	2020-05-27 10:35:44.800696+03
26988	74	-1	1010	2020-05-27 10:52:27.421638+03
26989	16	-1	1380	2020-05-27 11:10:26.247825+03
26990	82	-1	560	2020-05-27 11:33:04.605458+03
26991	54	-1	3470	2020-05-27 11:36:29.534518+03
26992	10	-1	2080	2020-05-27 11:57:03.741483+03
26993	38	-2	1100	2020-05-27 12:29:14.509525+03
26994	46	-1	1270	2020-05-27 12:34:58.083055+03
26995	6	-1	980	2020-05-27 12:35:21.889975+03
26996	69	-2	1100	2020-05-27 13:13:56.904914+03
26997	22	-1	1070	2020-05-27 13:29:01.923705+03
26998	14	-1	1350	2020-05-27 13:29:33.202852+03
26999	25	-1	1100	2020-05-27 13:38:28.776954+03
27000	94	-1	1230	2020-05-27 13:50:07.412049+03
27001	87	-1	2320	2020-05-27 14:07:27.410787+03
27002	49	-1	970	2020-05-27 14:16:47.099904+03
27003	41	-1	830	2020-05-27 14:53:58.673561+03
27004	55	-1	3480	2020-05-27 15:00:06.373084+03
27005	74	-2	1010	2020-05-27 15:27:36.93348+03
27006	14	-1	1350	2020-05-27 15:43:12.400952+03
27007	40	-1	1430	2020-05-27 15:46:28.48465+03
27008	59	-1	1030	2020-05-27 15:49:52.862871+03
27009	42	-1	1790	2020-05-27 15:55:50.687639+03
27010	48	-1	640	2020-05-27 16:21:15.028953+03
27011	80	-1	1120	2020-05-27 16:37:12.301753+03
27012	26	-1	390	2020-05-27 16:37:27.232107+03
27013	81	-1	1620	2020-05-27 16:46:48.69519+03
27014	9	-1	2090	2020-05-27 17:26:59.540249+03
27015	2	-2	470	2020-05-27 17:30:20.81565+03
27016	37	-1	1290	2020-05-27 17:34:42.713684+03
27017	7	-1	810	2020-05-27 18:45:41.796769+03
27018	10	-1	2080	2020-05-27 18:53:57.166469+03
27019	24	-1	950	2020-05-27 18:58:50.59545+03
27020	89	-1	1420	2020-05-27 19:05:49.909486+03
27021	42	-1	1790	2020-05-27 19:12:25.887364+03
27022	96	-1	1570	2020-05-27 19:28:32.014617+03
27023	32	-1	710	2020-05-27 19:51:32.082432+03
27024	50	-1	1140	2020-05-27 20:30:25.965326+03
27025	25	-1	1100	2020-05-27 21:18:16.476078+03
27026	8	-2	1920	2020-05-27 21:28:36.007811+03
27027	96	-1	1570	2020-05-27 21:33:49.234181+03
27028	36	-1	630	2020-05-27 21:44:49.662326+03
27029	43	-1	380	2020-05-27 22:08:05.593115+03
27030	22	-1	1070	2020-05-27 22:08:30.102569+03
27031	35	-1	670	2020-05-27 22:29:22.477617+03
27032	26	-1	390	2020-05-27 22:48:49.031081+03
27033	44	-1	500	2020-05-27 23:08:59.845193+03
27034	43	-2	380	2020-05-27 23:11:18.510325+03
27035	19	-1	1220	2020-05-27 23:14:25.267464+03
27036	75	33	348	2020-05-28 00:01:28.071465+03
27037	70	-1	760	2020-05-28 00:13:10.257369+03
27038	87	-1	2320	2020-05-28 00:27:13.948258+03
27039	73	-1	960	2020-05-28 00:36:30.96124+03
27040	74	23	524	2020-05-28 00:37:48.456878+03
27041	21	-1	960	2020-05-28 00:40:49.343943+03
27042	93	-1	1620	2020-05-28 00:40:54.699216+03
27043	30	-1	1140	2020-05-28 00:45:36.324495+03
27044	21	-2	960	2020-05-28 00:52:51.7015+03
27045	95	-1	480	2020-05-28 00:53:05.081317+03
27046	5	-1	1620	2020-05-28 01:18:50.48881+03
27047	58	-1	2830	2020-05-28 01:37:02.025246+03
27048	85	-1	730	2020-05-28 01:57:15.553217+03
27049	64	24	525	2020-05-28 02:19:30.291212+03
27050	47	-1	1480	2020-05-28 02:22:34.013687+03
27051	91	-1	1620	2020-05-28 02:34:34.683023+03
27052	8	-1	1920	2020-05-28 02:42:28.896181+03
27053	90	-1	1780	2020-05-28 02:54:14.124276+03
27054	43	-1	380	2020-05-28 03:03:54.330061+03
27055	95	-1	480	2020-05-28 03:06:57.452231+03
27056	38	-1	1100	2020-05-28 03:19:12.983981+03
27057	30	-1	1140	2020-05-28 03:31:40.260695+03
27058	14	-1	1350	2020-05-28 04:26:20.398817+03
27059	57	-1	1900	2020-05-28 04:30:20.12371+03
27060	75	-1	830	2020-05-28 04:35:49.760057+03
27061	77	-2	640	2020-05-28 04:50:08.630232+03
27062	82	-1	560	2020-05-28 04:55:25.939343+03
27063	41	-1	830	2020-05-28 06:14:59.589343+03
27064	85	-1	730	2020-05-28 06:23:01.923976+03
27065	68	22	273	2020-05-28 06:28:16.916896+03
27066	89	-2	1420	2020-05-28 06:28:54.395271+03
27067	38	-1	1100	2020-05-28 06:38:03.028688+03
27068	70	-1	760	2020-05-28 06:39:53.545982+03
27069	55	-1	3480	2020-05-28 07:02:14.676172+03
27070	83	-1	1230	2020-05-28 07:08:35.769333+03
27071	20	-1	830	2020-05-28 07:09:57.93939+03
27072	77	-1	640	2020-05-28 07:10:40.855158+03
27073	8	-2	1920	2020-05-28 07:32:32.34729+03
27074	84	-1	2700	2020-05-28 07:38:02.344712+03
27075	75	-1	830	2020-05-28 08:16:17.964716+03
27076	51	-1	1310	2020-05-28 08:16:25.677733+03
27077	77	-1	640	2020-05-28 08:18:58.871801+03
27078	83	-2	1230	2020-05-28 08:41:03.981456+03
27079	47	-1	1480	2020-05-28 08:43:14.930984+03
27080	46	-1	1270	2020-05-28 08:44:06.968481+03
27081	29	-1	1940	2020-05-28 09:11:21.967273+03
27082	96	-1	1570	2020-05-28 09:17:43.867898+03
27083	46	-2	1270	2020-05-28 09:32:02.429454+03
27084	56	-1	2460	2020-05-28 09:45:52.455888+03
27085	36	-2	630	2020-05-28 09:51:56.42465+03
27086	58	-1	2830	2020-05-28 10:35:54.279165+03
27087	85	-2	730	2020-05-28 10:43:20.775582+03
27088	12	-1	1650	2020-05-28 11:10:16.767548+03
27089	12	-1	1650	2020-05-28 11:16:25.78665+03
27090	88	-1	1270	2020-05-28 11:21:32.891458+03
27091	36	-1	630	2020-05-28 11:52:29.662468+03
27092	84	-1	2700	2020-05-28 12:15:39.257345+03
27093	77	-1	640	2020-05-28 12:25:16.661363+03
27094	49	-1	970	2020-05-28 12:31:50.479512+03
27095	74	-1	1010	2020-05-28 12:53:16.533551+03
27096	86	-1	910	2020-05-28 12:58:02.764063+03
27097	23	-1	4390	2020-05-28 13:21:07.012028+03
27098	60	-1	2700	2020-05-28 13:52:48.886145+03
27099	83	-2	1230	2020-05-28 13:57:21.548026+03
27100	40	-1	1430	2020-05-28 13:58:23.317465+03
27101	12	-1	1650	2020-05-28 14:15:56.167971+03
27102	77	-1	640	2020-05-28 14:17:01.688418+03
27103	93	-1	1620	2020-05-28 14:48:47.768702+03
27104	31	-1	1190	2020-05-28 14:58:59.417942+03
27105	52	-1	1090	2020-05-28 15:00:01.211157+03
27106	46	-1	1270	2020-05-28 15:03:55.303384+03
27107	8	-1	1920	2020-05-28 15:04:54.913583+03
27108	95	-1	480	2020-05-28 15:06:40.458223+03
27109	85	-1	730	2020-05-28 15:23:33.097139+03
27110	67	-1	350	2020-05-28 15:29:18.331102+03
27111	61	-1	1510	2020-05-28 15:53:27.906607+03
27112	10	-1	2080	2020-05-28 16:08:41.998153+03
27113	59	-1	1030	2020-05-28 16:49:23.246179+03
27114	4	49	602	2020-05-28 16:54:27.895717+03
27115	52	-1	1090	2020-05-28 17:11:37.403343+03
27116	10	-2	2080	2020-05-28 17:29:22.988843+03
27117	73	-1	960	2020-05-28 17:36:25.414651+03
27118	54	-1	3470	2020-05-28 17:39:29.898656+03
27119	70	-1	760	2020-05-28 18:03:24.237742+03
27120	23	-1	4390	2020-05-28 18:05:24.373057+03
27121	90	-1	1780	2020-05-28 18:10:56.774677+03
27122	70	-2	760	2020-05-28 18:15:52.597146+03
27123	92	-1	630	2020-05-28 18:16:14.605831+03
27124	86	-1	910	2020-05-28 18:18:45.966834+03
27125	47	-2	1480	2020-05-28 18:22:06.784821+03
27126	83	-2	1230	2020-05-28 18:36:14.972996+03
27127	29	-1	1940	2020-05-28 19:04:03.83807+03
27128	5	-1	1620	2020-05-28 19:28:21.471551+03
27129	8	-1	1920	2020-05-28 19:31:46.583057+03
27130	92	-2	630	2020-05-28 20:42:38.932519+03
27131	76	-1	1070	2020-05-28 20:43:13.3333+03
27132	68	-1	490	2020-05-28 21:07:21.748626+03
27133	52	-1	1090	2020-05-28 21:20:37.452593+03
27134	26	-1	390	2020-05-28 21:26:20.673883+03
27135	96	-1	1570	2020-05-28 21:27:02.749576+03
27136	71	-1	1030	2020-05-28 21:34:31.191271+03
27137	13	-1	460	2020-05-28 21:39:40.79805+03
27138	29	-2	1940	2020-05-28 21:58:36.900101+03
27139	12	-1	1650	2020-05-28 22:07:36.605809+03
27140	57	32	1086	2020-05-28 22:11:37.172805+03
27141	86	-2	910	2020-05-28 22:34:13.000681+03
27142	79	-1	550	2020-05-28 22:36:44.174476+03
27143	42	-1	1790	2020-05-28 22:43:53.817385+03
27144	49	-1	970	2020-05-28 23:26:16.951288+03
27145	75	-1	830	2020-05-28 23:56:18.921644+03
27146	46	-1	1270	2020-05-29 00:13:05.632796+03
27147	1	-1	640	2020-05-29 00:18:11.037784+03
27148	59	-1	1030	2020-05-29 00:35:14.703687+03
27149	81	-1	1620	2020-05-29 00:45:14.62115+03
27150	33	-1	900	2020-05-29 01:41:01.676504+03
27151	84	-1	2700	2020-05-29 01:56:24.587982+03
27152	63	-1	1780	2020-05-29 02:04:24.427101+03
27153	79	-1	550	2020-05-29 02:20:11.755428+03
27154	2	-1	470	2020-05-29 02:42:13.555648+03
27155	93	-1	1620	2020-05-29 03:29:45.84239+03
27156	40	-2	1430	2020-05-29 03:42:02.252306+03
27157	59	-1	1030	2020-05-29 04:13:36.520448+03
27158	9	-1	2090	2020-05-29 04:17:24.357799+03
27159	27	-1	880	2020-05-29 05:13:28.427406+03
27160	9	-1	2090	2020-05-29 05:40:08.059777+03
27161	2	-1	470	2020-05-29 05:42:31.605818+03
27162	81	-1	1620	2020-05-29 05:50:15.9687+03
27163	24	-1	950	2020-05-29 05:55:51.498344+03
27164	9	-1	2090	2020-05-29 06:46:29.662592+03
27165	42	-1	1790	2020-05-29 07:23:56.947099+03
27166	90	-1	1780	2020-05-29 07:32:49.654993+03
27167	53	-1	3120	2020-05-29 07:56:09.651487+03
27168	18	-1	910	2020-05-29 08:22:23.33905+03
27169	50	-1	1140	2020-05-29 08:27:15.483694+03
27170	12	-1	1650	2020-05-29 08:55:56.770677+03
27171	92	-1	630	2020-05-29 09:04:27.307504+03
27172	59	30	488	2020-05-29 09:06:16.722209+03
27173	12	-1	1650	2020-05-29 09:32:26.562854+03
27174	94	-1	1230	2020-05-29 09:44:50.753455+03
27175	67	-1	350	2020-05-29 10:28:59.045224+03
27176	49	-1	970	2020-05-29 10:29:58.992625+03
27177	89	-2	1420	2020-05-29 10:37:28.248813+03
27178	41	-1	830	2020-05-29 10:43:28.610099+03
27179	56	-1	2460	2020-05-29 10:55:42.416281+03
27180	19	-1	1220	2020-05-29 10:57:21.095319+03
27181	46	-2	1270	2020-05-29 10:57:23.784241+03
27182	90	-1	1780	2020-05-29 11:12:55.051914+03
27183	93	-2	1620	2020-05-29 11:20:44.613698+03
27184	15	-1	2830	2020-05-29 11:32:32.819539+03
27185	82	-1	560	2020-05-29 11:33:56.515485+03
27186	67	-1	350	2020-05-29 11:49:53.790735+03
27187	85	-2	730	2020-05-29 12:25:28.373178+03
27188	18	-2	910	2020-05-29 12:38:54.157606+03
27189	53	-1	3120	2020-05-29 12:52:55.039036+03
27190	49	-1	970	2020-05-29 12:54:39.702556+03
27191	35	-1	670	2020-05-29 13:30:57.394341+03
27192	34	-1	1550	2020-05-29 13:33:35.896967+03
27193	85	-2	730	2020-05-29 13:37:46.443895+03
27194	57	-2	1900	2020-05-29 14:11:11.688334+03
27195	64	-1	970	2020-05-29 14:14:55.454616+03
27196	4	-1	1420	2020-05-29 15:07:15.862311+03
27197	87	-1	2320	2020-05-29 15:17:45.024443+03
27198	10	-2	2080	2020-05-29 15:24:27.731176+03
27199	28	-1	1860	2020-05-29 15:29:03.162018+03
27200	41	-1	830	2020-05-29 15:44:25.402295+03
27201	12	-1	1650	2020-05-29 15:47:19.576348+03
27202	13	-1	460	2020-05-29 15:54:19.04879+03
27203	20	-1	830	2020-05-29 15:57:25.998581+03
27204	87	-1	2320	2020-05-29 15:58:47.160543+03
27205	60	-2	2700	2020-05-29 16:23:37.447392+03
27206	54	-1	3470	2020-05-29 17:47:38.674456+03
27207	94	-1	1230	2020-05-29 17:48:28.40667+03
27208	13	-1	460	2020-05-29 17:50:15.770131+03
27209	7	-1	810	2020-05-29 17:56:03.649398+03
27210	53	-1	3120	2020-05-29 18:01:35.226184+03
27211	77	-1	640	2020-05-29 18:05:06.052323+03
27212	80	-1	1120	2020-05-29 18:06:35.198791+03
27213	68	-1	490	2020-05-29 18:10:17.867825+03
27214	12	-1	1650	2020-05-29 18:14:40.863872+03
27215	4	-1	1420	2020-05-29 18:30:01.341579+03
27216	17	-1	1500	2020-05-29 18:47:59.826416+03
27217	34	-2	1550	2020-05-29 19:01:10.081141+03
27218	5	-1	1620	2020-05-29 19:01:39.4649+03
27219	27	-1	880	2020-05-29 19:03:42.710844+03
27220	95	-1	480	2020-05-29 19:31:33.79509+03
27221	33	-1	900	2020-05-29 20:25:36.585028+03
27222	24	-1	950	2020-05-29 20:29:24.875985+03
27223	50	-1	1140	2020-05-29 20:33:50.323219+03
27224	30	-1	1140	2020-05-29 20:34:25.549735+03
27225	44	-1	500	2020-05-29 20:43:39.230024+03
27226	75	-1	830	2020-05-29 21:39:26.688569+03
27227	33	-1	900	2020-05-29 21:53:28.726014+03
27228	45	-1	1590	2020-05-29 21:56:54.015138+03
27229	96	-2	1570	2020-05-29 22:48:50.286299+03
27230	83	-1	1230	2020-05-29 22:51:21.579967+03
27231	6	-1	980	2020-05-29 22:54:12.285016+03
27232	93	-1	1620	2020-05-29 22:57:01.208861+03
27233	13	-1	460	2020-05-29 23:03:42.049958+03
27234	2	-2	470	2020-05-29 23:23:09.030408+03
27235	4	-2	1420	2020-05-29 23:45:50.637862+03
27236	88	-2	1270	2020-05-30 00:00:54.760926+03
27237	26	-1	390	2020-05-30 00:11:01.267664+03
27238	78	-1	900	2020-05-30 00:22:57.367576+03
27239	84	21	1464	2020-05-30 00:29:48.555119+03
27240	63	-1	1780	2020-05-30 00:33:41.795599+03
27241	67	-1	350	2020-05-30 00:51:08.011448+03
27242	96	-1	1570	2020-05-30 00:53:50.485013+03
27243	96	-1	1570	2020-05-30 01:52:35.434312+03
27244	51	-1	1310	2020-05-30 01:55:17.839481+03
27245	12	-1	1650	2020-05-30 02:00:17.990091+03
27246	18	-1	910	2020-05-30 02:02:08.987885+03
27247	6	-1	980	2020-05-30 02:11:08.006342+03
27248	29	-1	1940	2020-05-30 02:30:42.078453+03
27249	69	-1	1100	2020-05-30 02:40:53.655241+03
27250	55	-1	3480	2020-05-30 02:43:30.105401+03
27251	64	-1	970	2020-05-30 02:52:47.785882+03
27252	10	-1	2080	2020-05-30 02:59:15.118905+03
27253	34	-1	1550	2020-05-30 03:28:00.440638+03
27254	2	-2	470	2020-05-30 04:12:39.215702+03
27255	6	-2	980	2020-05-30 04:25:43.107293+03
27256	82	-2	560	2020-05-30 04:33:01.946697+03
27257	49	-2	970	2020-05-30 04:52:07.256087+03
27258	8	-2	1920	2020-05-30 05:24:45.830319+03
27259	64	-1	970	2020-05-30 06:17:20.04709+03
27260	22	-1	1070	2020-05-30 06:17:29.523229+03
27261	87	-1	2320	2020-05-30 07:10:22.782215+03
27262	20	-3	830	2020-05-30 08:32:02.219562+03
27263	29	-2	1940	2020-05-30 08:50:21.510671+03
27264	82	-1	560	2020-05-30 09:00:29.685229+03
27265	12	-1	1650	2020-05-30 09:02:26.991335+03
27266	30	-1	1140	2020-05-30 09:09:24.394884+03
27267	75	-1	830	2020-05-30 09:26:04.604146+03
27268	83	-1	1230	2020-05-30 10:05:20.805391+03
27269	46	-1	1270	2020-05-30 10:36:36.315792+03
27270	65	-1	490	2020-05-30 10:50:26.718783+03
27271	34	-1	1550	2020-05-30 10:50:42.859135+03
27272	73	-1	960	2020-05-30 10:55:00.446655+03
27273	35	-1	670	2020-05-30 11:39:53.537043+03
27274	40	-1	1430	2020-05-30 11:49:00.829896+03
27275	46	-1	1270	2020-05-30 12:29:53.952239+03
27276	36	-1	630	2020-05-30 12:57:14.769859+03
27277	21	-1	960	2020-05-30 13:15:39.112892+03
27278	85	16	342	2020-05-30 13:24:13.667591+03
27279	28	-1	1860	2020-05-30 13:29:09.502057+03
27280	78	-1	900	2020-05-30 13:48:44.414832+03
27281	48	-1	640	2020-05-30 13:52:23.050105+03
27282	67	-1	350	2020-05-30 14:05:33.493427+03
27283	81	29	820	2020-05-30 14:23:27.422095+03
27284	42	-1	1790	2020-05-30 14:58:10.335035+03
27285	8	-1	1920	2020-05-30 14:58:34.084938+03
27286	54	-2	3470	2020-05-30 15:18:08.116487+03
27287	57	-1	1900	2020-05-30 15:26:23.28766+03
27288	68	-1	490	2020-05-30 15:56:13.25156+03
27289	82	-1	560	2020-05-30 16:02:57.58231+03
27290	37	-1	1290	2020-05-30 16:15:43.678853+03
27291	13	-1	460	2020-05-30 16:19:14.128951+03
27292	34	-1	1550	2020-05-30 16:55:59.752193+03
27293	87	-1	2320	2020-05-30 17:00:41.912095+03
27294	93	-1	1620	2020-05-30 17:12:46.033056+03
27295	86	-1	910	2020-05-30 17:29:36.158972+03
27296	49	41	477	2020-05-30 17:58:02.484036+03
27297	11	-1	830	2020-05-30 17:58:28.634069+03
27298	2	-1	470	2020-05-30 19:05:16.889043+03
27299	35	-1	670	2020-05-30 19:12:26.54651+03
27300	12	-1	1650	2020-05-30 19:24:14.064152+03
27301	76	-1	1070	2020-05-30 19:25:53.665953+03
27302	23	-1	4390	2020-05-30 19:27:58.805033+03
27303	34	-2	1550	2020-05-30 19:34:07.134527+03
27304	8	-1	1920	2020-05-30 19:36:27.35677+03
27305	93	-1	1620	2020-05-30 19:43:22.490712+03
27306	39	-1	910	2020-05-30 19:43:23.020517+03
27307	4	-2	1420	2020-05-30 19:46:11.404284+03
27308	71	-2	1030	2020-05-30 20:05:55.718595+03
27309	7	-1	810	2020-05-30 20:15:46.97255+03
27310	83	-1	1230	2020-05-30 20:28:04.66595+03
27311	18	-1	910	2020-05-30 20:38:06.486828+03
27312	7	-2	810	2020-05-30 20:58:13.664684+03
27313	47	-1	1480	2020-05-30 21:04:31.783465+03
27314	61	-1	1510	2020-05-30 21:15:57.85786+03
27315	70	-1	760	2020-05-30 21:17:08.322814+03
27316	61	-1	1510	2020-05-30 21:17:34.249053+03
27317	91	-1	1620	2020-05-30 21:24:34.583601+03
27318	42	-2	1790	2020-05-30 21:37:14.497016+03
27319	9	-1	2090	2020-05-30 21:38:29.612377+03
27320	11	-2	830	2020-05-30 21:54:28.513554+03
27321	46	-1	1270	2020-05-30 21:57:24.900529+03
27322	33	-1	900	2020-05-30 21:59:48.995799+03
27323	13	-1	460	2020-05-30 22:35:55.152901+03
27324	33	-2	900	2020-05-30 23:17:14.375123+03
27325	94	-1	1230	2020-05-30 23:21:17.593661+03
27326	55	-2	3480	2020-05-30 23:25:05.078979+03
27327	10	-1	2080	2020-05-30 23:46:04.146556+03
27328	85	-1	730	2020-05-31 00:14:28.09361+03
27329	17	-1	1500	2020-05-31 00:15:35.934961+03
27330	49	-2	970	2020-05-31 00:17:44.020264+03
27331	85	-1	730	2020-05-31 00:37:06.39379+03
27332	89	-1	1420	2020-05-31 00:53:36.827+03
27333	30	-2	1140	2020-05-31 01:03:15.498727+03
27334	32	-1	710	2020-05-31 01:25:37.04078+03
27335	13	-2	460	2020-05-31 01:26:05.106399+03
27336	96	-1	1570	2020-05-31 02:03:54.875666+03
27337	49	-2	970	2020-05-31 02:55:54.803577+03
27338	87	-1	2320	2020-05-31 03:38:56.444745+03
27339	30	-1	1140	2020-05-31 03:51:28.928119+03
27340	48	-1	640	2020-05-31 03:52:28.835935+03
27341	84	-1	2700	2020-05-31 04:43:39.868616+03
27342	23	29	2552	2020-05-31 04:52:34.851266+03
27343	4	-1	1420	2020-05-31 04:57:45.702753+03
27344	7	-1	810	2020-05-31 05:17:08.450001+03
27345	15	-1	2830	2020-05-31 05:19:39.559254+03
27346	55	-2	3480	2020-05-31 05:42:24.128076+03
27347	7	-1	810	2020-05-31 05:42:32.683437+03
27348	61	-1	1510	2020-05-31 06:03:03.711039+03
27349	59	-1	1030	2020-05-31 06:05:57.032852+03
27350	44	-1	500	2020-05-31 06:06:54.008818+03
27351	17	-1	1500	2020-05-31 06:41:14.981425+03
27352	20	-1	830	2020-05-31 07:10:47.955584+03
27353	50	22	607	2020-05-31 07:22:42.474328+03
27354	40	-2	1430	2020-05-31 07:53:19.902129+03
27355	13	-1	460	2020-05-31 07:59:15.767836+03
27356	37	-1	1290	2020-05-31 08:02:02.271221+03
27357	91	-2	1620	2020-05-31 08:44:43.043193+03
27358	13	-1	460	2020-05-31 08:47:00.242042+03
27359	17	-1	1500	2020-05-31 09:04:07.457033+03
27360	38	-1	1100	2020-05-31 09:04:17.279296+03
27361	91	-1	1620	2020-05-31 09:10:34.749728+03
27362	44	-1	500	2020-05-31 09:30:14.193879+03
27363	51	-1	1310	2020-05-31 09:31:22.636207+03
27364	32	-1	710	2020-05-31 10:11:03.846254+03
27365	90	-1	1780	2020-05-31 10:21:42.832464+03
27366	38	-2	1100	2020-05-31 10:24:33.847208+03
27367	40	-2	1430	2020-05-31 10:26:39.35958+03
27368	92	-1	630	2020-05-31 10:36:29.999123+03
27369	86	37	372	2020-05-31 10:56:36.77137+03
27370	59	-1	1030	2020-05-31 11:07:23.199969+03
27371	8	-1	1920	2020-05-31 11:31:20.921077+03
27372	86	-1	910	2020-05-31 11:39:33.767512+03
27373	40	-1	1430	2020-05-31 11:39:46.686151+03
27374	95	29	226	2020-05-31 11:57:15.880905+03
27375	64	-1	970	2020-05-31 12:01:42.206294+03
27376	20	-2	830	2020-05-31 12:46:04.506871+03
27377	20	31	418	2020-05-31 13:07:34.827583+03
27378	81	-1	1620	2020-05-31 13:27:01.267151+03
27379	78	-2	900	2020-05-31 13:34:38.085803+03
27380	56	-1	2460	2020-05-31 13:37:54.209399+03
27381	87	-1	2320	2020-05-31 13:43:10.953279+03
27382	1	-1	640	2020-05-31 13:54:23.158311+03
27383	61	-1	1510	2020-05-31 14:41:08.887221+03
27384	55	-1	3480	2020-05-31 14:48:19.386904+03
27385	62	-2	1220	2020-05-31 15:03:30.443568+03
27386	53	-1	3120	2020-05-31 15:08:42.761239+03
27387	75	-1	830	2020-05-31 16:22:43.119282+03
27388	93	-1	1620	2020-05-31 16:32:26.048559+03
27389	84	-1	2700	2020-05-31 16:37:09.344128+03
27390	56	34	1199	2020-05-31 16:40:20.609037+03
27391	1	-1	640	2020-05-31 16:43:16.397722+03
27392	59	-1	1030	2020-05-31 16:47:59.664679+03
27393	20	-1	830	2020-05-31 17:01:24.105795+03
27394	82	-1	560	2020-05-31 17:22:38.877363+03
27395	82	22	313	2020-05-31 17:34:50.657536+03
27396	6	-2	980	2020-05-31 17:55:56.000673+03
27397	6	-1	980	2020-05-31 18:14:39.810326+03
27398	56	-1	2460	2020-05-31 18:23:56.48244+03
27399	58	-2	2830	2020-05-31 18:33:15.516953+03
27400	88	-1	1270	2020-05-31 19:19:06.832706+03
27401	31	25	546	2020-05-31 19:19:44.744004+03
27402	68	-1	490	2020-05-31 19:30:52.700803+03
27403	44	20	222	2020-05-31 19:40:16.737642+03
27404	63	-2	1780	2020-05-31 19:44:43.729886+03
27405	53	-1	3120	2020-05-31 19:47:47.592549+03
27406	71	-1	1030	2020-05-31 20:20:37.456751+03
27407	8	-1	1920	2020-05-31 21:17:34.876644+03
27408	30	-1	1140	2020-05-31 21:48:05.3723+03
27409	25	-2	1100	2020-05-31 21:57:24.066833+03
27410	41	-1	830	2020-05-31 22:14:43.680317+03
27411	83	-2	1230	2020-05-31 22:32:18.887065+03
27412	94	-1	1230	2020-05-31 22:40:07.46189+03
27413	36	-1	630	2020-05-31 22:55:26.604367+03
27414	51	-1	1310	2020-05-31 22:56:56.837543+03
27415	92	-2	630	2020-05-31 22:57:04.800823+03
27416	2	-1	470	2020-05-31 23:00:22.5259+03
27417	89	-3	1420	2020-05-31 23:13:58.478585+03
27418	73	-2	960	2020-05-31 23:25:12.942241+03
27419	83	-1	1230	2020-05-31 23:39:45.535881+03
27420	6	-1	980	2020-05-31 23:43:59.185784+03
27421	82	-1	560	2020-05-31 23:54:19.368411+03
27422	4	-1	1420	2020-06-01 00:01:58.754773+03
27423	36	-1	630	2020-06-01 00:11:08.775967+03
27424	13	-2	460	2020-06-01 00:19:11.241454+03
27425	71	-1	1030	2020-06-01 00:22:28.97339+03
27426	40	-1	1430	2020-06-01 00:28:02.520075+03
27427	23	-1	4390	2020-06-01 00:59:46.804262+03
27428	91	-2	1620	2020-06-01 01:02:24.06029+03
27429	47	-2	1480	2020-06-01 01:04:39.337147+03
27430	45	-1	1590	2020-06-01 01:34:33.02899+03
27431	87	-1	2320	2020-06-01 01:50:08.78172+03
27432	69	-1	1100	2020-06-01 01:53:35.7912+03
27433	4	-2	1420	2020-06-01 01:54:09.068019+03
27434	38	-1	1100	2020-06-01 03:48:26.763187+03
27435	8	-1	1920	2020-06-01 03:49:46.904094+03
27436	70	-1	760	2020-06-01 04:08:29.524944+03
27437	6	-1	980	2020-06-01 04:08:55.278995+03
27438	19	-1	1220	2020-06-01 04:11:06.866618+03
27439	40	-1	1430	2020-06-01 04:27:39.906677+03
27440	89	-1	1420	2020-06-01 04:39:13.883685+03
27441	11	-1	830	2020-06-01 05:11:00.127486+03
27442	37	-2	1290	2020-06-01 05:15:07.328288+03
27443	8	-1	1920	2020-06-01 05:23:06.634728+03
27444	51	-1	1310	2020-06-01 05:48:24.94557+03
27445	51	-1	1310	2020-06-01 05:51:12.003986+03
27446	83	-1	1230	2020-06-01 05:57:17.063334+03
27447	34	-1	1550	2020-06-01 06:17:13.601117+03
27448	89	-1	1420	2020-06-01 06:22:40.759017+03
27449	12	-2	1650	2020-06-01 06:43:39.125162+03
27450	71	-1	1030	2020-06-01 06:47:08.883108+03
27451	79	25	303	2020-06-01 06:53:36.01593+03
27452	32	-1	710	2020-06-01 06:57:30.612407+03
27453	94	-1	1230	2020-06-01 06:59:15.628655+03
27454	61	-1	1510	2020-06-01 07:04:13.193297+03
27455	45	-2	1590	2020-06-01 07:06:59.843545+03
27456	68	-1	490	2020-06-01 07:08:56.20068+03
27457	41	-1	830	2020-06-01 07:18:12.790527+03
27458	20	-1	830	2020-06-01 07:49:28.510018+03
27459	19	-2	1220	2020-06-01 08:00:10.447074+03
27460	7	-1	810	2020-06-01 08:19:26.740013+03
27461	78	-2	900	2020-06-01 08:22:35.502785+03
27462	10	-1	2080	2020-06-01 08:27:00.175697+03
27463	75	-1	830	2020-06-01 09:27:42.684708+03
27464	52	-1	1090	2020-06-01 09:45:22.112764+03
27465	40	-2	1430	2020-06-01 09:52:25.88599+03
27466	25	16	620	2020-06-01 09:53:00.770339+03
27467	32	-1	710	2020-06-01 10:01:20.944769+03
27468	96	-1	1570	2020-06-01 10:46:41.150196+03
27469	46	-1	1270	2020-06-01 11:06:07.632145+03
27470	38	-1	1100	2020-06-01 11:29:10.366727+03
27471	20	-1	830	2020-06-01 11:39:15.727194+03
27472	63	-1	1780	2020-06-01 11:39:17.627297+03
27473	39	-1	910	2020-06-01 11:45:33.705961+03
27474	1	-1	640	2020-06-01 12:10:42.715447+03
27475	16	-1	1380	2020-06-01 12:25:39.29278+03
27476	91	-1	1620	2020-06-01 12:27:54.988792+03
27477	80	-2	1120	2020-06-01 12:38:32.576396+03
27478	14	-1	1350	2020-06-01 12:45:54.111032+03
27479	5	-1	1620	2020-06-01 12:57:45.082008+03
27480	14	-1	1350	2020-06-01 13:01:33.403992+03
27481	8	-1	1920	2020-06-01 13:30:35.119475+03
27482	68	-2	490	2020-06-01 13:37:01.531685+03
27483	4	-2	1420	2020-06-01 13:39:54.299773+03
27484	57	-2	1900	2020-06-01 14:06:56.97222+03
27485	14	-1	1350	2020-06-01 14:08:40.020227+03
27486	30	-1	1140	2020-06-01 14:18:16.211673+03
27487	3	-1	660	2020-06-01 14:40:31.897834+03
27488	89	-1	1420	2020-06-01 15:39:29.545948+03
27489	81	-1	1620	2020-06-01 15:50:01.726773+03
27490	52	-1	1090	2020-06-01 16:07:10.9677+03
27491	83	-1	1230	2020-06-01 16:07:17.98559+03
27492	13	-1	460	2020-06-01 16:08:05.754317+03
27493	88	-1	1270	2020-06-01 16:39:14.295756+03
27494	46	-1	1270	2020-06-01 16:43:42.949692+03
27495	68	-1	490	2020-06-01 17:44:23.134755+03
27496	64	-2	970	2020-06-01 17:52:52.535173+03
27497	13	-1	460	2020-06-01 17:55:29.823543+03
27498	95	-1	480	2020-06-01 18:03:10.226667+03
27499	83	-1	1230	2020-06-01 18:03:39.257907+03
27500	27	-1	880	2020-06-01 18:23:22.631037+03
27501	47	-1	1480	2020-06-01 18:38:06.844862+03
27502	52	-1	1090	2020-06-01 18:56:00.236057+03
27503	47	-1	1480	2020-06-01 19:01:26.073919+03
27504	22	-1	1070	2020-06-01 19:06:33.012744+03
27505	17	-1	1500	2020-06-01 20:22:08.641963+03
27506	28	-1	1860	2020-06-01 20:23:46.293804+03
27507	10	-1	2080	2020-06-01 20:37:34.708527+03
27508	35	-1	670	2020-06-01 20:53:35.897627+03
27509	24	-1	950	2020-06-01 21:37:23.733123+03
27510	59	-1	1030	2020-06-01 23:01:53.161433+03
27511	6	-1	980	2020-06-01 23:07:52.919635+03
27512	11	-2	830	2020-06-01 23:22:04.396251+03
27513	65	-1	490	2020-06-02 00:26:02.21009+03
27514	26	-1	390	2020-06-02 00:28:39.000413+03
27515	75	-1	830	2020-06-02 01:23:06.403312+03
27516	81	-1	1620	2020-06-02 01:27:00.547702+03
27517	29	-1	1940	2020-06-02 01:28:02.49822+03
27518	55	-1	3480	2020-06-02 01:32:19.012328+03
27519	23	-1	4390	2020-06-02 01:40:31.328051+03
27520	55	-1	3480	2020-06-02 01:41:51.645808+03
27521	44	-1	500	2020-06-02 01:46:02.25136+03
27522	15	-1	2830	2020-06-02 01:48:12.523693+03
27523	89	-1	1420	2020-06-02 02:04:13.49121+03
27524	47	-1	1480	2020-06-02 02:06:07.095265+03
27525	95	-1	480	2020-06-02 02:29:58.185194+03
27526	69	-2	1100	2020-06-02 02:46:10.079677+03
27527	82	-1	560	2020-06-02 02:53:51.889067+03
27528	57	-1	1900	2020-06-02 03:22:37.784333+03
27529	49	-1	970	2020-06-02 03:22:48.871817+03
27530	41	-1	830	2020-06-02 03:36:30.356368+03
27531	80	-1	1120	2020-06-02 03:38:34.633153+03
27532	59	-2	1030	2020-06-02 03:38:42.207325+03
27533	87	-1	2320	2020-06-02 03:39:44.040375+03
27534	25	-2	1100	2020-06-02 03:56:47.05834+03
27535	32	-1	710	2020-06-02 04:02:39.556776+03
27536	45	-1	1590	2020-06-02 04:26:51.730462+03
27537	63	-2	1780	2020-06-02 04:33:39.865301+03
27538	41	-1	830	2020-06-02 04:41:59.031983+03
27539	1	-2	640	2020-06-02 04:57:56.741506+03
27540	19	-1	1220	2020-06-02 05:04:58.430407+03
27541	89	-1	1420	2020-06-02 05:57:37.417049+03
27542	34	-1	1550	2020-06-02 06:03:48.874983+03
27543	35	-1	670	2020-06-02 07:20:24.864888+03
27544	96	-1	1570	2020-06-02 07:26:13.019292+03
27545	77	-1	640	2020-06-02 07:28:46.550681+03
27546	59	-1	1030	2020-06-02 07:58:10.807857+03
27547	14	-2	1350	2020-06-02 08:05:39.491669+03
27548	22	-2	1070	2020-06-02 08:44:43.211212+03
27549	10	-1	2080	2020-06-02 08:54:26.985057+03
27550	8	-1	1920	2020-06-02 09:03:23.41807+03
27551	29	-1	1940	2020-06-02 09:13:47.321642+03
27552	29	-1	1940	2020-06-02 10:20:15.839188+03
27553	52	-1	1090	2020-06-02 10:24:09.826528+03
27554	88	-1	1270	2020-06-02 10:28:28.678008+03
27555	3	-1	660	2020-06-02 10:49:55.815213+03
27556	46	-2	1270	2020-06-02 11:20:04.669925+03
27557	71	-3	1030	2020-06-02 11:46:22.939462+03
27558	29	-1	1940	2020-06-02 12:14:23.357454+03
27559	65	-1	490	2020-06-02 12:17:46.712622+03
27560	65	-1	490	2020-06-02 12:25:44.289003+03
27561	13	-1	460	2020-06-02 12:27:34.229163+03
27562	54	-1	3470	2020-06-02 13:21:32.272388+03
27563	76	-2	1070	2020-06-02 13:24:14.44693+03
27564	29	-1	1940	2020-06-02 13:47:50.20271+03
27565	6	-1	980	2020-06-02 13:49:44.873893+03
27566	29	-1	1940	2020-06-02 13:53:49.646824+03
27567	86	-1	910	2020-06-02 14:26:47.882122+03
27568	87	-1	2320	2020-06-02 14:30:50.067006+03
27569	9	25	1126	2020-06-02 14:35:39.081181+03
27570	61	-1	1510	2020-06-02 14:50:33.870121+03
27571	61	-1	1510	2020-06-02 15:16:25.773721+03
27572	7	-2	810	2020-06-02 15:26:32.002179+03
27573	22	-1	1070	2020-06-02 15:33:21.245891+03
27574	37	-1	1290	2020-06-02 15:42:02.710739+03
27575	65	-1	490	2020-06-02 16:20:05.887783+03
27576	63	-1	1780	2020-06-02 16:45:28.574211+03
27577	45	-1	1590	2020-06-02 16:45:52.819088+03
27578	32	-1	710	2020-06-02 17:00:58.960635+03
27579	35	-1	670	2020-06-02 17:45:51.621967+03
27580	50	-1	1140	2020-06-02 18:11:28.32658+03
27581	36	-1	630	2020-06-02 18:18:00.324755+03
27582	11	-1	830	2020-06-02 18:20:44.451135+03
27583	20	-1	830	2020-06-02 18:30:43.43108+03
27584	86	-1	910	2020-06-02 18:37:29.841476+03
27585	42	-1	1790	2020-06-02 18:58:34.996136+03
27586	21	27	401	2020-06-02 19:04:21.793826+03
27587	17	-1	1500	2020-06-02 19:13:26.471714+03
27588	25	-1	1100	2020-06-02 19:13:53.635759+03
27589	30	-1	1140	2020-06-02 19:49:38.584941+03
27590	33	-1	900	2020-06-02 20:17:55.461517+03
27591	63	-1	1780	2020-06-02 20:24:36.615204+03
27592	86	-1	910	2020-06-02 20:28:21.85439+03
27593	22	-1	1070	2020-06-02 20:40:26.371634+03
27594	87	-1	2320	2020-06-02 21:01:01.113888+03
27595	51	26	626	2020-06-02 21:13:58.840296+03
27596	78	-1	900	2020-06-02 21:38:21.210406+03
27597	94	-1	1230	2020-06-02 21:51:46.830338+03
27598	88	-2	1270	2020-06-02 22:22:17.935913+03
27599	46	-1	1270	2020-06-02 22:24:07.239126+03
27600	60	-1	2700	2020-06-02 22:51:34.623159+03
27601	14	36	672	2020-06-02 23:02:05.395766+03
27602	13	32	194	2020-06-02 23:02:24.61955+03
27603	67	-1	350	2020-06-02 23:21:02.02031+03
27604	89	-1	1420	2020-06-02 23:32:43.220395+03
27605	38	-2	1100	2020-06-02 23:37:23.356345+03
27606	9	-1	2090	2020-06-02 23:56:31.019816+03
27607	20	-1	830	2020-06-03 00:00:28.707296+03
27608	41	-1	830	2020-06-03 00:02:18.858444+03
27609	93	33	707	2020-06-03 00:28:20.023254+03
27610	25	-1	1100	2020-06-03 00:29:46.967717+03
27611	56	-2	2460	2020-06-03 00:39:31.384584+03
27612	21	-1	960	2020-06-03 00:43:04.866998+03
27613	38	-1	1100	2020-06-03 00:46:37.488785+03
27614	25	-1	1100	2020-06-03 00:58:11.909547+03
27615	89	-1	1420	2020-06-03 01:05:38.28755+03
27616	51	-1	1310	2020-06-03 01:17:30.44433+03
27617	43	-1	380	2020-06-03 01:39:22.10588+03
27618	32	-1	710	2020-06-03 01:48:30.333567+03
27619	8	-1	1920	2020-06-03 01:55:52.51147+03
27620	74	-2	1010	2020-06-03 02:07:31.66571+03
27621	96	-2	1570	2020-06-03 02:11:34.500285+03
27622	81	-2	1620	2020-06-03 02:32:07.326009+03
27623	51	-1	1310	2020-06-03 02:47:57.719246+03
27624	49	-1	970	2020-06-03 03:16:35.47138+03
27625	49	-1	970	2020-06-03 04:27:51.903626+03
27626	46	-1	1270	2020-06-03 04:31:54.554633+03
27627	55	-1	3480	2020-06-03 04:39:03.629444+03
27628	83	29	510	2020-06-03 04:56:33.823626+03
27629	4	-1	1420	2020-06-03 05:20:40.075744+03
27630	25	-2	1100	2020-06-03 05:43:11.150959+03
27631	38	-2	1100	2020-06-03 05:54:50.860759+03
27632	69	-1	1100	2020-06-03 06:02:58.171082+03
27633	66	-1	690	2020-06-03 06:21:27.189978+03
27634	24	-2	950	2020-06-03 06:24:59.51748+03
27635	46	-1	1270	2020-06-03 06:28:04.648156+03
27636	58	-1	2830	2020-06-03 06:38:38.660618+03
27637	47	-1	1480	2020-06-03 06:46:08.124126+03
27638	85	-1	730	2020-06-03 06:52:54.2242+03
27639	54	-1	3470	2020-06-03 07:08:00.295927+03
27640	92	-1	630	2020-06-03 07:11:17.962113+03
27641	59	-1	1030	2020-06-03 07:29:04.063387+03
27642	53	-1	3120	2020-06-03 07:29:26.273588+03
27643	52	-1	1090	2020-06-03 08:26:41.780341+03
27644	81	-2	1620	2020-06-03 08:58:32.270115+03
27645	60	-1	2700	2020-06-03 09:02:16.029138+03
27646	41	-1	830	2020-06-03 09:10:45.810268+03
27647	2	-1	470	2020-06-03 09:28:23.029728+03
27648	13	-1	460	2020-06-03 09:34:10.667686+03
27649	22	-1	1070	2020-06-03 10:26:56.970676+03
27650	44	-1	500	2020-06-03 10:42:03.549325+03
27651	11	-1	830	2020-06-03 10:43:30.432392+03
27652	96	-2	1570	2020-06-03 10:44:20.261735+03
27653	44	-1	500	2020-06-03 10:54:24.755357+03
27654	42	-1	1790	2020-06-03 10:57:29.166056+03
27655	31	-1	1190	2020-06-03 11:10:52.299816+03
27656	66	-1	690	2020-06-03 11:20:35.201993+03
27657	72	-1	620	2020-06-03 11:31:11.7092+03
27658	45	-1	1590	2020-06-03 11:31:37.917669+03
27659	88	-2	1270	2020-06-03 11:52:37.019907+03
27660	43	-1	380	2020-06-03 12:26:04.901246+03
27661	8	32	779	2020-06-03 12:34:18.062722+03
27662	22	-1	1070	2020-06-03 12:34:53.6631+03
27663	65	-1	490	2020-06-03 12:42:04.487496+03
27664	51	-1	1310	2020-06-03 13:29:20.378833+03
27665	49	-3	970	2020-06-03 13:39:48.842851+03
27666	89	-1	1420	2020-06-03 13:49:55.439907+03
27667	81	-1	1620	2020-06-03 13:54:16.21952+03
27668	29	-1	1940	2020-06-03 14:34:49.38896+03
27669	31	-2	1190	2020-06-03 14:38:01.73239+03
27670	86	-1	910	2020-06-03 15:20:01.238381+03
27671	68	-2	490	2020-06-03 15:48:05.776492+03
27672	92	-1	630	2020-06-03 15:49:08.679404+03
27673	24	-1	950	2020-06-03 16:07:21.98549+03
27674	33	-3	900	2020-06-03 16:32:38.962804+03
27675	85	-1	730	2020-06-03 16:35:11.799454+03
27676	76	-1	1070	2020-06-03 16:36:33.510988+03
27677	79	-1	550	2020-06-03 17:27:21.949918+03
27678	37	-1	1290	2020-06-03 17:28:54.343891+03
27679	73	-1	960	2020-06-03 17:36:03.339572+03
27680	8	-1	1920	2020-06-03 17:37:06.650514+03
27681	31	-1	1190	2020-06-03 17:41:55.969569+03
27682	81	-2	1620	2020-06-03 17:48:36.725095+03
27683	30	-1	1140	2020-06-03 18:06:59.219432+03
27684	71	-1	1030	2020-06-03 18:40:03.781077+03
27685	51	-1	1310	2020-06-03 18:48:17.456903+03
27686	48	-1	640	2020-06-03 18:58:54.039896+03
27687	72	-1	620	2020-06-03 19:15:26.361843+03
27688	88	-1	1270	2020-06-03 19:24:39.219308+03
27689	18	-1	910	2020-06-03 19:47:48.424551+03
27690	37	-2	1290	2020-06-03 20:21:23.886525+03
27691	53	-1	3120	2020-06-03 20:30:28.381538+03
27692	50	-2	1140	2020-06-03 20:32:21.249398+03
27693	4	-1	1420	2020-06-03 20:55:45.434247+03
27694	18	-2	910	2020-06-03 20:56:31.957536+03
27695	41	-1	830	2020-06-03 21:03:35.779799+03
27696	69	-1	1100	2020-06-03 21:10:15.148459+03
27697	72	-1	620	2020-06-03 21:23:17.567951+03
27698	40	-1	1430	2020-06-03 21:23:56.460771+03
27699	73	-2	960	2020-06-03 21:30:07.120712+03
27700	10	-1	2080	2020-06-03 21:46:41.020471+03
27701	61	-1	1510	2020-06-03 21:47:07.81413+03
27702	40	-2	1430	2020-06-03 22:05:14.608777+03
27703	31	-1	1190	2020-06-03 22:43:15.859832+03
27704	60	-2	2700	2020-06-03 22:55:11.35343+03
27705	38	-2	1100	2020-06-03 22:57:26.186988+03
27706	87	-1	2320	2020-06-03 22:58:47.68231+03
27707	10	-1	2080	2020-06-03 23:17:23.969538+03
27708	4	-1	1420	2020-06-03 23:26:11.607082+03
27709	42	-1	1790	2020-06-03 23:29:08.094409+03
27710	35	-1	670	2020-06-03 23:42:15.527874+03
27711	80	-1	1120	2020-06-04 00:05:22.711997+03
27712	17	-1	1500	2020-06-04 00:07:52.674158+03
27713	38	-2	1100	2020-06-04 00:10:21.299729+03
27714	58	-1	2830	2020-06-04 00:15:25.683826+03
27715	16	-2	1380	2020-06-04 00:17:04.431779+03
27716	75	-1	830	2020-06-04 00:23:03.558854+03
27717	28	-2	1860	2020-06-04 00:43:46.677445+03
27718	70	-2	760	2020-06-04 00:56:32.289951+03
27719	87	-1	2320	2020-06-04 01:05:32.768792+03
27720	66	11	311	2020-06-04 01:10:47.781751+03
27721	78	-1	900	2020-06-04 01:14:49.296284+03
27722	76	-1	1070	2020-06-04 01:35:21.332972+03
27723	49	-1	970	2020-06-04 01:35:36.164657+03
27724	20	-1	830	2020-06-04 02:01:46.168068+03
27725	75	-1	830	2020-06-04 02:06:24.251064+03
27726	43	-1	380	2020-06-04 02:48:32.329407+03
27727	65	-1	490	2020-06-04 03:00:38.111546+03
27728	13	-1	460	2020-06-04 03:06:18.993602+03
27729	34	-1	1550	2020-06-04 03:07:30.827644+03
27730	15	22	1636	2020-06-04 03:08:02.909109+03
27731	42	-1	1790	2020-06-04 03:18:32.984361+03
27732	92	-1	630	2020-06-04 03:20:32.208912+03
27733	2	-1	470	2020-06-04 03:24:30.191154+03
27734	73	-2	960	2020-06-04 03:33:39.067403+03
27735	32	-1	710	2020-06-04 03:44:02.01919+03
27736	92	-2	630	2020-06-04 03:57:11.971778+03
27737	20	-1	830	2020-06-04 04:56:11.590621+03
27738	31	-1	1190	2020-06-04 05:08:47.844076+03
27739	76	-1	1070	2020-06-04 05:13:25.589834+03
27740	19	-1	1220	2020-06-04 05:15:03.497033+03
27741	56	-1	2460	2020-06-04 05:20:06.783688+03
27742	89	-1	1420	2020-06-04 05:42:32.754402+03
27743	56	-1	2460	2020-06-04 06:00:23.63915+03
27744	26	-2	390	2020-06-04 06:18:27.03692+03
27745	29	-1	1940	2020-06-04 06:22:04.1869+03
27746	58	-3	2830	2020-06-04 06:49:50.788114+03
27747	78	-1	900	2020-06-04 07:18:45.692952+03
27748	2	-1	470	2020-06-04 07:18:54.34683+03
27749	32	-1	710	2020-06-04 07:27:24.478256+03
27750	70	-2	760	2020-06-04 07:46:03.327092+03
27751	34	-1	1550	2020-06-04 07:56:19.788269+03
27752	67	-2	350	2020-06-04 08:11:11.135344+03
27753	14	-1	1350	2020-06-04 08:22:35.290393+03
27754	26	-1	390	2020-06-04 08:30:07.695726+03
27755	69	-2	1100	2020-06-04 09:03:10.814151+03
27756	54	-1	3470	2020-06-04 09:10:09.965378+03
27757	49	-2	970	2020-06-04 09:29:17.64233+03
27758	88	-1	1270	2020-06-04 09:40:19.254739+03
27759	22	-1	1070	2020-06-04 09:42:24.838503+03
27760	91	-1	1620	2020-06-04 09:54:57.641041+03
27761	93	-1	1620	2020-06-04 09:55:40.810247+03
27762	55	-1	3480	2020-06-04 10:00:27.965561+03
27763	58	-1	2830	2020-06-04 10:05:59.275058+03
27764	37	-2	1290	2020-06-04 10:09:02.528545+03
27765	40	40	777	2020-06-04 10:47:44.88938+03
27766	64	-2	970	2020-06-04 11:16:23.272799+03
27767	31	-2	1190	2020-06-04 11:17:06.60211+03
27768	8	-1	1920	2020-06-04 11:37:11.48721+03
27769	61	-2	1510	2020-06-04 11:39:48.674493+03
27770	59	-1	1030	2020-06-04 11:43:04.020482+03
27771	47	-1	1480	2020-06-04 11:51:56.076852+03
27772	46	-1	1270	2020-06-04 12:08:36.875055+03
27773	30	-2	1140	2020-06-04 12:09:01.21319+03
27774	26	-1	390	2020-06-04 12:37:43.000213+03
27775	59	-1	1030	2020-06-04 12:41:02.113673+03
27776	29	-1	1940	2020-06-04 12:53:08.888706+03
27777	72	9	340	2020-06-04 13:07:49.787306+03
27778	4	-1	1420	2020-06-04 13:58:59.450016+03
27779	81	-1	1620	2020-06-04 14:07:18.987639+03
27780	22	-1	1070	2020-06-04 14:09:01.192796+03
27781	26	-1	390	2020-06-04 14:22:06.842389+03
27782	13	-1	460	2020-06-04 14:58:49.25187+03
27783	12	-1	1650	2020-06-04 14:59:29.973994+03
27784	90	-1	1780	2020-06-04 15:11:22.159626+03
27785	91	-1	1620	2020-06-04 15:11:36.262104+03
27786	87	-1	2320	2020-06-04 15:13:55.230839+03
27787	50	-2	1140	2020-06-04 15:26:18.421507+03
27788	8	-1	1920	2020-06-04 15:57:25.10235+03
27789	4	-1	1420	2020-06-04 16:16:06.980114+03
27790	27	15	522	2020-06-04 16:19:33.72225+03
27791	73	-1	960	2020-06-04 16:21:04.750069+03
27792	73	-1	960	2020-06-04 16:39:30.598906+03
27793	93	-1	1620	2020-06-04 16:46:01.41376+03
27794	38	-1	1100	2020-06-04 16:49:53.365178+03
27795	40	-2	1430	2020-06-04 17:09:24.2519+03
27796	71	-1	1030	2020-06-04 17:17:29.599971+03
27797	73	-1	960	2020-06-04 17:33:52.972548+03
27798	70	-1	760	2020-06-04 17:52:14.689752+03
27799	88	-1	1270	2020-06-04 18:10:03.716425+03
27800	78	-1	900	2020-06-04 18:29:03.455394+03
27801	6	-1	980	2020-06-04 18:59:26.581264+03
27802	43	-1	380	2020-06-04 19:26:20.767469+03
27803	18	-1	910	2020-06-04 19:33:47.662915+03
27804	67	-1	350	2020-06-04 19:37:26.775062+03
27805	32	-1	710	2020-06-04 19:42:00.118813+03
27806	18	-1	910	2020-06-04 20:18:00.043299+03
27807	19	29	629	2020-06-04 20:29:49.410741+03
27808	4	-1	1420	2020-06-04 20:46:02.783044+03
27809	4	-1	1420	2020-06-04 20:56:33.814763+03
27810	17	-2	1500	2020-06-04 21:08:01.221898+03
27811	51	-1	1310	2020-06-04 21:09:13.534549+03
27812	7	-1	810	2020-06-04 21:24:51.582136+03
27813	31	-2	1190	2020-06-04 21:27:43.48676+03
27814	96	-1	1570	2020-06-04 21:28:44.163786+03
27815	91	-1	1620	2020-06-04 21:32:13.144906+03
27816	55	-1	3480	2020-06-04 21:40:16.799068+03
27817	29	-1	1940	2020-06-04 21:56:18.539825+03
27818	39	-2	910	2020-06-04 22:09:09.55074+03
27819	61	-1	1510	2020-06-04 22:56:34.275494+03
27820	35	-1	670	2020-06-04 23:02:19.471632+03
27821	38	-1	1100	2020-06-04 23:28:28.340568+03
27822	54	-1	3470	2020-06-04 23:53:13.775322+03
27823	35	-1	670	2020-06-04 23:53:23.657588+03
27824	60	-1	2700	2020-06-05 00:00:33.692506+03
27825	79	-3	550	2020-06-05 00:34:20.364804+03
27826	91	-1	1620	2020-06-05 01:04:20.133171+03
27827	43	25	154	2020-06-05 01:35:36.337135+03
27828	21	-1	960	2020-06-05 01:58:12.79098+03
27829	10	34	928	2020-06-05 02:33:13.726336+03
27830	37	-3	1290	2020-06-05 02:39:02.06511+03
27831	27	-1	880	2020-06-05 02:43:01.627184+03
27832	42	-1	1790	2020-06-05 02:43:54.900363+03
27833	91	-1	1620	2020-06-05 03:21:54.523384+03
27834	67	-1	350	2020-06-05 03:59:31.604291+03
27835	74	-1	1010	2020-06-05 04:13:24.939871+03
27836	71	-2	1030	2020-06-05 04:33:20.694059+03
27837	33	-1	900	2020-06-05 05:07:52.20061+03
27838	93	-1	1620	2020-06-05 05:08:44.584031+03
27839	45	30	858	2020-06-05 05:13:13.812537+03
27840	49	-1	970	2020-06-05 05:20:33.098969+03
27841	29	-2	1940	2020-06-05 05:21:52.159866+03
27842	25	-1	1100	2020-06-05 05:30:20.279507+03
27843	57	-2	1900	2020-06-05 05:31:53.151778+03
27844	35	-1	670	2020-06-05 05:49:13.28146+03
27845	7	-2	810	2020-06-05 05:50:27.995273+03
27846	70	-1	760	2020-06-05 06:06:51.24167+03
27847	77	-2	640	2020-06-05 06:17:55.957738+03
27848	79	-1	550	2020-06-05 06:32:53.5214+03
27849	32	-1	710	2020-06-05 07:09:41.669901+03
27850	69	-1	1100	2020-06-05 07:25:30.543918+03
27851	33	-1	900	2020-06-05 07:25:47.893837+03
27852	85	-1	730	2020-06-05 07:56:06.200352+03
27853	95	-1	480	2020-06-05 07:58:16.984309+03
27854	64	-1	970	2020-06-05 08:20:41.517907+03
27855	12	-1	1650	2020-06-05 08:37:42.323437+03
27856	45	-2	1590	2020-06-05 08:44:04.83389+03
27857	53	-1	3120	2020-06-05 09:04:32.673281+03
27858	23	-1	4390	2020-06-05 09:13:44.516698+03
27859	45	-1	1590	2020-06-05 09:14:08.659454+03
27860	9	-1	2090	2020-06-05 09:18:39.030863+03
27861	19	-1	1220	2020-06-05 10:13:48.576187+03
27862	68	-1	490	2020-06-05 10:35:46.31237+03
27863	40	-1	1430	2020-06-05 10:55:24.723176+03
27864	87	-1	2320	2020-06-05 11:40:30.719918+03
27865	79	-2	550	2020-06-05 11:47:27.437026+03
27866	96	-1	1570	2020-06-05 11:48:31.639402+03
27867	9	-2	2090	2020-06-05 12:15:37.619813+03
27868	71	-2	1030	2020-06-05 12:20:02.166112+03
27869	91	-1	1620	2020-06-05 12:32:41.060893+03
27870	23	-1	4390	2020-06-05 12:35:11.482219+03
27871	89	-2	1420	2020-06-05 12:53:55.985102+03
27872	8	-1	1920	2020-06-05 13:18:51.18342+03
27873	14	-1	1350	2020-06-05 13:30:24.278214+03
27874	62	-1	1220	2020-06-05 13:53:32.181408+03
27875	53	-1	3120	2020-06-05 14:22:55.696242+03
27876	3	-1	660	2020-06-05 15:04:53.370487+03
27877	95	-1	480	2020-06-05 15:15:36.466586+03
27878	92	24	319	2020-06-05 15:31:41.998457+03
27879	42	24	854	2020-06-05 15:32:03.184113+03
27880	19	-1	1220	2020-06-05 15:46:22.937456+03
27881	72	-2	620	2020-06-05 15:49:32.825255+03
27882	57	-1	1900	2020-06-05 15:55:51.775371+03
27883	7	-1	810	2020-06-05 15:58:48.374191+03
27884	71	-1	1030	2020-06-05 16:19:52.427012+03
27885	32	-1	710	2020-06-05 16:31:35.420582+03
27886	62	-1	1220	2020-06-05 17:00:06.624823+03
27887	66	-1	690	2020-06-05 17:18:18.086027+03
27888	69	-1	1100	2020-06-05 17:24:57.635375+03
27889	78	-1	900	2020-06-05 17:53:43.92829+03
27890	29	-1	1940	2020-06-05 18:35:53.697317+03
27891	83	-1	1230	2020-06-05 18:39:47.17201+03
27892	12	-2	1650	2020-06-05 18:55:05.272875+03
27893	4	-1	1420	2020-06-05 19:07:11.601817+03
27894	48	-1	640	2020-06-05 19:24:43.379333+03
27895	93	-1	1620	2020-06-05 19:26:19.53525+03
27896	14	-1	1350	2020-06-05 19:26:57.00063+03
27897	18	-2	910	2020-06-05 19:46:00.721115+03
27898	26	-2	390	2020-06-05 19:47:31.362952+03
27899	60	-1	2700	2020-06-05 19:57:12.123513+03
27900	86	-1	910	2020-06-05 20:07:10.268472+03
27901	94	-1	1230	2020-06-05 21:31:43.735253+03
27902	44	-1	500	2020-06-05 21:33:55.976742+03
27903	9	-2	2090	2020-06-05 21:55:59.5008+03
27904	93	-1	1620	2020-06-05 22:24:16.154754+03
27905	37	32	591	2020-06-05 22:56:12.992844+03
27906	13	-2	460	2020-06-05 23:12:24.282327+03
27907	6	-1	980	2020-06-05 23:24:24.476343+03
27908	28	-1	1860	2020-06-05 23:26:34.766173+03
27909	86	-1	910	2020-06-05 23:31:46.551053+03
27910	61	-1	1510	2020-06-05 23:51:02.978193+03
27911	16	10	722	2020-06-06 00:41:51.821424+03
27912	64	-2	970	2020-06-06 00:42:11.308704+03
27913	39	-1	910	2020-06-06 00:43:38.795112+03
27914	6	-1	980	2020-06-06 00:49:23.453112+03
27915	77	-1	640	2020-06-06 01:20:50.694883+03
27916	21	-1	960	2020-06-06 01:21:46.557871+03
27917	18	-1	910	2020-06-06 01:22:44.502657+03
27918	25	-3	1100	2020-06-06 01:24:28.857133+03
27919	80	-1	1120	2020-06-06 01:28:15.067782+03
27920	13	-2	460	2020-06-06 01:50:43.71812+03
27921	76	-2	1070	2020-06-06 02:18:34.298266+03
27922	37	-1	1290	2020-06-06 03:17:53.083412+03
27923	39	-1	910	2020-06-06 03:20:36.238151+03
27924	94	-1	1230	2020-06-06 03:35:25.478027+03
27925	58	-1	2830	2020-06-06 03:46:01.410421+03
27926	87	-2	2320	2020-06-06 03:53:24.783421+03
27927	83	-1	1230	2020-06-06 04:03:49.374166+03
27928	64	-1	970	2020-06-06 04:05:24.004423+03
27929	53	-1	3120	2020-06-06 04:42:34.524239+03
27930	63	-1	1780	2020-06-06 05:10:33.173584+03
27931	25	-1	1100	2020-06-06 05:32:26.887987+03
27932	31	-1	1190	2020-06-06 06:20:08.031103+03
27933	48	-1	640	2020-06-06 06:31:27.751812+03
27934	77	-1	640	2020-06-06 06:55:43.043525+03
27935	18	-1	910	2020-06-06 06:57:33.993559+03
27936	47	-2	1480	2020-06-06 07:28:13.251006+03
27937	30	-1	1140	2020-06-06 07:47:48.229362+03
27938	5	-1	1620	2020-06-06 08:24:09.792203+03
27939	51	-1	1310	2020-06-06 09:30:54.075073+03
27940	73	-1	960	2020-06-06 09:43:14.99323+03
27941	90	-1	1780	2020-06-06 10:01:05.163148+03
27942	30	-1	1140	2020-06-06 10:29:36.877067+03
27943	3	-1	660	2020-06-06 10:31:01.372344+03
27944	32	-1	710	2020-06-06 10:34:16.823677+03
27945	12	-1	1650	2020-06-06 10:43:18.681536+03
27946	19	-3	1220	2020-06-06 11:14:08.24124+03
27947	64	-1	970	2020-06-06 11:15:04.640432+03
27948	10	-1	2080	2020-06-06 11:17:07.781079+03
27949	22	-1	1070	2020-06-06 11:47:25.750093+03
27950	8	-1	1920	2020-06-06 12:03:36.628718+03
27951	36	-1	630	2020-06-06 12:06:49.591771+03
27952	68	-1	490	2020-06-06 12:24:39.724129+03
27953	61	-2	1510	2020-06-06 12:30:16.982963+03
27954	85	-1	730	2020-06-06 12:33:34.117152+03
27955	17	-1	1500	2020-06-06 12:37:51.644053+03
27956	73	-1	960	2020-06-06 12:48:18.794855+03
27957	8	-1	1920	2020-06-06 13:16:25.324079+03
27958	64	-2	970	2020-06-06 13:29:35.472334+03
27959	77	-1	640	2020-06-06 13:41:17.13993+03
27960	56	-1	2460	2020-06-06 13:46:11.260687+03
27961	93	-1	1620	2020-06-06 14:11:35.905245+03
27962	74	-1	1010	2020-06-06 14:19:46.855178+03
27963	63	-1	1780	2020-06-06 14:27:26.715031+03
27964	64	-1	970	2020-06-06 14:41:24.002502+03
27965	80	-1	1120	2020-06-06 14:44:02.563273+03
27966	15	-1	2830	2020-06-06 14:50:55.093696+03
27967	66	-1	690	2020-06-06 14:54:35.561175+03
27968	77	-1	640	2020-06-06 15:00:41.501882+03
27969	54	-1	3470	2020-06-06 15:43:55.7478+03
27970	76	-1	1070	2020-06-06 15:46:06.383088+03
27971	89	-1	1420	2020-06-06 16:06:49.248876+03
27972	20	-2	830	2020-06-06 16:12:29.324124+03
27973	84	-1	2700	2020-06-06 16:15:57.099588+03
27974	4	-1	1420	2020-06-06 16:17:02.858817+03
27975	84	-2	2700	2020-06-06 16:31:49.955773+03
27976	32	-1	710	2020-06-06 17:09:05.064811+03
27977	7	-1	810	2020-06-06 17:23:29.573168+03
27978	89	-1	1420	2020-06-06 17:32:02.201837+03
27979	6	-2	980	2020-06-06 17:38:18.702067+03
27980	80	22	639	2020-06-06 18:05:09.294464+03
27981	10	-2	2080	2020-06-06 18:07:31.911447+03
27982	25	-1	1100	2020-06-06 18:40:52.423577+03
27983	77	-1	640	2020-06-06 18:48:19.728638+03
27984	20	-1	830	2020-06-06 18:51:55.771066+03
27985	12	-1	1650	2020-06-06 19:06:00.853445+03
27986	82	-1	560	2020-06-06 19:13:23.570404+03
27987	68	-1	490	2020-06-06 19:17:43.249666+03
27988	70	-1	760	2020-06-06 19:21:29.888368+03
27989	73	-1	960	2020-06-06 19:42:48.76027+03
27990	46	-1	1270	2020-06-06 19:48:40.408704+03
27991	54	-1	3470	2020-06-06 20:06:54.133138+03
27992	7	-1	810	2020-06-06 20:13:15.244179+03
27993	89	32	641	2020-06-06 20:24:48.908764+03
27994	79	-1	550	2020-06-06 20:44:39.062913+03
27995	17	-1	1500	2020-06-06 20:57:31.08227+03
27996	73	-1	960	2020-06-06 21:07:25.292103+03
27997	55	26	1971	2020-06-06 21:20:01.28648+03
27998	95	-1	480	2020-06-06 21:55:52.059292+03
27999	20	-1	830	2020-06-06 21:58:17.90373+03
28000	40	-2	1430	2020-06-06 22:39:32.73231+03
28001	80	-1	1120	2020-06-06 22:45:24.143551+03
28002	5	-1	1620	2020-06-06 22:45:48.433128+03
28003	26	-1	390	2020-06-06 22:50:08.387384+03
28004	33	-1	900	2020-06-06 22:59:24.444669+03
28005	19	-1	1220	2020-06-06 23:01:23.183659+03
28006	8	-2	1920	2020-06-06 23:15:23.772125+03
28007	13	-1	460	2020-06-06 23:39:50.942092+03
28008	65	-1	490	2020-06-07 00:16:34.209209+03
28009	64	-1	970	2020-06-07 01:02:38.817545+03
28010	94	-1	1230	2020-06-07 01:03:00.512001+03
28011	47	-1	1480	2020-06-07 01:55:57.542396+03
28012	13	-1	460	2020-06-07 02:02:26.558771+03
28013	27	-1	880	2020-06-07 02:14:01.310059+03
28014	29	31	1159	2020-06-07 02:22:43.308155+03
28015	47	-1	1480	2020-06-07 02:48:15.1074+03
28016	13	-1	460	2020-06-07 03:01:51.006882+03
28017	76	-1	1070	2020-06-07 03:04:50.590153+03
28018	84	-1	2700	2020-06-07 03:52:16.284532+03
28019	3	-1	660	2020-06-07 03:55:50.127927+03
28020	60	-2	2700	2020-06-07 04:05:21.646505+03
28021	95	-2	480	2020-06-07 04:24:12.315019+03
28022	5	-1	1620	2020-06-07 04:35:59.968643+03
28023	40	-1	1430	2020-06-07 04:41:47.838928+03
28024	23	-1	4390	2020-06-07 04:52:48.722403+03
28025	76	-1	1070	2020-06-07 05:04:01.206112+03
28026	29	-1	1940	2020-06-07 05:22:53.790994+03
28027	84	-1	2700	2020-06-07 05:40:02.030569+03
28028	69	-1	1100	2020-06-07 05:59:56.80311+03
28029	96	-2	1570	2020-06-07 06:05:33.980152+03
28030	35	-2	670	2020-06-07 06:46:38.956926+03
28031	71	34	549	2020-06-07 06:47:43.551238+03
28032	92	-1	630	2020-06-07 06:48:15.331208+03
28033	19	-1	1220	2020-06-07 06:58:11.178047+03
28034	55	-1	3480	2020-06-07 07:01:44.309009+03
28035	32	-1	710	2020-06-07 07:30:20.579396+03
28036	18	-1	910	2020-06-07 07:35:41.064298+03
28037	91	-1	1620	2020-06-07 07:42:00.371204+03
28038	70	-1	760	2020-06-07 07:54:53.57637+03
28039	36	-1	630	2020-06-07 08:24:05.380536+03
28040	54	-2	3470	2020-06-07 08:40:08.461958+03
28041	76	-1	1070	2020-06-07 09:10:21.276767+03
28042	53	-1	3120	2020-06-07 09:18:28.652371+03
28043	51	-1	1310	2020-06-07 09:27:45.421427+03
28044	88	34	515	2020-06-07 09:57:45.692455+03
28045	8	-1	1920	2020-06-07 10:02:19.938587+03
28046	42	-1	1790	2020-06-07 10:11:26.934009+03
28047	61	-1	1510	2020-06-07 10:26:45.93156+03
28048	95	-2	480	2020-06-07 10:37:35.171158+03
28049	80	-1	1120	2020-06-07 10:51:24.483139+03
28050	4	-2	1420	2020-06-07 10:53:15.012785+03
28051	47	-1	1480	2020-06-07 11:11:25.761588+03
28052	19	-1	1220	2020-06-07 11:12:07.774194+03
28053	86	-1	910	2020-06-07 11:19:15.831068+03
28054	54	-1	3470	2020-06-07 11:20:55.33397+03
28055	60	-2	2700	2020-06-07 11:32:30.004591+03
28056	2	-1	470	2020-06-07 11:39:17.229786+03
28057	39	-1	910	2020-06-07 11:43:58.678252+03
28058	38	-1	1100	2020-06-07 11:59:57.767919+03
28059	43	-1	380	2020-06-07 12:02:28.090592+03
28060	50	-1	1140	2020-06-07 12:12:56.826252+03
28061	96	-2	1570	2020-06-07 12:16:46.405088+03
28062	87	-1	2320	2020-06-07 12:36:57.590244+03
28063	4	-1	1420	2020-06-07 12:41:35.119372+03
28064	18	-1	910	2020-06-07 12:44:29.305819+03
28065	74	-1	1010	2020-06-07 12:54:16.090617+03
28066	28	-1	1860	2020-06-07 13:17:38.01675+03
28067	60	-1	2700	2020-06-07 13:38:59.648555+03
28068	85	-1	730	2020-06-07 13:54:55.660017+03
28069	29	-1	1940	2020-06-07 13:59:03.8429+03
28070	64	-1	970	2020-06-07 14:03:59.175071+03
28071	79	-1	550	2020-06-07 14:24:02.306372+03
28072	57	-1	1900	2020-06-07 14:24:37.016877+03
28073	1	-1	640	2020-06-07 14:30:32.352964+03
28074	95	-1	480	2020-06-07 14:36:53.86853+03
28075	79	-1	550	2020-06-07 14:36:59.815294+03
28076	36	-1	630	2020-06-07 14:37:08.327096+03
28077	36	-1	630	2020-06-07 14:50:30.439798+03
28078	39	-1	910	2020-06-07 15:43:51.111307+03
28079	65	-1	490	2020-06-07 16:35:24.285324+03
28080	29	-2	1940	2020-06-07 16:44:50.335022+03
28081	82	-2	560	2020-06-07 16:56:58.761506+03
28082	86	-1	910	2020-06-07 17:00:58.544791+03
28083	55	-1	3480	2020-06-07 17:48:55.619638+03
28084	56	-1	2460	2020-06-07 17:54:25.565717+03
28085	93	-1	1620	2020-06-07 18:23:24.647455+03
28086	4	-1	1420	2020-06-07 18:41:07.513304+03
28087	49	-1	970	2020-06-07 18:46:21.750802+03
28088	40	-1	1430	2020-06-07 18:57:32.387729+03
28089	87	-1	2320	2020-06-07 19:22:39.688372+03
28090	18	-1	910	2020-06-07 19:32:23.285322+03
28091	68	-1	490	2020-06-07 19:32:33.027863+03
28092	8	-1	1920	2020-06-07 19:57:56.022119+03
28093	31	-1	1190	2020-06-07 20:38:20.864253+03
28094	55	-1	3480	2020-06-07 21:08:13.300844+03
28095	60	-1	2700	2020-06-07 21:13:22.271754+03
28096	37	-2	1290	2020-06-07 21:15:46.169974+03
28097	4	-1	1420	2020-06-07 21:17:23.404897+03
28098	7	-1	810	2020-06-07 21:35:33.607559+03
28099	8	-1	1920	2020-06-07 21:57:33.230952+03
28100	61	-1	1510	2020-06-07 21:57:53.376899+03
28101	21	-1	960	2020-06-07 22:26:42.709336+03
28102	8	-1	1920	2020-06-07 22:27:38.013107+03
28103	40	-1	1430	2020-06-07 22:31:39.489735+03
28104	96	-1	1570	2020-06-07 22:48:10.789254+03
28105	11	-1	830	2020-06-07 22:53:11.172149+03
28106	21	-1	960	2020-06-07 23:21:10.112473+03
28107	89	-2	1420	2020-06-07 23:24:33.703707+03
28108	9	-1	2090	2020-06-07 23:24:39.557487+03
28109	4	-1	1420	2020-06-08 00:09:54.289014+03
28110	47	-1	1480	2020-06-08 00:15:23.098873+03
28111	70	-2	760	2020-06-08 00:15:37.041747+03
28112	78	-2	900	2020-06-08 00:21:55.140828+03
28113	80	-1	1120	2020-06-08 00:38:20.68269+03
28114	14	-1	1350	2020-06-08 00:49:38.630835+03
28115	86	-1	910	2020-06-08 00:51:18.084999+03
28116	51	-1	1310	2020-06-08 01:08:20.855276+03
28117	18	-1	910	2020-06-08 01:22:50.136026+03
28118	14	-1	1350	2020-06-08 01:28:49.800373+03
28119	12	-1	1650	2020-06-08 01:33:38.438472+03
28120	54	-1	3470	2020-06-08 01:54:41.740808+03
28121	80	-1	1120	2020-06-08 02:05:04.250842+03
28122	25	-1	1100	2020-06-08 02:18:01.472586+03
28123	4	-1	1420	2020-06-08 03:03:05.631343+03
28124	57	-1	1900	2020-06-08 03:07:25.845313+03
28125	6	-2	980	2020-06-08 03:24:48.469723+03
28126	80	-1	1120	2020-06-08 03:30:31.739967+03
28127	61	-1	1510	2020-06-08 03:43:36.167559+03
28128	91	-1	1620	2020-06-08 03:50:41.229967+03
28129	26	-1	390	2020-06-08 03:51:40.201702+03
28130	62	-1	1220	2020-06-08 04:50:07.616005+03
28131	59	-1	1030	2020-06-08 04:55:00.401669+03
28132	20	-1	830	2020-06-08 05:12:11.736135+03
28133	12	-1	1650	2020-06-08 05:20:43.501587+03
28134	82	-2	560	2020-06-08 05:27:16.80861+03
28135	43	-1	380	2020-06-08 05:46:21.414237+03
28136	25	-1	1100	2020-06-08 05:46:56.551165+03
28137	63	-1	1780	2020-06-08 05:51:19.302659+03
28138	61	-1	1510	2020-06-08 06:04:15.427793+03
28139	13	-1	460	2020-06-08 06:07:04.223695+03
28140	85	-1	730	2020-06-08 06:16:56.594125+03
28141	74	-2	1010	2020-06-08 06:37:39.06479+03
28142	11	-2	830	2020-06-08 06:48:46.517947+03
28143	77	-2	640	2020-06-08 07:25:41.088467+03
28144	78	-1	900	2020-06-08 07:32:40.818573+03
28145	63	-2	1780	2020-06-08 07:52:55.869803+03
28146	11	19	410	2020-06-08 08:07:05.899359+03
28147	46	-2	1270	2020-06-08 08:10:15.058337+03
28148	34	-1	1550	2020-06-08 08:17:00.045302+03
28149	87	36	1151	2020-06-08 08:24:48.478451+03
28150	20	-1	830	2020-06-08 08:25:36.954632+03
28151	1	-1	640	2020-06-08 08:26:30.097388+03
28152	33	-1	900	2020-06-08 09:04:23.708763+03
28153	73	-1	960	2020-06-08 09:10:26.642203+03
28154	9	-1	2090	2020-06-08 09:29:55.982416+03
28155	52	-2	1090	2020-06-08 09:33:31.578982+03
28156	6	-1	980	2020-06-08 09:59:26.124478+03
28157	24	-1	950	2020-06-08 09:59:29.187254+03
28158	37	-1	1290	2020-06-08 10:00:04.398504+03
28159	71	-1	1030	2020-06-08 10:05:52.417195+03
28160	64	-1	970	2020-06-08 10:26:10.830718+03
28161	83	-1	1230	2020-06-08 10:30:43.016952+03
28162	83	-1	1230	2020-06-08 10:42:06.617369+03
28163	36	-1	630	2020-06-08 10:43:58.005202+03
28164	82	-1	560	2020-06-08 10:45:29.770965+03
28165	88	-1	1270	2020-06-08 10:49:24.766713+03
28166	69	-1	1100	2020-06-08 10:53:04.532605+03
28167	1	-2	640	2020-06-08 11:02:56.784792+03
28168	29	-1	1940	2020-06-08 11:22:56.910361+03
28169	66	-1	690	2020-06-08 11:31:17.058462+03
28170	18	-1	910	2020-06-08 11:44:10.412017+03
28171	95	-1	480	2020-06-08 12:18:12.255643+03
28172	34	-1	1550	2020-06-08 12:20:59.634098+03
28173	44	-2	500	2020-06-08 12:58:59.220713+03
28174	1	-1	640	2020-06-08 13:00:31.390013+03
28175	55	-1	3480	2020-06-08 13:03:29.076144+03
28176	24	-2	950	2020-06-08 13:04:44.00496+03
28177	73	-2	960	2020-06-08 13:13:30.688875+03
28178	33	-1	900	2020-06-08 13:23:59.609371+03
28179	65	-1	490	2020-06-08 13:30:25.163163+03
28180	49	-1	970	2020-06-08 13:33:30.808037+03
28181	54	-1	3470	2020-06-08 13:47:47.479919+03
28182	47	-2	1480	2020-06-08 14:01:19.309804+03
28183	32	29	400	2020-06-08 14:11:38.349783+03
28184	89	-1	1420	2020-06-08 14:24:29.956752+03
28185	7	25	403	2020-06-08 14:26:51.151744+03
28186	85	-1	730	2020-06-08 14:31:09.925321+03
28187	41	-1	830	2020-06-08 14:44:54.398313+03
28188	58	-1	2830	2020-06-08 15:20:47.60928+03
28189	58	-1	2830	2020-06-08 15:23:34.173399+03
28190	15	-2	2830	2020-06-08 15:33:43.354019+03
28191	77	-2	640	2020-06-08 15:44:47.528626+03
28192	91	-1	1620	2020-06-08 15:53:06.427101+03
28193	77	-1	640	2020-06-08 15:53:46.832729+03
28194	21	-1	960	2020-06-08 16:21:18.333786+03
28195	86	-1	910	2020-06-08 16:29:54.506063+03
28196	12	-1	1650	2020-06-08 16:40:53.423559+03
28197	94	-1	1230	2020-06-08 16:48:15.350592+03
28198	33	-1	900	2020-06-08 16:51:44.075638+03
28199	63	-1	1780	2020-06-08 17:46:52.109318+03
28200	75	-1	830	2020-06-08 18:29:08.890177+03
28201	10	-1	2080	2020-06-08 18:40:32.270995+03
28202	78	-1	900	2020-06-08 19:05:19.946443+03
28203	7	-1	810	2020-06-08 19:21:29.733442+03
28204	34	-1	1550	2020-06-08 19:25:20.015244+03
28205	58	-1	2830	2020-06-08 19:36:32.810372+03
28206	90	-2	1780	2020-06-08 19:40:22.727545+03
28207	22	-1	1070	2020-06-08 19:52:10.879953+03
28208	5	-1	1620	2020-06-08 20:00:19.54742+03
28209	40	-3	1430	2020-06-08 20:12:20.679189+03
28210	58	28	1678	2020-06-08 20:12:47.025983+03
28211	76	-1	1070	2020-06-08 20:31:54.984029+03
28212	55	-1	3480	2020-06-08 20:52:59.935823+03
28213	4	-1	1420	2020-06-08 21:34:33.593098+03
28214	30	-1	1140	2020-06-08 21:41:25.176633+03
28215	86	-1	910	2020-06-08 22:05:11.072492+03
28216	54	-1	3470	2020-06-08 22:21:39.39903+03
28217	74	-1	1010	2020-06-08 22:21:53.323793+03
28218	19	-2	1220	2020-06-08 22:25:00.534381+03
28219	89	-1	1420	2020-06-08 22:32:44.318922+03
28220	91	-1	1620	2020-06-08 22:45:11.371709+03
28221	83	-2	1230	2020-06-08 22:59:21.498076+03
28222	47	-1	1480	2020-06-08 23:08:13.00683+03
28223	13	-1	460	2020-06-08 23:20:31.872056+03
28224	26	-1	390	2020-06-09 00:35:47.763194+03
28225	55	-1	3480	2020-06-09 00:48:02.648034+03
28226	27	-1	880	2020-06-09 00:57:43.419699+03
28227	54	-1	3470	2020-06-09 01:19:52.627569+03
28228	56	-1	2460	2020-06-09 01:20:19.062711+03
28229	51	-1	1310	2020-06-09 01:25:46.305318+03
28230	71	-1	1030	2020-06-09 01:33:31.177845+03
28231	86	-1	910	2020-06-09 01:50:47.541122+03
28232	26	21	199	2020-06-09 02:02:48.891516+03
28233	77	-1	640	2020-06-09 02:13:22.232831+03
28234	76	-1	1070	2020-06-09 02:50:34.874743+03
28235	66	-2	690	2020-06-09 03:12:31.238937+03
28236	29	-1	1940	2020-06-09 03:48:09.564092+03
28237	56	-2	2460	2020-06-09 04:00:39.231027+03
28238	30	-2	1140	2020-06-09 04:22:15.977904+03
28239	20	-2	830	2020-06-09 04:27:47.058756+03
28240	86	-1	910	2020-06-09 04:32:15.020364+03
28241	47	41	680	2020-06-09 04:43:33.80992+03
28242	63	-2	1780	2020-06-09 04:55:56.94834+03
28243	13	-1	460	2020-06-09 05:19:23.736657+03
28244	68	-2	490	2020-06-09 06:04:18.903083+03
28245	83	-2	1230	2020-06-09 06:45:18.47869+03
28246	41	-1	830	2020-06-09 06:48:53.807146+03
28247	41	-2	830	2020-06-09 07:03:29.278807+03
28248	61	-1	1510	2020-06-09 07:16:19.167077+03
28249	10	-1	2080	2020-06-09 07:21:20.464659+03
28250	2	-1	470	2020-06-09 07:36:38.48408+03
28251	95	-1	480	2020-06-09 07:47:00.956169+03
28252	16	-1	1380	2020-06-09 08:10:08.627778+03
28253	77	-1	640	2020-06-09 08:11:24.40651+03
28254	12	-1	1650	2020-06-09 08:17:28.699191+03
28255	3	-1	660	2020-06-09 08:19:04.953837+03
28256	28	-1	1860	2020-06-09 08:26:15.043627+03
28257	31	-1	1190	2020-06-09 08:27:49.242756+03
28258	51	-1	1310	2020-06-09 08:30:49.636163+03
28259	64	-1	970	2020-06-09 08:31:39.757039+03
28260	51	-1	1310	2020-06-09 08:41:12.017919+03
28261	64	-1	970	2020-06-09 08:52:36.471315+03
28262	52	-2	1090	2020-06-09 08:54:06.446354+03
28263	53	-1	3120	2020-06-09 09:25:01.511288+03
28264	67	-1	350	2020-06-09 09:32:38.714841+03
28265	24	-1	950	2020-06-09 09:38:03.305276+03
28266	59	-1	1030	2020-06-09 09:43:09.967402+03
28267	51	-2	1310	2020-06-09 10:05:54.817043+03
28268	13	-1	460	2020-06-09 10:07:03.859239+03
28269	87	-1	2320	2020-06-09 10:13:34.238084+03
28270	4	-1	1420	2020-06-09 10:15:32.874263+03
28271	4	-1	1420	2020-06-09 10:16:34.452978+03
28272	31	-1	1190	2020-06-09 10:22:42.027118+03
28273	50	-2	1140	2020-06-09 10:43:19.633254+03
28274	3	-1	660	2020-06-09 10:51:21.755999+03
28275	88	-2	1270	2020-06-09 10:58:00.050277+03
28276	52	-2	1090	2020-06-09 11:30:16.041985+03
28277	75	-1	830	2020-06-09 11:36:42.546203+03
28278	79	-2	550	2020-06-09 11:37:37.459203+03
28279	87	-1	2320	2020-06-09 11:49:32.778626+03
28280	38	-1	1100	2020-06-09 12:01:27.389815+03
28281	75	-1	830	2020-06-09 12:03:00.592368+03
28282	32	-1	710	2020-06-09 12:45:35.282422+03
28283	6	-1	980	2020-06-09 12:48:41.382844+03
28284	39	-1	910	2020-06-09 12:56:20.454216+03
28285	60	-1	2700	2020-06-09 12:59:38.548479+03
28286	6	-1	980	2020-06-09 13:23:51.150946+03
28287	32	-1	710	2020-06-09 13:24:56.982731+03
28288	82	-1	560	2020-06-09 13:33:33.086958+03
28289	31	-1	1190	2020-06-09 13:34:40.402081+03
28290	78	-1	900	2020-06-09 14:04:57.931704+03
28291	67	-1	350	2020-06-09 14:12:10.345039+03
28292	20	-1	830	2020-06-09 14:52:13.152075+03
28293	46	-1	1270	2020-06-09 14:58:14.873467+03
28294	46	-1	1270	2020-06-09 15:04:00.449121+03
28295	6	-1	980	2020-06-09 15:04:27.923692+03
28296	59	-1	1030	2020-06-09 15:12:01.32942+03
28297	85	-2	730	2020-06-09 15:12:40.098021+03
28298	68	-1	490	2020-06-09 15:18:59.057969+03
28299	33	-1	900	2020-06-09 15:23:15.762579+03
28300	6	-1	980	2020-06-09 15:25:01.530679+03
28301	4	-2	1420	2020-06-09 17:00:06.068437+03
28302	43	-1	380	2020-06-09 17:08:00.874704+03
28303	1	-1	640	2020-06-09 17:15:17.792836+03
28304	12	-1	1650	2020-06-09 17:22:19.300154+03
28305	39	-1	910	2020-06-09 18:03:57.076045+03
28306	80	-1	1120	2020-06-09 18:25:42.538403+03
28307	88	-1	1270	2020-06-09 18:34:46.172007+03
28308	40	-1	1430	2020-06-09 19:08:56.290562+03
28309	47	-1	1480	2020-06-09 19:13:33.61078+03
28310	93	-1	1620	2020-06-09 19:37:15.472307+03
28311	83	-1	1230	2020-06-09 20:58:32.619117+03
28312	48	-1	640	2020-06-09 21:07:41.410993+03
28313	4	-1	1420	2020-06-09 21:10:31.173134+03
28314	33	-1	900	2020-06-09 21:28:05.062013+03
28315	5	-1	1620	2020-06-09 21:29:29.452807+03
28316	3	17	362	2020-06-09 21:37:35.694161+03
28317	76	-1	1070	2020-06-09 21:54:56.663965+03
28318	40	-1	1430	2020-06-09 21:56:58.659521+03
28319	56	-1	2460	2020-06-09 22:03:43.311774+03
28320	53	-1	3120	2020-06-09 22:07:46.189047+03
28321	6	-1	980	2020-06-09 22:25:15.219513+03
28322	59	-1	1030	2020-06-09 22:33:59.972635+03
28323	18	-1	910	2020-06-09 22:49:03.136144+03
28324	1	-1	640	2020-06-09 23:15:49.283127+03
28325	13	-1	460	2020-06-09 23:18:15.252586+03
28326	86	-2	910	2020-06-09 23:24:34.804458+03
28327	95	-1	480	2020-06-09 23:47:45.589909+03
28328	6	-1	980	2020-06-09 23:56:32.918161+03
28329	42	-2	1790	2020-06-10 00:10:13.561527+03
28330	25	-1	1100	2020-06-10 00:28:38.745555+03
28331	33	-1	900	2020-06-10 00:49:11.890626+03
28332	71	-1	1030	2020-06-10 01:01:02.51623+03
28333	78	-2	900	2020-06-10 01:03:27.55884+03
28334	93	-1	1620	2020-06-10 01:42:27.058379+03
28335	41	-1	830	2020-06-10 01:55:20.342681+03
28336	32	-2	710	2020-06-10 01:57:19.317707+03
28337	65	-1	490	2020-06-10 02:36:34.249386+03
28338	95	-1	480	2020-06-10 02:40:02.341962+03
28339	74	-1	1010	2020-06-10 02:41:57.214367+03
28340	60	-1	2700	2020-06-10 02:55:35.296997+03
28341	67	-1	350	2020-06-10 02:56:41.564113+03
28342	6	-1	980	2020-06-10 03:00:07.542303+03
28343	93	-1	1620	2020-06-10 03:26:48.987167+03
28344	60	-1	2700	2020-06-10 03:47:22.700981+03
28345	34	-1	1550	2020-06-10 03:47:28.590514+03
28346	88	-1	1270	2020-06-10 04:00:57.722317+03
28347	52	-1	1090	2020-06-10 04:02:47.820972+03
28348	20	-1	830	2020-06-10 04:12:15.804425+03
28349	79	-1	550	2020-06-10 04:22:11.326702+03
28350	47	-1	1480	2020-06-10 04:36:35.177707+03
28351	37	-2	1290	2020-06-10 05:13:43.184668+03
28352	22	-1	1070	2020-06-10 05:26:55.936292+03
28353	76	-1	1070	2020-06-10 05:30:25.245752+03
28354	44	-1	500	2020-06-10 05:32:53.791426+03
28355	71	-1	1030	2020-06-10 05:37:24.683643+03
28356	88	-1	1270	2020-06-10 05:49:39.330587+03
28357	70	-1	760	2020-06-10 05:50:03.762938+03
28358	46	-1	1270	2020-06-10 05:55:50.022501+03
28359	82	-1	560	2020-06-10 06:20:40.565776+03
28360	6	-1	980	2020-06-10 06:28:51.409374+03
28361	67	-1	350	2020-06-10 06:33:32.496219+03
28362	89	-1	1420	2020-06-10 06:39:24.716158+03
28363	47	-1	1480	2020-06-10 06:51:33.30333+03
28364	9	-1	2090	2020-06-10 07:19:31.726469+03
28365	76	-1	1070	2020-06-10 07:29:02.302745+03
28366	93	-1	1620	2020-06-10 07:54:29.784737+03
28367	79	-2	550	2020-06-10 07:58:56.926927+03
28368	25	13	588	2020-06-10 08:16:10.432391+03
28369	49	-1	970	2020-06-10 08:31:04.204189+03
28370	31	-1	1190	2020-06-10 08:41:42.95222+03
28371	52	-1	1090	2020-06-10 08:51:21.062084+03
28372	57	-1	1900	2020-06-10 09:14:22.015168+03
28373	2	-1	470	2020-06-10 09:54:40.622823+03
28374	39	-1	910	2020-06-10 10:21:19.167246+03
28375	94	-1	1230	2020-06-10 10:29:04.236166+03
28376	83	-2	1230	2020-06-10 10:31:45.395997+03
28377	5	-1	1620	2020-06-10 10:42:55.026264+03
28378	37	-1	1290	2020-06-10 11:06:08.57808+03
28379	38	25	461	2020-06-10 11:24:25.376369+03
28380	59	-1	1030	2020-06-10 11:38:05.200691+03
28381	14	-1	1350	2020-06-10 11:44:15.658846+03
28382	63	-3	1780	2020-06-10 12:07:45.277294+03
28383	6	-1	980	2020-06-10 12:40:27.586339+03
28384	14	-1	1350	2020-06-10 13:04:22.312589+03
28385	74	-2	1010	2020-06-10 13:13:22.086731+03
28386	21	-1	960	2020-06-10 13:39:51.917484+03
28387	59	-1	1030	2020-06-10 13:52:24.188701+03
28388	53	-1	3120	2020-06-10 14:07:31.938893+03
28389	15	-1	2830	2020-06-10 14:25:41.941347+03
28390	29	-1	1940	2020-06-10 14:34:16.968974+03
28391	30	-1	1140	2020-06-10 15:14:26.833055+03
28392	71	-1	1030	2020-06-10 15:22:23.443946+03
28393	88	-1	1270	2020-06-10 15:23:27.071546+03
28394	50	-2	1140	2020-06-10 15:28:27.477544+03
28395	13	-1	460	2020-06-10 15:38:21.207256+03
28396	96	-2	1570	2020-06-10 15:47:12.995489+03
28397	42	-1	1790	2020-06-10 16:32:17.377289+03
28398	70	-2	760	2020-06-10 16:35:20.23613+03
28399	21	-1	960	2020-06-10 16:44:11.115086+03
28400	28	-1	1860	2020-06-10 16:46:29.748489+03
28401	77	-1	640	2020-06-10 17:22:30.889547+03
28402	10	-2	2080	2020-06-10 17:28:57.492929+03
28403	58	-1	2830	2020-06-10 18:14:27.698994+03
28404	51	-1	1310	2020-06-10 18:25:51.800914+03
28405	96	-1	1570	2020-06-10 18:26:00.280615+03
28406	29	-1	1940	2020-06-10 18:49:07.546225+03
28407	33	-1	900	2020-06-10 18:49:52.744597+03
28408	58	-1	2830	2020-06-10 18:51:07.835071+03
28409	46	-1	1270	2020-06-10 19:01:29.940526+03
28410	45	-1	1590	2020-06-10 19:16:56.800362+03
28411	91	-1	1620	2020-06-10 19:28:18.085181+03
28412	46	-2	1270	2020-06-10 19:44:17.222676+03
28413	89	-2	1420	2020-06-10 20:04:33.072254+03
28414	85	-2	730	2020-06-10 20:18:21.234063+03
28415	95	-1	480	2020-06-10 20:26:28.05139+03
28416	12	-2	1650	2020-06-10 20:39:40.613371+03
28417	63	-1	1780	2020-06-10 20:45:19.158138+03
28418	7	-1	810	2020-06-10 20:47:07.85422+03
28419	80	-1	1120	2020-06-10 20:58:01.360285+03
28420	54	-1	3470	2020-06-10 21:21:07.44416+03
28421	56	-1	2460	2020-06-10 21:31:48.185683+03
28422	63	-1	1780	2020-06-10 21:45:39.658453+03
28423	54	-3	3470	2020-06-10 21:57:06.886933+03
28424	35	-1	670	2020-06-10 22:04:02.153193+03
28425	56	-1	2460	2020-06-10 22:25:49.211514+03
28426	90	-1	1780	2020-06-10 22:28:07.089288+03
28427	76	-1	1070	2020-06-10 22:29:57.567449+03
28428	68	-1	490	2020-06-10 22:38:27.632832+03
28429	73	-1	960	2020-06-10 22:48:53.450271+03
28430	13	-1	460	2020-06-10 22:56:17.981328+03
28431	14	-1	1350	2020-06-10 23:13:26.443797+03
28432	58	-1	2830	2020-06-10 23:20:40.776268+03
28433	71	-1	1030	2020-06-10 23:38:41.612908+03
28434	19	-1	1220	2020-06-10 23:50:17.37016+03
28435	4	-1	1420	2020-06-10 23:51:15.675149+03
28436	59	-1	1030	2020-06-10 23:56:43.692636+03
28437	78	-1	900	2020-06-11 00:33:16.2007+03
28438	5	-1	1620	2020-06-11 00:34:07.640439+03
28439	8	-1	1920	2020-06-11 01:32:13.457549+03
28440	81	-1	1620	2020-06-11 02:08:56.89542+03
28441	87	-1	2320	2020-06-11 02:27:13.211434+03
28442	62	-2	1220	2020-06-11 02:36:34.179267+03
28443	94	-1	1230	2020-06-11 02:50:28.770733+03
28444	49	-1	970	2020-06-11 03:13:48.875166+03
28445	49	-1	970	2020-06-11 03:33:34.974969+03
28446	22	-2	1070	2020-06-11 03:45:11.937884+03
28447	8	-1	1920	2020-06-11 03:53:46.915733+03
28448	75	-1	830	2020-06-11 04:05:16.668227+03
28449	56	-2	2460	2020-06-11 04:14:27.125317+03
28450	70	-1	760	2020-06-11 04:48:28.974151+03
28451	83	-1	1230	2020-06-11 05:01:56.709673+03
28452	12	-1	1650	2020-06-11 05:17:59.063418+03
28453	55	-2	3480	2020-06-11 05:46:24.949607+03
28454	67	-2	350	2020-06-11 06:32:06.591284+03
28455	7	-1	810	2020-06-11 06:52:17.907384+03
28456	80	-1	1120	2020-06-11 07:24:03.994964+03
28457	78	15	507	2020-06-11 07:28:05.895087+03
28458	16	-2	1380	2020-06-11 07:36:06.790785+03
28459	1	-1	640	2020-06-11 07:48:03.010667+03
28460	17	-1	1500	2020-06-11 08:03:54.193431+03
28461	69	18	558	2020-06-11 08:16:05.816918+03
28462	6	-1	980	2020-06-11 08:25:40.154216+03
28463	31	-1	1190	2020-06-11 08:43:28.84772+03
28464	1	-1	640	2020-06-11 08:48:35.007455+03
28465	41	-1	830	2020-06-11 08:54:28.98596+03
28466	42	-1	1790	2020-06-11 08:56:11.021991+03
28467	96	-1	1570	2020-06-11 09:03:31.531859+03
28468	73	-1	960	2020-06-11 09:57:56.067669+03
28469	25	-1	1100	2020-06-11 10:26:34.101179+03
28470	17	-1	1500	2020-06-11 10:31:42.371014+03
28471	41	-2	830	2020-06-11 10:34:06.884417+03
28472	60	-1	2700	2020-06-11 11:09:50.21101+03
28473	50	-1	1140	2020-06-11 11:16:52.401699+03
28474	51	-2	1310	2020-06-11 11:20:24.079386+03
28475	51	-1	1310	2020-06-11 11:25:26.830914+03
28476	20	-1	830	2020-06-11 11:34:51.025106+03
28477	36	-2	630	2020-06-11 12:45:41.010877+03
28478	41	-1	830	2020-06-11 12:48:32.476534+03
28479	67	-2	350	2020-06-11 12:48:52.863981+03
28480	13	-1	460	2020-06-11 12:53:19.879091+03
28481	46	-1	1270	2020-06-11 12:58:55.114656+03
28482	49	-2	970	2020-06-11 13:19:19.925269+03
28483	5	-1	1620	2020-06-11 13:23:54.379513+03
28484	47	-1	1480	2020-06-11 13:37:08.971844+03
28485	84	-2	2700	2020-06-11 13:42:00.175355+03
28486	70	-1	760	2020-06-11 13:43:41.030473+03
28487	20	-1	830	2020-06-11 13:52:03.445433+03
28488	54	-2	3470	2020-06-11 14:08:19.093821+03
28489	58	-1	2830	2020-06-11 14:14:18.429049+03
28490	28	-1	1860	2020-06-11 14:22:57.296274+03
28491	86	-1	910	2020-06-11 14:35:22.782+03
28492	46	39	647	2020-06-11 15:17:50.443322+03
28493	18	-1	910	2020-06-11 15:21:37.629735+03
28494	49	-1	970	2020-06-11 15:31:10.794755+03
28495	53	-1	3120	2020-06-11 15:32:05.625369+03
28496	4	-1	1420	2020-06-11 15:43:05.118479+03
28497	35	-2	670	2020-06-11 16:10:18.052469+03
28498	64	-1	970	2020-06-11 16:18:20.848498+03
28499	12	47	853	2020-06-11 16:25:40.530699+03
28500	10	-1	2080	2020-06-11 16:26:35.433897+03
28501	9	-1	2090	2020-06-11 16:32:21.847918+03
28502	67	-1	350	2020-06-11 16:32:46.937259+03
28503	19	-1	1220	2020-06-11 16:35:09.006502+03
28504	42	-1	1790	2020-06-11 16:44:09.252503+03
28505	30	27	458	2020-06-11 16:49:03.600587+03
28506	90	-1	1780	2020-06-11 17:25:05.463044+03
28507	93	-1	1620	2020-06-11 17:25:37.139026+03
28508	95	-1	480	2020-06-11 17:29:43.178687+03
28509	40	-1	1430	2020-06-11 17:30:11.481357+03
28510	64	-1	970	2020-06-11 18:26:16.909538+03
28511	38	-1	1100	2020-06-11 19:06:25.395116+03
28512	67	-1	350	2020-06-11 19:12:00.08487+03
28513	54	-1	3470	2020-06-11 19:12:07.15213+03
28514	94	-1	1230	2020-06-11 19:14:23.094351+03
28515	29	-1	1940	2020-06-11 19:15:06.475522+03
28516	6	-1	980	2020-06-11 19:26:58.168773+03
28517	4	-1	1420	2020-06-11 19:29:42.136391+03
28518	70	30	418	2020-06-11 19:32:23.31218+03
28519	23	-2	4390	2020-06-11 19:52:56.787625+03
28520	15	-1	2830	2020-06-11 19:56:48.346165+03
28521	11	-2	830	2020-06-11 20:32:56.377091+03
28522	42	-2	1790	2020-06-11 20:52:45.322199+03
28523	58	-1	2830	2020-06-11 21:01:48.763306+03
28524	44	-1	500	2020-06-11 21:17:56.546714+03
28525	84	-1	2700	2020-06-11 21:33:03.449693+03
28526	63	26	872	2020-06-11 22:43:00.549262+03
28527	36	-1	630	2020-06-11 23:00:36.840854+03
28528	56	-1	2460	2020-06-11 23:08:49.269861+03
28529	7	-1	810	2020-06-11 23:20:18.321798+03
28530	25	-1	1100	2020-06-11 23:51:43.975681+03
28531	93	-1	1620	2020-06-11 23:56:01.134692+03
28532	95	-1	480	2020-06-11 23:57:05.800577+03
28533	96	32	861	2020-06-12 00:12:26.859616+03
28534	45	-1	1590	2020-06-12 00:21:07.300552+03
28535	67	-1	350	2020-06-12 00:25:50.122414+03
28536	16	-1	1380	2020-06-12 00:48:48.845055+03
28537	67	-1	350	2020-06-12 01:20:58.870222+03
28538	40	-2	1430	2020-06-12 01:23:20.309219+03
28539	36	-1	630	2020-06-12 01:34:31.427488+03
28540	31	-1	1190	2020-06-12 01:57:20.894289+03
28541	69	-2	1100	2020-06-12 02:35:16.508908+03
28542	19	-1	1220	2020-06-12 03:25:46.619781+03
28543	78	-1	900	2020-06-12 03:36:51.953675+03
28544	46	-1	1270	2020-06-12 03:47:53.639656+03
28545	74	-2	1010	2020-06-12 03:49:23.379572+03
28546	40	-1	1430	2020-06-12 03:59:39.593918+03
28547	67	38	155	2020-06-12 04:00:09.986612+03
28548	45	-1	1590	2020-06-12 04:42:21.279775+03
28549	55	-1	3480	2020-06-12 05:25:12.078741+03
28550	37	-1	1290	2020-06-12 05:46:04.459206+03
28551	21	-1	960	2020-06-12 06:47:37.751413+03
28552	54	-1	3470	2020-06-12 06:51:19.670083+03
28553	13	-1	460	2020-06-12 06:56:54.461635+03
28554	34	-1	1550	2020-06-12 06:59:19.286895+03
28555	89	-1	1420	2020-06-12 07:09:23.951624+03
28556	61	29	757	2020-06-12 07:16:40.840692+03
28557	73	-1	960	2020-06-12 07:51:18.449307+03
28558	20	-1	830	2020-06-12 07:55:06.326697+03
28559	34	-1	1550	2020-06-12 08:33:18.8976+03
28560	80	-1	1120	2020-06-12 08:40:08.050024+03
28561	89	-1	1420	2020-06-12 09:03:35.03189+03
28562	78	-1	900	2020-06-12 09:05:20.565052+03
28563	18	-1	910	2020-06-12 09:25:22.443744+03
28564	42	-1	1790	2020-06-12 09:30:34.309497+03
28565	17	-1	1500	2020-06-12 09:32:05.279976+03
28566	10	-2	2080	2020-06-12 09:43:34.49218+03
28567	63	-1	1780	2020-06-12 09:49:09.086055+03
28568	51	-1	1310	2020-06-12 10:12:13.807152+03
28569	25	-2	1100	2020-06-12 10:19:52.335186+03
28570	96	-1	1570	2020-06-12 10:23:11.468871+03
28571	56	-2	2460	2020-06-12 10:23:33.474683+03
28572	13	-1	460	2020-06-12 10:25:34.204464+03
28573	87	-1	2320	2020-06-12 10:37:42.145521+03
28574	79	-1	550	2020-06-12 11:22:06.683065+03
28575	92	-1	630	2020-06-12 11:28:08.315171+03
28576	61	-1	1510	2020-06-12 11:41:32.367822+03
28577	66	-1	690	2020-06-12 11:47:50.970322+03
28578	59	-3	1030	2020-06-12 11:49:34.276188+03
28579	84	-1	2700	2020-06-12 11:51:51.342658+03
28580	56	-2	2460	2020-06-12 12:03:39.957206+03
28581	79	-1	550	2020-06-12 12:36:31.922541+03
28582	94	-1	1230	2020-06-12 12:45:43.935814+03
28583	93	-1	1620	2020-06-12 12:46:09.587953+03
28584	9	-1	2090	2020-06-12 13:08:05.854398+03
28585	22	-1	1070	2020-06-12 13:19:59.093187+03
28586	49	-1	970	2020-06-12 13:24:22.912424+03
28587	30	-1	1140	2020-06-12 13:24:50.73142+03
28588	39	-1	910	2020-06-12 14:05:59.941777+03
28589	75	-1	830	2020-06-12 14:09:15.668425+03
28590	40	-1	1430	2020-06-12 14:24:18.422926+03
28591	76	-1	1070	2020-06-12 14:47:58.287671+03
28592	44	-1	500	2020-06-12 14:58:51.025442+03
28593	12	-2	1650	2020-06-12 15:04:30.703227+03
28594	75	-2	830	2020-06-12 15:10:42.739189+03
28595	50	-1	1140	2020-06-12 15:25:54.730543+03
28596	69	-1	1100	2020-06-12 15:26:03.553229+03
28597	84	-1	2700	2020-06-12 15:31:58.536768+03
28598	33	-1	900	2020-06-12 16:01:52.318115+03
28599	70	-1	760	2020-06-12 16:04:05.154694+03
28600	87	-1	2320	2020-06-12 16:07:55.947494+03
28601	32	-2	710	2020-06-12 16:12:15.779096+03
28602	70	-1	760	2020-06-12 16:18:06.844598+03
28603	52	-1	1090	2020-06-12 16:40:37.984873+03
28604	30	-1	1140	2020-06-12 16:43:15.652116+03
28605	9	-1	2090	2020-06-12 16:45:38.840778+03
28606	94	-1	1230	2020-06-12 17:14:12.372345+03
28607	74	-1	1010	2020-06-12 17:15:35.824994+03
28608	63	-1	1780	2020-06-12 17:24:07.677799+03
28609	41	-1	830	2020-06-12 17:55:56.19597+03
28610	1	-1	640	2020-06-12 17:59:17.181469+03
28611	29	-1	1940	2020-06-12 18:00:49.363356+03
28612	96	-2	1570	2020-06-12 18:10:06.34285+03
28613	89	-1	1420	2020-06-12 18:27:34.493078+03
28614	9	-1	2090	2020-06-12 19:02:59.73047+03
28615	68	-1	490	2020-06-12 19:04:03.545946+03
28616	76	-1	1070	2020-06-12 19:15:44.931599+03
28617	32	-1	710	2020-06-12 19:18:52.982368+03
28618	76	-2	1070	2020-06-12 19:27:42.824118+03
28619	10	-1	2080	2020-06-12 19:58:58.290465+03
28620	10	-1	2080	2020-06-12 20:05:35.836441+03
28621	29	-1	1940	2020-06-12 20:09:11.919544+03
28622	69	-1	1100	2020-06-12 20:33:15.91479+03
28623	18	-1	910	2020-06-12 21:16:46.316918+03
28624	23	-1	4390	2020-06-12 21:41:54.295275+03
28625	61	-1	1510	2020-06-12 22:01:11.205274+03
28626	46	-1	1270	2020-06-12 22:07:19.576921+03
28627	70	-1	760	2020-06-12 22:17:45.647765+03
28628	30	-2	1140	2020-06-12 22:26:12.264796+03
28629	12	-1	1650	2020-06-12 22:35:23.90356+03
28630	15	-1	2830	2020-06-12 23:08:37.950018+03
28631	49	-1	970	2020-06-12 23:19:02.858813+03
28632	31	-2	1190	2020-06-13 00:02:51.895842+03
28633	65	-1	490	2020-06-13 00:22:43.567051+03
28634	52	-2	1090	2020-06-13 00:23:11.006456+03
28635	60	25	1294	2020-06-13 00:33:47.509396+03
28636	8	-1	1920	2020-06-13 00:38:13.946848+03
28637	10	-1	2080	2020-06-13 00:54:52.746022+03
28638	14	-1	1350	2020-06-13 01:42:39.338569+03
28639	42	-1	1790	2020-06-13 01:43:56.773271+03
28640	41	-1	830	2020-06-13 01:45:08.3629+03
28641	50	-1	1140	2020-06-13 02:25:47.952836+03
28642	42	-1	1790	2020-06-13 02:32:26.557662+03
28643	55	-1	3480	2020-06-13 02:54:59.613973+03
28644	9	-1	2090	2020-06-13 02:55:08.539137+03
28645	25	-1	1100	2020-06-13 03:00:48.526379+03
28646	7	-2	810	2020-06-13 03:25:37.03081+03
28647	47	-1	1480	2020-06-13 03:34:45.627008+03
28648	53	-2	3120	2020-06-13 05:00:35.95655+03
28649	30	-2	1140	2020-06-13 05:17:40.45157+03
28650	75	-1	830	2020-06-13 05:19:39.913735+03
28651	32	-1	710	2020-06-13 05:21:40.196162+03
28652	82	-1	560	2020-06-13 05:31:43.211222+03
28653	55	-1	3480	2020-06-13 05:37:52.743233+03
28654	89	-2	1420	2020-06-13 06:27:40.88421+03
28655	73	-2	960	2020-06-13 06:32:07.560732+03
28656	56	-1	2460	2020-06-13 06:49:38.0756+03
28657	20	-1	830	2020-06-13 06:59:19.927448+03
28658	51	-1	1310	2020-06-13 08:31:00.866978+03
28659	53	-1	3120	2020-06-13 08:48:58.147389+03
28660	35	-2	670	2020-06-13 09:05:27.76296+03
28661	40	-1	1430	2020-06-13 09:16:16.529047+03
28662	46	-1	1270	2020-06-13 09:16:56.465042+03
28663	76	-1	1070	2020-06-13 09:18:04.167669+03
28664	12	-1	1650	2020-06-13 10:06:35.885895+03
28665	69	-1	1100	2020-06-13 10:18:42.903529+03
28666	36	-2	630	2020-06-13 10:20:10.422476+03
28667	26	-2	390	2020-06-13 10:28:10.673444+03
28668	78	-1	900	2020-06-13 10:52:29.306752+03
28669	69	-1	1100	2020-06-13 10:53:24.298982+03
28670	75	-1	830	2020-06-13 11:47:00.149913+03
28671	49	-1	970	2020-06-13 12:07:09.907216+03
28672	44	-1	500	2020-06-13 12:27:02.769903+03
28673	45	-1	1590	2020-06-13 12:51:34.101957+03
28674	63	-1	1780	2020-06-13 12:55:40.09432+03
28675	2	5	191	2020-06-13 13:03:59.050585+03
28676	35	-2	670	2020-06-13 13:09:41.813831+03
28677	44	-1	500	2020-06-13 13:26:36.993329+03
28678	87	-1	2320	2020-06-13 14:15:00.094519+03
28679	50	-1	1140	2020-06-13 14:15:57.409218+03
28680	36	-1	630	2020-06-13 14:54:04.916858+03
28681	6	-1	980	2020-06-13 15:09:19.254281+03
28682	10	-1	2080	2020-06-13 15:14:33.388282+03
28683	33	-1	900	2020-06-13 15:17:45.927024+03
28684	55	-1	3480	2020-06-13 15:19:41.60594+03
28685	12	-1	1650	2020-06-13 15:25:07.854328+03
28686	8	-1	1920	2020-06-13 15:48:19.459962+03
28687	47	-1	1480	2020-06-13 16:18:25.252136+03
28688	3	-1	660	2020-06-13 16:19:53.912113+03
28689	42	-1	1790	2020-06-13 16:23:01.24816+03
28690	69	-1	1100	2020-06-13 16:49:06.895561+03
28691	10	-1	2080	2020-06-13 17:30:22.381263+03
28692	89	-1	1420	2020-06-13 17:39:37.300905+03
28693	63	-1	1780	2020-06-13 17:44:21.684074+03
28694	30	-1	1140	2020-06-13 17:53:50.389896+03
28695	42	-1	1790	2020-06-13 18:17:33.428277+03
28696	63	-1	1780	2020-06-13 18:22:39.894661+03
28697	96	-1	1570	2020-06-13 18:46:56.652751+03
28698	1	-1	640	2020-06-13 18:53:10.932198+03
28699	33	-1	900	2020-06-13 19:09:17.698474+03
28700	44	-2	500	2020-06-13 19:12:24.393956+03
28701	10	-1	2080	2020-06-13 19:18:20.603729+03
28702	13	-2	460	2020-06-13 19:19:06.937144+03
28703	87	-1	2320	2020-06-13 19:23:56.932723+03
28704	34	-1	1550	2020-06-13 20:00:43.552038+03
28705	34	-1	1550	2020-06-13 20:08:51.552997+03
28706	75	-1	830	2020-06-13 20:13:21.732667+03
28707	19	-1	1220	2020-06-13 20:15:39.348748+03
28708	95	-2	480	2020-06-13 20:16:58.939025+03
28709	81	-1	1620	2020-06-13 20:19:05.681513+03
28710	35	31	291	2020-06-13 20:23:06.501588+03
28711	87	-1	2320	2020-06-13 20:54:48.808742+03
28712	11	-2	830	2020-06-13 21:01:18.345194+03
28713	30	-2	1140	2020-06-13 21:24:08.436615+03
28714	51	-1	1310	2020-06-13 21:36:05.173678+03
28715	30	-1	1140	2020-06-13 21:39:39.916155+03
28716	26	-1	390	2020-06-13 21:41:49.067815+03
28717	68	-1	490	2020-06-13 21:45:10.977771+03
28718	88	-1	1270	2020-06-13 22:14:02.066405+03
28719	33	-1	900	2020-06-13 22:24:58.125009+03
28720	27	-1	880	2020-06-13 22:42:28.186549+03
28721	36	-1	630	2020-06-13 22:49:11.026242+03
28722	90	-1	1780	2020-06-13 23:07:04.364106+03
28723	19	-2	1220	2020-06-13 23:07:14.272769+03
28724	39	-2	910	2020-06-13 23:20:59.735674+03
28725	27	-1	880	2020-06-13 23:26:29.212845+03
28726	69	-1	1100	2020-06-13 23:59:20.448984+03
28727	38	-1	1100	2020-06-14 00:09:02.051072+03
28728	7	-1	810	2020-06-14 00:43:36.634357+03
28729	62	-1	1220	2020-06-14 00:45:52.679655+03
28730	78	-2	900	2020-06-14 00:52:37.129244+03
28731	49	-1	970	2020-06-14 01:07:36.969173+03
28732	21	-1	960	2020-06-14 01:08:16.812987+03
28733	17	-2	1500	2020-06-14 01:17:42.029454+03
28734	90	-1	1780	2020-06-14 01:30:40.905927+03
28735	35	-1	670	2020-06-14 01:32:41.717198+03
28736	13	-2	460	2020-06-14 01:52:28.739881+03
28737	46	-2	1270	2020-06-14 02:02:23.703952+03
28738	68	-1	490	2020-06-14 02:21:39.795513+03
28739	8	-1	1920	2020-06-14 02:23:17.24962+03
28740	6	-1	980	2020-06-14 04:15:03.120938+03
28741	24	-1	950	2020-06-14 04:28:21.618108+03
28742	81	-1	1620	2020-06-14 04:40:23.031527+03
28743	67	-1	350	2020-06-14 04:57:34.298694+03
28744	96	-1	1570	2020-06-14 05:15:55.650481+03
28745	74	-2	1010	2020-06-14 05:25:26.472752+03
28746	4	-1	1420	2020-06-14 05:28:40.207685+03
28747	92	-1	630	2020-06-14 06:13:00.021075+03
28748	6	-1	980	2020-06-14 06:26:39.086979+03
28749	96	-1	1570	2020-06-14 06:30:31.183107+03
28750	26	-1	390	2020-06-14 06:41:05.449441+03
28751	26	-1	390	2020-06-14 06:59:50.760839+03
28752	9	-1	2090	2020-06-14 06:59:51.956678+03
28753	64	-1	970	2020-06-14 07:08:02.969721+03
28754	71	-2	1030	2020-06-14 07:58:53.542793+03
28755	39	-2	910	2020-06-14 07:59:35.053548+03
28756	13	-1	460	2020-06-14 08:24:57.481003+03
28757	12	-1	1650	2020-06-14 08:26:21.916441+03
28758	4	-1	1420	2020-06-14 08:39:20.049091+03
28759	14	-1	1350	2020-06-14 08:39:27.641099+03
28760	94	-1	1230	2020-06-14 08:40:07.236277+03
28761	73	-1	960	2020-06-14 08:42:04.343634+03
28762	74	-1	1010	2020-06-14 09:59:35.225434+03
28763	37	-1	1290	2020-06-14 10:09:35.085435+03
28764	5	-1	1620	2020-06-14 10:53:50.431833+03
28765	46	-1	1270	2020-06-14 11:50:07.235166+03
28766	46	-2	1270	2020-06-14 12:42:01.002332+03
28767	73	14	448	2020-06-14 12:48:26.481842+03
28768	35	-1	670	2020-06-14 12:58:12.570195+03
28769	61	-1	1510	2020-06-14 13:43:58.121043+03
28770	49	-1	970	2020-06-14 14:51:03.921192+03
28771	81	-1	1620	2020-06-14 14:52:17.389978+03
28772	89	-1	1420	2020-06-14 15:25:13.830556+03
28773	3	-1	660	2020-06-14 15:27:00.243892+03
28774	58	-1	2830	2020-06-14 15:41:37.618471+03
28775	95	-2	480	2020-06-14 16:31:13.833878+03
28776	11	-1	830	2020-06-14 16:52:04.679508+03
28777	67	-1	350	2020-06-14 17:07:08.713267+03
28778	79	-1	550	2020-06-14 17:29:46.461223+03
28779	6	-1	980	2020-06-14 17:30:50.22388+03
28780	94	-1	1230	2020-06-14 17:54:09.731882+03
28781	42	-1	1790	2020-06-14 18:15:44.972572+03
28782	75	-1	830	2020-06-14 18:32:45.433038+03
28783	46	-1	1270	2020-06-14 18:50:05.540314+03
28784	85	-1	730	2020-06-14 19:23:37.493607+03
28785	80	-1	1120	2020-06-14 19:26:38.007959+03
28786	53	-1	3120	2020-06-14 19:35:35.384046+03
28787	40	-1	1430	2020-06-14 19:38:21.53795+03
28788	73	-1	960	2020-06-14 19:54:59.690787+03
28789	20	-1	830	2020-06-14 20:19:12.396287+03
28790	13	-1	460	2020-06-14 20:35:17.866975+03
28791	43	-3	380	2020-06-14 20:46:41.196629+03
28792	62	-1	1220	2020-06-14 20:46:42.748771+03
28793	13	-1	460	2020-06-14 20:50:15.940414+03
28794	87	-1	2320	2020-06-14 20:50:54.404595+03
28795	9	-1	2090	2020-06-14 21:40:15.509417+03
28796	30	-1	1140	2020-06-14 22:06:10.638695+03
28797	31	-1	1190	2020-06-14 22:08:54.749208+03
28798	40	-1	1430	2020-06-14 22:33:05.306487+03
28799	21	-2	960	2020-06-14 22:36:00.965154+03
28800	95	-2	480	2020-06-14 22:54:28.983087+03
28801	7	-1	810	2020-06-14 23:00:39.809794+03
28802	4	-1	1420	2020-06-14 23:06:33.959971+03
28803	43	-1	380	2020-06-14 23:14:15.051609+03
28804	56	-2	2460	2020-06-14 23:46:20.424559+03
28805	46	-1	1270	2020-06-15 00:10:41.906825+03
28806	30	-2	1140	2020-06-15 00:19:09.215183+03
28807	1	-1	640	2020-06-15 00:26:56.211098+03
28808	32	-1	710	2020-06-15 00:29:47.977881+03
28809	61	-1	1510	2020-06-15 01:07:16.411461+03
28810	89	-2	1420	2020-06-15 02:06:15.061357+03
28811	72	-1	620	2020-06-15 02:08:42.119514+03
28812	90	-2	1780	2020-06-15 02:12:33.471506+03
28813	44	-1	500	2020-06-15 02:22:00.759653+03
28814	4	-1	1420	2020-06-15 02:23:08.957087+03
28815	83	-1	1230	2020-06-15 02:29:01.012427+03
28816	2	-3	470	2020-06-15 03:26:56.850242+03
28817	23	-2	4390	2020-06-15 03:29:44.226178+03
28818	18	25	535	2020-06-15 03:36:44.104164+03
28819	53	-1	3120	2020-06-15 04:06:55.008229+03
28820	79	-1	550	2020-06-15 04:09:48.025775+03
28821	29	-1	1940	2020-06-15 04:14:42.581894+03
28822	70	-1	760	2020-06-15 04:29:18.643249+03
28823	93	-2	1620	2020-06-15 04:30:25.189021+03
28824	46	-1	1270	2020-06-15 04:40:50.185593+03
28825	60	-2	2700	2020-06-15 04:42:47.25707+03
28826	32	-1	710	2020-06-15 04:45:25.271892+03
28827	67	-1	350	2020-06-15 05:00:23.900549+03
28828	90	-2	1780	2020-06-15 05:02:04.410787+03
28829	7	-1	810	2020-06-15 05:11:13.43081+03
28830	47	-1	1480	2020-06-15 05:15:00.995391+03
28831	82	-1	560	2020-06-15 05:17:01.662832+03
28832	46	-1	1270	2020-06-15 05:25:21.147864+03
28833	60	-2	2700	2020-06-15 05:34:55.501158+03
28834	83	-1	1230	2020-06-15 06:02:07.619385+03
28835	55	-1	3480	2020-06-15 06:05:47.32593+03
28836	4	-1	1420	2020-06-15 06:06:56.523664+03
28837	47	-1	1480	2020-06-15 06:18:18.132269+03
28838	15	-1	2830	2020-06-15 06:20:19.898278+03
28839	54	-1	3470	2020-06-15 06:20:53.607665+03
28840	32	-1	710	2020-06-15 06:24:14.038896+03
28841	94	-1	1230	2020-06-15 06:52:16.033171+03
28842	89	-1	1420	2020-06-15 07:00:21.528291+03
28843	25	-1	1100	2020-06-15 07:09:13.164663+03
28844	39	-2	910	2020-06-15 07:15:09.313032+03
28845	48	-1	640	2020-06-15 07:32:55.231986+03
28846	57	-1	1900	2020-06-15 07:40:04.569167+03
28847	76	-1	1070	2020-06-15 07:43:32.76395+03
28848	73	-1	960	2020-06-15 08:14:42.304888+03
28849	88	-1	1270	2020-06-15 09:41:09.965764+03
28850	42	-1	1790	2020-06-15 10:04:56.141705+03
28851	34	-1	1550	2020-06-15 10:05:37.190385+03
28852	94	-1	1230	2020-06-15 10:15:40.571326+03
28853	37	-2	1290	2020-06-15 10:29:24.732568+03
28854	45	-1	1590	2020-06-15 10:35:13.64846+03
28855	67	-1	350	2020-06-15 10:44:36.088071+03
28856	58	-1	2830	2020-06-15 11:02:37.791011+03
28857	67	-2	350	2020-06-15 11:26:20.162117+03
28858	21	-1	960	2020-06-15 11:32:34.378372+03
28859	82	-2	560	2020-06-15 11:35:32.661263+03
28860	46	-1	1270	2020-06-15 11:45:55.485803+03
28861	19	-2	1220	2020-06-15 11:53:57.239095+03
28862	46	-2	1270	2020-06-15 12:16:48.6636+03
28863	47	-1	1480	2020-06-15 12:26:48.731803+03
28864	29	-1	1940	2020-06-15 12:57:18.146933+03
28865	64	28	529	2020-06-15 13:02:29.557551+03
28866	37	-1	1290	2020-06-15 13:10:12.500346+03
28867	80	-2	1120	2020-06-15 13:15:29.838501+03
28868	26	-2	390	2020-06-15 13:23:40.790774+03
28869	1	-2	640	2020-06-15 13:39:31.9232+03
28870	96	-1	1570	2020-06-15 13:41:42.93249+03
28871	43	-1	380	2020-06-15 13:57:42.155998+03
28872	25	-1	1100	2020-06-15 14:23:14.945336+03
28873	18	-3	910	2020-06-15 15:34:10.395003+03
28874	87	-1	2320	2020-06-15 15:52:20.853656+03
28875	32	-1	710	2020-06-15 16:08:46.913176+03
28876	47	-1	1480	2020-06-15 16:09:12.683085+03
28877	63	-1	1780	2020-06-15 16:23:48.058992+03
28878	69	-1	1100	2020-06-15 16:25:01.234951+03
28879	33	-1	900	2020-06-15 16:32:26.052118+03
28880	35	-1	670	2020-06-15 16:40:27.023685+03
28881	42	-1	1790	2020-06-15 17:11:49.035954+03
28882	51	-1	1310	2020-06-15 17:50:12.15338+03
28883	12	-1	1650	2020-06-15 17:50:17.145072+03
28884	25	-1	1100	2020-06-15 18:14:36.631234+03
28885	30	-1	1140	2020-06-15 18:28:51.016405+03
28886	19	-1	1220	2020-06-15 18:29:16.366687+03
28887	86	-1	910	2020-06-15 18:34:04.802696+03
28888	55	-1	3480	2020-06-15 18:48:35.997477+03
28889	87	-1	2320	2020-06-15 18:54:59.974666+03
28890	19	-2	1220	2020-06-15 18:55:26.654283+03
28891	18	-1	910	2020-06-15 18:55:30.334104+03
28892	26	-1	390	2020-06-15 19:05:54.062592+03
28893	60	-2	2700	2020-06-15 19:24:59.223266+03
28894	8	-1	1920	2020-06-15 20:14:28.22913+03
28895	40	-1	1430	2020-06-15 20:45:26.859274+03
28896	36	-2	630	2020-06-15 21:04:36.563618+03
28897	46	-1	1270	2020-06-15 21:04:50.445116+03
28898	45	-2	1590	2020-06-15 21:05:54.648179+03
28899	33	37	454	2020-06-15 21:27:37.539437+03
28900	24	-2	950	2020-06-15 21:36:56.704482+03
28901	81	-3	1620	2020-06-15 21:58:26.975608+03
28902	23	-2	4390	2020-06-15 22:24:19.179854+03
28903	67	-1	350	2020-06-15 22:59:04.946793+03
28904	25	-1	1100	2020-06-15 23:25:41.899716+03
28905	14	-1	1350	2020-06-15 23:27:17.017528+03
28906	17	-1	1500	2020-06-16 00:24:14.241531+03
28907	15	-1	2830	2020-06-16 00:51:16.846968+03
28908	75	-1	830	2020-06-16 00:51:30.450382+03
28909	13	-2	460	2020-06-16 00:52:12.706484+03
28910	46	-1	1270	2020-06-16 01:08:29.387102+03
28911	78	-1	900	2020-06-16 02:07:50.227001+03
28912	40	-1	1430	2020-06-16 02:40:32.474465+03
28913	19	-1	1220	2020-06-16 03:01:59.37461+03
28914	51	-1	1310	2020-06-16 03:12:20.60209+03
28915	76	-2	1070	2020-06-16 03:26:45.171779+03
28916	13	-2	460	2020-06-16 03:36:16.814483+03
28917	2	-1	470	2020-06-16 04:06:24.47736+03
28918	88	-1	1270	2020-06-16 04:14:46.672614+03
28919	12	-1	1650	2020-06-16 05:21:17.247832+03
28920	94	-1	1230	2020-06-16 05:43:42.271452+03
28921	79	-2	550	2020-06-16 05:51:48.092765+03
28922	12	-1	1650	2020-06-16 06:11:11.962635+03
28923	46	-1	1270	2020-06-16 06:24:01.975729+03
28924	51	-1	1310	2020-06-16 06:57:35.802215+03
28925	37	-1	1290	2020-06-16 07:06:45.984892+03
28926	27	-1	880	2020-06-16 07:53:53.689542+03
28927	48	-3	640	2020-06-16 07:54:56.074589+03
28928	37	-2	1290	2020-06-16 08:29:29.912387+03
28929	9	-1	2090	2020-06-16 08:41:26.782732+03
28930	62	-1	1220	2020-06-16 09:08:34.17007+03
28931	89	-1	1420	2020-06-16 09:20:56.679386+03
28932	74	-1	1010	2020-06-16 09:35:32.322124+03
28933	30	-2	1140	2020-06-16 09:37:49.741546+03
28934	32	-1	710	2020-06-16 09:38:08.664279+03
28935	63	-1	1780	2020-06-16 09:44:56.164836+03
28936	18	-1	910	2020-06-16 09:55:17.179656+03
28937	18	-1	910	2020-06-16 10:13:25.332608+03
28938	83	-1	1230	2020-06-16 10:24:36.989764+03
28939	81	-1	1620	2020-06-16 10:43:18.356961+03
28940	47	-2	1480	2020-06-16 11:15:38.108475+03
28941	31	-1	1190	2020-06-16 11:30:43.270603+03
28942	1	-1	640	2020-06-16 11:36:53.665295+03
28943	89	-1	1420	2020-06-16 11:55:01.48894+03
28944	27	-1	880	2020-06-16 11:55:15.198923+03
28945	68	-2	490	2020-06-16 11:55:48.719067+03
28946	13	-3	460	2020-06-16 11:56:54.936224+03
28947	28	-2	1860	2020-06-16 12:00:45.13275+03
28948	17	-1	1500	2020-06-16 12:15:13.04878+03
28949	24	-1	950	2020-06-16 12:31:27.936632+03
28950	30	-1	1140	2020-06-16 12:51:22.64812+03
28951	22	-2	1070	2020-06-16 14:06:16.311752+03
28952	12	-1	1650	2020-06-16 14:06:56.027056+03
28953	76	-1	1070	2020-06-16 14:12:43.60589+03
28954	59	-1	1030	2020-06-16 14:16:02.032769+03
28955	6	-1	980	2020-06-16 14:42:34.016596+03
28956	46	-2	1270	2020-06-16 15:10:01.799615+03
28957	42	-1	1790	2020-06-16 15:15:42.995481+03
28958	58	-1	2830	2020-06-16 15:27:20.244101+03
28959	78	-1	900	2020-06-16 16:14:59.209087+03
28960	40	-2	1430	2020-06-16 16:37:09.15602+03
28961	35	-2	670	2020-06-16 16:39:19.360602+03
28962	18	-1	910	2020-06-16 17:00:52.346836+03
28963	37	-1	1290	2020-06-16 17:07:58.364389+03
28964	69	-1	1100	2020-06-16 17:25:22.538116+03
28965	16	-2	1380	2020-06-16 17:38:38.514286+03
28966	54	36	1511	2020-06-16 17:44:00.836695+03
28967	89	-2	1420	2020-06-16 17:46:25.422125+03
28968	33	-1	900	2020-06-16 17:49:56.963115+03
28969	83	-2	1230	2020-06-16 17:57:10.783551+03
28970	54	-1	3470	2020-06-16 18:10:16.002085+03
28971	39	-1	910	2020-06-16 18:12:31.690779+03
28972	27	-1	880	2020-06-16 18:26:02.970773+03
28973	64	-1	970	2020-06-16 18:46:20.190992+03
28974	10	-1	2080	2020-06-16 18:54:28.143074+03
28975	36	-3	630	2020-06-16 19:12:48.900649+03
28976	63	-1	1780	2020-06-16 19:22:07.01696+03
28977	14	-1	1350	2020-06-16 19:45:35.700777+03
28978	74	-1	1010	2020-06-16 19:46:23.266827+03
28979	53	-3	3120	2020-06-16 20:04:42.941444+03
28980	27	-1	880	2020-06-16 20:17:58.73551+03
28981	5	-1	1620	2020-06-16 20:19:04.095622+03
28982	51	-2	1310	2020-06-16 20:33:44.549943+03
28983	96	-1	1570	2020-06-16 20:34:45.180429+03
28984	68	13	229	2020-06-16 20:47:21.678755+03
28985	29	-1	1940	2020-06-16 20:48:21.709936+03
28986	93	-1	1620	2020-06-16 20:50:16.12988+03
28987	90	-1	1780	2020-06-16 21:11:08.097041+03
28988	67	-2	350	2020-06-16 21:25:10.082999+03
28989	75	-1	830	2020-06-16 21:41:22.575197+03
28990	94	27	625	2020-06-16 21:55:09.421755+03
28991	64	-1	970	2020-06-16 21:56:54.807343+03
28992	8	-1	1920	2020-06-16 22:09:39.061549+03
28993	57	-1	1900	2020-06-16 22:36:22.181587+03
28994	32	-1	710	2020-06-16 22:36:23.562062+03
28995	80	-1	1120	2020-06-16 23:45:31.092559+03
28996	20	-1	830	2020-06-16 23:55:52.041498+03
28997	17	-1	1500	2020-06-16 23:56:51.651737+03
28998	40	-1	1430	2020-06-17 00:31:30.967854+03
28999	31	-1	1190	2020-06-17 00:44:52.099938+03
29000	66	-1	690	2020-06-17 01:02:37.31916+03
29001	96	-1	1570	2020-06-17 01:15:36.935292+03
29002	45	-2	1590	2020-06-17 01:39:01.295527+03
29003	20	-2	830	2020-06-17 01:55:46.893229+03
29004	30	-1	1140	2020-06-17 02:04:14.857537+03
29005	54	-1	3470	2020-06-17 02:56:42.321009+03
29006	74	-1	1010	2020-06-17 04:27:35.025286+03
29007	79	-1	550	2020-06-17 04:30:42.141019+03
29008	28	-1	1860	2020-06-17 04:35:00.594694+03
29009	68	-1	490	2020-06-17 04:38:42.805338+03
29010	11	-1	830	2020-06-17 04:54:20.075459+03
29011	18	-1	910	2020-06-17 05:10:25.273964+03
29012	88	-1	1270	2020-06-17 05:18:24.923269+03
29013	56	-1	2460	2020-06-17 05:24:48.664351+03
29014	56	-1	2460	2020-06-17 05:24:50.821517+03
29015	4	-1	1420	2020-06-17 05:55:44.434876+03
29016	32	-1	710	2020-06-17 06:16:06.036589+03
29017	87	-2	2320	2020-06-17 06:28:22.287695+03
29018	93	-1	1620	2020-06-17 06:52:37.0874+03
29019	55	-1	3480	2020-06-17 07:16:23.174801+03
29020	84	-2	2700	2020-06-17 07:25:53.135245+03
29021	12	-1	1650	2020-06-17 07:43:18.872507+03
29022	42	-1	1790	2020-06-17 07:57:35.839322+03
29023	46	-2	1270	2020-06-17 07:59:59.168806+03
29024	96	-1	1570	2020-06-17 08:04:18.266199+03
29025	61	-2	1510	2020-06-17 08:09:15.08786+03
29026	9	-2	2090	2020-06-17 08:30:18.978805+03
29027	41	-2	830	2020-06-17 08:48:36.602629+03
29028	8	-2	1920	2020-06-17 09:12:21.462161+03
29029	40	-2	1430	2020-06-17 09:24:59.89646+03
29030	11	-1	830	2020-06-17 09:38:44.660027+03
29031	85	-1	730	2020-06-17 09:46:24.679311+03
29032	73	-1	960	2020-06-17 10:09:45.839763+03
29033	48	-2	640	2020-06-17 10:11:17.175148+03
29034	11	-1	830	2020-06-17 10:11:54.796473+03
29035	43	-1	380	2020-06-17 10:19:02.258754+03
29036	87	-1	2320	2020-06-17 10:55:39.406234+03
29037	7	-1	810	2020-06-17 11:28:15.070628+03
29038	8	-1	1920	2020-06-17 11:45:13.260633+03
29039	84	-1	2700	2020-06-17 11:46:21.626909+03
29040	64	-1	970	2020-06-17 11:48:56.02507+03
29041	49	-1	970	2020-06-17 12:05:33.401536+03
29042	5	-1	1620	2020-06-17 12:16:52.174029+03
29043	55	-1	3480	2020-06-17 12:25:13.88796+03
29044	51	-1	1310	2020-06-17 12:28:58.172767+03
29045	38	-1	1100	2020-06-17 12:35:36.883634+03
29046	81	-1	1620	2020-06-17 13:32:15.063783+03
29047	36	-1	630	2020-06-17 13:40:29.491475+03
29048	86	-1	910	2020-06-17 13:57:35.015835+03
29049	13	30	274	2020-06-17 14:39:41.606588+03
29050	77	-3	640	2020-06-17 14:42:55.026724+03
29051	84	-1	2700	2020-06-17 14:55:24.145624+03
29052	76	-1	1070	2020-06-17 15:37:03.703148+03
29053	47	-1	1480	2020-06-17 15:51:09.869851+03
29054	68	-1	490	2020-06-17 16:02:08.601551+03
29055	23	-2	4390	2020-06-17 16:09:16.147137+03
29056	57	-1	1900	2020-06-17 16:22:10.50366+03
29057	71	-1	1030	2020-06-17 17:23:15.640019+03
29058	77	-1	640	2020-06-17 17:27:57.676183+03
29059	80	-2	1120	2020-06-17 17:32:01.960813+03
29060	28	-1	1860	2020-06-17 18:36:35.181361+03
29061	57	-2	1900	2020-06-17 18:46:06.93818+03
29062	22	-2	1070	2020-06-17 18:50:21.388392+03
29063	42	-2	1790	2020-06-17 19:11:58.225898+03
29064	80	-1	1120	2020-06-17 19:19:43.096719+03
29065	82	-1	560	2020-06-17 19:23:45.504496+03
29066	14	-1	1350	2020-06-17 20:04:35.458661+03
29067	48	-2	640	2020-06-17 20:06:18.181469+03
29068	34	-1	1550	2020-06-17 20:07:53.603256+03
29069	5	-1	1620	2020-06-17 20:30:47.268153+03
29070	14	-1	1350	2020-06-17 20:34:00.229921+03
29071	94	-2	1230	2020-06-17 20:56:36.959044+03
29072	78	-1	900	2020-06-17 20:59:30.53828+03
29073	30	-1	1140	2020-06-17 21:02:07.269255+03
29074	67	-1	350	2020-06-17 21:14:04.548425+03
29075	75	-1	830	2020-06-17 21:35:32.091685+03
29076	72	-1	620	2020-06-17 21:59:01.111317+03
29077	96	-1	1570	2020-06-17 22:24:38.825227+03
29078	58	-1	2830	2020-06-17 22:25:26.409411+03
29079	33	-1	900	2020-06-17 22:38:18.374055+03
29080	53	-1	3120	2020-06-17 22:45:37.636435+03
29081	35	-1	670	2020-06-17 23:05:45.237894+03
29082	89	-1	1420	2020-06-17 23:27:27.183713+03
29083	80	-1	1120	2020-06-18 00:12:07.968018+03
29084	49	-1	970	2020-06-18 00:21:18.912657+03
29085	51	25	634	2020-06-18 00:30:01.683906+03
29086	3	-1	660	2020-06-18 00:53:45.914854+03
29087	86	-2	910	2020-06-18 01:16:51.054842+03
29088	54	-1	3470	2020-06-18 01:22:40.891449+03
29089	68	-1	490	2020-06-18 01:32:49.963832+03
29090	61	-2	1510	2020-06-18 01:36:09.17762+03
29091	48	-1	640	2020-06-18 01:40:05.235053+03
29092	42	-2	1790	2020-06-18 01:42:22.614161+03
29093	64	-1	970	2020-06-18 01:43:51.852811+03
29094	33	-1	900	2020-06-18 02:09:27.708957+03
29095	14	-1	1350	2020-06-18 02:40:29.645459+03
29096	33	-1	900	2020-06-18 02:41:13.011026+03
29097	4	-1	1420	2020-06-18 03:12:41.717042+03
29098	9	-2	2090	2020-06-18 03:32:01.042023+03
29099	17	-1	1500	2020-06-18 03:35:05.4181+03
29100	83	-1	1230	2020-06-18 03:36:57.577627+03
29101	28	19	870	2020-06-18 03:46:53.783267+03
29102	86	-2	910	2020-06-18 04:04:08.89981+03
29103	35	-2	670	2020-06-18 04:17:58.53549+03
29104	40	-1	1430	2020-06-18 04:29:29.505879+03
29105	83	-1	1230	2020-06-18 04:32:09.589299+03
29106	79	-1	550	2020-06-18 04:41:03.484933+03
29107	85	-1	730	2020-06-18 04:42:01.473077+03
29108	52	-1	1090	2020-06-18 04:43:07.56158+03
29109	18	-1	910	2020-06-18 04:48:56.165901+03
29110	46	-1	1270	2020-06-18 06:05:25.35533+03
29111	46	-1	1270	2020-06-18 06:32:44.796044+03
29112	30	-1	1140	2020-06-18 06:44:07.863366+03
29113	36	-1	630	2020-06-18 07:01:00.639458+03
29114	5	-1	1620	2020-06-18 07:17:27.295941+03
29115	8	-1	1920	2020-06-18 07:35:33.036133+03
29116	54	-1	3470	2020-06-18 07:38:52.60105+03
29117	7	-2	810	2020-06-18 07:47:43.580861+03
29118	90	-1	1780	2020-06-18 07:58:45.613574+03
29119	29	-1	1940	2020-06-18 08:24:46.325757+03
29120	12	-2	1650	2020-06-18 08:35:18.693845+03
29121	9	-1	2090	2020-06-18 08:41:10.993113+03
29122	40	-2	1430	2020-06-18 08:43:32.763559+03
29123	69	-1	1100	2020-06-18 08:44:03.953365+03
29124	19	-1	1220	2020-06-18 09:04:43.993064+03
29125	30	-1	1140	2020-06-18 09:05:38.687255+03
29126	36	18	348	2020-06-18 09:16:35.426802+03
29127	58	-1	2830	2020-06-18 09:20:46.507935+03
29128	5	-1	1620	2020-06-18 09:52:46.871514+03
29129	81	-1	1620	2020-06-18 11:00:33.634132+03
29130	33	-1	900	2020-06-18 11:05:25.349165+03
29131	84	-1	2700	2020-06-18 11:06:32.617897+03
29132	83	-1	1230	2020-06-18 11:25:29.765607+03
29133	46	-1	1270	2020-06-18 11:31:50.806924+03
29134	77	-1	640	2020-06-18 12:11:13.647712+03
29135	91	-1	1620	2020-06-18 12:20:06.102587+03
29136	47	-2	1480	2020-06-18 12:34:40.299409+03
29137	93	-2	1620	2020-06-18 13:07:00.647801+03
29138	88	-1	1270	2020-06-18 13:21:34.618524+03
29139	44	-1	500	2020-06-18 13:26:20.6053+03
29140	43	-1	380	2020-06-18 13:30:33.292761+03
29141	70	-1	760	2020-06-18 13:31:17.390447+03
29142	8	-1	1920	2020-06-18 13:56:37.56629+03
29143	13	-1	460	2020-06-18 14:34:10.805302+03
29144	77	-1	640	2020-06-18 15:05:25.43919+03
29145	44	-1	500	2020-06-18 15:41:07.375187+03
29146	81	-2	1620	2020-06-18 15:42:23.90883+03
29147	64	-1	970	2020-06-18 15:45:07.51677+03
29148	60	-1	2700	2020-06-18 15:48:31.21159+03
29149	82	-1	560	2020-06-18 16:05:04.471057+03
29150	17	23	661	2020-06-18 16:07:08.744044+03
29151	94	-1	1230	2020-06-18 16:10:51.923424+03
29152	77	35	321	2020-06-18 16:17:54.120375+03
29153	42	-1	1790	2020-06-18 16:26:02.572207+03
29154	67	-1	350	2020-06-18 16:39:31.255364+03
29155	89	-1	1420	2020-06-18 16:45:46.905155+03
29156	45	-1	1590	2020-06-18 16:51:56.01766+03
29157	48	-1	640	2020-06-18 16:57:09.274727+03
29158	68	-1	490	2020-06-18 17:05:17.391532+03
29159	54	-1	3470	2020-06-18 17:14:59.519692+03
29160	20	-1	830	2020-06-18 17:49:24.41101+03
29161	64	-1	970	2020-06-18 18:13:13.928327+03
29162	11	-1	830	2020-06-18 18:31:18.203593+03
29163	57	-1	1900	2020-06-18 18:33:36.957504+03
29164	69	-1	1100	2020-06-18 18:36:16.625221+03
29165	51	-1	1310	2020-06-18 18:40:00.318831+03
29166	76	47	551	2020-06-18 19:16:27.870313+03
29167	12	-1	1650	2020-06-18 19:22:45.178878+03
29168	36	-1	630	2020-06-18 19:25:18.986463+03
29169	1	-1	640	2020-06-18 19:41:59.348531+03
29170	37	-1	1290	2020-06-18 19:44:10.162123+03
29171	87	-1	2320	2020-06-18 19:48:47.193014+03
29172	63	-1	1780	2020-06-18 19:58:16.869187+03
29173	93	-2	1620	2020-06-18 20:13:59.769403+03
29174	71	-2	1030	2020-06-18 20:20:54.018573+03
29175	12	-1	1650	2020-06-18 20:52:45.973532+03
29176	94	-2	1230	2020-06-18 21:20:48.069646+03
29177	85	22	344	2020-06-18 21:21:23.444188+03
29178	14	-1	1350	2020-06-18 21:59:50.283619+03
29179	36	-1	630	2020-06-18 22:00:28.867447+03
29180	5	-2	1620	2020-06-18 22:17:21.821491+03
29181	5	-1	1620	2020-06-18 22:29:42.58611+03
29182	43	-2	380	2020-06-18 22:30:00.415858+03
29183	29	-1	1940	2020-06-18 22:49:56.548107+03
29184	87	-2	2320	2020-06-18 22:53:11.672322+03
29185	48	-1	640	2020-06-18 23:04:02.967515+03
29186	71	-2	1030	2020-06-18 23:16:49.925858+03
29187	10	-1	2080	2020-06-18 23:17:36.672146+03
29188	19	-1	1220	2020-06-18 23:44:46.136088+03
29189	8	-1	1920	2020-06-18 23:56:55.562459+03
29190	71	-1	1030	2020-06-19 01:05:10.762648+03
29191	89	-1	1420	2020-06-19 01:12:26.34198+03
29192	17	-1	1500	2020-06-19 01:24:36.718134+03
29193	96	-1	1570	2020-06-19 01:26:20.090169+03
29194	30	-1	1140	2020-06-19 01:49:35.90582+03
29195	12	-1	1650	2020-06-19 01:52:15.647684+03
29196	51	-1	1310	2020-06-19 01:53:32.904411+03
29197	71	-1	1030	2020-06-19 02:25:48.912216+03
29198	1	-2	640	2020-06-19 03:14:27.373048+03
29199	64	-2	970	2020-06-19 03:16:37.260789+03
29200	21	-1	960	2020-06-19 03:30:45.1749+03
29201	64	-1	970	2020-06-19 03:50:22.162224+03
29202	15	-2	2830	2020-06-19 04:10:42.478967+03
29203	49	-1	970	2020-06-19 04:24:31.665539+03
29204	71	-1	1030	2020-06-19 05:20:02.422022+03
29205	1	-2	640	2020-06-19 05:24:12.514534+03
29206	19	-2	1220	2020-06-19 05:27:40.230079+03
29207	54	-1	3470	2020-06-19 05:29:10.892428+03
29208	84	-1	2700	2020-06-19 05:39:18.840228+03
29209	20	-1	830	2020-06-19 05:52:54.018769+03
29210	77	-1	640	2020-06-19 06:12:03.284224+03
29211	28	-1	1860	2020-06-19 06:13:39.13613+03
29212	46	-1	1270	2020-06-19 06:19:44.953853+03
29213	53	-1	3120	2020-06-19 06:27:12.329812+03
29214	28	-2	1860	2020-06-19 06:29:41.628468+03
29215	28	-2	1860	2020-06-19 06:50:09.390702+03
29216	32	-2	710	2020-06-19 06:52:45.439278+03
29217	59	-1	1030	2020-06-19 07:06:27.586267+03
29218	83	-1	1230	2020-06-19 07:07:19.124075+03
29219	2	-1	470	2020-06-19 07:19:46.029694+03
29220	15	-1	2830	2020-06-19 07:23:55.530084+03
29221	36	-1	630	2020-06-19 07:32:50.013716+03
29222	15	-1	2830	2020-06-19 07:33:12.913115+03
29223	25	-1	1100	2020-06-19 08:11:03.456021+03
29224	87	-1	2320	2020-06-19 08:12:45.382834+03
29225	22	-1	1070	2020-06-19 08:35:52.287184+03
29226	87	-1	2320	2020-06-19 08:55:17.650986+03
29227	29	-1	1940	2020-06-19 08:59:52.769143+03
29228	45	-2	1590	2020-06-19 09:09:45.076924+03
29229	63	-1	1780	2020-06-19 09:18:35.712798+03
29230	74	-1	1010	2020-06-19 10:03:23.54018+03
29231	49	-2	970	2020-06-19 11:24:47.337266+03
29232	33	-1	900	2020-06-19 11:34:40.887151+03
29233	34	-1	1550	2020-06-19 11:35:28.658512+03
29234	8	-1	1920	2020-06-19 11:37:31.18363+03
29235	80	-2	1120	2020-06-19 11:51:30.006631+03
29236	30	-1	1140	2020-06-19 11:54:06.496934+03
29237	22	-1	1070	2020-06-19 12:04:45.75043+03
29238	35	-1	670	2020-06-19 12:05:25.454807+03
29239	59	-1	1030	2020-06-19 12:14:36.178451+03
29240	8	-1	1920	2020-06-19 12:19:37.342652+03
29241	14	-1	1350	2020-06-19 12:21:05.619775+03
29242	1	-1	640	2020-06-19 12:24:12.349257+03
29243	20	-1	830	2020-06-19 12:28:20.217252+03
29244	30	-1	1140	2020-06-19 12:47:19.18586+03
29245	23	-1	4390	2020-06-19 13:00:37.566157+03
29246	39	-1	910	2020-06-19 13:15:23.578726+03
29247	29	-1	1940	2020-06-19 13:32:40.157023+03
29248	52	-1	1090	2020-06-19 14:01:44.06336+03
29249	20	-1	830	2020-06-19 14:08:37.080616+03
29250	21	-1	960	2020-06-19 14:12:40.330399+03
29251	57	-1	1900	2020-06-19 14:25:05.505977+03
29252	16	-1	1380	2020-06-19 14:30:57.818623+03
29253	71	-1	1030	2020-06-19 14:42:45.534685+03
29254	93	-1	1620	2020-06-19 14:46:53.575201+03
29255	47	-1	1480	2020-06-19 15:18:15.3501+03
29256	70	-1	760	2020-06-19 15:46:11.680739+03
29257	81	-2	1620	2020-06-19 15:46:24.883281+03
29258	94	-1	1230	2020-06-19 16:03:56.210467+03
29259	30	-1	1140	2020-06-19 16:42:43.891338+03
29260	26	-1	390	2020-06-19 16:46:23.617508+03
29261	12	-1	1650	2020-06-19 17:27:23.561626+03
29262	79	-1	550	2020-06-19 17:38:30.618858+03
29263	95	-1	480	2020-06-19 17:43:50.064242+03
29264	89	-2	1420	2020-06-19 17:47:43.299578+03
29265	44	-1	500	2020-06-19 18:07:42.878217+03
29266	5	-1	1620	2020-06-19 18:30:28.973676+03
29267	80	-1	1120	2020-06-19 18:44:57.063067+03
29268	38	-1	1100	2020-06-19 19:05:38.304429+03
29269	68	-1	490	2020-06-19 19:30:58.104352+03
29270	47	-1	1480	2020-06-19 19:49:02.719785+03
29271	34	-1	1550	2020-06-19 20:10:05.552686+03
29272	79	-1	550	2020-06-19 20:15:34.751386+03
29273	42	31	750	2020-06-19 20:30:27.707851+03
29274	88	-1	1270	2020-06-19 20:52:36.380317+03
29275	26	-1	390	2020-06-19 21:06:33.471381+03
29276	80	-2	1120	2020-06-19 21:07:33.551898+03
29277	19	-1	1220	2020-06-19 21:07:57.508341+03
29278	71	-1	1030	2020-06-19 21:10:55.241101+03
29279	86	-1	910	2020-06-19 21:30:36.190599+03
29280	23	-2	4390	2020-06-19 21:47:56.914046+03
29281	26	-1	390	2020-06-19 22:14:24.044821+03
29282	63	-3	1780	2020-06-19 22:52:13.158286+03
29283	3	-1	660	2020-06-19 22:56:41.813186+03
29284	4	-2	1420	2020-06-19 23:30:31.671161+03
29285	83	-1	1230	2020-06-19 23:49:59.091168+03
29286	65	-1	490	2020-06-19 23:52:53.72947+03
29287	26	-1	390	2020-06-20 00:07:25.701223+03
29288	29	-1	1940	2020-06-20 00:30:37.827985+03
29289	27	-1	880	2020-06-20 00:34:26.00337+03
29290	70	-1	760	2020-06-20 00:45:01.431813+03
29291	31	-1	1190	2020-06-20 00:56:55.412128+03
29292	77	-1	640	2020-06-20 01:09:05.219782+03
29293	84	-1	2700	2020-06-20 01:37:17.950866+03
29294	96	-1	1570	2020-06-20 01:49:11.447343+03
29295	5	-1	1620	2020-06-20 01:57:05.229693+03
29296	91	-1	1620	2020-06-20 02:15:19.337364+03
29297	45	-1	1590	2020-06-20 02:20:37.562267+03
29298	38	-1	1100	2020-06-20 02:23:58.078142+03
29299	49	-1	970	2020-06-20 02:44:28.12495+03
29300	42	-1	1790	2020-06-20 02:49:15.605342+03
29301	85	-1	730	2020-06-20 02:56:14.789726+03
29302	7	-1	810	2020-06-20 02:58:52.198814+03
29303	38	-2	1100	2020-06-20 03:01:04.189924+03
29304	51	-1	1310	2020-06-20 03:21:59.42869+03
29305	58	-2	2830	2020-06-20 03:28:00.085778+03
29306	47	-1	1480	2020-06-20 03:48:56.649171+03
29307	40	-1	1430	2020-06-20 04:22:57.175558+03
29308	21	-1	960	2020-06-20 04:59:36.004159+03
29309	16	-2	1380	2020-06-20 05:00:49.526585+03
29310	18	-1	910	2020-06-20 05:09:31.350239+03
29311	54	-1	3470	2020-06-20 05:10:16.491639+03
29312	14	-1	1350	2020-06-20 05:10:55.568011+03
29313	9	-1	2090	2020-06-20 05:12:08.08575+03
29314	63	-2	1780	2020-06-20 05:13:41.96841+03
29315	4	-1	1420	2020-06-20 05:50:22.181813+03
29316	55	-1	3480	2020-06-20 06:17:37.487721+03
29317	82	-1	560	2020-06-20 07:01:26.308843+03
29318	10	-1	2080	2020-06-20 07:10:57.325285+03
29319	7	-1	810	2020-06-20 07:13:26.173533+03
29320	54	-1	3470	2020-06-20 07:20:43.093357+03
29321	36	-1	630	2020-06-20 07:37:01.707709+03
29322	18	-1	910	2020-06-20 07:45:57.136365+03
29323	88	-1	1270	2020-06-20 08:06:46.590767+03
29324	93	-1	1620	2020-06-20 08:17:58.233992+03
29325	54	-1	3470	2020-06-20 08:18:10.879563+03
29326	6	26	563	2020-06-20 08:20:52.873129+03
29327	23	-1	4390	2020-06-20 08:28:17.219511+03
29328	76	-2	1070	2020-06-20 08:41:00.933551+03
29329	56	-1	2460	2020-06-20 09:07:54.756962+03
29330	31	16	590	2020-06-20 09:18:23.013263+03
29331	29	-1	1940	2020-06-20 09:22:44.449543+03
29332	47	-1	1480	2020-06-20 09:30:40.784327+03
29333	32	-1	710	2020-06-20 09:35:58.534625+03
29334	75	-1	830	2020-06-20 11:05:37.344304+03
29335	85	-1	730	2020-06-20 11:17:52.863047+03
29336	1	-1	640	2020-06-20 11:48:05.813587+03
29337	60	-1	2700	2020-06-20 12:02:14.166388+03
29338	28	-1	1860	2020-06-20 12:54:43.043021+03
29339	87	-2	2320	2020-06-20 13:02:28.790651+03
29340	46	-1	1270	2020-06-20 13:11:40.256108+03
29341	65	-2	490	2020-06-20 13:31:09.579958+03
29342	12	-1	1650	2020-06-20 13:45:10.330556+03
29343	12	-1	1650	2020-06-20 13:45:48.226413+03
29344	13	-1	460	2020-06-20 13:46:37.890633+03
29345	18	-1	910	2020-06-20 13:50:29.918384+03
29346	9	-1	2090	2020-06-20 14:14:43.065856+03
29347	57	-1	1900	2020-06-20 14:28:08.49051+03
29348	94	-1	1230	2020-06-20 15:12:04.112672+03
29349	63	-1	1780	2020-06-20 15:20:37.063456+03
29350	38	-2	1100	2020-06-20 15:31:40.757517+03
29351	90	29	886	2020-06-20 15:46:42.22373+03
29352	85	-1	730	2020-06-20 15:59:24.260897+03
29353	19	-1	1220	2020-06-20 16:04:34.417399+03
29354	50	-1	1140	2020-06-20 16:31:24.926453+03
29355	61	-1	1510	2020-06-20 16:45:30.775522+03
29356	46	-1	1270	2020-06-20 16:55:45.757221+03
29357	13	-1	460	2020-06-20 17:04:30.642682+03
29358	11	-1	830	2020-06-20 17:53:38.529698+03
29359	92	-1	630	2020-06-20 18:01:49.341827+03
29360	47	-1	1480	2020-06-20 18:03:03.844269+03
29361	79	24	321	2020-06-20 18:27:29.084084+03
29362	52	-2	1090	2020-06-20 18:30:28.702123+03
29363	18	-1	910	2020-06-20 18:33:38.71539+03
29364	51	-2	1310	2020-06-20 18:37:31.464627+03
29365	88	-1	1270	2020-06-20 18:42:11.12636+03
29366	53	-1	3120	2020-06-20 18:53:07.04847+03
29367	87	-1	2320	2020-06-20 18:58:40.788232+03
29368	34	-1	1550	2020-06-20 19:11:58.940287+03
29369	37	-1	1290	2020-06-20 19:32:34.501995+03
29370	61	-1	1510	2020-06-20 19:34:39.624695+03
29371	47	-1	1480	2020-06-20 19:40:40.602419+03
29372	95	-1	480	2020-06-20 19:47:37.289672+03
29373	75	-1	830	2020-06-20 19:57:36.718275+03
29374	41	21	432	2020-06-20 20:02:57.726129+03
29375	19	-1	1220	2020-06-20 20:08:37.893207+03
29376	17	-2	1500	2020-06-20 20:14:06.446029+03
29377	2	-1	470	2020-06-20 20:23:16.816594+03
29378	90	-1	1780	2020-06-20 20:30:55.189238+03
29379	41	-2	830	2020-06-20 20:40:29.567017+03
29380	74	-1	1010	2020-06-20 21:08:18.842371+03
29381	44	-1	500	2020-06-20 21:16:50.00722+03
29382	86	-1	910	2020-06-20 21:23:20.530798+03
29383	85	-1	730	2020-06-20 21:36:24.537076+03
29384	19	22	591	2020-06-20 22:26:17.644055+03
29385	55	-1	3480	2020-06-20 22:47:09.368223+03
29386	87	-1	2320	2020-06-20 22:53:26.63953+03
29387	14	-1	1350	2020-06-21 00:02:20.405143+03
29388	8	-1	1920	2020-06-21 00:13:11.527134+03
29389	47	-1	1480	2020-06-21 00:27:50.545779+03
29390	53	-1	3120	2020-06-21 00:38:04.761636+03
29391	56	-1	2460	2020-06-21 00:39:21.263927+03
29392	76	-1	1070	2020-06-21 01:07:22.256376+03
29393	90	-1	1780	2020-06-21 01:09:10.380897+03
29394	19	-2	1220	2020-06-21 01:12:52.089291+03
29395	95	-1	480	2020-06-21 01:32:34.005045+03
29396	1	-1	640	2020-06-21 01:38:02.447239+03
29397	32	-1	710	2020-06-21 01:54:24.822353+03
29398	29	-2	1940	2020-06-21 02:02:23.877937+03
29399	87	-1	2320	2020-06-21 03:07:53.25608+03
29400	40	-1	1430	2020-06-21 03:11:15.140133+03
29401	45	-1	1590	2020-06-21 03:18:04.873821+03
29402	64	-1	970	2020-06-21 03:29:48.099439+03
29403	38	-1	1100	2020-06-21 03:48:27.204857+03
29404	25	-1	1100	2020-06-21 04:05:36.652468+03
29405	94	-1	1230	2020-06-21 04:20:00.554994+03
29406	12	-1	1650	2020-06-21 05:01:38.347629+03
29407	46	-1	1270	2020-06-21 05:09:14.50936+03
29408	14	-1	1350	2020-06-21 05:27:48.982656+03
29409	2	21	201	2020-06-21 05:30:04.963369+03
29410	22	-2	1070	2020-06-21 06:01:59.685698+03
29411	71	-1	1030	2020-06-21 06:27:08.947721+03
29412	55	-1	3480	2020-06-21 06:41:21.406799+03
29413	84	-2	2700	2020-06-21 06:41:50.180871+03
29414	42	-1	1790	2020-06-21 06:50:12.724467+03
29415	95	-1	480	2020-06-21 06:51:19.528362+03
29416	57	-1	1900	2020-06-21 08:51:28.0042+03
29417	88	-1	1270	2020-06-21 08:55:28.677674+03
29418	96	-1	1570	2020-06-21 09:21:19.948674+03
29419	94	-2	1230	2020-06-21 09:24:59.795324+03
29420	59	-1	1030	2020-06-21 09:39:57.096443+03
29421	14	-1	1350	2020-06-21 09:49:10.67296+03
29422	45	-1	1590	2020-06-21 09:54:35.471213+03
29423	60	-1	2700	2020-06-21 09:54:40.040012+03
29424	41	-1	830	2020-06-21 10:01:26.948985+03
29425	23	-1	4390	2020-06-21 10:03:43.050351+03
29426	59	-1	1030	2020-06-21 10:07:41.975965+03
29427	76	-1	1070	2020-06-21 11:06:44.405921+03
29428	71	-1	1030	2020-06-21 11:13:20.578904+03
29429	71	-1	1030	2020-06-21 11:13:48.344041+03
29430	47	-2	1480	2020-06-21 11:35:29.478814+03
29431	86	-1	910	2020-06-21 12:13:27.598403+03
29432	9	-1	2090	2020-06-21 12:20:47.839878+03
29433	22	-1	1070	2020-06-21 13:07:23.317114+03
29434	55	-1	3480	2020-06-21 13:11:26.905673+03
29435	7	-2	810	2020-06-21 13:29:00.14099+03
29436	40	-2	1430	2020-06-21 13:57:20.151698+03
29437	74	20	456	2020-06-21 14:07:56.568158+03
29438	65	14	231	2020-06-21 14:25:48.74477+03
29439	36	-1	630	2020-06-21 14:41:56.554961+03
29440	38	-1	1100	2020-06-21 14:43:22.83728+03
29441	29	-1	1940	2020-06-21 15:28:50.280995+03
29442	4	-1	1420	2020-06-21 15:51:59.193798+03
29443	31	-1	1190	2020-06-21 16:08:57.857606+03
29444	57	-1	1900	2020-06-21 16:22:11.693184+03
29445	51	-1	1310	2020-06-21 16:22:47.877588+03
29446	88	-1	1270	2020-06-21 16:45:44.380572+03
29447	30	-1	1140	2020-06-21 17:03:15.976675+03
29448	21	-2	960	2020-06-21 17:38:23.786656+03
29449	30	-1	1140	2020-06-21 17:50:28.870965+03
29450	7	-1	810	2020-06-21 18:01:07.639058+03
29451	80	-1	1120	2020-06-21 18:02:19.079098+03
29452	18	-1	910	2020-06-21 18:24:26.830196+03
29453	13	-1	460	2020-06-21 18:25:05.24552+03
29454	13	-1	460	2020-06-21 18:28:08.202002+03
29455	32	-1	710	2020-06-21 18:39:33.100975+03
29456	58	-1	2830	2020-06-21 18:44:12.288119+03
29457	95	-2	480	2020-06-21 18:46:59.030267+03
29458	27	-1	880	2020-06-21 19:01:48.238202+03
29459	20	-1	830	2020-06-21 19:02:33.796037+03
29460	54	-1	3470	2020-06-21 19:12:44.559587+03
29461	65	-1	490	2020-06-21 19:47:03.341366+03
29462	22	-1	1070	2020-06-21 19:47:49.365141+03
29463	41	-1	830	2020-06-21 19:54:34.070214+03
29464	50	-1	1140	2020-06-21 20:08:40.906004+03
29465	18	-1	910	2020-06-21 20:52:38.298834+03
29466	16	-1	1380	2020-06-21 20:57:27.06331+03
29467	2	-1	470	2020-06-21 21:07:27.295956+03
29468	76	-1	1070	2020-06-21 21:41:15.711214+03
29469	86	-1	910	2020-06-21 21:47:59.424703+03
29470	2	-1	470	2020-06-21 22:01:40.410656+03
29471	1	23	324	2020-06-21 22:09:17.226757+03
29472	2	-1	470	2020-06-21 22:12:14.820702+03
29473	94	-1	1230	2020-06-21 22:20:00.70448+03
29474	68	-1	490	2020-06-21 22:42:02.992575+03
29475	32	-2	710	2020-06-21 22:49:51.502556+03
29476	96	-1	1570	2020-06-21 23:04:30.815544+03
29477	93	-1	1620	2020-06-21 23:14:47.824729+03
29478	80	26	641	2020-06-21 23:37:17.328869+03
29479	58	-1	2830	2020-06-21 23:43:33.63899+03
29480	6	-1	980	2020-06-21 23:50:56.184746+03
29481	46	-1	1270	2020-06-21 23:54:41.798308+03
29482	81	-1	1620	2020-06-22 00:09:00.097881+03
29483	96	-1	1570	2020-06-22 00:19:41.193155+03
29484	33	-1	900	2020-06-22 00:53:29.805675+03
29485	1	-2	640	2020-06-22 01:20:21.13092+03
29486	17	-1	1500	2020-06-22 01:26:22.084622+03
29487	83	-2	1230	2020-06-22 01:34:51.64846+03
29488	65	-3	490	2020-06-22 01:49:27.148998+03
29489	39	-1	910	2020-06-22 02:07:22.65427+03
29490	54	-1	3470	2020-06-22 02:14:45.651076+03
29491	68	-1	490	2020-06-22 03:06:46.085274+03
29492	69	-1	1100	2020-06-22 03:20:23.465502+03
29493	23	-1	4390	2020-06-22 03:36:58.21325+03
29494	19	-1	1220	2020-06-22 03:41:43.491268+03
29495	28	-1	1860	2020-06-22 04:13:45.280118+03
29496	79	-1	550	2020-06-22 04:23:03.192583+03
29497	46	-2	1270	2020-06-22 04:23:14.90857+03
29498	27	-1	880	2020-06-22 04:31:10.038129+03
29499	76	-1	1070	2020-06-22 04:39:17.259074+03
29500	52	-1	1090	2020-06-22 05:00:18.168888+03
29501	80	-1	1120	2020-06-22 05:06:49.592072+03
29502	55	-1	3480	2020-06-22 05:41:59.762475+03
29503	28	-1	1860	2020-06-22 05:48:20.956621+03
29504	77	-1	640	2020-06-22 05:54:55.090804+03
29505	87	-1	2320	2020-06-22 06:29:33.223345+03
29506	39	-1	910	2020-06-22 06:43:35.087436+03
29507	13	-1	460	2020-06-22 06:55:16.409552+03
29508	78	-1	900	2020-06-22 06:57:33.423946+03
29509	76	-2	1070	2020-06-22 06:57:56.952018+03
29510	65	-1	490	2020-06-22 07:10:22.314635+03
29511	46	-1	1270	2020-06-22 07:57:38.215594+03
29512	86	-1	910	2020-06-22 08:00:50.333342+03
29513	34	26	755	2020-06-22 08:14:18.964492+03
29514	44	-1	500	2020-06-22 08:48:51.537131+03
29515	29	-2	1940	2020-06-22 09:12:57.28233+03
29516	20	-1	830	2020-06-22 10:26:39.228852+03
29517	56	-1	2460	2020-06-22 10:43:53.16345+03
29518	14	-1	1350	2020-06-22 10:44:17.976357+03
29519	10	-1	2080	2020-06-22 11:06:07.893445+03
29520	8	-1	1920	2020-06-22 11:30:59.005352+03
29521	83	-1	1230	2020-06-22 11:35:09.610832+03
29522	78	-1	900	2020-06-22 11:41:19.862181+03
29523	87	-1	2320	2020-06-22 11:48:03.717062+03
29524	96	-2	1570	2020-06-22 12:24:16.937571+03
29525	95	36	218	2020-06-22 12:25:20.774508+03
29526	80	-2	1120	2020-06-22 12:31:29.736156+03
29527	94	-1	1230	2020-06-22 12:34:21.243947+03
29528	14	-2	1350	2020-06-22 12:46:46.035824+03
29529	54	-1	3470	2020-06-22 12:46:55.407268+03
29530	31	-3	1190	2020-06-22 12:58:46.74242+03
29531	73	-1	960	2020-06-22 13:17:45.658455+03
29532	29	-1	1940	2020-06-22 13:24:06.972471+03
29533	18	-1	910	2020-06-22 13:30:18.432331+03
29534	84	-1	2700	2020-06-22 13:32:08.755949+03
29535	67	-1	350	2020-06-22 13:33:17.839363+03
29536	46	-2	1270	2020-06-22 13:34:57.958562+03
29537	94	-1	1230	2020-06-22 13:36:21.033012+03
29538	41	-1	830	2020-06-22 13:43:55.81152+03
29539	89	-2	1420	2020-06-22 13:49:19.348783+03
29540	22	-1	1070	2020-06-22 14:03:59.44642+03
29541	28	-1	1860	2020-06-22 14:06:01.059855+03
29542	84	37	1439	2020-06-22 14:43:29.240033+03
29543	37	-1	1290	2020-06-22 15:00:55.642809+03
29544	15	-1	2830	2020-06-22 15:48:03.27317+03
29545	36	-1	630	2020-06-22 15:57:49.102618+03
29546	70	-1	760	2020-06-22 16:03:00.02386+03
29547	57	-1	1900	2020-06-22 16:16:41.945277+03
29548	22	-1	1070	2020-06-22 16:17:37.015545+03
29549	20	28	383	2020-06-22 16:30:25.7407+03
29550	78	-1	900	2020-06-22 16:40:45.094799+03
29551	18	-1	910	2020-06-22 16:54:46.600127+03
29552	52	-2	1090	2020-06-22 17:00:16.623376+03
29553	93	-1	1620	2020-06-22 17:24:52.647102+03
29554	17	-1	1500	2020-06-22 17:39:18.116798+03
29555	77	-1	640	2020-06-22 17:44:01.004459+03
29556	39	-1	910	2020-06-22 17:48:54.851331+03
29557	56	-2	2460	2020-06-22 17:52:32.821371+03
29558	48	-1	640	2020-06-22 17:59:29.251401+03
29559	86	-1	910	2020-06-22 18:00:07.567033+03
29560	20	-1	830	2020-06-22 19:13:55.234111+03
29561	30	24	524	2020-06-22 19:23:15.132652+03
29562	59	-1	1030	2020-06-22 19:39:57.881289+03
29563	20	-1	830	2020-06-22 19:45:09.000421+03
29564	13	-2	460	2020-06-22 19:48:02.587934+03
29565	13	-2	460	2020-06-22 20:03:36.325453+03
29566	18	-2	910	2020-06-22 20:11:11.891949+03
29567	74	-1	1010	2020-06-22 20:59:05.491034+03
29568	81	-1	1620	2020-06-22 21:04:22.731861+03
29569	42	-1	1790	2020-06-22 21:11:15.813717+03
29570	49	-1	970	2020-06-22 21:13:07.266677+03
29571	34	-2	1550	2020-06-22 21:32:00.353706+03
29572	10	-1	2080	2020-06-22 21:41:29.594152+03
29573	18	-1	910	2020-06-22 21:49:01.703018+03
29574	89	-1	1420	2020-06-22 22:01:28.51523+03
29575	24	26	382	2020-06-22 22:05:43.982201+03
29576	84	-1	2700	2020-06-22 22:11:45.051964+03
29577	12	-1	1650	2020-06-22 23:07:22.328256+03
29578	65	-2	490	2020-06-22 23:09:47.400073+03
29579	36	-2	630	2020-06-22 23:42:30.910299+03
29580	32	-1	710	2020-06-23 00:04:44.074016+03
29581	70	-1	760	2020-06-23 00:25:59.563103+03
29582	58	-1	2830	2020-06-23 00:29:12.701473+03
29583	70	-1	760	2020-06-23 00:43:41.133713+03
29584	91	18	656	2020-06-23 00:46:29.737432+03
29585	86	-1	910	2020-06-23 01:06:30.450385+03
29586	54	-1	3470	2020-06-23 01:09:39.863472+03
29587	8	-1	1920	2020-06-23 01:20:57.055348+03
29588	22	-1	1070	2020-06-23 01:38:35.732879+03
29589	95	-1	480	2020-06-23 02:14:53.215973+03
29590	96	-1	1570	2020-06-23 03:01:12.45756+03
29591	54	-1	3470	2020-06-23 03:25:20.548797+03
29592	85	-1	730	2020-06-23 03:29:17.954603+03
29593	42	-1	1790	2020-06-23 03:45:20.763445+03
29594	51	-1	1310	2020-06-23 03:46:18.934271+03
29595	51	-1	1310	2020-06-23 04:30:11.623976+03
29596	21	-1	960	2020-06-23 04:33:17.760007+03
29597	56	-1	2460	2020-06-23 04:40:44.344766+03
29598	58	-1	2830	2020-06-23 04:45:41.988637+03
29599	67	-1	350	2020-06-23 05:02:08.71436+03
29600	56	-1	2460	2020-06-23 05:26:52.852475+03
29601	93	-1	1620	2020-06-23 06:30:35.675642+03
29602	12	-2	1650	2020-06-23 06:39:34.776566+03
29603	10	-1	2080	2020-06-23 07:21:05.525165+03
29604	59	-1	1030	2020-06-23 07:47:10.082949+03
29605	47	-1	1480	2020-06-23 07:55:10.066555+03
29606	83	-1	1230	2020-06-23 07:57:11.130155+03
29607	83	-1	1230	2020-06-23 08:23:32.389383+03
29608	93	-2	1620	2020-06-23 08:49:54.628878+03
29609	33	-1	900	2020-06-23 09:08:59.809542+03
29610	85	-1	730	2020-06-23 09:12:03.779924+03
29611	33	-1	900	2020-06-23 09:19:57.70458+03
29612	90	-1	1780	2020-06-23 09:41:05.136057+03
29613	64	-1	970	2020-06-23 09:59:43.824793+03
29614	74	-2	1010	2020-06-23 10:17:22.194171+03
29615	28	-1	1860	2020-06-23 10:23:03.110683+03
29616	92	-1	630	2020-06-23 10:41:05.911615+03
29617	38	-1	1100	2020-06-23 10:59:16.078024+03
29618	80	-1	1120	2020-06-23 11:14:52.297071+03
29619	4	-1	1420	2020-06-23 12:00:23.17969+03
29620	84	-2	2700	2020-06-23 12:21:04.841757+03
29621	63	-2	1780	2020-06-23 12:25:51.254961+03
29622	32	-1	710	2020-06-23 12:49:33.23036+03
29623	17	-1	1500	2020-06-23 12:53:56.456527+03
29624	96	-1	1570	2020-06-23 13:02:12.208311+03
29625	13	-1	460	2020-06-23 13:02:46.801883+03
29626	41	-1	830	2020-06-23 13:09:32.718626+03
29627	30	-1	1140	2020-06-23 13:24:19.98279+03
29628	12	-1	1650	2020-06-23 13:29:41.725856+03
29629	6	-1	980	2020-06-23 13:45:57.298992+03
29630	68	-1	490	2020-06-23 13:48:29.909827+03
29631	68	-1	490	2020-06-23 13:49:28.357604+03
29632	31	-2	1190	2020-06-23 13:54:28.619261+03
29633	84	-1	2700	2020-06-23 14:05:15.18576+03
29634	30	-2	1140	2020-06-23 14:10:54.919742+03
29635	70	-1	760	2020-06-23 14:15:48.300816+03
29636	5	-1	1620	2020-06-23 14:19:06.273526+03
29637	51	-1	1310	2020-06-23 14:38:00.291969+03
29638	53	23	1513	2020-06-23 14:39:56.010721+03
29639	38	-1	1100	2020-06-23 14:41:53.307422+03
29640	90	-2	1780	2020-06-23 14:45:46.129701+03
29641	49	-1	970	2020-06-23 14:48:44.830338+03
29642	36	-1	630	2020-06-23 14:52:16.095016+03
29643	42	-1	1790	2020-06-23 15:17:33.705566+03
29644	60	-1	2700	2020-06-23 15:20:08.876118+03
29645	5	-1	1620	2020-06-23 15:21:09.707379+03
29646	45	-1	1590	2020-06-23 15:23:18.045329+03
29647	13	-1	460	2020-06-23 15:29:05.231881+03
29648	6	-1	980	2020-06-23 16:06:16.959644+03
29649	90	-1	1780	2020-06-23 16:16:45.01098+03
29650	79	-1	550	2020-06-23 17:01:00.061703+03
29651	14	-1	1350	2020-06-23 17:19:57.291357+03
29652	12	-1	1650	2020-06-23 17:24:34.833371+03
29653	70	-1	760	2020-06-23 17:34:57.533256+03
29654	78	-1	900	2020-06-23 17:41:05.845676+03
29655	7	-1	810	2020-06-23 18:04:07.655841+03
29656	13	-2	460	2020-06-23 18:11:13.900421+03
29657	28	-1	1860	2020-06-23 18:16:44.122677+03
29658	57	-1	1900	2020-06-23 18:34:35.144751+03
29659	81	-1	1620	2020-06-23 18:45:08.311182+03
29660	73	-1	960	2020-06-23 19:05:48.289228+03
29661	73	-1	960	2020-06-23 19:09:19.751822+03
29662	94	-1	1230	2020-06-23 19:32:54.56823+03
29663	77	-1	640	2020-06-23 20:08:49.868668+03
29664	55	-2	3480	2020-06-23 20:53:53.531756+03
29665	21	-1	960	2020-06-23 21:00:19.221456+03
29666	5	-1	1620	2020-06-23 21:15:15.164151+03
29667	66	-1	690	2020-06-23 21:18:30.327762+03
29668	23	-1	4390	2020-06-23 21:25:51.608067+03
29669	53	-1	3120	2020-06-23 21:27:17.946722+03
29670	54	-1	3470	2020-06-23 21:48:23.113614+03
29671	29	-1	1940	2020-06-23 21:59:06.247168+03
29672	74	-2	1010	2020-06-23 22:04:17.762704+03
29673	47	-1	1480	2020-06-23 22:11:29.181666+03
29674	96	-1	1570	2020-06-23 22:15:21.761047+03
29675	44	-1	500	2020-06-23 22:47:41.177235+03
29676	52	-1	1090	2020-06-23 22:57:01.560395+03
29677	37	-1	1290	2020-06-23 22:57:37.587161+03
29678	94	-1	1230	2020-06-23 23:09:48.122956+03
29679	5	-1	1620	2020-06-23 23:32:57.630037+03
29680	62	15	627	2020-06-24 00:04:05.754399+03
29681	86	-1	910	2020-06-24 00:39:18.667805+03
29682	49	-1	970	2020-06-24 00:57:32.802412+03
29683	76	-1	1070	2020-06-24 01:23:10.301142+03
29684	95	-2	480	2020-06-24 01:35:19.907312+03
29685	33	-1	900	2020-06-24 01:46:55.262188+03
29686	77	-1	640	2020-06-24 02:00:15.156963+03
29687	13	-2	460	2020-06-24 02:05:10.678897+03
29688	88	-1	1270	2020-06-24 02:17:48.94348+03
29689	84	-2	2700	2020-06-24 02:18:26.25716+03
29690	56	-1	2460	2020-06-24 02:36:08.891772+03
29691	7	-1	810	2020-06-24 02:37:46.5489+03
29692	38	-1	1100	2020-06-24 02:41:56.647081+03
29693	5	-1	1620	2020-06-24 02:54:14.08829+03
29694	42	-1	1790	2020-06-24 03:00:32.459928+03
29695	6	-1	980	2020-06-24 04:36:41.948156+03
29696	15	-1	2830	2020-06-24 04:39:59.892799+03
29697	26	-1	390	2020-06-24 04:47:04.238523+03
29698	77	-1	640	2020-06-24 05:04:29.903146+03
29699	30	-1	1140	2020-06-24 05:08:23.824655+03
29700	2	-1	470	2020-06-24 05:14:59.707603+03
29701	82	-1	560	2020-06-24 05:15:02.153072+03
29702	87	-2	2320	2020-06-24 05:25:19.482661+03
29703	69	-1	1100	2020-06-24 05:29:08.807926+03
29704	78	-1	900	2020-06-24 06:10:13.729521+03
29705	90	-2	1780	2020-06-24 06:26:46.738857+03
29706	77	-1	640	2020-06-24 07:56:49.330538+03
29707	58	-1	2830	2020-06-24 08:13:40.6734+03
29708	10	-1	2080	2020-06-24 08:21:57.6973+03
29709	44	18	227	2020-06-24 08:29:30.583942+03
29710	66	-1	690	2020-06-24 08:37:14.883497+03
29711	46	-1	1270	2020-06-24 08:46:58.989138+03
29712	55	-1	3480	2020-06-24 08:58:43.468147+03
29713	95	-1	480	2020-06-24 09:24:03.72508+03
29714	47	-2	1480	2020-06-24 09:24:12.468193+03
29715	68	-1	490	2020-06-24 09:25:27.933032+03
29716	64	-1	970	2020-06-24 09:27:08.388844+03
29717	49	-1	970	2020-06-24 09:33:37.376118+03
29718	1	-1	640	2020-06-24 09:57:13.198367+03
29719	91	-1	1620	2020-06-24 10:03:40.01646+03
29720	47	-1	1480	2020-06-24 10:09:15.561886+03
29721	39	-1	910	2020-06-24 10:26:15.803751+03
29722	13	-1	460	2020-06-24 11:12:27.582785+03
29723	13	-1	460	2020-06-24 11:41:40.901669+03
29724	40	-1	1430	2020-06-24 12:11:43.863048+03
29725	74	-1	1010	2020-06-24 12:16:19.989427+03
29726	45	-1	1590	2020-06-24 12:49:19.570221+03
29727	34	-1	1550	2020-06-24 13:03:26.374503+03
29728	67	-1	350	2020-06-24 13:05:37.272114+03
29729	61	-1	1510	2020-06-24 13:13:00.783044+03
29730	24	-1	950	2020-06-24 13:28:27.68718+03
29731	24	-1	950	2020-06-24 14:02:28.819699+03
29732	22	-1	1070	2020-06-24 14:16:35.517654+03
29733	78	-1	900	2020-06-24 14:58:22.638422+03
29734	15	-1	2830	2020-06-24 15:00:03.368664+03
29735	54	-1	3470	2020-06-24 15:10:30.60529+03
29736	40	-1	1430	2020-06-24 15:17:31.184563+03
29737	19	-1	1220	2020-06-24 15:28:50.577067+03
29738	29	-1	1940	2020-06-24 15:36:43.568543+03
29739	20	-2	830	2020-06-24 15:42:33.004548+03
29740	22	37	638	2020-06-24 16:39:27.744641+03
29741	11	-1	830	2020-06-24 16:41:34.899483+03
29742	57	-1	1900	2020-06-24 16:45:39.364644+03
29743	29	-1	1940	2020-06-24 17:00:14.449867+03
29744	4	35	826	2020-06-24 17:42:00.699898+03
29745	63	-2	1780	2020-06-24 17:58:49.358983+03
29746	46	-1	1270	2020-06-24 17:59:32.576378+03
29747	85	-2	730	2020-06-24 18:12:43.698344+03
29748	29	-1	1940	2020-06-24 18:44:56.635965+03
29749	69	-1	1100	2020-06-24 18:54:21.420443+03
29750	56	-1	2460	2020-06-24 19:11:25.290875+03
29751	76	-1	1070	2020-06-24 19:24:32.357676+03
29752	59	-1	1030	2020-06-24 20:18:38.043818+03
29753	1	-1	640	2020-06-24 20:22:35.326782+03
29754	29	-1	1940	2020-06-24 20:24:52.62382+03
29755	62	-2	1220	2020-06-24 20:35:39.930066+03
29756	70	-1	760	2020-06-24 20:35:52.883134+03
29757	31	-2	1190	2020-06-24 20:40:30.013724+03
29758	95	-1	480	2020-06-24 20:44:36.828484+03
29759	76	-1	1070	2020-06-24 20:50:57.248944+03
29760	40	-1	1430	2020-06-24 20:57:44.281945+03
29761	61	-1	1510	2020-06-24 22:22:51.301861+03
29762	32	-1	710	2020-06-24 22:30:58.419078+03
29763	36	-1	630	2020-06-24 22:42:15.456877+03
29764	18	-1	910	2020-06-24 23:42:03.267984+03
29765	93	-1	1620	2020-06-24 23:44:04.705904+03
29766	31	-1	1190	2020-06-24 23:48:07.515475+03
29767	8	-1	1920	2020-06-25 00:22:16.182151+03
29768	31	-1	1190	2020-06-25 00:42:17.980227+03
29769	95	-1	480	2020-06-25 00:51:20.052069+03
29770	12	-1	1650	2020-06-25 01:04:25.568856+03
29771	71	-2	1030	2020-06-25 01:21:45.172106+03
29772	50	-1	1140	2020-06-25 01:24:01.16506+03
29773	86	-1	910	2020-06-25 02:16:13.768029+03
29774	18	-1	910	2020-06-25 02:35:48.495166+03
29775	51	-1	1310	2020-06-25 03:13:29.002829+03
29776	55	-1	3480	2020-06-25 03:17:12.718288+03
29777	94	-1	1230	2020-06-25 03:29:23.257041+03
29778	27	-1	880	2020-06-25 03:34:38.95973+03
29779	30	-1	1140	2020-06-25 03:41:29.023835+03
29780	94	-1	1230	2020-06-25 03:54:30.548846+03
29781	35	-1	670	2020-06-25 04:10:57.278839+03
29782	73	-1	960	2020-06-25 04:24:16.298783+03
29783	56	34	1275	2020-06-25 04:25:53.558669+03
29784	88	-1	1270	2020-06-25 04:44:53.068083+03
29785	91	-1	1620	2020-06-25 04:53:13.354376+03
29786	87	-1	2320	2020-06-25 04:55:43.848496+03
29787	54	-1	3470	2020-06-25 04:58:27.972207+03
29788	6	-1	980	2020-06-25 04:58:30.727302+03
29789	33	-1	900	2020-06-25 05:02:06.5625+03
29790	13	-2	460	2020-06-25 05:48:00.537556+03
29791	39	-1	910	2020-06-25 06:05:24.25276+03
29792	5	31	953	2020-06-25 06:05:57.069877+03
29793	58	-1	2830	2020-06-25 06:17:34.449981+03
29794	27	-1	880	2020-06-25 06:57:09.079488+03
29795	96	-1	1570	2020-06-25 06:59:38.998733+03
29796	94	-1	1230	2020-06-25 07:05:58.376254+03
29797	53	-1	3120	2020-06-25 07:10:01.138071+03
29798	43	-1	380	2020-06-25 07:16:35.247099+03
29799	36	-2	630	2020-06-25 07:19:24.234507+03
29800	56	-1	2460	2020-06-25 07:22:11.985746+03
29801	87	-1	2320	2020-06-25 07:31:22.747392+03
29802	84	-1	2700	2020-06-25 07:36:44.064892+03
29803	72	-1	620	2020-06-25 07:43:45.372903+03
29804	5	-2	1620	2020-06-25 08:37:25.110764+03
29805	57	-1	1900	2020-06-25 08:37:50.67416+03
29806	39	-1	910	2020-06-25 08:50:43.725133+03
29807	91	-1	1620	2020-06-25 08:55:37.525901+03
29808	51	-1	1310	2020-06-25 08:56:00.992334+03
29809	12	-1	1650	2020-06-25 08:59:32.255777+03
29810	57	-1	1900	2020-06-25 09:37:26.325428+03
29811	64	-1	970	2020-06-25 10:20:36.893919+03
29812	47	-1	1480	2020-06-25 10:25:18.388054+03
29813	59	-1	1030	2020-06-25 10:33:40.259535+03
29814	45	-1	1590	2020-06-25 11:13:07.563772+03
29815	49	-1	970	2020-06-25 11:22:25.024967+03
29816	81	23	733	2020-06-25 11:26:14.860263+03
29817	64	-1	970	2020-06-25 11:28:00.673484+03
29818	31	-1	1190	2020-06-25 12:01:02.48676+03
29819	57	-1	1900	2020-06-25 12:21:42.750715+03
29820	71	-2	1030	2020-06-25 12:37:36.824825+03
29821	14	-1	1350	2020-06-25 13:24:33.848073+03
29822	32	-1	710	2020-06-25 13:49:29.461655+03
29823	62	-1	1220	2020-06-25 14:05:00.888533+03
29824	46	-1	1270	2020-06-25 14:12:16.254232+03
29825	59	-1	1030	2020-06-25 15:03:14.491257+03
29826	55	-1	3480	2020-06-25 15:10:11.839697+03
29827	74	-1	1010	2020-06-25 15:21:58.94086+03
29828	32	-1	710	2020-06-25 15:27:43.356755+03
29829	31	-1	1190	2020-06-25 15:30:28.703901+03
29830	4	-1	1420	2020-06-25 15:44:57.868288+03
29831	79	-1	550	2020-06-25 16:16:13.968269+03
29832	56	-1	2460	2020-06-25 16:17:23.208924+03
29833	79	-1	550	2020-06-25 16:23:41.611753+03
29834	88	-1	1270	2020-06-25 16:41:17.649954+03
29835	33	-1	900	2020-06-25 16:56:45.242961+03
29836	8	-1	1920	2020-06-25 17:07:16.472671+03
29837	44	-1	500	2020-06-25 17:13:29.946091+03
29838	89	-1	1420	2020-06-25 17:14:32.709525+03
29839	56	-2	2460	2020-06-25 17:14:57.513526+03
29840	4	-1	1420	2020-06-25 17:16:19.574795+03
29841	23	-1	4390	2020-06-25 17:20:33.841096+03
29842	19	-1	1220	2020-06-25 17:21:48.723682+03
29843	22	-1	1070	2020-06-25 17:34:33.047545+03
29844	42	-1	1790	2020-06-25 18:03:34.238665+03
29845	13	-1	460	2020-06-25 18:15:09.956001+03
29846	38	-1	1100	2020-06-25 18:18:48.265187+03
29847	77	-1	640	2020-06-25 18:39:34.523367+03
29848	35	-1	670	2020-06-25 18:40:35.206772+03
29849	48	-1	640	2020-06-25 18:49:14.490349+03
29850	3	-1	660	2020-06-25 18:53:38.84287+03
29851	10	-2	2080	2020-06-25 19:26:09.920779+03
29852	50	-1	1140	2020-06-25 19:26:43.703048+03
29853	68	-2	490	2020-06-25 20:41:08.81612+03
29854	12	-2	1650	2020-06-25 20:48:59.152952+03
29855	49	-1	970	2020-06-25 21:10:43.950852+03
29856	17	-1	1500	2020-06-25 21:37:20.080885+03
29857	4	-1	1420	2020-06-25 21:46:29.640104+03
29858	26	-1	390	2020-06-25 21:51:45.829678+03
29859	17	-2	1500	2020-06-25 21:57:43.977554+03
29860	72	-2	620	2020-06-25 22:08:49.032913+03
29861	25	-1	1100	2020-06-25 22:24:01.666711+03
29862	70	-1	760	2020-06-25 22:44:09.525134+03
29863	13	-1	460	2020-06-25 22:55:48.366827+03
29864	37	-1	1290	2020-06-25 23:11:03.397654+03
29865	36	-1	630	2020-06-25 23:28:51.816375+03
29866	27	-2	880	2020-06-25 23:36:03.408561+03
29867	58	-2	2830	2020-06-26 00:01:40.462236+03
29868	34	-1	1550	2020-06-26 00:30:48.884593+03
29869	63	-1	1780	2020-06-26 00:33:00.050186+03
29870	20	-1	830	2020-06-26 00:46:09.681678+03
29871	1	-1	640	2020-06-26 01:13:48.741205+03
29872	84	-1	2700	2020-06-26 01:14:17.18746+03
29873	9	25	983	2020-06-26 01:18:17.75108+03
29874	91	-1	1620	2020-06-26 01:58:59.552419+03
29875	19	-1	1220	2020-06-26 02:11:25.275849+03
29876	57	-1	1900	2020-06-26 02:14:46.017321+03
29877	46	-1	1270	2020-06-26 02:16:09.408908+03
29878	10	-1	2080	2020-06-26 02:16:18.400555+03
29879	80	-1	1120	2020-06-26 02:40:02.282768+03
29880	18	-1	910	2020-06-26 02:42:08.253214+03
29881	87	-2	2320	2020-06-26 02:47:51.514075+03
29882	52	-2	1090	2020-06-26 03:07:18.69801+03
29883	23	-1	4390	2020-06-26 03:20:14.708628+03
29884	94	-1	1230	2020-06-26 04:01:39.453466+03
29885	1	-1	640	2020-06-26 04:17:25.393687+03
29886	47	-1	1480	2020-06-26 04:46:04.024886+03
29887	16	11	647	2020-06-26 04:47:40.070587+03
29888	95	-1	480	2020-06-26 04:59:40.6452+03
29889	70	-1	760	2020-06-26 05:06:28.485306+03
29890	44	-1	500	2020-06-26 05:14:52.427858+03
29891	22	-1	1070	2020-06-26 05:16:11.497284+03
29892	39	32	475	2020-06-26 05:31:05.001509+03
29893	82	-1	560	2020-06-26 05:36:38.683512+03
29894	63	-1	1780	2020-06-26 05:44:06.59262+03
29895	22	-2	1070	2020-06-26 05:51:08.983566+03
29896	95	-1	480	2020-06-26 05:55:11.557009+03
29897	57	-2	1900	2020-06-26 05:58:17.808313+03
29898	83	-1	1230	2020-06-26 06:34:40.096276+03
29899	71	-1	1030	2020-06-26 07:21:15.502441+03
29900	55	21	1736	2020-06-26 08:03:36.450315+03
29901	6	-2	980	2020-06-26 08:36:30.468653+03
29902	29	43	1148	2020-06-26 08:44:49.663024+03
29903	9	-1	2090	2020-06-26 08:47:03.039437+03
29904	40	-1	1430	2020-06-26 08:48:37.987478+03
29905	49	-1	970	2020-06-26 09:17:40.043003+03
29906	37	-1	1290	2020-06-26 09:32:02.925832+03
29907	49	-1	970	2020-06-26 09:47:53.42226+03
29908	43	-1	380	2020-06-26 10:12:52.806268+03
29909	61	-1	1510	2020-06-26 10:53:14.225095+03
29910	20	-1	830	2020-06-26 11:37:25.672884+03
29911	65	-1	490	2020-06-26 12:06:47.234936+03
29912	1	-1	640	2020-06-26 12:13:51.145471+03
29913	42	-1	1790	2020-06-26 12:31:49.443441+03
29914	54	-2	3470	2020-06-26 12:31:49.844178+03
29915	82	-1	560	2020-06-26 12:46:40.987109+03
29916	17	-1	1500	2020-06-26 12:47:48.375397+03
29917	14	-1	1350	2020-06-26 12:47:54.287195+03
29918	34	-1	1550	2020-06-26 13:07:42.073757+03
29919	44	-1	500	2020-06-26 13:21:17.910272+03
29920	71	-1	1030	2020-06-26 13:22:30.455897+03
29921	34	-1	1550	2020-06-26 13:33:23.172306+03
29922	63	-1	1780	2020-06-26 13:52:00.509514+03
29923	80	-2	1120	2020-06-26 14:01:42.606329+03
29924	78	-1	900	2020-06-26 14:17:26.911847+03
29925	72	-1	620	2020-06-26 14:25:04.004763+03
29926	40	-1	1430	2020-06-26 14:39:29.359327+03
29927	70	-1	760	2020-06-26 15:01:01.384795+03
29928	75	-1	830	2020-06-26 15:15:27.726459+03
29929	41	-1	830	2020-06-26 15:23:05.014957+03
29930	18	-1	910	2020-06-26 15:27:03.947598+03
29931	26	-1	390	2020-06-26 15:30:44.825668+03
29932	32	-1	710	2020-06-26 15:35:25.550698+03
29933	39	-2	910	2020-06-26 15:37:54.93682+03
29934	32	-1	710	2020-06-26 16:03:04.812461+03
29935	4	-2	1420	2020-06-26 16:19:25.397295+03
29936	56	-2	2460	2020-06-26 16:33:49.456393+03
29937	76	-1	1070	2020-06-26 16:38:21.695008+03
29938	76	-1	1070	2020-06-26 17:04:31.052242+03
29939	6	-1	980	2020-06-26 17:26:46.784748+03
29940	47	-1	1480	2020-06-26 17:38:55.852987+03
29941	95	-1	480	2020-06-26 18:16:28.370643+03
29942	45	-1	1590	2020-06-26 18:48:48.809056+03
29943	96	-1	1570	2020-06-26 19:31:09.496734+03
29944	18	-1	910	2020-06-26 19:31:25.806204+03
29945	95	-1	480	2020-06-26 20:10:28.808658+03
29946	31	-1	1190	2020-06-26 20:12:42.939794+03
29947	81	-2	1620	2020-06-26 20:22:48.156013+03
29948	58	-1	2830	2020-06-26 20:27:18.196563+03
29949	21	-1	960	2020-06-26 20:52:51.131359+03
29950	21	-1	960	2020-06-26 20:58:33.758726+03
29951	54	-1	3470	2020-06-26 21:32:23.279484+03
29952	35	-1	670	2020-06-26 21:41:44.495797+03
29953	34	-1	1550	2020-06-26 21:59:36.666978+03
29954	60	-1	2700	2020-06-26 22:12:36.303106+03
29955	35	-2	670	2020-06-26 22:33:24.799738+03
29956	78	15	385	2020-06-26 22:46:56.59784+03
29957	76	-1	1070	2020-06-26 22:47:35.493674+03
29958	41	-1	830	2020-06-26 23:01:07.268115+03
29959	75	-1	830	2020-06-26 23:18:23.683835+03
29960	12	-1	1650	2020-06-26 23:38:39.09793+03
29961	29	-2	1940	2020-06-26 23:55:42.750864+03
29962	88	-1	1270	2020-06-27 00:06:33.178191+03
29963	29	-2	1940	2020-06-27 00:11:51.286825+03
29964	53	-1	3120	2020-06-27 00:22:48.961983+03
29965	44	-1	500	2020-06-27 00:35:24.281196+03
29966	56	-1	2460	2020-06-27 00:53:50.830236+03
29967	12	-1	1650	2020-06-27 01:17:41.894738+03
29968	46	24	755	2020-06-27 01:25:26.310531+03
29969	86	-1	910	2020-06-27 01:33:19.268063+03
29970	10	-1	2080	2020-06-27 01:34:25.873681+03
29971	40	22	833	2020-06-27 01:42:48.638656+03
29972	8	23	1064	2020-06-27 01:44:21.545249+03
29973	54	-2	3470	2020-06-27 01:47:11.598883+03
29974	77	-1	640	2020-06-27 02:32:47.162145+03
29975	30	-1	1140	2020-06-27 02:38:28.850782+03
29976	92	-2	630	2020-06-27 03:15:30.278974+03
29977	25	13	458	2020-06-27 03:26:39.954758+03
29978	4	-1	1420	2020-06-27 03:32:32.491917+03
29979	17	-1	1500	2020-06-27 03:43:50.774147+03
29980	47	-2	1480	2020-06-27 03:47:00.541404+03
29981	36	-2	630	2020-06-27 03:55:11.754622+03
29982	78	-1	900	2020-06-27 04:08:50.730426+03
29983	12	-1	1650	2020-06-27 04:09:18.119022+03
29984	10	-1	2080	2020-06-27 05:14:04.61289+03
29985	86	-1	910	2020-06-27 05:34:47.832498+03
29986	70	-1	760	2020-06-27 05:39:15.280706+03
29987	74	-2	1010	2020-06-27 06:41:04.060455+03
29988	96	-1	1570	2020-06-27 07:00:33.556265+03
29989	52	22	464	2020-06-27 07:05:30.133299+03
29990	49	32	416	2020-06-27 07:17:55.053646+03
29991	29	-1	1940	2020-06-27 07:55:13.858247+03
29992	9	-1	2090	2020-06-27 08:25:57.471447+03
29993	20	-1	830	2020-06-27 08:25:57.605868+03
29994	4	-1	1420	2020-06-27 08:42:40.081324+03
29995	3	-1	660	2020-06-27 08:42:42.9282+03
29996	6	-1	980	2020-06-27 09:21:30.122101+03
29997	83	31	568	2020-06-27 09:49:29.853811+03
29998	85	-1	730	2020-06-27 10:00:28.565695+03
29999	32	27	362	2020-06-27 10:02:36.794465+03
30000	21	-1	960	2020-06-27 10:07:18.766644+03
30001	96	-1	1570	2020-06-27 10:11:44.477939+03
30002	72	-1	620	2020-06-27 10:17:40.377867+03
30003	86	-1	910	2020-06-27 10:24:38.818583+03
30004	14	-1	1350	2020-06-27 10:31:37.530925+03
30005	69	-1	1100	2020-06-27 11:07:08.669345+03
30006	56	-1	2460	2020-06-27 11:53:38.492282+03
30007	8	-1	1920	2020-06-27 11:56:54.651628+03
30008	32	-1	710	2020-06-27 11:57:17.142678+03
30009	7	-1	810	2020-06-27 13:21:07.585014+03
30010	62	-1	1220	2020-06-27 13:41:24.518758+03
30011	77	-1	640	2020-06-27 13:42:14.744813+03
30012	11	-1	830	2020-06-27 14:15:56.970664+03
30013	5	-1	1620	2020-06-27 14:23:50.336694+03
30014	70	-1	760	2020-06-27 15:08:21.753227+03
30015	71	-1	1030	2020-06-27 15:17:02.751428+03
30016	48	-1	640	2020-06-27 15:19:25.767024+03
30017	84	-2	2700	2020-06-27 15:21:40.628679+03
30018	87	-1	2320	2020-06-27 15:22:51.262913+03
30019	88	-2	1270	2020-06-27 16:25:31.975006+03
30020	14	-1	1350	2020-06-27 16:26:36.400246+03
30021	50	-1	1140	2020-06-27 16:27:18.287731+03
30022	56	-1	2460	2020-06-27 16:35:10.122411+03
30023	46	-1	1270	2020-06-27 16:35:48.62075+03
30024	79	-1	550	2020-06-27 16:39:34.115178+03
30025	73	-2	960	2020-06-27 17:32:45.115621+03
30026	63	-1	1780	2020-06-27 17:43:44.345004+03
30027	83	-1	1230	2020-06-27 17:58:10.002809+03
30028	23	-1	4390	2020-06-27 18:22:30.537149+03
30029	83	-2	1230	2020-06-27 18:24:47.648182+03
30030	40	-1	1430	2020-06-27 18:58:38.345333+03
30031	90	-1	1780	2020-06-27 19:21:36.568385+03
30032	24	-1	950	2020-06-27 19:35:16.237814+03
30033	36	-1	630	2020-06-27 19:35:21.148048+03
30034	39	-1	910	2020-06-27 19:49:35.257895+03
30035	89	-1	1420	2020-06-27 19:52:10.868138+03
30036	48	25	349	2020-06-27 19:55:38.937717+03
30037	43	-1	380	2020-06-27 20:09:39.698906+03
30038	65	-1	490	2020-06-27 20:11:19.190045+03
30039	95	-2	480	2020-06-27 20:41:21.531121+03
30040	1	-2	640	2020-06-27 20:46:53.467743+03
30041	11	-1	830	2020-06-27 20:47:40.716268+03
30042	81	-2	1620	2020-06-27 21:09:48.12325+03
30043	17	-2	1500	2020-06-27 21:28:23.141237+03
30044	35	-1	670	2020-06-27 21:44:44.935117+03
30045	96	-2	1570	2020-06-27 21:55:59.803088+03
30046	54	-1	3470	2020-06-27 22:14:04.573712+03
30047	76	-1	1070	2020-06-27 22:17:55.412043+03
30048	96	-1	1570	2020-06-27 22:21:26.173302+03
30049	82	-1	560	2020-06-27 22:38:20.749645+03
30050	2	-2	470	2020-06-27 22:52:46.313493+03
30051	69	-1	1100	2020-06-27 23:30:12.628807+03
30052	71	-1	1030	2020-06-27 23:31:43.322501+03
30053	54	-1	3470	2020-06-27 23:33:47.519437+03
30054	66	-2	690	2020-06-27 23:41:37.948423+03
30055	84	-1	2700	2020-06-27 23:41:44.613482+03
30056	57	-1	1900	2020-06-27 23:43:01.055831+03
30057	31	-1	1190	2020-06-27 23:46:04.911321+03
30058	59	-1	1030	2020-06-27 23:47:29.079348+03
30059	65	-1	490	2020-06-27 23:54:52.968569+03
30060	84	-2	2700	2020-06-28 00:36:12.285571+03
30061	93	-1	1620	2020-06-28 01:14:56.896491+03
30062	40	-1	1430	2020-06-28 01:17:54.125612+03
30063	83	-1	1230	2020-06-28 01:53:04.267835+03
30064	71	-1	1030	2020-06-28 01:58:03.661697+03
30065	79	-1	550	2020-06-28 02:05:47.307709+03
30066	83	-1	1230	2020-06-28 02:12:08.80884+03
30067	7	-1	810	2020-06-28 02:13:19.328454+03
30068	76	-1	1070	2020-06-28 02:30:04.979005+03
30069	70	-1	760	2020-06-28 02:37:12.5016+03
30070	10	-3	2080	2020-06-28 02:48:01.297113+03
30071	87	-1	2320	2020-06-28 02:51:43.243379+03
30072	12	-1	1650	2020-06-28 03:02:23.663544+03
30073	88	-1	1270	2020-06-28 03:20:02.27069+03
30074	11	-1	830	2020-06-28 03:23:21.996977+03
30075	9	-1	2090	2020-06-28 03:31:00.744898+03
30076	5	-1	1620	2020-06-28 03:37:18.473844+03
30077	9	-1	2090	2020-06-28 03:46:48.119239+03
30078	43	-1	380	2020-06-28 03:53:05.504641+03
30079	1	-1	640	2020-06-28 04:16:17.131865+03
30080	34	-1	1550	2020-06-28 04:33:30.658199+03
30081	86	-2	910	2020-06-28 04:36:13.97401+03
30082	36	-1	630	2020-06-28 04:47:41.453983+03
30083	67	-1	350	2020-06-28 04:51:45.672179+03
30084	4	-1	1420	2020-06-28 05:04:02.568755+03
30085	33	-1	900	2020-06-28 05:48:49.522944+03
30086	84	-1	2700	2020-06-28 05:49:38.465055+03
30087	14	-1	1350	2020-06-28 05:57:41.331749+03
30088	51	-1	1310	2020-06-28 06:25:04.732168+03
30089	54	-1	3470	2020-06-28 06:33:28.227205+03
30090	13	-1	460	2020-06-28 06:39:38.698986+03
30091	46	-1	1270	2020-06-28 07:04:32.875602+03
30092	79	-1	550	2020-06-28 07:13:39.772343+03
30093	95	-1	480	2020-06-28 07:28:54.210864+03
30094	65	-1	490	2020-06-28 07:51:45.477864+03
30095	88	-1	1270	2020-06-28 07:58:13.571209+03
30096	80	-1	1120	2020-06-28 07:58:28.772738+03
30097	39	-1	910	2020-06-28 08:01:22.051172+03
30098	45	-1	1590	2020-06-28 08:15:48.347977+03
30099	19	-1	1220	2020-06-28 08:42:20.259353+03
30100	22	-1	1070	2020-06-28 08:58:34.086656+03
30101	42	-1	1790	2020-06-28 09:24:00.119909+03
30102	7	-1	810	2020-06-28 09:24:52.991674+03
30103	7	-1	810	2020-06-28 09:47:41.310273+03
30104	68	-1	490	2020-06-28 09:52:22.59891+03
30105	42	-1	1790	2020-06-28 10:20:55.072582+03
30106	43	-1	380	2020-06-28 10:25:39.894646+03
30107	59	29	525	2020-06-28 10:26:18.784146+03
30108	5	-2	1620	2020-06-28 10:36:37.320062+03
30109	44	-2	500	2020-06-28 10:44:44.62564+03
30110	1	-2	640	2020-06-28 11:15:32.577489+03
30111	83	-1	1230	2020-06-28 11:24:15.709885+03
30112	23	-2	4390	2020-06-28 11:26:18.185782+03
30113	86	25	431	2020-06-28 11:27:44.706587+03
30114	29	-1	1940	2020-06-28 12:12:45.095879+03
30115	18	38	420	2020-06-28 12:17:24.668965+03
30116	14	-1	1350	2020-06-28 12:24:08.18141+03
30117	62	-1	1220	2020-06-28 13:25:53.66484+03
30118	75	-1	830	2020-06-28 13:31:21.824761+03
30119	92	-2	630	2020-06-28 13:39:58.125298+03
30120	59	-1	1030	2020-06-28 13:52:43.093263+03
30121	14	-2	1350	2020-06-28 14:15:51.183558+03
30122	48	-1	640	2020-06-28 15:23:41.103403+03
30123	25	-1	1100	2020-06-28 15:29:37.281023+03
30124	12	-1	1650	2020-06-28 15:34:36.469255+03
30125	12	-1	1650	2020-06-28 16:09:51.523394+03
30126	62	-1	1220	2020-06-28 16:33:24.365459+03
30127	50	-1	1140	2020-06-28 17:10:28.219172+03
30128	34	-1	1550	2020-06-28 17:30:08.685916+03
30129	1	-1	640	2020-06-28 17:32:31.910419+03
30130	42	-1	1790	2020-06-28 17:36:09.416463+03
30131	87	-1	2320	2020-06-28 17:40:44.19188+03
30132	47	-1	1480	2020-06-28 17:55:31.031117+03
30133	17	-1	1500	2020-06-28 18:19:09.604853+03
30134	31	-1	1190	2020-06-28 18:25:44.026352+03
30135	49	-1	970	2020-06-28 18:36:21.481466+03
30136	95	-1	480	2020-06-28 18:48:06.651571+03
30137	49	-1	970	2020-06-28 18:48:21.742137+03
30138	11	-1	830	2020-06-28 18:52:10.179027+03
30139	87	-1	2320	2020-06-28 18:56:52.772705+03
30140	87	39	1219	2020-06-28 19:02:54.160137+03
30141	69	-1	1100	2020-06-28 19:23:30.604262+03
30142	11	-2	830	2020-06-28 19:42:55.710853+03
30143	9	-1	2090	2020-06-28 19:55:08.286501+03
30144	30	-1	1140	2020-06-28 20:04:08.259964+03
30145	23	-1	4390	2020-06-28 20:12:27.076146+03
30146	87	-1	2320	2020-06-28 21:04:31.211971+03
30147	14	-1	1350	2020-06-28 21:33:49.213191+03
30148	3	-1	660	2020-06-28 21:50:12.274928+03
30149	13	-1	460	2020-06-28 22:08:59.006959+03
30150	18	-2	910	2020-06-28 23:07:17.919645+03
30151	36	-1	630	2020-06-28 23:14:47.250343+03
30152	30	-1	1140	2020-06-28 23:22:15.98497+03
30153	86	-1	910	2020-06-28 23:26:26.355172+03
30154	37	-2	1290	2020-06-28 23:41:06.531127+03
30155	77	-1	640	2020-06-29 00:20:15.067353+03
30156	87	-1	2320	2020-06-29 01:03:26.709478+03
30157	39	-1	910	2020-06-29 01:03:56.288405+03
30158	53	-1	3120	2020-06-29 01:55:53.506232+03
30159	19	-1	1220	2020-06-29 02:08:32.391984+03
30160	18	-1	910	2020-06-29 02:16:18.576775+03
30161	52	-1	1090	2020-06-29 02:22:18.648193+03
30162	49	-2	970	2020-06-29 02:27:21.012112+03
30163	32	-1	710	2020-06-29 02:33:06.971013+03
30164	75	-1	830	2020-06-29 02:34:50.966086+03
30165	26	-1	390	2020-06-29 02:46:54.699995+03
30166	17	-1	1500	2020-06-29 02:53:25.785804+03
30167	31	-1	1190	2020-06-29 03:04:01.003483+03
30168	92	-1	630	2020-06-29 03:07:31.575303+03
30169	81	-1	1620	2020-06-29 03:15:07.966789+03
30170	6	-1	980	2020-06-29 03:46:48.563713+03
30171	88	-1	1270	2020-06-29 03:54:12.944231+03
30172	71	-1	1030	2020-06-29 04:04:02.934351+03
30173	58	-1	2830	2020-06-29 04:16:44.41701+03
30174	68	22	208	2020-06-29 04:26:18.105874+03
30175	17	-1	1500	2020-06-29 05:03:52.557853+03
30176	24	-1	950	2020-06-29 05:16:05.570064+03
30177	70	-1	760	2020-06-29 05:21:03.553972+03
30178	11	-1	830	2020-06-29 05:25:36.873758+03
30179	49	-1	970	2020-06-29 05:49:45.501043+03
30180	32	-1	710	2020-06-29 06:21:13.00108+03
30181	81	-1	1620	2020-06-29 06:29:48.402986+03
30182	17	-1	1500	2020-06-29 06:53:37.821327+03
30183	27	24	395	2020-06-29 06:56:59.142053+03
30184	65	-1	490	2020-06-29 07:10:45.237574+03
30185	41	-1	830	2020-06-29 07:15:17.48515+03
30186	45	-1	1590	2020-06-29 07:30:47.88969+03
30187	76	-1	1070	2020-06-29 07:31:10.478994+03
30188	40	-1	1430	2020-06-29 07:40:59.317421+03
30189	47	-1	1480	2020-06-29 08:08:17.10028+03
30190	12	-1	1650	2020-06-29 08:53:10.826668+03
30191	17	-1	1500	2020-06-29 08:56:44.131931+03
30192	80	-1	1120	2020-06-29 08:57:58.528331+03
30193	36	30	276	2020-06-29 08:58:44.366507+03
30194	15	-2	2830	2020-06-29 10:03:30.851499+03
30195	16	-1	1380	2020-06-29 10:04:06.23874+03
30196	20	-1	830	2020-06-29 10:25:35.830972+03
30197	60	-1	2700	2020-06-29 10:37:11.324111+03
30198	14	-1	1350	2020-06-29 10:57:47.653237+03
30199	62	-1	1220	2020-06-29 10:59:23.477688+03
30200	46	-1	1270	2020-06-29 11:08:03.75269+03
30201	94	-1	1230	2020-06-29 11:13:28.034105+03
30202	23	-1	4390	2020-06-29 11:37:22.424025+03
30203	13	-1	460	2020-06-29 11:38:06.95622+03
30204	30	-2	1140	2020-06-29 11:41:06.159074+03
30205	66	-1	690	2020-06-29 12:01:39.651813+03
30206	81	-1	1620	2020-06-29 12:06:05.760089+03
30207	60	-1	2700	2020-06-29 12:08:55.04965+03
30208	29	-1	1940	2020-06-29 12:10:34.294308+03
30209	66	14	296	2020-06-29 12:38:56.006362+03
30210	70	-1	760	2020-06-29 12:51:44.718557+03
30211	90	-1	1780	2020-06-29 12:51:56.942803+03
30212	65	-2	490	2020-06-29 12:55:51.692234+03
30213	65	15	202	2020-06-29 12:58:43.71993+03
30214	30	-1	1140	2020-06-29 13:11:35.808172+03
30215	37	-1	1290	2020-06-29 13:38:43.257043+03
30216	33	-1	900	2020-06-29 14:06:33.029754+03
30217	93	-2	1620	2020-06-29 14:39:10.097253+03
30218	82	-1	560	2020-06-29 14:56:32.955055+03
30219	71	-1	1030	2020-06-29 14:59:09.263371+03
30220	40	-1	1430	2020-06-29 14:59:29.100911+03
30221	52	-1	1090	2020-06-29 15:03:52.387962+03
30222	76	-1	1070	2020-06-29 15:10:08.768009+03
30223	83	-1	1230	2020-06-29 15:44:33.73015+03
30224	93	39	660	2020-06-29 16:10:09.888373+03
30225	29	-1	1940	2020-06-29 16:13:43.526695+03
30226	18	-1	910	2020-06-29 17:10:32.703276+03
30227	83	-2	1230	2020-06-29 17:25:43.724311+03
30228	40	-1	1430	2020-06-29 17:28:30.288855+03
30229	33	-1	900	2020-06-29 17:55:33.879876+03
30230	24	-1	950	2020-06-29 17:59:17.946641+03
30231	61	-1	1510	2020-06-29 18:09:16.560529+03
30232	1	-1	640	2020-06-29 18:12:44.327307+03
30233	34	-1	1550	2020-06-29 18:22:58.270159+03
30234	20	-1	830	2020-06-29 18:36:28.751803+03
30235	93	-1	1620	2020-06-29 18:50:48.347939+03
30236	62	-1	1220	2020-06-29 19:22:25.822499+03
30237	71	-2	1030	2020-06-29 19:23:13.182355+03
30238	34	-1	1550	2020-06-29 19:25:50.228079+03
30239	21	-1	960	2020-06-29 19:49:28.750833+03
30240	93	-1	1620	2020-06-29 19:58:14.809777+03
30241	77	-1	640	2020-06-29 20:00:34.880396+03
30242	83	-1	1230	2020-06-29 20:06:46.550513+03
30243	88	-1	1270	2020-06-29 20:17:41.531482+03
30244	53	-1	3120	2020-06-29 20:47:18.155213+03
30245	12	-1	1650	2020-06-29 20:51:39.933448+03
30246	65	-1	490	2020-06-29 20:58:18.488665+03
30247	40	-1	1430	2020-06-29 21:28:56.270719+03
30248	42	-1	1790	2020-06-29 21:35:16.331474+03
30249	64	-2	970	2020-06-29 21:41:37.848731+03
30250	42	-1	1790	2020-06-29 21:46:41.85024+03
30251	69	20	654	2020-06-29 22:09:52.175958+03
30252	35	-1	670	2020-06-29 22:33:06.921569+03
30253	51	-1	1310	2020-06-29 22:46:44.780903+03
30254	95	-1	480	2020-06-29 22:49:20.17096+03
30255	56	-1	2460	2020-06-29 22:51:57.208622+03
30256	29	-1	1940	2020-06-29 23:16:36.063163+03
30257	39	-1	910	2020-06-29 23:22:57.166502+03
30258	43	-1	380	2020-06-29 23:32:19.777166+03
30259	77	-2	640	2020-06-29 23:44:36.051397+03
30260	22	-1	1070	2020-06-30 00:01:18.946774+03
30261	36	-1	630	2020-06-30 00:16:28.55961+03
30262	7	-1	810	2020-06-30 00:30:24.188068+03
30263	64	-1	970	2020-06-30 00:37:38.833088+03
30264	45	-1	1590	2020-06-30 00:40:53.588139+03
30265	71	41	562	2020-06-30 00:53:14.636444+03
30266	22	-1	1070	2020-06-30 00:54:17.072944+03
30267	49	-1	970	2020-06-30 01:14:30.396049+03
30268	84	-1	2700	2020-06-30 01:30:01.819854+03
30269	84	-1	2700	2020-06-30 01:36:19.445904+03
30270	63	-2	1780	2020-06-30 02:42:21.11783+03
30271	27	-2	880	2020-06-30 02:43:43.054203+03
30272	47	-1	1480	2020-06-30 03:08:04.169574+03
30273	10	-1	2080	2020-06-30 03:10:52.526255+03
30274	59	-1	1030	2020-06-30 03:59:51.853188+03
30275	78	-2	900	2020-06-30 04:13:12.415161+03
30276	41	-1	830	2020-06-30 04:15:21.22521+03
30277	5	-2	1620	2020-06-30 04:43:38.768868+03
30278	90	-1	1780	2020-06-30 04:50:14.874051+03
30279	23	-1	4390	2020-06-30 05:13:26.696416+03
30280	51	-1	1310	2020-06-30 05:19:23.280732+03
30281	80	-1	1120	2020-06-30 05:43:12.358963+03
30282	96	-1	1570	2020-06-30 05:50:59.177215+03
30283	11	-1	830	2020-06-30 06:00:47.146395+03
30284	77	-1	640	2020-06-30 06:30:46.544454+03
30285	75	-1	830	2020-06-30 06:32:31.930024+03
30286	56	-1	2460	2020-06-30 06:42:43.728179+03
30287	22	-1	1070	2020-06-30 06:47:03.329047+03
30288	4	-1	1420	2020-06-30 07:04:42.50668+03
30289	36	-1	630	2020-06-30 07:12:51.812083+03
30290	24	-1	950	2020-06-30 07:55:20.686726+03
30291	60	-1	2700	2020-06-30 08:12:52.746844+03
30292	19	-1	1220	2020-06-30 08:15:38.089986+03
30293	82	20	312	2020-06-30 08:32:45.404492+03
30294	22	-1	1070	2020-06-30 08:39:31.91566+03
30295	22	-1	1070	2020-06-30 09:07:05.430155+03
30296	82	-1	560	2020-06-30 09:16:12.733207+03
30297	7	-1	810	2020-06-30 09:16:21.875435+03
30298	8	-1	1920	2020-06-30 09:22:25.795063+03
30299	89	-1	1420	2020-06-30 09:30:31.071842+03
30300	4	-1	1420	2020-06-30 09:35:53.073054+03
30301	83	-1	1230	2020-06-30 09:49:29.365361+03
30302	23	29	1819	2020-06-30 09:53:35.739158+03
30303	81	-1	1620	2020-06-30 10:00:15.994426+03
30304	59	-1	1030	2020-06-30 10:19:28.444287+03
30305	4	-1	1420	2020-06-30 10:26:34.036798+03
30306	64	-1	970	2020-06-30 10:35:17.441248+03
30307	18	-1	910	2020-06-30 10:44:09.639645+03
30308	80	-1	1120	2020-06-30 10:51:44.599274+03
30309	77	-2	640	2020-06-30 11:12:48.111719+03
30310	23	-1	4390	2020-06-30 11:15:24.280221+03
30311	6	-1	980	2020-06-30 11:28:03.79421+03
30312	4	-1	1420	2020-06-30 11:38:55.879279+03
30313	47	-1	1480	2020-06-30 11:52:07.305801+03
30314	69	-1	1100	2020-06-30 12:01:05.063707+03
30315	6	-1	980	2020-06-30 12:32:30.645303+03
30316	94	-1	1230	2020-06-30 12:42:49.137031+03
30317	74	-2	1010	2020-06-30 13:02:03.241949+03
30318	77	-2	640	2020-06-30 13:14:22.875753+03
30319	64	-1	970	2020-06-30 13:42:17.478555+03
30320	63	21	954	2020-06-30 13:54:34.699688+03
30321	47	-2	1480	2020-06-30 13:57:58.317657+03
30322	61	-1	1510	2020-06-30 15:02:08.595468+03
30323	71	-2	1030	2020-06-30 15:27:02.955895+03
30324	82	-1	560	2020-06-30 15:40:49.225463+03
30325	9	-2	2090	2020-06-30 16:41:18.632458+03
30326	79	-2	550	2020-06-30 16:43:00.626002+03
30327	36	-1	630	2020-06-30 16:48:26.454464+03
30328	22	-1	1070	2020-06-30 17:20:24.755131+03
30329	9	-1	2090	2020-06-30 17:30:34.055704+03
30330	85	-1	730	2020-06-30 17:59:58.610152+03
30331	35	-1	670	2020-06-30 18:13:44.751785+03
30332	94	-1	1230	2020-06-30 18:17:24.909061+03
30333	91	-1	1620	2020-06-30 18:18:14.376866+03
30334	30	-1	1140	2020-06-30 18:39:21.799238+03
30335	18	-1	910	2020-06-30 18:43:02.834876+03
30336	85	-1	730	2020-06-30 19:07:42.526436+03
30337	6	-1	980	2020-06-30 19:13:39.184574+03
30338	54	-1	3470	2020-06-30 19:26:06.688254+03
30339	5	-1	1620	2020-06-30 19:54:53.925351+03
30340	81	-1	1620	2020-06-30 20:20:13.264295+03
30341	8	-1	1920	2020-06-30 20:29:43.150878+03
30342	36	-1	630	2020-06-30 20:36:02.872297+03
30343	79	-1	550	2020-06-30 20:56:26.9738+03
30344	84	-1	2700	2020-06-30 21:19:27.963812+03
30345	52	-1	1090	2020-06-30 21:34:24.595862+03
30346	38	-1	1100	2020-06-30 21:38:43.152841+03
30347	71	-1	1030	2020-06-30 22:47:14.479191+03
30348	44	-2	500	2020-06-30 22:50:56.931911+03
30349	94	-2	1230	2020-06-30 22:51:41.212085+03
30350	85	-1	730	2020-06-30 23:05:21.249093+03
30351	90	-1	1780	2020-06-30 23:26:40.161881+03
30352	70	-1	760	2020-06-30 23:49:05.220661+03
30353	35	-1	670	2020-07-01 00:24:39.083623+03
30354	83	-1	1230	2020-07-01 00:37:12.629463+03
30355	6	-1	980	2020-07-01 00:41:03.666262+03
30356	93	-1	1620	2020-07-01 00:46:21.823165+03
30357	21	-1	960	2020-07-01 00:59:12.204578+03
30358	57	-1	1900	2020-07-01 01:38:40.618437+03
30359	59	-1	1030	2020-07-01 01:39:47.237805+03
30360	49	-1	970	2020-07-01 02:17:21.978741+03
30361	7	23	470	2020-07-01 02:23:53.078958+03
30362	75	-1	830	2020-07-01 02:57:02.664725+03
30363	71	-1	1030	2020-07-01 03:03:11.874033+03
30364	9	-2	2090	2020-07-01 03:16:58.979961+03
30365	22	-2	1070	2020-07-01 03:31:13.865077+03
30366	39	-1	910	2020-07-01 04:49:50.569937+03
30367	22	-2	1070	2020-07-01 05:01:43.272546+03
30368	86	-1	910	2020-07-01 05:59:05.868392+03
30369	37	-1	1290	2020-07-01 06:13:23.401143+03
30370	94	-2	1230	2020-07-01 06:15:43.810262+03
30371	56	-1	2460	2020-07-01 06:54:39.095909+03
30372	46	-1	1270	2020-07-01 07:14:10.229307+03
30373	22	-2	1070	2020-07-01 07:18:22.442512+03
30374	63	-1	1780	2020-07-01 07:26:25.656984+03
30375	25	-1	1100	2020-07-01 08:02:57.38036+03
30376	22	-1	1070	2020-07-01 08:25:57.679678+03
30377	88	-1	1270	2020-07-01 09:03:35.438438+03
30378	4	-1	1420	2020-07-01 09:16:47.02538+03
30379	40	-1	1430	2020-07-01 09:20:15.482157+03
30380	4	-1	1420	2020-07-01 10:00:46.839932+03
30381	33	-1	900	2020-07-01 10:30:35.641469+03
30382	7	-1	810	2020-07-01 10:44:57.73319+03
30383	65	-1	490	2020-07-01 11:25:19.543861+03
30384	16	-1	1380	2020-07-01 11:30:03.170557+03
30385	59	-1	1030	2020-07-01 11:31:01.518936+03
30386	58	-1	2830	2020-07-01 11:35:58.202675+03
30387	38	-1	1100	2020-07-01 11:36:17.574017+03
30388	31	29	556	2020-07-01 11:57:23.551718+03
30389	55	-1	3480	2020-07-01 12:04:24.972091+03
30390	94	-1	1230	2020-07-01 12:21:30.221339+03
30391	77	-1	640	2020-07-01 12:21:48.284989+03
30392	9	-2	2090	2020-07-01 13:47:16.649422+03
30393	70	-1	760	2020-07-01 13:48:06.743063+03
30394	53	-1	3120	2020-07-01 14:01:15.852292+03
30395	34	-1	1550	2020-07-01 14:05:42.493586+03
30396	3	-1	660	2020-07-01 14:40:31.880515+03
30397	81	-1	1620	2020-07-01 14:43:23.14621+03
30398	70	-2	760	2020-07-01 15:09:31.546286+03
30399	79	-2	550	2020-07-01 15:11:14.757317+03
30400	90	-2	1780	2020-07-01 15:20:51.525914+03
30401	13	-1	460	2020-07-01 15:21:31.514786+03
30402	32	-2	710	2020-07-01 15:41:44.723414+03
30403	86	-1	910	2020-07-01 15:48:08.615669+03
30404	56	-2	2460	2020-07-01 15:49:06.497358+03
30405	3	-1	660	2020-07-01 16:15:02.071454+03
30406	82	-1	560	2020-07-01 17:02:34.81589+03
30407	10	-2	2080	2020-07-01 17:06:28.754176+03
30408	46	-2	1270	2020-07-01 17:14:50.583147+03
30409	76	-2	1070	2020-07-01 17:21:28.130954+03
30410	33	-2	900	2020-07-01 17:21:55.727535+03
30411	85	-1	730	2020-07-01 17:34:43.401704+03
30412	33	-1	900	2020-07-01 17:39:43.050656+03
30413	38	-1	1100	2020-07-01 17:46:10.785928+03
30414	49	-1	970	2020-07-01 17:57:42.506385+03
30415	42	-1	1790	2020-07-01 18:00:22.373655+03
30416	55	-1	3480	2020-07-01 18:19:55.026343+03
30417	23	-1	4390	2020-07-01 18:41:47.871269+03
30418	18	-1	910	2020-07-01 18:54:30.988869+03
30419	33	-1	900	2020-07-01 19:04:32.168784+03
30420	84	-2	2700	2020-07-01 19:08:38.725379+03
30421	79	-2	550	2020-07-01 19:22:33.428289+03
30422	87	-1	2320	2020-07-01 19:23:17.354668+03
30423	71	-1	1030	2020-07-01 19:25:10.613332+03
30424	64	-1	970	2020-07-01 19:29:27.637559+03
30425	19	-2	1220	2020-07-01 19:45:21.624274+03
30426	95	-1	480	2020-07-01 19:52:02.651406+03
30427	11	21	469	2020-07-01 20:03:43.631346+03
30428	13	-1	460	2020-07-01 21:23:17.360012+03
30429	96	-1	1570	2020-07-01 21:33:51.303628+03
30430	64	-1	970	2020-07-01 21:37:53.705484+03
30431	6	-1	980	2020-07-01 21:39:57.647556+03
30432	71	-1	1030	2020-07-01 21:41:42.794588+03
30433	57	-1	1900	2020-07-01 21:47:41.141148+03
30434	95	-1	480	2020-07-01 21:54:05.673869+03
30435	84	-1	2700	2020-07-01 22:01:35.763777+03
30436	34	-1	1550	2020-07-01 22:04:28.833147+03
30437	46	-1	1270	2020-07-01 22:19:32.171905+03
30438	56	-1	2460	2020-07-01 22:21:06.138671+03
30439	83	-1	1230	2020-07-01 22:48:46.552757+03
30440	29	-1	1940	2020-07-01 23:29:40.961922+03
30441	45	-1	1590	2020-07-01 23:41:53.278322+03
30442	38	-2	1100	2020-07-01 23:45:14.738128+03
30443	12	-1	1650	2020-07-02 00:01:13.430328+03
30444	70	-1	760	2020-07-02 00:09:23.173293+03
30445	85	-1	730	2020-07-02 01:02:04.017122+03
30446	71	-1	1030	2020-07-02 01:06:31.197336+03
30447	13	-1	460	2020-07-02 02:36:24.315949+03
30448	7	-1	810	2020-07-02 02:41:27.728282+03
30449	92	-1	630	2020-07-02 03:07:11.253311+03
30450	13	-1	460	2020-07-02 03:08:25.376341+03
30451	2	-1	470	2020-07-02 03:16:52.238817+03
30452	20	-1	830	2020-07-02 03:25:05.762791+03
30453	18	-1	910	2020-07-02 03:42:26.095768+03
30454	87	-1	2320	2020-07-02 03:43:59.122381+03
30455	94	31	700	2020-07-02 04:06:18.850879+03
30456	20	-1	830	2020-07-02 04:35:10.628195+03
30457	25	-1	1100	2020-07-02 04:44:04.713749+03
30458	20	-1	830	2020-07-02 05:20:22.590654+03
30459	92	-1	630	2020-07-02 05:27:44.882586+03
30460	14	-1	1350	2020-07-02 06:03:41.067673+03
30461	23	-1	4390	2020-07-02 06:15:28.800631+03
30462	26	-2	390	2020-07-02 06:42:27.617964+03
30463	77	-1	640	2020-07-02 06:51:13.32828+03
30464	45	-1	1590	2020-07-02 06:59:15.239085+03
30465	37	-1	1290	2020-07-02 07:04:01.140671+03
30466	81	-1	1620	2020-07-02 07:13:05.140414+03
30467	61	-1	1510	2020-07-02 07:37:49.122055+03
30468	93	-2	1620	2020-07-02 07:53:52.867254+03
30469	82	-1	560	2020-07-02 08:05:12.918491+03
30470	34	-1	1550	2020-07-02 08:07:53.823841+03
30471	61	-2	1510	2020-07-02 08:08:00.245389+03
30472	28	-2	1860	2020-07-02 08:20:46.735827+03
30473	38	-2	1100	2020-07-02 08:22:07.504069+03
30474	20	-1	830	2020-07-02 08:31:26.397238+03
30475	19	-1	1220	2020-07-02 08:32:26.35175+03
30476	49	-1	970	2020-07-02 08:58:11.362018+03
30477	6	-1	980	2020-07-02 09:00:42.53602+03
30478	69	-1	1100	2020-07-02 09:29:49.957288+03
30479	31	-1	1190	2020-07-02 09:33:15.26151+03
30480	40	-1	1430	2020-07-02 09:55:10.654358+03
30481	86	-1	910	2020-07-02 10:06:27.028933+03
30482	1	-1	640	2020-07-02 10:10:58.799923+03
30483	9	-2	2090	2020-07-02 10:22:15.844722+03
30484	10	34	945	2020-07-02 10:28:39.671709+03
30485	33	-1	900	2020-07-02 10:47:20.848242+03
30486	67	-1	350	2020-07-02 10:48:03.187076+03
30487	66	-2	690	2020-07-02 10:54:17.309302+03
30488	77	-1	640	2020-07-02 10:59:11.105278+03
30489	65	-2	490	2020-07-02 11:05:38.39817+03
30490	58	-3	2830	2020-07-02 11:30:29.23573+03
30491	43	-1	380	2020-07-02 11:30:34.506116+03
30492	47	-1	1480	2020-07-02 11:30:39.778299+03
30493	9	-1	2090	2020-07-02 11:47:49.600758+03
30494	12	-1	1650	2020-07-02 12:05:53.344522+03
30495	40	-1	1430	2020-07-02 12:07:29.492573+03
30496	41	-1	830	2020-07-02 12:21:20.539588+03
30497	29	-2	1940	2020-07-02 12:43:37.13455+03
30498	88	-2	1270	2020-07-02 12:43:39.148973+03
30499	33	-2	900	2020-07-02 12:51:49.204037+03
30500	13	-1	460	2020-07-02 13:05:46.589159+03
30501	30	-1	1140	2020-07-02 13:08:12.316797+03
30502	74	-1	1010	2020-07-02 13:11:26.032877+03
30503	88	-1	1270	2020-07-02 13:33:24.970794+03
30504	59	-1	1030	2020-07-02 13:53:47.631749+03
30505	96	-1	1570	2020-07-02 14:13:34.550022+03
30506	42	-1	1790	2020-07-02 14:28:10.99601+03
30507	54	-1	3470	2020-07-02 14:52:50.917663+03
30508	44	-1	500	2020-07-02 15:01:05.88282+03
30509	19	-2	1220	2020-07-02 15:24:12.387558+03
30510	36	-1	630	2020-07-02 15:35:26.546195+03
30511	52	-1	1090	2020-07-02 15:48:12.844695+03
30512	30	-1	1140	2020-07-02 16:03:23.832676+03
30513	75	23	494	2020-07-02 16:35:56.24516+03
30514	45	-1	1590	2020-07-02 16:37:40.045381+03
30515	20	-1	830	2020-07-02 17:40:35.424841+03
30516	71	-1	1030	2020-07-02 17:55:22.513086+03
30517	88	-2	1270	2020-07-02 17:56:36.165178+03
30518	12	-1	1650	2020-07-02 18:05:01.733155+03
30519	93	-1	1620	2020-07-02 18:23:35.414994+03
30520	3	-1	660	2020-07-02 18:41:13.254782+03
30521	29	-1	1940	2020-07-02 18:49:17.591785+03
30522	22	-2	1070	2020-07-02 18:57:43.254166+03
30523	52	-2	1090	2020-07-02 18:58:38.717268+03
30524	47	50	855	2020-07-02 19:09:33.917936+03
30525	47	-1	1480	2020-07-02 19:48:53.195537+03
30526	26	-1	390	2020-07-02 21:06:18.627171+03
30527	90	-1	1780	2020-07-02 21:21:31.856939+03
30528	89	24	786	2020-07-02 21:28:33.85405+03
30529	94	-1	1230	2020-07-02 21:38:17.515634+03
30530	49	-2	970	2020-07-02 21:39:24.431923+03
30531	35	-1	670	2020-07-02 21:39:57.219261+03
30532	17	-2	1500	2020-07-02 21:44:34.215363+03
30533	20	-2	830	2020-07-02 21:49:15.211304+03
30534	47	-1	1480	2020-07-02 22:00:49.631931+03
30535	42	-1	1790	2020-07-02 22:06:58.146698+03
30536	31	-1	1190	2020-07-02 22:16:25.563349+03
30537	47	-2	1480	2020-07-02 22:57:39.276691+03
30538	19	-2	1220	2020-07-02 23:13:12.511319+03
30539	81	-1	1620	2020-07-02 23:27:17.566873+03
30540	46	-1	1270	2020-07-02 23:36:31.409205+03
30541	57	34	1020	2020-07-02 23:41:36.182574+03
30542	74	-1	1010	2020-07-02 23:43:28.289238+03
30543	8	-1	1920	2020-07-02 23:44:19.461077+03
30544	30	-2	1140	2020-07-02 23:59:29.439163+03
30545	4	-1	1420	2020-07-03 00:28:27.671183+03
30546	14	37	641	2020-07-03 00:44:25.685048+03
30547	91	-1	1620	2020-07-03 01:25:05.94995+03
30548	92	-2	630	2020-07-03 01:35:42.035251+03
30549	8	-2	1920	2020-07-03 02:00:21.762027+03
30550	10	-1	2080	2020-07-03 02:59:55.586078+03
30551	53	-1	3120	2020-07-03 03:00:20.688455+03
30552	6	-2	980	2020-07-03 03:06:19.247769+03
30553	37	-1	1290	2020-07-03 03:11:38.147176+03
30554	78	-1	900	2020-07-03 03:12:36.396025+03
30555	20	-1	830	2020-07-03 03:32:30.384+03
30556	42	-1	1790	2020-07-03 03:40:26.664647+03
30557	54	-1	3470	2020-07-03 03:43:08.313548+03
30558	35	-1	670	2020-07-03 04:00:11.787261+03
30559	56	-1	2460	2020-07-03 04:07:17.086603+03
30560	77	-1	640	2020-07-03 04:15:22.002238+03
30561	37	-1	1290	2020-07-03 04:18:55.429948+03
30562	18	-1	910	2020-07-03 04:24:21.951516+03
30563	77	-1	640	2020-07-03 04:39:18.612436+03
30564	16	-1	1380	2020-07-03 04:40:14.957581+03
30565	86	-1	910	2020-07-03 04:56:22.241685+03
30566	70	-1	760	2020-07-03 05:03:56.430177+03
30567	45	-1	1590	2020-07-03 05:19:55.229843+03
30568	12	-1	1650	2020-07-03 05:29:51.689348+03
30569	27	-2	880	2020-07-03 05:30:23.735142+03
30570	42	-2	1790	2020-07-03 05:52:17.089055+03
30571	4	-1	1420	2020-07-03 05:52:18.377872+03
30572	37	-2	1290	2020-07-03 06:01:41.896134+03
30573	77	-2	640	2020-07-03 06:04:11.278489+03
30574	85	-1	730	2020-07-03 06:12:41.140856+03
30575	34	-1	1550	2020-07-03 06:23:38.09114+03
30576	63	-1	1780	2020-07-03 06:47:34.975066+03
30577	4	-1	1420	2020-07-03 06:48:42.536097+03
30578	50	-2	1140	2020-07-03 06:56:43.007107+03
30579	35	-1	670	2020-07-03 07:01:19.121231+03
30580	11	-1	830	2020-07-03 07:08:19.024842+03
30581	64	-1	970	2020-07-03 07:29:32.014468+03
30582	39	-2	910	2020-07-03 07:34:22.130627+03
30583	63	-1	1780	2020-07-03 07:49:23.483949+03
30584	60	-1	2700	2020-07-03 07:49:45.936364+03
30585	47	-1	1480	2020-07-03 08:00:00.263137+03
30586	36	-1	630	2020-07-03 08:36:10.667236+03
30587	61	-1	1510	2020-07-03 08:45:36.96208+03
30588	95	-1	480	2020-07-03 09:00:42.328058+03
30589	30	-1	1140	2020-07-03 09:22:03.94066+03
30590	94	-1	1230	2020-07-03 09:41:03.238148+03
30591	93	-2	1620	2020-07-03 09:41:34.061589+03
30592	90	-1	1780	2020-07-03 10:00:07.577173+03
30593	48	-2	640	2020-07-03 10:06:31.649824+03
30594	62	-2	1220	2020-07-03 10:08:59.810646+03
30595	69	-1	1100	2020-07-03 10:54:07.901229+03
30596	77	-1	640	2020-07-03 11:09:06.516731+03
30597	65	-1	490	2020-07-03 11:15:32.895138+03
30598	19	-1	1220	2020-07-03 11:52:03.448283+03
30599	32	-1	710	2020-07-03 12:01:16.176693+03
30600	63	-2	1780	2020-07-03 12:14:38.518851+03
30601	40	-2	1430	2020-07-03 12:28:28.350232+03
30602	96	-1	1570	2020-07-03 12:49:28.836817+03
30603	46	-1	1270	2020-07-03 12:50:24.110594+03
30604	66	-1	690	2020-07-03 13:05:28.265565+03
30605	2	-1	470	2020-07-03 13:05:33.003326+03
30606	67	-1	350	2020-07-03 13:22:59.382766+03
30607	55	-1	3480	2020-07-03 13:27:25.111823+03
30608	53	-1	3120	2020-07-03 13:36:16.525206+03
30609	7	-1	810	2020-07-03 13:50:14.136197+03
30610	10	-1	2080	2020-07-03 13:55:39.431641+03
30611	4	-1	1420	2020-07-03 14:04:39.526827+03
30612	60	-1	2700	2020-07-03 14:36:53.278515+03
30613	88	-1	1270	2020-07-03 14:40:43.536507+03
30614	9	-1	2090	2020-07-03 15:21:24.02726+03
30615	55	-1	3480	2020-07-03 15:31:07.487544+03
30616	69	-1	1100	2020-07-03 15:33:20.390433+03
30617	76	-2	1070	2020-07-03 15:34:33.366551+03
30618	47	-1	1480	2020-07-03 15:35:39.413454+03
30619	22	-2	1070	2020-07-03 15:59:50.666055+03
30620	22	-1	1070	2020-07-03 16:04:05.393257+03
30621	42	-1	1790	2020-07-03 16:06:34.198248+03
30622	46	-1	1270	2020-07-03 16:25:10.207789+03
30623	4	-1	1420	2020-07-03 16:43:30.21706+03
30624	12	-1	1650	2020-07-03 16:44:17.074428+03
30625	89	-2	1420	2020-07-03 16:46:03.750883+03
30626	51	-1	1310	2020-07-03 17:07:12.10813+03
30627	22	-1	1070	2020-07-03 17:39:06.651001+03
30628	23	-1	4390	2020-07-03 17:43:42.687586+03
30629	92	-1	630	2020-07-03 17:57:20.177248+03
30630	21	-1	960	2020-07-03 18:12:59.368753+03
30631	70	-1	760	2020-07-03 18:40:43.823015+03
30632	23	-1	4390	2020-07-03 18:42:12.890665+03
30633	74	-2	1010	2020-07-03 18:50:58.017842+03
30634	58	-1	2830	2020-07-03 19:31:27.555434+03
30635	86	-1	910	2020-07-03 19:35:07.781733+03
30636	71	-1	1030	2020-07-03 19:46:19.914238+03
30637	71	-1	1030	2020-07-03 19:55:28.356537+03
30638	32	-1	710	2020-07-03 20:03:49.60485+03
30639	38	-1	1100	2020-07-03 20:39:39.528256+03
30640	83	-1	1230	2020-07-03 21:14:48.004411+03
30641	82	-1	560	2020-07-03 21:29:50.789861+03
30642	19	-2	1220	2020-07-03 21:42:07.523891+03
30643	93	-2	1620	2020-07-03 22:07:16.7732+03
30644	10	-1	2080	2020-07-03 22:35:01.894242+03
30645	29	-2	1940	2020-07-03 22:55:36.643622+03
30646	14	-2	1350	2020-07-03 23:28:51.571754+03
30647	3	-1	660	2020-07-03 23:47:09.225542+03
30648	60	-1	2700	2020-07-03 23:56:51.356158+03
30649	65	-1	490	2020-07-04 00:00:03.572985+03
30650	27	-1	880	2020-07-04 00:03:08.782853+03
30651	62	-1	1220	2020-07-04 00:55:40.873146+03
30652	70	-1	760	2020-07-04 00:55:44.651284+03
30653	10	-1	2080	2020-07-04 01:04:30.176032+03
30654	59	-2	1030	2020-07-04 01:23:50.225036+03
30655	88	34	664	2020-07-04 01:27:10.248411+03
30656	62	-1	1220	2020-07-04 01:27:44.811244+03
30657	21	21	524	2020-07-04 01:45:55.468501+03
30658	21	-1	960	2020-07-04 02:04:19.776653+03
30659	47	-1	1480	2020-07-04 02:07:56.861551+03
30660	53	-1	3120	2020-07-04 03:04:38.016727+03
30661	49	-1	970	2020-07-04 03:20:42.167889+03
30662	41	-1	830	2020-07-04 03:46:11.09155+03
30663	11	-1	830	2020-07-04 04:43:03.682248+03
30664	89	-1	1420	2020-07-04 04:55:33.479019+03
30665	22	-1	1070	2020-07-04 04:55:49.583809+03
30666	93	-2	1620	2020-07-04 04:58:23.653784+03
30667	67	-2	350	2020-07-04 05:42:00.958168+03
30668	26	-1	390	2020-07-04 05:48:36.169996+03
30669	6	-1	980	2020-07-04 05:50:19.991639+03
30670	34	-1	1550	2020-07-04 05:56:02.917041+03
30671	61	-1	1510	2020-07-04 06:23:19.17116+03
30672	76	-1	1070	2020-07-04 07:10:03.460341+03
30673	12	-1	1650	2020-07-04 07:32:03.972678+03
30674	34	-1	1550	2020-07-04 08:13:29.713065+03
30675	22	-1	1070	2020-07-04 08:18:05.766524+03
30676	63	-1	1780	2020-07-04 08:21:11.514842+03
30677	5	-2	1620	2020-07-04 08:43:15.790701+03
30678	86	-1	910	2020-07-04 08:49:25.869601+03
30679	55	-1	3480	2020-07-04 08:50:36.887732+03
30680	39	-1	910	2020-07-04 08:56:02.006672+03
30681	6	-1	980	2020-07-04 09:06:07.591536+03
30682	34	-1	1550	2020-07-04 09:13:54.422697+03
30683	71	-1	1030	2020-07-04 09:27:54.137771+03
30684	87	-1	2320	2020-07-04 09:37:09.138241+03
30685	43	-1	380	2020-07-04 09:45:29.686992+03
30686	21	-1	960	2020-07-04 09:54:07.338862+03
30687	80	-1	1120	2020-07-04 10:08:29.890265+03
30688	7	-1	810	2020-07-04 10:15:22.738552+03
30689	24	-1	950	2020-07-04 10:16:07.314963+03
30690	17	-1	1500	2020-07-04 10:17:13.104175+03
30691	90	-1	1780	2020-07-04 10:18:21.020551+03
30692	5	-1	1620	2020-07-04 10:39:35.277982+03
30693	68	-1	490	2020-07-04 10:47:31.373406+03
30694	92	-1	630	2020-07-04 10:47:58.520809+03
30695	21	-1	960	2020-07-04 11:14:43.491794+03
30696	56	-2	2460	2020-07-04 11:55:26.823584+03
30697	93	-1	1620	2020-07-04 12:07:51.484804+03
30698	1	-1	640	2020-07-04 12:08:26.98047+03
30699	63	-1	1780	2020-07-04 12:09:19.467095+03
30700	79	-1	550	2020-07-04 12:56:16.701285+03
30701	87	-1	2320	2020-07-04 12:58:07.66978+03
30702	49	-1	970	2020-07-04 12:58:26.843879+03
30703	40	-1	1430	2020-07-04 13:08:08.470186+03
30704	44	-1	500	2020-07-04 13:22:06.315684+03
30705	38	-1	1100	2020-07-04 13:29:05.42341+03
30706	47	-1	1480	2020-07-04 13:34:40.577151+03
30707	35	-1	670	2020-07-04 13:38:03.378196+03
30708	96	-1	1570	2020-07-04 13:43:04.36241+03
30709	40	-1	1430	2020-07-04 13:57:53.623375+03
30710	25	-1	1100	2020-07-04 14:01:43.950913+03
30711	37	-1	1290	2020-07-04 14:05:40.176119+03
30712	77	-1	640	2020-07-04 14:11:28.593518+03
30713	67	-2	350	2020-07-04 14:15:53.3011+03
30714	74	-1	1010	2020-07-04 14:58:09.492297+03
30715	82	-1	560	2020-07-04 15:00:32.270237+03
30716	43	-1	380	2020-07-04 15:44:03.304359+03
30717	93	-1	1620	2020-07-04 16:10:57.347805+03
30718	19	-1	1220	2020-07-04 16:12:56.870505+03
30719	67	-1	350	2020-07-04 16:50:18.955858+03
30720	73	-1	960	2020-07-04 16:51:35.423535+03
30721	6	-1	980	2020-07-04 17:17:45.118727+03
30722	38	-1	1100	2020-07-04 17:26:16.271503+03
30723	55	-1	3480	2020-07-04 18:07:06.785885+03
30724	64	-1	970	2020-07-04 18:16:25.868965+03
30725	80	-2	1120	2020-07-04 18:26:42.597825+03
30726	40	-1	1430	2020-07-04 18:32:39.415552+03
30727	36	-1	630	2020-07-04 18:34:15.296584+03
30728	85	-1	730	2020-07-04 19:14:26.970273+03
30729	22	-1	1070	2020-07-04 19:22:41.637147+03
30730	6	-1	980	2020-07-04 19:33:34.642829+03
30731	12	-1	1650	2020-07-04 19:33:36.183883+03
30732	54	-1	3470	2020-07-04 20:06:25.979674+03
30733	7	-2	810	2020-07-04 20:07:28.778182+03
30734	20	-2	830	2020-07-04 20:07:51.444723+03
30735	54	-1	3470	2020-07-04 20:33:58.814015+03
30736	3	-1	660	2020-07-04 20:35:30.315246+03
30737	44	-1	500	2020-07-04 21:05:23.689421+03
30738	12	-1	1650	2020-07-04 21:15:31.029317+03
30739	33	-1	900	2020-07-04 21:25:12.421143+03
30740	5	-1	1620	2020-07-04 21:27:35.995568+03
30741	88	-1	1270	2020-07-04 21:34:04.782125+03
30742	61	-1	1510	2020-07-04 21:44:25.396234+03
30743	69	-2	1100	2020-07-04 22:19:25.808395+03
30744	53	-1	3120	2020-07-04 22:25:30.330919+03
30745	50	18	520	2020-07-04 22:33:25.75313+03
30746	13	37	215	2020-07-04 22:45:33.629061+03
30747	19	-1	1220	2020-07-04 22:50:12.287322+03
30748	70	-1	760	2020-07-04 23:57:15.340044+03
30749	7	-1	810	2020-07-05 00:08:14.690847+03
30750	94	-1	1230	2020-07-05 00:10:47.177824+03
30751	55	-1	3480	2020-07-05 00:35:25.743457+03
30752	9	-1	2090	2020-07-05 00:43:40.469276+03
30753	40	-1	1430	2020-07-05 01:12:26.373591+03
30754	14	-2	1350	2020-07-05 01:31:36.103873+03
30755	27	-1	880	2020-07-05 01:34:49.013161+03
30756	25	-1	1100	2020-07-05 01:42:37.968239+03
30757	73	-1	960	2020-07-05 02:03:02.620058+03
30758	74	-1	1010	2020-07-05 02:04:06.494769+03
30759	59	-2	1030	2020-07-05 02:12:31.072092+03
30760	82	-2	560	2020-07-05 02:19:47.707896+03
30761	74	-1	1010	2020-07-05 02:20:35.255092+03
30762	63	-1	1780	2020-07-05 02:27:02.763309+03
30763	6	-1	980	2020-07-05 03:14:36.120324+03
30764	8	-1	1920	2020-07-05 03:29:40.721844+03
30765	71	-1	1030	2020-07-05 03:34:34.055066+03
30766	29	-1	1940	2020-07-05 04:09:25.828586+03
30767	5	-1	1620	2020-07-05 04:49:00.157246+03
30768	37	39	724	2020-07-05 05:02:45.743464+03
30769	79	-1	550	2020-07-05 05:34:56.369469+03
30770	54	-2	3470	2020-07-05 05:43:38.569454+03
30771	42	-1	1790	2020-07-05 06:36:34.328143+03
30772	70	21	399	2020-07-05 06:37:59.540577+03
30773	48	-1	640	2020-07-05 06:40:11.503001+03
30774	38	24	646	2020-07-05 06:50:25.32939+03
30775	6	-2	980	2020-07-05 06:54:26.316504+03
30776	59	-1	1030	2020-07-05 06:58:48.562673+03
30777	33	-2	900	2020-07-05 07:02:17.457873+03
30778	27	-1	880	2020-07-05 07:07:30.617996+03
30779	13	-1	460	2020-07-05 07:18:04.538418+03
30780	5	-1	1620	2020-07-05 07:43:09.442923+03
30781	64	-2	970	2020-07-05 08:00:31.047858+03
30782	11	-1	830	2020-07-05 08:09:28.034126+03
30783	48	-1	640	2020-07-05 09:03:32.407982+03
30784	80	-1	1120	2020-07-05 09:04:33.396892+03
30785	48	-1	640	2020-07-05 09:24:40.625623+03
30786	42	-1	1790	2020-07-05 09:29:01.742548+03
30787	81	-1	1620	2020-07-05 09:38:01.43938+03
30788	71	-1	1030	2020-07-05 09:48:09.247674+03
30789	17	-2	1500	2020-07-05 10:02:54.138766+03
30790	92	-1	630	2020-07-05 10:13:52.319768+03
30791	9	-1	2090	2020-07-05 10:35:54.129468+03
30792	70	-1	760	2020-07-05 10:46:07.92424+03
30793	43	-1	380	2020-07-05 10:51:25.313872+03
30794	30	-1	1140	2020-07-05 10:59:20.119366+03
30795	33	-1	900	2020-07-05 10:59:43.788769+03
30796	53	-1	3120	2020-07-05 11:10:35.285964+03
30797	17	25	638	2020-07-05 11:17:46.273678+03
30798	62	-1	1220	2020-07-05 11:23:01.779042+03
30799	81	-1	1620	2020-07-05 11:47:44.438173+03
30800	18	-2	910	2020-07-05 11:59:24.803256+03
30801	51	-2	1310	2020-07-05 12:18:42.448708+03
30802	69	-1	1100	2020-07-05 12:20:26.045477+03
30803	51	-2	1310	2020-07-05 12:25:22.02857+03
30804	44	-1	500	2020-07-05 12:25:30.395346+03
30805	59	-2	1030	2020-07-05 12:43:19.716948+03
30806	34	-1	1550	2020-07-05 12:57:53.482961+03
30807	80	-1	1120	2020-07-05 13:10:57.257277+03
30808	9	-1	2090	2020-07-05 13:29:45.025744+03
30809	34	-1	1550	2020-07-05 13:44:38.642562+03
30810	47	-1	1480	2020-07-05 13:46:05.635845+03
30811	3	-1	660	2020-07-05 13:46:34.731993+03
30812	91	-1	1620	2020-07-05 13:57:43.668141+03
30813	33	-1	900	2020-07-05 14:08:33.773611+03
30814	57	-1	1900	2020-07-05 14:28:38.737357+03
30815	28	-1	1860	2020-07-05 14:40:11.079344+03
30816	4	-1	1420	2020-07-05 14:45:34.338691+03
30817	96	35	784	2020-07-05 15:14:59.183468+03
30818	61	-1	1510	2020-07-05 15:16:20.453996+03
30819	41	-1	830	2020-07-05 15:19:41.106921+03
30820	30	-1	1140	2020-07-05 15:23:58.720168+03
30821	88	-1	1270	2020-07-05 15:26:19.635191+03
30822	20	-1	830	2020-07-05 15:45:16.827085+03
30823	90	-1	1780	2020-07-05 15:47:08.882067+03
30824	76	-2	1070	2020-07-05 15:55:13.577803+03
30825	9	-2	2090	2020-07-05 15:55:21.497552+03
30826	35	-1	670	2020-07-05 16:13:23.703443+03
30827	43	-1	380	2020-07-05 16:41:18.095081+03
30828	67	-1	350	2020-07-05 16:47:17.317526+03
30829	71	-1	1030	2020-07-05 16:55:14.699415+03
30830	6	-1	980	2020-07-05 16:56:09.667328+03
30831	89	-2	1420	2020-07-05 17:13:09.745046+03
30832	93	-1	1620	2020-07-05 17:34:49.666257+03
30833	49	-3	970	2020-07-05 17:54:49.138008+03
30834	63	-2	1780	2020-07-05 17:58:03.505184+03
30835	55	-2	3480	2020-07-05 18:47:05.497484+03
30836	40	-1	1430	2020-07-05 18:48:05.146984+03
30837	54	-1	3470	2020-07-05 19:17:08.974915+03
30838	32	-1	710	2020-07-05 19:21:28.386206+03
30839	50	-1	1140	2020-07-05 19:28:56.810883+03
30840	71	-1	1030	2020-07-05 19:34:38.474009+03
30841	73	-2	960	2020-07-05 19:59:56.324731+03
30842	7	-1	810	2020-07-05 20:41:41.704246+03
30843	47	-1	1480	2020-07-05 21:26:37.440042+03
30844	71	-1	1030	2020-07-05 21:45:41.26414+03
30845	48	-1	640	2020-07-05 21:46:15.617855+03
30846	51	-1	1310	2020-07-05 22:08:50.248818+03
30847	78	-1	900	2020-07-05 22:19:07.393618+03
30848	15	-2	2830	2020-07-05 22:41:05.52832+03
30849	12	-1	1650	2020-07-05 22:42:26.482983+03
30850	27	-1	880	2020-07-05 22:43:36.024478+03
30851	83	-2	1230	2020-07-05 22:48:25.253333+03
30852	50	-1	1140	2020-07-05 23:02:08.448971+03
30853	20	-1	830	2020-07-05 23:04:03.036622+03
30854	96	-1	1570	2020-07-05 23:22:21.833205+03
30855	40	-1	1430	2020-07-05 23:51:14.9788+03
30856	67	-1	350	2020-07-06 00:39:04.512609+03
30857	47	-1	1480	2020-07-06 00:42:46.868873+03
30858	29	-1	1940	2020-07-06 00:58:35.375637+03
30859	56	-1	2460	2020-07-06 01:24:09.17273+03
30860	30	-1	1140	2020-07-06 01:54:43.600026+03
30861	5	-1	1620	2020-07-06 02:21:57.887618+03
30862	3	-1	660	2020-07-06 02:53:48.849925+03
30863	12	52	773	2020-07-06 03:06:26.613361+03
30864	12	-1	1650	2020-07-06 03:06:50.451257+03
30865	71	-1	1030	2020-07-06 03:32:00.74499+03
30866	87	-2	2320	2020-07-06 03:51:26.271889+03
30867	38	-1	1100	2020-07-06 04:42:55.472091+03
30868	18	-1	910	2020-07-06 05:05:32.9104+03
30869	76	-1	1070	2020-07-06 05:13:41.627836+03
30870	38	-1	1100	2020-07-06 05:16:56.74932+03
30871	7	-1	810	2020-07-06 05:18:21.524984+03
30872	50	-1	1140	2020-07-06 05:24:51.031544+03
30873	18	-2	910	2020-07-06 06:58:49.476072+03
30874	53	-1	3120	2020-07-06 07:19:42.032663+03
30875	92	-1	630	2020-07-06 07:32:30.424173+03
30876	64	-2	970	2020-07-06 07:48:48.509818+03
30877	8	-1	1920	2020-07-06 08:03:36.55689+03
30878	81	-1	1620	2020-07-06 08:09:49.865153+03
30879	74	-2	1010	2020-07-06 08:38:13.7391+03
30880	85	-1	730	2020-07-06 09:02:48.195326+03
30881	65	-1	490	2020-07-06 09:21:30.207828+03
30882	11	-1	830	2020-07-06 09:53:47.733896+03
30883	41	-1	830	2020-07-06 09:59:38.476844+03
30884	40	-1	1430	2020-07-06 10:01:55.125567+03
30885	42	-1	1790	2020-07-06 10:03:54.093079+03
30886	63	-1	1780	2020-07-06 10:30:20.41191+03
30887	93	-1	1620	2020-07-06 10:42:53.025543+03
30888	46	-1	1270	2020-07-06 10:59:45.37514+03
30889	29	-1	1940	2020-07-06 11:05:04.376294+03
30890	2	-1	470	2020-07-06 11:05:58.109579+03
30891	48	-1	640	2020-07-06 11:26:11.456541+03
30892	79	-2	550	2020-07-06 11:26:54.491433+03
30893	39	-1	910	2020-07-06 12:01:00.784435+03
30894	6	40	476	2020-07-06 12:03:28.085829+03
30895	35	-1	670	2020-07-06 12:08:29.733211+03
30896	39	-1	910	2020-07-06 12:44:02.393241+03
30897	25	-1	1100	2020-07-06 12:49:01.087539+03
30898	45	-1	1590	2020-07-06 12:56:37.828099+03
30899	32	-2	710	2020-07-06 12:59:03.373509+03
30900	26	-1	390	2020-07-06 13:15:45.757003+03
30901	54	-1	3470	2020-07-06 13:16:52.568759+03
30902	57	-1	1900	2020-07-06 13:18:47.185636+03
30903	74	27	551	2020-07-06 13:31:47.706692+03
30904	89	-1	1420	2020-07-06 13:41:29.990199+03
30905	1	-1	640	2020-07-06 13:59:03.72969+03
30906	40	-2	1430	2020-07-06 14:08:30.595024+03
30907	54	-2	3470	2020-07-06 15:22:24.68061+03
30908	49	-1	970	2020-07-06 15:26:00.288946+03
30909	37	-1	1290	2020-07-06 15:40:27.208242+03
30910	30	-1	1140	2020-07-06 15:43:27.966028+03
30911	12	-2	1650	2020-07-06 15:58:19.020316+03
30912	49	-1	970	2020-07-06 16:08:36.720096+03
30913	14	-2	1350	2020-07-06 16:12:11.954689+03
30914	22	-1	1070	2020-07-06 16:25:23.767713+03
30915	45	25	850	2020-07-06 16:26:39.065835+03
30916	78	-1	900	2020-07-06 17:03:52.723057+03
30917	32	-1	710	2020-07-06 17:16:01.938467+03
30918	56	-2	2460	2020-07-06 17:19:51.928427+03
30919	35	-1	670	2020-07-06 17:21:53.51101+03
30920	49	-1	970	2020-07-06 17:24:40.742412+03
30921	91	-1	1620	2020-07-06 17:54:57.329648+03
30922	88	-1	1270	2020-07-06 18:12:51.679563+03
30923	76	-2	1070	2020-07-06 18:14:54.633868+03
30924	86	-1	910	2020-07-06 18:19:21.991631+03
30925	49	-1	970	2020-07-06 18:20:23.534612+03
30926	53	-1	3120	2020-07-06 18:25:34.455544+03
30927	52	-1	1090	2020-07-06 18:33:15.64237+03
30928	31	-2	1190	2020-07-06 19:02:35.144907+03
30929	55	-1	3480	2020-07-06 19:16:09.216612+03
30930	76	-1	1070	2020-07-06 19:21:30.788536+03
30931	21	-1	960	2020-07-06 20:01:03.492969+03
30932	88	-1	1270	2020-07-06 20:15:18.283004+03
30933	10	-1	2080	2020-07-06 20:27:36.596846+03
30934	60	-1	2700	2020-07-06 20:39:15.837512+03
30935	49	-2	970	2020-07-06 20:50:57.627391+03
30936	67	-2	350	2020-07-06 21:08:00.035403+03
30937	93	-1	1620	2020-07-06 21:21:30.563597+03
30938	63	-1	1780	2020-07-06 21:29:31.553434+03
30939	45	-1	1590	2020-07-06 22:46:46.278056+03
30940	16	-1	1380	2020-07-06 23:12:18.303919+03
30941	24	-2	950	2020-07-06 23:48:20.878507+03
30942	89	-1	1420	2020-07-07 00:58:21.223603+03
30943	68	-1	490	2020-07-07 01:05:39.485665+03
30944	64	-1	970	2020-07-07 01:20:59.602513+03
30945	95	-1	480	2020-07-07 01:27:43.154259+03
30946	4	-1	1420	2020-07-07 01:59:01.738419+03
30947	43	-1	380	2020-07-07 02:02:56.421214+03
30948	42	-1	1790	2020-07-07 02:41:03.68609+03
30949	86	-1	910	2020-07-07 02:44:40.961833+03
30950	20	-1	830	2020-07-07 02:55:13.148816+03
30951	89	-1	1420	2020-07-07 03:09:10.204441+03
30952	71	-1	1030	2020-07-07 03:13:02.886749+03
30953	56	-1	2460	2020-07-07 03:23:59.904448+03
30954	17	-1	1500	2020-07-07 03:24:00.050494+03
30955	95	-1	480	2020-07-07 03:32:44.580292+03
30956	77	-1	640	2020-07-07 03:37:09.842648+03
30957	28	-2	1860	2020-07-07 04:04:25.172558+03
30958	60	-1	2700	2020-07-07 04:14:49.630626+03
30959	90	-1	1780	2020-07-07 04:23:28.182004+03
30960	64	28	471	2020-07-07 04:27:13.028731+03
30961	73	-1	960	2020-07-07 04:46:36.428+03
30962	87	-2	2320	2020-07-07 04:53:36.972018+03
30963	37	-2	1290	2020-07-07 05:00:24.225744+03
30964	34	-1	1550	2020-07-07 05:02:21.440911+03
30965	50	-1	1140	2020-07-07 05:15:33.605547+03
30966	64	-1	970	2020-07-07 05:42:08.2656+03
30967	13	-1	460	2020-07-07 05:49:02.958003+03
30968	54	36	1619	2020-07-07 06:17:37.499136+03
30969	77	-1	640	2020-07-07 06:34:10.198755+03
30970	31	-1	1190	2020-07-07 06:57:36.684422+03
30971	77	-1	640	2020-07-07 07:12:56.014374+03
30972	32	-1	710	2020-07-07 07:24:10.445312+03
30973	30	-1	1140	2020-07-07 07:45:02.424388+03
30974	14	-1	1350	2020-07-07 07:53:53.588467+03
30975	94	-1	1230	2020-07-07 08:05:36.551132+03
30976	84	-1	2700	2020-07-07 08:21:39.811945+03
30977	4	-1	1420	2020-07-07 08:28:45.994902+03
30978	19	26	575	2020-07-07 08:31:23.805944+03
30979	25	-1	1100	2020-07-07 08:40:44.64039+03
30980	73	-1	960	2020-07-07 09:02:02.63295+03
30981	33	-2	900	2020-07-07 09:05:45.393026+03
30982	56	-1	2460	2020-07-07 09:09:01.412154+03
30983	90	-1	1780	2020-07-07 09:09:42.461803+03
30984	51	-2	1310	2020-07-07 09:10:07.623968+03
30985	3	-1	660	2020-07-07 09:33:56.842455+03
30986	50	-2	1140	2020-07-07 09:35:31.849908+03
30987	29	-1	1940	2020-07-07 09:40:24.764953+03
30988	30	-2	1140	2020-07-07 09:54:57.833244+03
30989	4	-1	1420	2020-07-07 10:00:26.098023+03
30990	54	-1	3470	2020-07-07 10:10:41.937044+03
30991	12	-1	1650	2020-07-07 10:21:06.59684+03
30992	86	-3	910	2020-07-07 10:47:01.817374+03
30993	14	-1	1350	2020-07-07 10:50:57.868045+03
30994	77	-1	640	2020-07-07 11:13:04.495675+03
30995	23	-2	4390	2020-07-07 11:44:26.139861+03
30996	51	-1	1310	2020-07-07 12:11:22.357622+03
30997	71	-1	1030	2020-07-07 12:33:00.036023+03
30998	64	-2	970	2020-07-07 12:47:29.397282+03
30999	3	-1	660	2020-07-07 13:13:32.14505+03
31000	39	-1	910	2020-07-07 13:23:19.593002+03
31001	23	-1	4390	2020-07-07 13:26:06.78284+03
31002	46	-1	1270	2020-07-07 13:52:32.767217+03
31003	96	-1	1570	2020-07-07 14:07:41.272092+03
31004	31	-1	1190	2020-07-07 14:23:26.147287+03
31005	93	-2	1620	2020-07-07 14:26:40.622598+03
31006	67	-2	350	2020-07-07 14:49:02.775115+03
31007	73	22	460	2020-07-07 14:49:21.156005+03
31008	49	-2	970	2020-07-07 15:11:33.401797+03
31009	9	-1	2090	2020-07-07 15:20:59.56621+03
31010	20	-1	830	2020-07-07 15:28:45.825417+03
31011	58	-1	2830	2020-07-07 15:47:39.386715+03
31012	66	-1	690	2020-07-07 15:58:44.718658+03
31013	21	-1	960	2020-07-07 16:30:32.060139+03
31014	81	-2	1620	2020-07-07 16:50:46.810245+03
31015	45	-1	1590	2020-07-07 17:22:54.291369+03
31016	22	-1	1070	2020-07-07 17:30:06.430634+03
31017	35	-1	670	2020-07-07 17:57:48.717279+03
31018	96	-1	1570	2020-07-07 18:07:02.406159+03
31019	41	-2	830	2020-07-07 18:14:54.83783+03
31020	52	-2	1090	2020-07-07 18:17:42.227608+03
31021	75	-1	830	2020-07-07 18:24:03.069262+03
31022	56	-1	2460	2020-07-07 18:39:49.822118+03
31023	29	-1	1940	2020-07-07 18:45:08.862892+03
31024	39	-2	910	2020-07-07 18:48:35.747467+03
31025	50	-1	1140	2020-07-07 19:09:02.318799+03
31026	46	-1	1270	2020-07-07 19:10:57.759928+03
31027	18	-1	910	2020-07-07 19:23:46.77779+03
31028	96	-1	1570	2020-07-07 19:29:20.169556+03
31029	86	-1	910	2020-07-07 19:44:33.400105+03
31030	42	-2	1790	2020-07-07 19:53:23.934209+03
31031	14	-2	1350	2020-07-07 19:59:18.530897+03
31032	17	-2	1500	2020-07-07 20:03:35.975951+03
31033	32	-1	710	2020-07-07 20:15:56.614964+03
31034	80	-1	1120	2020-07-07 20:18:19.60169+03
31035	63	-1	1780	2020-07-07 20:25:15.82266+03
31036	14	-1	1350	2020-07-07 20:25:52.975623+03
31037	25	-1	1100	2020-07-07 20:30:14.192496+03
31038	65	-1	490	2020-07-07 20:54:34.116237+03
31039	28	-1	1860	2020-07-07 21:23:15.807775+03
31040	74	-1	1010	2020-07-07 21:42:45.749766+03
31041	52	-1	1090	2020-07-07 21:55:06.155049+03
31042	14	-1	1350	2020-07-07 21:59:31.093927+03
31043	12	-2	1650	2020-07-07 22:00:00.946298+03
31044	28	-1	1860	2020-07-07 22:02:19.303089+03
31045	3	-1	660	2020-07-07 22:23:26.806166+03
31046	51	-1	1310	2020-07-07 22:36:26.224083+03
31047	46	-1	1270	2020-07-07 22:40:39.772654+03
31048	5	-1	1620	2020-07-07 22:49:40.614009+03
31049	67	-1	350	2020-07-07 23:00:07.252666+03
31050	12	-1	1650	2020-07-07 23:09:56.846859+03
31051	51	-1	1310	2020-07-07 23:31:42.062759+03
31052	37	-1	1290	2020-07-07 23:38:27.331438+03
31053	54	-1	3470	2020-07-07 23:53:36.691853+03
31054	14	-1	1350	2020-07-08 00:23:21.848698+03
31055	77	-1	640	2020-07-08 01:07:17.970362+03
31056	78	-1	900	2020-07-08 02:03:20.268504+03
31057	5	-1	1620	2020-07-08 02:08:31.93131+03
31058	71	-2	1030	2020-07-08 02:12:43.30352+03
31059	40	-1	1430	2020-07-08 02:27:01.750976+03
31060	18	-1	910	2020-07-08 02:42:45.350343+03
31061	31	-1	1190	2020-07-08 03:01:43.301481+03
31062	38	-1	1100	2020-07-08 03:22:27.817916+03
31063	48	-1	640	2020-07-08 03:24:32.399631+03
31064	1	-1	640	2020-07-08 03:32:20.408226+03
31065	90	-1	1780	2020-07-08 04:15:32.376797+03
31066	80	-2	1120	2020-07-08 04:28:41.475558+03
31067	33	-1	900	2020-07-08 04:29:59.663102+03
31068	47	-1	1480	2020-07-08 04:35:04.455726+03
31069	87	-2	2320	2020-07-08 04:39:42.996775+03
31070	87	-1	2320	2020-07-08 04:43:55.256435+03
31071	67	-1	350	2020-07-08 05:17:09.008908+03
31072	40	31	825	2020-07-08 05:28:02.835514+03
31073	80	-1	1120	2020-07-08 05:31:18.599672+03
31074	91	-2	1620	2020-07-08 05:32:41.363418+03
31075	77	-1	640	2020-07-08 05:49:56.78205+03
31076	91	-1	1620	2020-07-08 05:50:56.10503+03
31077	96	-1	1570	2020-07-08 05:58:30.290582+03
31078	12	-1	1650	2020-07-08 06:03:01.421707+03
31079	4	-1	1420	2020-07-08 06:15:55.019534+03
31080	64	-1	970	2020-07-08 07:39:19.388936+03
31081	7	-1	810	2020-07-08 07:47:58.803535+03
31082	74	-1	1010	2020-07-08 07:48:11.065358+03
31083	5	-1	1620	2020-07-08 07:56:08.684621+03
31084	39	-1	910	2020-07-08 08:24:51.923443+03
31085	80	-2	1120	2020-07-08 08:43:40.899725+03
31086	4	-1	1420	2020-07-08 08:55:34.760564+03
31087	18	-1	910	2020-07-08 08:58:11.683827+03
31088	20	-2	830	2020-07-08 08:59:43.367123+03
31089	78	-2	900	2020-07-08 09:18:48.701315+03
31090	8	-1	1920	2020-07-08 09:49:37.821687+03
31091	33	-2	900	2020-07-08 09:57:33.941194+03
31092	20	-1	830	2020-07-08 10:14:47.113685+03
31093	28	-1	1860	2020-07-08 10:32:16.716709+03
31094	90	-1	1780	2020-07-08 10:32:43.705398+03
31095	15	-2	2830	2020-07-08 10:56:30.441477+03
31096	56	-1	2460	2020-07-08 11:29:27.637046+03
31097	29	-1	1940	2020-07-08 11:30:01.169299+03
31098	18	-1	910	2020-07-08 11:51:31.522668+03
31099	4	-2	1420	2020-07-08 12:01:07.556897+03
31100	95	-1	480	2020-07-08 12:09:13.25847+03
31101	23	-1	4390	2020-07-08 12:29:30.686436+03
31102	92	-1	630	2020-07-08 14:16:48.800924+03
31103	49	-1	970	2020-07-08 14:43:30.320677+03
31104	90	-1	1780	2020-07-08 14:49:40.695176+03
31105	7	-1	810	2020-07-08 15:03:10.189997+03
31106	4	-1	1420	2020-07-08 15:03:18.550475+03
31107	31	-2	1190	2020-07-08 15:08:06.616389+03
31108	96	-1	1570	2020-07-08 15:19:12.204032+03
31109	23	-1	4390	2020-07-08 15:47:06.472381+03
31110	17	-1	1500	2020-07-08 15:52:20.882114+03
31111	20	-1	830	2020-07-08 15:59:33.587417+03
31112	55	-1	3480	2020-07-08 16:12:14.0794+03
31113	67	-1	350	2020-07-08 16:31:14.034284+03
31114	65	-1	490	2020-07-08 16:39:12.624869+03
31115	47	-1	1480	2020-07-08 16:44:22.507455+03
31116	79	-1	550	2020-07-08 17:05:19.21418+03
31117	51	23	778	2020-07-08 17:14:29.359257+03
31118	36	-2	630	2020-07-08 17:19:44.859148+03
31119	32	-1	710	2020-07-08 17:25:04.167377+03
31120	8	-1	1920	2020-07-08 18:08:00.238957+03
31121	22	-1	1070	2020-07-08 18:10:28.651303+03
31122	38	-1	1100	2020-07-08 18:18:09.072973+03
31123	12	-1	1650	2020-07-08 18:22:57.964609+03
31124	83	-1	1230	2020-07-08 18:32:53.421482+03
31125	24	-1	950	2020-07-08 18:38:29.486517+03
31126	89	-1	1420	2020-07-08 18:38:42.672364+03
31127	3	18	341	2020-07-08 18:44:35.674605+03
31128	22	-1	1070	2020-07-08 18:47:13.254775+03
31129	84	-1	2700	2020-07-08 19:37:37.961734+03
31130	35	-1	670	2020-07-08 19:52:07.039623+03
31131	54	-2	3470	2020-07-08 20:14:49.602163+03
31132	65	-1	490	2020-07-08 20:18:35.118888+03
31133	4	-1	1420	2020-07-08 20:46:00.710597+03
31134	10	-1	2080	2020-07-08 21:06:18.228314+03
31135	29	-1	1940	2020-07-08 21:15:52.767408+03
31136	38	-1	1100	2020-07-08 21:34:28.920662+03
31137	18	-1	910	2020-07-08 21:46:10.162358+03
31138	37	-1	1290	2020-07-08 21:47:13.278749+03
31139	90	-1	1780	2020-07-08 21:54:01.855816+03
31140	89	-2	1420	2020-07-08 21:55:46.16899+03
31141	22	-1	1070	2020-07-08 21:59:00.745322+03
31142	20	-1	830	2020-07-08 22:20:18.704234+03
31143	94	-1	1230	2020-07-08 22:27:43.023538+03
31144	34	-1	1550	2020-07-08 22:29:27.929309+03
31145	25	-1	1100	2020-07-08 22:50:59.686163+03
31146	64	-1	970	2020-07-08 22:55:47.069275+03
31147	37	-1	1290	2020-07-08 23:10:19.366919+03
31148	3	-1	660	2020-07-08 23:18:10.94126+03
31149	48	-2	640	2020-07-08 23:18:50.467672+03
31150	90	-1	1780	2020-07-08 23:35:14.746868+03
31151	39	-1	910	2020-07-09 00:03:51.836398+03
31152	56	-2	2460	2020-07-09 00:09:49.131094+03
31153	1	-2	640	2020-07-09 00:40:31.086595+03
31154	69	-1	1100	2020-07-09 01:00:13.435777+03
31155	14	-1	1350	2020-07-09 01:43:11.198272+03
31156	46	-1	1270	2020-07-09 01:59:49.853681+03
31157	46	-1	1270	2020-07-09 02:01:41.744568+03
31158	87	-1	2320	2020-07-09 02:14:42.908419+03
31159	92	-2	630	2020-07-09 02:25:21.482395+03
31160	91	-1	1620	2020-07-09 02:36:26.725977+03
31161	81	-1	1620	2020-07-09 02:36:54.586271+03
31162	70	-1	760	2020-07-09 03:13:26.621217+03
31163	84	-1	2700	2020-07-09 03:18:42.311971+03
31164	23	-1	4390	2020-07-09 03:50:39.487767+03
31165	7	-1	810	2020-07-09 03:59:57.192902+03
31166	33	-1	900	2020-07-09 04:00:29.497658+03
31167	61	-1	1510	2020-07-09 04:02:57.395958+03
31168	2	-1	470	2020-07-09 04:09:18.986733+03
31169	86	-1	910	2020-07-09 04:21:11.171218+03
31170	5	-2	1620	2020-07-09 04:30:27.548286+03
31171	10	-1	2080	2020-07-09 04:39:40.249684+03
31172	87	-1	2320	2020-07-09 04:58:20.464767+03
31173	36	-1	630	2020-07-09 05:26:56.006287+03
31174	89	-2	1420	2020-07-09 05:27:45.385365+03
31175	31	-1	1190	2020-07-09 05:28:13.924307+03
31176	53	-2	3120	2020-07-09 05:45:07.673498+03
31177	46	-1	1270	2020-07-09 05:59:34.287284+03
31178	13	-1	460	2020-07-09 06:06:18.576478+03
31179	25	-1	1100	2020-07-09 06:20:11.525676+03
31180	71	-3	1030	2020-07-09 06:31:22.367152+03
31181	72	7	279	2020-07-09 06:46:05.761356+03
31182	55	-1	3480	2020-07-09 07:44:13.395328+03
31183	64	-2	970	2020-07-09 07:47:21.284304+03
31184	10	-1	2080	2020-07-09 07:48:07.97556+03
31185	58	24	1644	2020-07-09 07:53:48.373856+03
31186	9	-1	2090	2020-07-09 07:56:27.591786+03
31187	69	-1	1100	2020-07-09 08:21:26.783834+03
31188	13	-1	460	2020-07-09 08:23:21.438111+03
31189	30	34	487	2020-07-09 08:24:45.637594+03
31190	41	-1	830	2020-07-09 08:28:13.042234+03
31191	3	-2	660	2020-07-09 08:33:14.999495+03
31192	31	-1	1190	2020-07-09 08:35:30.772899+03
31193	19	-2	1220	2020-07-09 08:41:08.420943+03
31194	95	-1	480	2020-07-09 08:44:20.979701+03
31195	27	-2	880	2020-07-09 08:51:30.254737+03
31196	84	-2	2700	2020-07-09 09:36:46.288702+03
31197	89	-1	1420	2020-07-09 10:27:45.983452+03
31198	42	-1	1790	2020-07-09 10:59:38.502018+03
31199	37	-1	1290	2020-07-09 11:10:52.376706+03
31200	33	-1	900	2020-07-09 11:21:39.349142+03
31201	12	-1	1650	2020-07-09 11:43:03.433324+03
31202	25	-1	1100	2020-07-09 11:50:24.588018+03
31203	32	-1	710	2020-07-09 12:20:16.770088+03
31204	81	-1	1620	2020-07-09 12:20:22.338661+03
31205	8	-1	1920	2020-07-09 12:22:02.576418+03
31206	88	-1	1270	2020-07-09 12:33:08.281195+03
31207	26	25	197	2020-07-09 12:51:06.24558+03
31208	14	-2	1350	2020-07-09 13:10:55.073313+03
31209	6	-1	980	2020-07-09 13:21:01.149118+03
31210	64	-1	970	2020-07-09 13:32:04.270373+03
31211	46	-1	1270	2020-07-09 14:27:56.325236+03
31212	37	-1	1290	2020-07-09 14:36:43.905777+03
31213	23	-1	4390	2020-07-09 14:42:01.070149+03
31214	64	-1	970	2020-07-09 15:20:05.487669+03
31215	71	-1	1030	2020-07-09 15:35:48.197158+03
31216	54	-1	3470	2020-07-09 16:00:09.321162+03
31217	45	-1	1590	2020-07-09 16:14:28.248472+03
31218	48	-1	640	2020-07-09 16:16:37.367229+03
31219	36	-2	630	2020-07-09 16:49:12.965577+03
31220	21	-2	960	2020-07-09 17:29:46.604607+03
31221	71	-1	1030	2020-07-09 17:31:11.118616+03
31222	65	-1	490	2020-07-09 17:33:30.431968+03
31223	73	-1	960	2020-07-09 17:34:09.071408+03
31224	51	-1	1310	2020-07-09 17:43:10.550469+03
31225	11	-2	830	2020-07-09 17:46:11.993111+03
31226	96	-1	1570	2020-07-09 17:54:52.592569+03
31227	81	-1	1620	2020-07-09 18:25:33.456676+03
31228	40	-1	1430	2020-07-09 18:34:23.184756+03
31229	33	-1	900	2020-07-09 18:46:45.736544+03
31230	13	-1	460	2020-07-09 18:56:52.135253+03
31231	87	-1	2320	2020-07-09 19:08:57.621878+03
31232	51	-1	1310	2020-07-09 19:10:51.777101+03
31233	1	-1	640	2020-07-09 19:36:18.407866+03
31234	79	-1	550	2020-07-09 19:41:25.70446+03
31235	88	-1	1270	2020-07-09 19:47:32.310739+03
31236	96	-2	1570	2020-07-09 19:54:23.222367+03
31237	33	-1	900	2020-07-09 20:08:38.371088+03
31238	67	-1	350	2020-07-09 20:15:39.139959+03
31239	60	-2	2700	2020-07-09 20:18:06.99111+03
31240	38	-1	1100	2020-07-09 20:21:44.246456+03
31241	20	24	404	2020-07-09 20:55:48.872985+03
31242	95	-1	480	2020-07-09 21:03:32.512081+03
31243	77	36	279	2020-07-09 21:07:26.597417+03
31244	52	-1	1090	2020-07-09 21:25:39.974546+03
31245	39	-3	910	2020-07-09 21:35:18.759913+03
31246	41	-1	830	2020-07-09 21:46:08.513949+03
31247	28	15	970	2020-07-09 21:54:07.055339+03
31248	86	-1	910	2020-07-09 22:10:07.316791+03
31249	48	-1	640	2020-07-09 22:11:51.088861+03
31250	34	-1	1550	2020-07-09 23:13:27.984268+03
31251	44	-1	500	2020-07-09 23:13:38.957008+03
31252	32	-3	710	2020-07-09 23:16:37.315867+03
31253	58	-1	2830	2020-07-09 23:38:00.819546+03
31254	50	-1	1140	2020-07-09 23:55:31.367012+03
31255	37	-1	1290	2020-07-10 00:08:44.549632+03
31256	18	-1	910	2020-07-10 00:14:13.387451+03
31257	90	-2	1780	2020-07-10 00:58:44.680465+03
31258	51	-2	1310	2020-07-10 01:50:15.728578+03
31259	88	-1	1270	2020-07-10 01:57:02.367863+03
31260	44	-1	500	2020-07-10 01:57:23.835236+03
31261	48	-2	640	2020-07-10 02:45:08.264168+03
31262	5	-2	1620	2020-07-10 02:54:05.170932+03
31263	48	-1	640	2020-07-10 04:11:46.182039+03
31264	18	-1	910	2020-07-10 04:35:09.745843+03
31265	50	-1	1140	2020-07-10 04:58:44.809748+03
31266	51	-1	1310	2020-07-10 05:00:13.686821+03
31267	51	-1	1310	2020-07-10 05:36:38.468706+03
31268	35	-1	670	2020-07-10 05:40:44.108901+03
31269	53	-1	3120	2020-07-10 05:54:33.981976+03
31270	89	-1	1420	2020-07-10 06:08:27.307887+03
31271	32	-1	710	2020-07-10 06:11:58.500729+03
31272	28	-1	1860	2020-07-10 06:12:34.903151+03
31273	86	-1	910	2020-07-10 06:29:21.717875+03
31274	12	-1	1650	2020-07-10 06:33:03.274239+03
31275	10	-1	2080	2020-07-10 07:15:43.351686+03
31276	40	-1	1430	2020-07-10 07:27:51.198467+03
31277	94	-1	1230	2020-07-10 07:59:00.970438+03
31278	70	-1	760	2020-07-10 08:00:27.782955+03
31279	55	-1	3480	2020-07-10 08:01:24.798765+03
31280	42	-1	1790	2020-07-10 08:03:01.431281+03
31281	75	-2	830	2020-07-10 08:09:43.1424+03
31282	23	-1	4390	2020-07-10 08:24:36.221826+03
31283	80	-1	1120	2020-07-10 08:36:39.911683+03
31284	18	-1	910	2020-07-10 08:39:34.530442+03
31285	94	-1	1230	2020-07-10 09:07:02.733305+03
31286	49	-2	970	2020-07-10 09:15:13.45814+03
31287	79	-1	550	2020-07-10 09:25:27.534113+03
31288	29	-1	1940	2020-07-10 09:32:19.946487+03
31289	57	-1	1900	2020-07-10 09:53:27.316778+03
31290	73	-1	960	2020-07-10 10:01:25.411496+03
31291	65	-1	490	2020-07-10 10:10:18.089518+03
31292	67	-1	350	2020-07-10 10:16:39.936199+03
31293	56	-1	2460	2020-07-10 10:17:35.623261+03
31294	8	-1	1920	2020-07-10 10:31:34.152909+03
31295	63	-1	1780	2020-07-10 10:31:47.242495+03
31296	36	-1	630	2020-07-10 10:55:41.484653+03
31297	56	-1	2460	2020-07-10 11:49:15.139089+03
31298	61	-1	1510	2020-07-10 12:26:54.155757+03
31299	15	-1	2830	2020-07-10 12:31:36.062717+03
31300	56	-1	2460	2020-07-10 12:38:05.998268+03
31301	39	-1	910	2020-07-10 12:54:28.575818+03
31302	69	-1	1100	2020-07-10 12:58:55.200485+03
31303	42	-1	1790	2020-07-10 13:07:20.529969+03
31304	53	-1	3120	2020-07-10 13:18:05.546859+03
31305	44	-1	500	2020-07-10 13:18:16.673689+03
31306	87	-1	2320	2020-07-10 13:20:28.319606+03
31307	17	-1	1500	2020-07-10 13:24:33.597621+03
31308	7	-1	810	2020-07-10 13:26:01.648408+03
31309	50	-1	1140	2020-07-10 13:43:58.904073+03
31310	42	-1	1790	2020-07-10 13:48:21.573465+03
31311	2	-1	470	2020-07-10 13:49:27.769268+03
31312	29	-2	1940	2020-07-10 13:50:14.777586+03
31313	91	-1	1620	2020-07-10 13:50:48.606187+03
31314	65	-1	490	2020-07-10 13:58:35.258574+03
31315	31	-1	1190	2020-07-10 14:31:34.52236+03
31316	56	-1	2460	2020-07-10 14:46:35.731258+03
31317	49	-1	970	2020-07-10 14:47:26.365497+03
31318	63	-1	1780	2020-07-10 14:49:54.437743+03
31319	53	-1	3120	2020-07-10 14:57:18.432568+03
31320	62	-1	1220	2020-07-10 15:02:52.40098+03
31321	21	-1	960	2020-07-10 15:13:26.274938+03
31322	89	-1	1420	2020-07-10 15:18:38.453028+03
31323	7	-1	810	2020-07-10 15:34:04.399978+03
31324	77	-1	640	2020-07-10 15:36:12.599705+03
31325	40	-1	1430	2020-07-10 16:14:13.146522+03
31326	17	-1	1500	2020-07-10 16:46:55.496761+03
31327	63	-1	1780	2020-07-10 16:49:37.998828+03
31328	83	-1	1230	2020-07-10 17:45:47.21898+03
31329	92	-1	630	2020-07-10 17:46:12.199006+03
31330	18	-1	910	2020-07-10 17:47:19.158248+03
31331	86	-1	910	2020-07-10 18:09:46.976392+03
31332	37	-1	1290	2020-07-10 18:14:41.587312+03
31333	80	-1	1120	2020-07-10 18:23:41.178881+03
31334	71	-1	1030	2020-07-10 19:02:41.053909+03
31335	10	-1	2080	2020-07-10 19:07:07.380363+03
31336	47	-1	1480	2020-07-10 19:07:27.710803+03
31337	76	-1	1070	2020-07-10 19:27:47.842959+03
31338	33	36	524	2020-07-10 20:13:41.490999+03
31339	56	-2	2460	2020-07-10 20:26:26.315466+03
31340	96	-1	1570	2020-07-10 20:28:16.894493+03
31341	61	-1	1510	2020-07-10 21:04:27.648003+03
31342	52	-1	1090	2020-07-10 21:26:44.176264+03
31343	85	-2	730	2020-07-10 21:31:10.967061+03
31344	84	-2	2700	2020-07-10 21:43:06.374073+03
31345	56	-1	2460	2020-07-10 21:45:41.732666+03
31346	72	-1	620	2020-07-10 22:30:48.284254+03
31347	63	-1	1780	2020-07-10 22:40:32.252354+03
31348	91	-1	1620	2020-07-10 23:06:18.485578+03
31349	31	-2	1190	2020-07-10 23:06:35.344975+03
31350	33	-3	900	2020-07-11 00:24:24.280535+03
31351	6	-1	980	2020-07-11 00:29:28.446792+03
31352	39	-1	910	2020-07-11 00:54:44.510135+03
31353	79	-1	550	2020-07-11 02:02:23.684922+03
31354	37	-1	1290	2020-07-11 02:04:11.006452+03
31355	46	-1	1270	2020-07-11 02:07:20.331308+03
31356	59	-1	1030	2020-07-11 02:08:32.236354+03
31357	61	-1	1510	2020-07-11 02:18:02.449156+03
31358	59	-1	1030	2020-07-11 02:24:13.536399+03
31359	92	-1	630	2020-07-11 02:24:55.221924+03
31360	96	-1	1570	2020-07-11 02:54:56.02086+03
31361	86	-1	910	2020-07-11 03:09:10.371495+03
31362	53	-1	3120	2020-07-11 03:20:22.866603+03
31363	56	29	1087	2020-07-11 03:22:08.895598+03
31364	41	-1	830	2020-07-11 03:28:38.962214+03
31365	87	-1	2320	2020-07-11 03:30:11.445784+03
31366	50	-2	1140	2020-07-11 03:36:42.873695+03
31367	58	-1	2830	2020-07-11 04:29:19.145591+03
31368	33	-1	900	2020-07-11 04:35:35.423911+03
31369	61	-1	1510	2020-07-11 04:38:11.855141+03
31370	86	-1	910	2020-07-11 04:57:04.784451+03
31371	43	-1	380	2020-07-11 05:04:14.968032+03
31372	42	-1	1790	2020-07-11 05:40:00.264456+03
31373	82	-1	560	2020-07-11 05:49:01.669058+03
31374	23	-1	4390	2020-07-11 06:25:35.999315+03
31375	47	-1	1480	2020-07-11 06:50:44.706158+03
31376	31	-2	1190	2020-07-11 07:06:34.586664+03
31377	81	-1	1620	2020-07-11 07:23:02.891801+03
31378	17	-1	1500	2020-07-11 07:23:42.486282+03
31379	93	-1	1620	2020-07-11 07:23:55.023921+03
31380	40	-1	1430	2020-07-11 07:26:43.172727+03
31381	71	-1	1030	2020-07-11 07:47:06.523596+03
31382	6	-2	980	2020-07-11 07:52:48.083003+03
31383	47	-1	1480	2020-07-11 09:15:16.310182+03
31384	34	-1	1550	2020-07-11 09:36:01.76902+03
31385	64	-1	970	2020-07-11 09:37:57.872368+03
31386	11	-1	830	2020-07-11 09:38:59.740491+03
31387	89	-1	1420	2020-07-11 09:39:51.170482+03
31388	44	-1	500	2020-07-11 09:55:38.55773+03
31389	69	-1	1100	2020-07-11 10:09:08.503789+03
31390	80	-1	1120	2020-07-11 10:31:39.431804+03
31391	77	-1	640	2020-07-11 10:46:58.639675+03
31392	50	-1	1140	2020-07-11 11:24:45.189033+03
31393	95	-1	480	2020-07-11 11:26:29.270229+03
31394	18	-1	910	2020-07-11 11:39:01.191652+03
31395	67	-1	350	2020-07-11 11:57:58.14953+03
31396	12	-2	1650	2020-07-11 12:01:04.71548+03
31397	84	-1	2700	2020-07-11 12:02:46.628987+03
31398	34	-1	1550	2020-07-11 12:10:48.358473+03
31399	30	-1	1140	2020-07-11 12:33:40.710888+03
31400	35	-1	670	2020-07-11 12:45:13.64334+03
31401	30	-1	1140	2020-07-11 13:10:42.298932+03
31402	66	-1	690	2020-07-11 13:24:17.117575+03
31403	90	-2	1780	2020-07-11 13:38:24.821411+03
31404	92	-1	630	2020-07-11 13:50:32.831669+03
31405	64	-2	970	2020-07-11 14:23:29.342614+03
31406	61	-1	1510	2020-07-11 14:39:16.924438+03
31407	27	-1	880	2020-07-11 14:48:07.883661+03
31408	95	-1	480	2020-07-11 15:12:16.781595+03
31409	60	-1	2700	2020-07-11 16:26:51.951167+03
31410	18	-1	910	2020-07-11 17:15:16.082122+03
31411	34	-1	1550	2020-07-11 17:20:05.30278+03
31412	29	-1	1940	2020-07-11 17:36:33.741605+03
31413	67	-1	350	2020-07-11 18:15:32.993869+03
31414	17	-1	1500	2020-07-11 18:19:07.882117+03
31415	83	-2	1230	2020-07-11 18:52:32.875863+03
31416	21	-1	960	2020-07-11 19:11:34.38548+03
31417	35	-2	670	2020-07-11 19:35:34.252342+03
31418	87	-1	2320	2020-07-11 20:03:18.853384+03
31419	91	-1	1620	2020-07-11 20:13:26.641551+03
31420	84	-1	2700	2020-07-11 20:29:47.770651+03
31421	93	-1	1620	2020-07-11 20:30:24.629325+03
31422	23	-1	4390	2020-07-11 20:37:23.217245+03
31423	94	-1	1230	2020-07-11 20:41:53.600955+03
31424	49	-1	970	2020-07-11 21:31:31.817271+03
31425	92	-1	630	2020-07-11 21:32:58.293869+03
31426	77	-1	640	2020-07-11 21:42:28.180363+03
31427	25	-1	1100	2020-07-11 21:51:07.68396+03
31428	66	-1	690	2020-07-11 22:22:36.202518+03
31429	32	-1	710	2020-07-11 22:33:44.743974+03
31430	32	-1	710	2020-07-11 22:42:45.236936+03
31431	81	-1	1620	2020-07-11 23:01:56.883422+03
31432	80	-1	1120	2020-07-11 23:40:12.777109+03
31433	85	-3	730	2020-07-11 23:48:04.331586+03
31434	84	-2	2700	2020-07-12 00:01:46.567309+03
31435	49	-1	970	2020-07-12 00:27:10.120215+03
31436	88	-1	1270	2020-07-12 00:52:44.3334+03
31437	41	-2	830	2020-07-12 00:58:08.234918+03
31438	14	-1	1350	2020-07-12 01:12:53.235488+03
31439	93	-1	1620	2020-07-12 01:15:47.10274+03
31440	67	-1	350	2020-07-12 01:21:31.488905+03
31441	54	-1	3470	2020-07-12 02:01:24.500383+03
31442	9	-1	2090	2020-07-12 02:11:33.834482+03
31443	22	-1	1070	2020-07-12 02:13:26.812898+03
31444	10	-1	2080	2020-07-12 02:29:58.526617+03
31445	34	32	680	2020-07-12 03:03:18.481288+03
31446	71	-1	1030	2020-07-12 03:26:03.98907+03
31447	1	-2	640	2020-07-12 04:00:56.21523+03
31448	48	-1	640	2020-07-12 04:07:20.19725+03
31449	32	-1	710	2020-07-12 04:10:45.569216+03
31450	70	-2	760	2020-07-12 04:13:20.117587+03
31451	89	-1	1420	2020-07-12 04:19:11.593764+03
31452	88	-1	1270	2020-07-12 04:20:21.892501+03
31453	81	-1	1620	2020-07-12 04:45:37.724636+03
31454	71	-2	1030	2020-07-12 05:03:47.475267+03
31455	10	-1	2080	2020-07-12 05:49:32.05153+03
31456	88	-1	1270	2020-07-12 05:54:10.292703+03
31457	42	-1	1790	2020-07-12 06:06:30.036674+03
31458	6	-1	980	2020-07-12 06:11:55.009528+03
31459	41	23	417	2020-07-12 06:23:03.838613+03
31460	37	-1	1290	2020-07-12 06:26:39.674985+03
31461	12	-1	1650	2020-07-12 06:45:47.181824+03
31462	51	-2	1310	2020-07-12 06:56:02.508368+03
31463	8	-2	1920	2020-07-12 07:09:14.327419+03
31464	78	-1	900	2020-07-12 07:23:25.352121+03
31465	95	-1	480	2020-07-12 07:24:34.034818+03
31466	55	-1	3480	2020-07-12 07:27:24.364848+03
31467	13	-1	460	2020-07-12 07:52:23.008779+03
31468	42	34	939	2020-07-12 08:41:10.497175+03
31469	41	-2	830	2020-07-12 08:41:29.521258+03
31470	60	-2	2700	2020-07-12 08:43:31.821306+03
31471	85	28	358	2020-07-12 08:47:16.218124+03
31472	67	-2	350	2020-07-12 08:58:11.941897+03
31473	37	-1	1290	2020-07-12 09:04:06.497579+03
31474	67	37	194	2020-07-12 09:41:11.261237+03
31475	18	-1	910	2020-07-12 10:01:37.390295+03
31476	8	-2	1920	2020-07-12 10:11:02.959776+03
31477	12	-1	1650	2020-07-12 10:11:24.96816+03
31478	95	-1	480	2020-07-12 10:25:50.701436+03
31479	41	-2	830	2020-07-12 10:28:02.611826+03
31480	26	-1	390	2020-07-12 11:04:18.689354+03
31481	83	-2	1230	2020-07-12 11:24:08.245885+03
31482	72	-1	620	2020-07-12 11:56:01.641258+03
31483	65	-1	490	2020-07-12 11:56:17.616411+03
31484	87	-1	2320	2020-07-12 12:16:25.145954+03
31485	83	-1	1230	2020-07-12 12:17:41.030647+03
31486	12	-1	1650	2020-07-12 12:21:35.155233+03
31487	92	21	322	2020-07-12 12:25:52.240908+03
31488	22	-1	1070	2020-07-12 12:31:24.904225+03
31489	15	25	1334	2020-07-12 12:47:05.122331+03
31490	94	-1	1230	2020-07-12 12:49:36.606622+03
31491	96	-2	1570	2020-07-12 12:49:39.303833+03
31492	33	-2	900	2020-07-12 13:21:06.507206+03
31493	94	-1	1230	2020-07-12 13:28:19.306894+03
31494	14	-1	1350	2020-07-12 13:33:12.659843+03
31495	6	-1	980	2020-07-12 13:46:02.159447+03
31496	47	-1	1480	2020-07-12 13:51:57.238204+03
31497	15	-2	2830	2020-07-12 13:59:46.332061+03
31498	68	-1	490	2020-07-12 14:07:42.678964+03
31499	11	-1	830	2020-07-12 14:17:13.04236+03
31500	42	-1	1790	2020-07-12 14:19:17.672559+03
31501	56	-1	2460	2020-07-12 14:26:22.666729+03
31502	74	-1	1010	2020-07-12 14:26:33.65778+03
31503	88	-1	1270	2020-07-12 15:01:55.047136+03
31504	65	-1	490	2020-07-12 15:08:40.370151+03
31505	17	-1	1500	2020-07-12 15:17:35.13203+03
31506	10	-1	2080	2020-07-12 15:21:33.877201+03
31507	22	-2	1070	2020-07-12 15:32:35.149763+03
31508	90	27	765	2020-07-12 15:59:28.106225+03
31509	64	-1	970	2020-07-12 16:18:19.973843+03
31510	4	-1	1420	2020-07-12 16:23:56.646563+03
31511	60	-1	2700	2020-07-12 16:37:05.808688+03
31512	80	28	665	2020-07-12 16:39:55.185554+03
31513	56	-1	2460	2020-07-12 17:12:42.364016+03
31514	33	-1	900	2020-07-12 17:17:33.325923+03
31515	40	-1	1430	2020-07-12 17:28:30.605864+03
31516	3	-1	660	2020-07-12 17:37:27.134575+03
31517	26	-1	390	2020-07-12 17:43:07.115228+03
31518	65	22	270	2020-07-12 17:43:44.694061+03
31519	91	-1	1620	2020-07-12 17:52:52.570687+03
31520	81	-1	1620	2020-07-12 18:01:41.173268+03
31521	65	-1	490	2020-07-12 18:14:49.175595+03
31522	30	-1	1140	2020-07-12 18:24:02.147506+03
31523	37	-1	1290	2020-07-12 18:26:24.803972+03
31524	80	-1	1120	2020-07-12 18:32:25.455476+03
31525	89	-1	1420	2020-07-12 19:16:45.314992+03
31526	73	-1	960	2020-07-12 19:19:25.043705+03
31527	96	-1	1570	2020-07-12 19:35:41.882288+03
31528	47	-1	1480	2020-07-12 19:45:17.661996+03
31529	52	-1	1090	2020-07-12 20:02:27.25841+03
31530	77	-1	640	2020-07-12 20:23:42.530284+03
31531	73	-1	960	2020-07-12 20:27:07.483026+03
31532	18	-2	910	2020-07-12 20:29:37.292668+03
31533	59	-1	1030	2020-07-12 20:41:58.330632+03
31534	87	-1	2320	2020-07-12 21:07:56.538598+03
31535	80	-1	1120	2020-07-12 21:12:23.090815+03
31536	54	-1	3470	2020-07-12 21:17:26.056231+03
31537	96	-1	1570	2020-07-12 21:24:17.942496+03
31538	88	-1	1270	2020-07-12 21:36:41.476211+03
31539	89	-1	1420	2020-07-12 21:44:34.575115+03
31540	93	-1	1620	2020-07-12 22:05:01.0399+03
31541	68	-1	490	2020-07-12 22:11:14.455626+03
31542	54	-1	3470	2020-07-12 22:18:52.552932+03
31543	34	-1	1550	2020-07-12 22:20:26.826471+03
31544	18	-1	910	2020-07-12 22:49:25.812099+03
31545	89	-1	1420	2020-07-12 22:54:49.518726+03
31546	75	-2	830	2020-07-12 23:00:39.834405+03
31547	88	-1	1270	2020-07-12 23:11:10.615538+03
31548	18	-1	910	2020-07-12 23:15:08.899081+03
31549	28	-1	1860	2020-07-12 23:27:22.278838+03
31550	76	-1	1070	2020-07-13 00:05:07.917787+03
31551	12	-2	1650	2020-07-13 00:24:17.188143+03
31552	81	24	914	2020-07-13 00:27:46.89146+03
31553	83	-1	1230	2020-07-13 00:35:59.169213+03
31554	31	-2	1190	2020-07-13 00:45:11.942936+03
31555	47	-1	1480	2020-07-13 00:53:36.460891+03
31556	4	-1	1420	2020-07-13 01:33:57.787438+03
31557	67	-1	350	2020-07-13 01:45:30.970019+03
31558	70	-1	760	2020-07-13 02:23:51.930922+03
31559	41	-1	830	2020-07-13 03:14:50.128746+03
31560	89	-2	1420	2020-07-13 03:23:35.539268+03
31561	55	-2	3480	2020-07-13 03:31:13.682692+03
31562	6	-1	980	2020-07-13 03:46:06.014643+03
31563	3	-2	660	2020-07-13 03:53:49.358228+03
31564	5	-1	1620	2020-07-13 04:08:12.666656+03
31565	41	-2	830	2020-07-13 04:21:36.606897+03
31566	56	-1	2460	2020-07-13 04:45:20.872966+03
31567	8	-2	1920	2020-07-13 05:06:09.013648+03
31568	2	-1	470	2020-07-13 05:13:46.955228+03
31569	79	-1	550	2020-07-13 05:24:02.433436+03
31570	83	-1	1230	2020-07-13 05:29:55.601101+03
31571	41	-1	830	2020-07-13 05:30:16.326981+03
31572	67	-1	350	2020-07-13 05:31:26.461907+03
31573	74	-1	1010	2020-07-13 05:58:48.890013+03
31574	55	-1	3480	2020-07-13 06:05:52.968777+03
31575	73	-1	960	2020-07-13 06:20:04.861484+03
31576	29	-2	1940	2020-07-13 06:25:41.825062+03
31577	84	-1	2700	2020-07-13 06:33:33.332853+03
31578	48	-1	640	2020-07-13 06:53:27.186267+03
31579	13	-1	460	2020-07-13 07:19:12.985172+03
31580	13	-1	460	2020-07-13 07:36:23.366562+03
31581	71	-1	1030	2020-07-13 07:46:14.671425+03
31582	56	-2	2460	2020-07-13 07:52:27.880099+03
31583	82	-1	560	2020-07-13 08:02:16.6352+03
31584	20	-1	830	2020-07-13 08:25:50.655013+03
31585	89	-1	1420	2020-07-13 08:26:27.970681+03
31586	22	-1	1070	2020-07-13 08:28:38.610815+03
31587	5	-1	1620	2020-07-13 08:30:40.745687+03
31588	93	-1	1620	2020-07-13 08:35:16.07022+03
31589	4	-2	1420	2020-07-13 08:37:02.815686+03
31590	35	39	329	2020-07-13 08:37:56.638058+03
31591	36	-2	630	2020-07-13 08:48:52.02771+03
31592	47	-1	1480	2020-07-13 08:51:27.996194+03
31593	56	-1	2460	2020-07-13 08:57:52.498181+03
31594	14	-1	1350	2020-07-13 09:10:10.312611+03
31595	38	-2	1100	2020-07-13 09:23:16.989491+03
31596	1	-1	640	2020-07-13 09:31:15.974528+03
31597	42	-1	1790	2020-07-13 09:31:54.737111+03
31598	63	-3	1780	2020-07-13 09:42:23.010242+03
31599	91	-1	1620	2020-07-13 09:59:59.514766+03
31600	1	32	346	2020-07-13 10:06:14.971036+03
31601	26	-1	390	2020-07-13 10:15:39.433224+03
31602	90	-1	1780	2020-07-13 10:33:53.81277+03
31603	8	-1	1920	2020-07-13 10:48:15.137727+03
31604	37	-1	1290	2020-07-13 11:25:13.213536+03
31605	84	-1	2700	2020-07-13 11:47:11.059398+03
31606	10	-1	2080	2020-07-13 12:03:26.296255+03
31607	32	-2	710	2020-07-13 12:07:52.060128+03
31608	73	-1	960	2020-07-13 12:29:51.079513+03
31609	64	-1	970	2020-07-13 12:47:42.223384+03
31610	15	-1	2830	2020-07-13 14:20:43.533861+03
31611	35	-1	670	2020-07-13 14:31:53.901493+03
31612	57	-1	1900	2020-07-13 14:33:23.653559+03
31613	31	-1	1190	2020-07-13 14:33:53.727825+03
31614	18	-1	910	2020-07-13 14:43:37.437043+03
31615	69	-1	1100	2020-07-13 14:54:31.57618+03
31616	82	-2	560	2020-07-13 14:54:50.594513+03
31617	89	34	647	2020-07-13 15:15:53.557427+03
31618	56	-1	2460	2020-07-13 15:19:29.553136+03
31619	10	-1	2080	2020-07-13 15:22:26.020013+03
31620	75	-1	830	2020-07-13 15:27:48.964555+03
31621	66	-1	690	2020-07-13 15:49:33.369309+03
31622	90	-1	1780	2020-07-13 15:51:35.083131+03
31623	46	-1	1270	2020-07-13 16:24:18.636112+03
31624	95	-1	480	2020-07-13 16:35:35.567186+03
31625	37	-1	1290	2020-07-13 17:31:31.343989+03
31626	77	-1	640	2020-07-13 17:44:59.830185+03
31627	96	-1	1570	2020-07-13 18:24:37.230152+03
31628	55	-1	3480	2020-07-13 18:28:38.819268+03
31629	92	-1	630	2020-07-13 19:11:50.775984+03
31630	95	-1	480	2020-07-13 19:31:12.500449+03
31631	91	-1	1620	2020-07-13 19:32:50.224157+03
31632	83	-1	1230	2020-07-13 19:43:18.589639+03
31633	81	-2	1620	2020-07-13 20:08:08.045721+03
31634	92	-2	630	2020-07-13 20:09:38.467963+03
31635	7	-1	810	2020-07-13 20:23:50.504246+03
31636	12	-1	1650	2020-07-13 20:33:02.927536+03
31637	4	-2	1420	2020-07-13 21:36:29.628856+03
31638	87	-1	2320	2020-07-13 21:38:53.140442+03
31639	90	-2	1780	2020-07-13 22:04:32.733827+03
31640	91	-1	1620	2020-07-13 22:08:45.486815+03
31641	12	-1	1650	2020-07-13 22:35:56.434506+03
31642	13	-1	460	2020-07-13 23:00:55.795012+03
31643	6	-1	980	2020-07-13 23:14:51.33503+03
31644	4	37	636	2020-07-13 23:32:58.607276+03
31645	22	-1	1070	2020-07-13 23:42:29.829164+03
31646	86	-1	910	2020-07-13 23:48:24.423112+03
31647	61	-1	1510	2020-07-13 23:55:27.583972+03
31648	62	-1	1220	2020-07-14 00:20:09.569588+03
31649	23	-1	4390	2020-07-14 00:37:34.395769+03
31650	57	-1	1900	2020-07-14 00:49:02.438404+03
31651	60	32	1208	2020-07-14 00:54:06.579466+03
31652	1	-1	640	2020-07-14 00:55:38.080236+03
31653	75	-1	830	2020-07-14 00:59:13.879617+03
31654	21	-1	960	2020-07-14 01:50:21.780573+03
31655	10	-1	2080	2020-07-14 02:03:09.24668+03
31656	84	-1	2700	2020-07-14 02:04:10.847541+03
31657	47	-1	1480	2020-07-14 02:06:07.5939+03
31658	57	-1	1900	2020-07-14 02:40:06.479183+03
31659	82	-1	560	2020-07-14 02:42:16.387331+03
31660	48	-1	640	2020-07-14 02:45:43.675251+03
31661	8	-2	1920	2020-07-14 03:04:50.479256+03
31662	64	-1	970	2020-07-14 03:21:01.834954+03
31663	38	-1	1100	2020-07-14 03:46:39.618391+03
31664	45	-1	1590	2020-07-14 03:58:35.392744+03
31665	76	-1	1070	2020-07-14 04:00:34.381038+03
31666	42	-1	1790	2020-07-14 04:05:33.779184+03
31667	48	-2	640	2020-07-14 04:14:47.636817+03
31668	94	-1	1230	2020-07-14 04:52:06.590919+03
31669	28	-2	1860	2020-07-14 05:25:47.389297+03
31670	32	-1	710	2020-07-14 06:12:30.839782+03
31671	57	-1	1900	2020-07-14 06:26:12.107726+03
31672	85	-1	730	2020-07-14 06:28:39.00712+03
31673	4	-1	1420	2020-07-14 06:40:07.142807+03
31674	29	-1	1940	2020-07-14 07:22:44.953117+03
31675	21	-2	960	2020-07-14 07:27:20.625669+03
31676	23	-1	4390	2020-07-14 07:37:21.011434+03
31677	46	-1	1270	2020-07-14 07:45:37.900371+03
31678	83	-1	1230	2020-07-14 07:52:40.701533+03
31679	64	-1	970	2020-07-14 07:56:10.542806+03
31680	71	-1	1030	2020-07-14 08:17:21.031072+03
31681	36	-2	630	2020-07-14 08:33:54.456579+03
31682	49	-1	970	2020-07-14 08:40:19.615405+03
31683	44	-1	500	2020-07-14 08:45:56.616493+03
31684	91	21	678	2020-07-14 10:17:35.535552+03
31685	69	-1	1100	2020-07-14 10:25:18.900954+03
31686	70	-2	760	2020-07-14 10:25:20.395059+03
31687	17	-2	1500	2020-07-14 10:26:57.158801+03
31688	32	-2	710	2020-07-14 10:35:45.571376+03
31689	8	-1	1920	2020-07-14 10:47:16.233412+03
31690	95	-1	480	2020-07-14 11:00:53.116997+03
31691	38	-1	1100	2020-07-14 11:17:28.730622+03
31692	13	-1	460	2020-07-14 11:22:05.045175+03
31693	47	-1	1480	2020-07-14 11:51:21.034687+03
31694	12	-1	1650	2020-07-14 12:17:46.15325+03
31695	90	-1	1780	2020-07-14 12:20:32.113699+03
31696	59	-1	1030	2020-07-14 12:20:35.95159+03
31697	35	-2	670	2020-07-14 12:40:05.610084+03
31698	33	-1	900	2020-07-14 12:43:38.07825+03
31699	18	-1	910	2020-07-14 13:03:53.213059+03
31700	42	-2	1790	2020-07-14 14:08:48.799221+03
31701	54	-1	3470	2020-07-14 14:33:08.741269+03
31702	47	-1	1480	2020-07-14 14:33:56.851314+03
31703	58	-1	2830	2020-07-14 14:49:52.938223+03
31704	45	-1	1590	2020-07-14 14:53:22.668648+03
31705	15	-1	2830	2020-07-14 14:55:14.353348+03
31706	24	-1	950	2020-07-14 15:09:03.119995+03
31707	6	-2	980	2020-07-14 15:09:50.419976+03
31708	6	-1	980	2020-07-14 15:13:31.808201+03
31709	5	-1	1620	2020-07-14 15:15:10.941841+03
31710	63	-1	1780	2020-07-14 15:39:11.640342+03
31711	90	-1	1780	2020-07-14 16:02:19.973722+03
31712	56	-1	2460	2020-07-14 16:13:01.772943+03
31713	90	-1	1780	2020-07-14 16:38:45.098515+03
31714	19	-2	1220	2020-07-14 16:50:58.01857+03
31715	27	-1	880	2020-07-14 17:01:45.382287+03
31716	10	-1	2080	2020-07-14 17:26:07.044067+03
31717	63	26	982	2020-07-14 17:29:57.590823+03
31718	93	-1	1620	2020-07-14 17:44:01.949181+03
31719	71	-1	1030	2020-07-14 18:15:28.385736+03
31720	86	-1	910	2020-07-14 18:40:16.923501+03
31721	52	-1	1090	2020-07-14 18:51:59.877227+03
31722	85	-1	730	2020-07-14 18:59:02.764291+03
31723	48	-1	640	2020-07-14 19:32:42.579816+03
31724	9	23	1227	2020-07-14 19:33:58.648409+03
31725	73	-1	960	2020-07-14 19:58:29.596442+03
31726	49	-1	970	2020-07-14 20:21:32.024557+03
31727	3	-1	660	2020-07-14 20:29:04.333658+03
31728	14	-1	1350	2020-07-14 20:37:38.769023+03
31729	28	-2	1860	2020-07-14 20:45:05.103425+03
31730	7	-1	810	2020-07-14 21:00:13.153953+03
31731	17	-1	1500	2020-07-14 21:05:31.408296+03
31732	9	-1	2090	2020-07-14 21:06:15.074959+03
31733	14	-1	1350	2020-07-14 21:36:38.826107+03
31734	57	-1	1900	2020-07-14 21:57:33.889731+03
31735	88	-1	1270	2020-07-14 22:52:54.211836+03
31736	19	-1	1220	2020-07-14 23:17:43.294053+03
31737	39	-1	910	2020-07-14 23:23:17.521593+03
31738	56	-1	2460	2020-07-14 23:27:31.134407+03
31739	71	-2	1030	2020-07-14 23:37:17.01822+03
31740	49	45	433	2020-07-14 23:41:22.231621+03
31741	83	-1	1230	2020-07-15 00:20:41.339023+03
31742	78	-1	900	2020-07-15 00:37:30.938573+03
31743	87	-2	2320	2020-07-15 00:37:50.446948+03
31744	88	-1	1270	2020-07-15 00:48:02.767064+03
31745	91	-2	1620	2020-07-15 01:09:46.554975+03
31746	67	-1	350	2020-07-15 01:24:15.116184+03
31747	64	-2	970	2020-07-15 01:35:54.358964+03
31748	89	-1	1420	2020-07-15 02:38:56.557361+03
31749	75	-1	830	2020-07-15 02:44:35.265001+03
31750	64	-2	970	2020-07-15 02:56:43.928256+03
31751	33	-1	900	2020-07-15 03:01:22.839357+03
31752	84	-1	2700	2020-07-15 03:05:04.969515+03
31753	42	-2	1790	2020-07-15 03:06:23.849452+03
31754	59	-1	1030	2020-07-15 03:08:53.064552+03
31755	58	-1	2830	2020-07-15 03:33:26.250189+03
31756	49	-1	970	2020-07-15 03:34:46.989551+03
31757	1	-1	640	2020-07-15 03:45:41.395111+03
31758	42	-2	1790	2020-07-15 03:53:23.535485+03
31759	62	14	589	2020-07-15 04:23:09.446354+03
31760	78	-1	900	2020-07-15 05:08:11.475664+03
31761	24	-1	950	2020-07-15 05:13:20.669683+03
31762	83	-1	1230	2020-07-15 05:53:06.120566+03
31763	19	-1	1220	2020-07-15 05:57:15.339752+03
31764	82	-1	560	2020-07-15 06:02:35.068535+03
31765	33	-2	900	2020-07-15 06:03:46.056158+03
31766	91	-1	1620	2020-07-15 06:21:26.977457+03
31767	92	-1	630	2020-07-15 06:30:25.233164+03
31768	19	-2	1220	2020-07-15 07:01:23.106823+03
31769	33	-2	900	2020-07-15 07:06:10.969534+03
31770	30	-1	1140	2020-07-15 08:09:08.237067+03
31771	11	-1	830	2020-07-15 08:12:25.817616+03
31772	93	-1	1620	2020-07-15 08:18:07.459095+03
31773	2	-1	470	2020-07-15 08:21:44.233128+03
31774	32	36	305	2020-07-15 08:35:28.278771+03
31775	58	-1	2830	2020-07-15 08:52:12.545702+03
31776	92	-1	630	2020-07-15 09:15:41.272694+03
31777	69	-1	1100	2020-07-15 09:17:28.237813+03
31778	74	-2	1010	2020-07-15 09:17:37.966235+03
31779	45	-1	1590	2020-07-15 09:46:27.494943+03
31780	47	-1	1480	2020-07-15 10:33:35.906513+03
31781	25	-1	1100	2020-07-15 10:45:54.32252+03
31782	44	28	262	2020-07-15 10:49:33.260134+03
31783	32	-1	710	2020-07-15 10:53:27.182075+03
31784	52	-1	1090	2020-07-15 10:54:02.402976+03
31785	41	-1	830	2020-07-15 11:54:46.962113+03
31786	15	-1	2830	2020-07-15 11:57:04.476403+03
31787	33	-1	900	2020-07-15 12:17:03.53839+03
31788	31	-1	1190	2020-07-15 12:35:54.341312+03
31789	88	-1	1270	2020-07-15 12:43:28.718111+03
31790	34	-1	1550	2020-07-15 13:01:12.949543+03
31791	32	-1	710	2020-07-15 13:25:30.68382+03
31792	76	-2	1070	2020-07-15 13:37:47.64834+03
31793	75	-1	830	2020-07-15 13:39:28.237452+03
31794	11	-1	830	2020-07-15 13:48:22.973331+03
31795	50	-1	1140	2020-07-15 14:24:36.908543+03
31796	36	-1	630	2020-07-15 15:18:55.683861+03
31797	96	-1	1570	2020-07-15 16:27:14.32326+03
31798	95	-2	480	2020-07-15 18:01:10.257792+03
31799	94	-1	1230	2020-07-15 18:10:17.464862+03
31800	55	-1	3480	2020-07-15 18:25:33.020066+03
31801	48	-1	640	2020-07-15 18:30:58.942604+03
31802	80	-1	1120	2020-07-15 18:51:17.254529+03
31803	95	-1	480	2020-07-15 19:06:25.349627+03
31804	39	-1	910	2020-07-15 19:13:27.968654+03
31805	8	-1	1920	2020-07-15 19:21:48.11197+03
31806	94	-1	1230	2020-07-15 19:28:54.334787+03
31807	45	-1	1590	2020-07-15 19:42:05.34247+03
31808	3	-1	660	2020-07-15 19:59:04.882951+03
31809	80	-1	1120	2020-07-15 20:21:03.883147+03
31810	49	-1	970	2020-07-15 20:32:47.450954+03
31811	14	-1	1350	2020-07-15 21:14:24.481518+03
31812	53	-1	3120	2020-07-15 21:23:03.822036+03
31813	32	-1	710	2020-07-15 21:40:43.448079+03
31814	61	33	871	2020-07-15 21:51:48.744002+03
31815	96	-2	1570	2020-07-15 21:56:45.65941+03
31816	52	-1	1090	2020-07-15 22:29:10.551584+03
31817	34	-2	1550	2020-07-15 22:37:20.410533+03
31818	49	-1	970	2020-07-15 22:45:49.199767+03
31819	27	-2	880	2020-07-15 23:03:36.745207+03
31820	79	-1	550	2020-07-15 23:04:30.281387+03
31821	41	-1	830	2020-07-15 23:08:34.68937+03
31822	48	-1	640	2020-07-15 23:19:30.56541+03
31823	33	-1	900	2020-07-16 00:01:34.479599+03
31824	31	-1	1190	2020-07-16 00:05:39.338739+03
31825	58	-1	2830	2020-07-16 00:13:24.808409+03
31826	73	-1	960	2020-07-16 00:22:09.520737+03
31827	64	-1	970	2020-07-16 00:49:30.101146+03
31828	47	-1	1480	2020-07-16 00:56:59.098309+03
31829	47	-1	1480	2020-07-16 01:11:22.134742+03
31830	58	-1	2830	2020-07-16 01:26:36.185142+03
31831	74	-2	1010	2020-07-16 01:44:02.757107+03
31832	39	-2	910	2020-07-16 01:56:16.444647+03
31833	91	-2	1620	2020-07-16 02:01:52.224974+03
31834	53	-1	3120	2020-07-16 02:28:43.67256+03
31835	70	-1	760	2020-07-16 03:24:13.164306+03
31836	44	-2	500	2020-07-16 03:37:57.454788+03
31837	43	24	198	2020-07-16 03:39:17.047235+03
31838	76	-1	1070	2020-07-16 04:03:43.638644+03
31839	59	-2	1030	2020-07-16 04:38:13.87487+03
31840	50	-1	1140	2020-07-16 04:54:26.020485+03
31841	11	-1	830	2020-07-16 04:55:08.32593+03
31842	48	-1	640	2020-07-16 04:56:11.354858+03
31843	64	-2	970	2020-07-16 05:42:27.584873+03
31844	1	-2	640	2020-07-16 05:43:06.781741+03
31845	25	-1	1100	2020-07-16 06:25:14.471623+03
31846	41	-1	830	2020-07-16 06:49:55.587496+03
31847	41	-1	830	2020-07-16 06:55:21.747181+03
31848	78	-1	900	2020-07-16 07:08:41.943236+03
31849	52	-1	1090	2020-07-16 07:49:38.16171+03
31850	37	-1	1290	2020-07-16 07:55:33.924366+03
31851	59	-1	1030	2020-07-16 08:16:40.480934+03
31852	38	-1	1100	2020-07-16 08:51:26.535208+03
31853	12	-1	1650	2020-07-16 08:54:08.304448+03
31854	3	-2	660	2020-07-16 09:00:14.360534+03
31855	68	-1	490	2020-07-16 09:03:23.82257+03
31856	43	-1	380	2020-07-16 09:17:45.080381+03
31857	89	-1	1420	2020-07-16 09:22:44.559561+03
31858	46	-1	1270	2020-07-16 09:27:24.565197+03
31859	59	-1	1030	2020-07-16 09:35:42.511732+03
31860	41	-2	830	2020-07-16 10:17:18.074968+03
31861	4	-2	1420	2020-07-16 10:39:22.208392+03
31862	40	-1	1430	2020-07-16 10:48:21.039+03
31863	44	-1	500	2020-07-16 10:50:01.300551+03
31864	60	-1	2700	2020-07-16 11:54:41.83116+03
31865	8	28	781	2020-07-16 12:01:21.330318+03
31866	41	-1	830	2020-07-16 12:24:08.550277+03
31867	55	-1	3480	2020-07-16 12:35:40.509932+03
31868	59	-1	1030	2020-07-16 12:36:55.85958+03
31869	52	-2	1090	2020-07-16 12:49:13.968752+03
31870	7	-2	810	2020-07-16 12:53:11.247274+03
31871	36	-1	630	2020-07-16 13:06:27.928675+03
31872	13	-1	460	2020-07-16 13:38:53.688764+03
31873	23	-1	4390	2020-07-16 13:40:00.540083+03
31874	62	-1	1220	2020-07-16 14:22:25.075913+03
31875	14	-1	1350	2020-07-16 14:41:20.878717+03
31876	54	-1	3470	2020-07-16 14:59:57.460912+03
31877	35	-1	670	2020-07-16 15:27:44.115548+03
31878	38	-1	1100	2020-07-16 15:31:20.22316+03
31879	4	-1	1420	2020-07-16 15:34:05.32986+03
31880	82	-1	560	2020-07-16 15:35:31.915278+03
31881	29	-1	1940	2020-07-16 15:39:09.82777+03
31882	16	-2	1380	2020-07-16 15:51:09.533941+03
31883	5	-1	1620	2020-07-16 15:55:35.198812+03
31884	88	-2	1270	2020-07-16 15:59:10.142501+03
31885	46	-1	1270	2020-07-16 16:42:36.16623+03
31886	4	-2	1420	2020-07-16 16:44:36.551983+03
31887	83	-2	1230	2020-07-16 16:54:22.112046+03
31888	59	-1	1030	2020-07-16 16:56:27.162843+03
31889	7	-1	810	2020-07-16 17:04:15.854991+03
31890	76	-2	1070	2020-07-16 17:22:53.511144+03
31891	34	-1	1550	2020-07-16 17:53:19.716875+03
31892	45	-1	1590	2020-07-16 18:24:48.295911+03
31893	43	-2	380	2020-07-16 19:19:27.619916+03
31894	75	-1	830	2020-07-16 19:22:29.688436+03
31895	55	-2	3480	2020-07-16 19:25:28.833471+03
31896	64	-3	970	2020-07-16 19:27:18.432959+03
31897	69	-1	1100	2020-07-16 19:30:08.87491+03
31898	10	-1	2080	2020-07-16 19:34:34.999473+03
31899	71	-1	1030	2020-07-16 19:42:58.267699+03
31900	43	-1	380	2020-07-16 19:48:32.847784+03
31901	90	-1	1780	2020-07-16 20:23:18.754315+03
31902	15	-1	2830	2020-07-16 20:35:17.556719+03
31903	40	-1	1430	2020-07-16 20:39:26.027893+03
31904	27	-2	880	2020-07-16 21:14:27.883115+03
31905	35	-1	670	2020-07-16 21:45:43.675191+03
31906	49	-1	970	2020-07-16 21:45:45.365906+03
31907	12	-1	1650	2020-07-16 22:10:15.688166+03
31908	77	-1	640	2020-07-16 22:27:27.338198+03
31909	87	-1	2320	2020-07-16 22:30:49.9757+03
31910	84	-1	2700	2020-07-16 22:43:29.576612+03
31911	7	-1	810	2020-07-16 22:56:36.551542+03
31912	29	-1	1940	2020-07-16 23:23:44.60716+03
31913	64	-1	970	2020-07-16 23:41:12.109341+03
31914	38	-1	1100	2020-07-16 23:42:03.818221+03
31915	22	43	545	2020-07-17 00:26:00.833174+03
31916	44	-1	500	2020-07-17 00:41:06.691254+03
31917	25	12	520	2020-07-17 01:02:56.159736+03
31918	58	-1	2830	2020-07-17 02:06:06.06882+03
31919	50	-1	1140	2020-07-17 02:54:09.162247+03
31920	35	-2	670	2020-07-17 03:03:42.458392+03
31921	40	-1	1430	2020-07-17 03:40:55.198683+03
31922	27	-1	880	2020-07-17 03:50:37.019888+03
31923	84	-1	2700	2020-07-17 03:50:56.783923+03
31924	55	35	1725	2020-07-17 04:20:15.593337+03
31925	33	-1	900	2020-07-17 04:29:00.275172+03
31926	22	-1	1070	2020-07-17 04:37:03.121401+03
31927	9	-1	2090	2020-07-17 04:41:59.32787+03
31928	79	18	247	2020-07-17 05:36:12.184075+03
31929	95	-1	480	2020-07-17 05:42:29.483974+03
31930	21	-2	960	2020-07-17 05:42:30.017649+03
31931	53	-2	3120	2020-07-17 06:02:35.803901+03
31932	40	-1	1430	2020-07-17 06:05:10.442387+03
31933	5	-1	1620	2020-07-17 06:05:38.670818+03
31934	91	-1	1620	2020-07-17 06:11:34.002943+03
31935	19	-1	1220	2020-07-17 06:20:24.686699+03
31936	95	-1	480	2020-07-17 06:48:14.404051+03
31937	66	-1	690	2020-07-17 06:49:01.230071+03
31938	71	-1	1030	2020-07-17 07:55:58.566881+03
31939	83	-1	1230	2020-07-17 08:37:16.151987+03
31940	27	-1	880	2020-07-17 08:58:09.376795+03
31941	89	-1	1420	2020-07-17 08:58:28.943123+03
31942	49	-1	970	2020-07-17 09:08:52.51789+03
31943	59	-2	1030	2020-07-17 09:14:16.859028+03
31944	62	-1	1220	2020-07-17 09:22:31.606081+03
31945	84	21	1155	2020-07-17 09:23:54.906952+03
31946	94	-2	1230	2020-07-17 09:25:34.003811+03
31947	76	-1	1070	2020-07-17 09:42:40.757725+03
31948	30	-1	1140	2020-07-17 10:00:22.706712+03
31949	20	-1	830	2020-07-17 10:26:46.180968+03
31950	48	23	330	2020-07-17 10:52:26.61935+03
31951	88	-1	1270	2020-07-17 10:59:54.046971+03
31952	6	-1	980	2020-07-17 11:00:28.370219+03
31953	91	-1	1620	2020-07-17 11:12:44.625781+03
31954	28	-1	1860	2020-07-17 11:46:03.103977+03
31955	6	-1	980	2020-07-17 11:46:26.781572+03
31956	57	-1	1900	2020-07-17 11:49:59.90838+03
31957	35	-2	670	2020-07-17 11:50:20.660461+03
31958	95	-1	480	2020-07-17 11:53:11.180351+03
31959	96	-1	1570	2020-07-17 12:00:14.507343+03
31960	7	-1	810	2020-07-17 12:15:38.049534+03
31961	14	-2	1350	2020-07-17 12:17:34.211489+03
31962	56	-1	2460	2020-07-17 12:20:29.092532+03
31963	22	-1	1070	2020-07-17 12:41:25.490629+03
31964	29	-2	1940	2020-07-17 12:54:02.008288+03
31965	20	-1	830	2020-07-17 12:55:25.702983+03
31966	4	-1	1420	2020-07-17 12:59:14.907928+03
31967	36	-1	630	2020-07-17 13:05:44.837364+03
31968	34	-1	1550	2020-07-17 13:29:27.572148+03
31969	20	-2	830	2020-07-17 13:30:20.991067+03
31970	32	-1	710	2020-07-17 13:30:43.491965+03
31971	10	-2	2080	2020-07-17 13:41:54.51059+03
31972	55	-3	3480	2020-07-17 14:03:59.811636+03
31973	77	-1	640	2020-07-17 14:20:24.996146+03
31974	74	-2	1010	2020-07-17 15:36:17.732605+03
31975	76	-1	1070	2020-07-17 15:47:26.849616+03
31976	88	-1	1270	2020-07-17 15:52:43.06498+03
31977	79	-1	550	2020-07-17 16:00:14.849968+03
31978	34	-1	1550	2020-07-17 17:24:05.014819+03
31979	80	-1	1120	2020-07-17 17:29:09.162616+03
31980	69	-1	1100	2020-07-17 17:46:38.262483+03
31981	6	-1	980	2020-07-17 18:19:47.554521+03
31982	64	-1	970	2020-07-17 18:34:41.43611+03
31983	94	-1	1230	2020-07-17 19:08:29.43893+03
31984	2	-2	470	2020-07-17 19:20:18.42918+03
31985	67	-2	350	2020-07-17 19:30:00.03549+03
31986	77	-1	640	2020-07-17 19:36:12.653825+03
31987	18	-1	910	2020-07-17 19:55:37.088758+03
31988	8	-1	1920	2020-07-17 20:06:14.26601+03
31989	64	25	506	2020-07-17 20:25:16.81479+03
31990	30	-1	1140	2020-07-17 20:39:16.938821+03
31991	6	-3	980	2020-07-17 20:44:55.495638+03
31992	30	-1	1140	2020-07-17 21:13:16.050426+03
31993	42	-1	1790	2020-07-17 21:24:51.657674+03
31994	91	-1	1620	2020-07-17 21:31:35.865537+03
31995	20	-1	830	2020-07-17 22:05:31.308415+03
31996	57	-1	1900	2020-07-17 22:14:23.627203+03
31997	1	-1	640	2020-07-17 22:19:17.078551+03
31998	10	-1	2080	2020-07-17 23:10:23.108726+03
31999	91	-1	1620	2020-07-17 23:15:48.68346+03
32000	82	-1	560	2020-07-17 23:37:40.935759+03
32001	10	-1	2080	2020-07-17 23:49:26.600503+03
32002	18	-1	910	2020-07-17 23:50:34.07018+03
32003	10	-1	2080	2020-07-18 00:27:29.746837+03
32004	71	-1	1030	2020-07-18 00:32:54.078322+03
32005	86	-2	910	2020-07-18 00:48:21.090832+03
32006	5	-1	1620	2020-07-18 00:58:10.97329+03
32007	37	-1	1290	2020-07-18 01:18:27.563413+03
32008	84	-2	2700	2020-07-18 01:46:06.389253+03
32009	26	-1	390	2020-07-18 02:18:36.511316+03
32010	58	-2	2830	2020-07-18 02:44:20.836826+03
32011	85	-1	730	2020-07-18 02:55:41.832683+03
32012	74	-1	1010	2020-07-18 02:58:33.541903+03
32013	29	-1	1940	2020-07-18 03:17:46.149509+03
32014	10	-1	2080	2020-07-18 03:46:26.059294+03
32015	49	-1	970	2020-07-18 04:08:52.389541+03
32016	83	31	533	2020-07-18 04:13:30.858988+03
32017	34	-1	1550	2020-07-18 04:18:57.161908+03
32018	25	-1	1100	2020-07-18 04:37:24.170669+03
32019	73	-1	960	2020-07-18 04:41:47.48684+03
32020	88	-1	1270	2020-07-18 04:48:21.130683+03
32021	42	-1	1790	2020-07-18 04:59:27.484228+03
32022	10	-1	2080	2020-07-18 05:00:54.816985+03
32023	76	-1	1070	2020-07-18 05:06:12.056296+03
32024	6	-1	980	2020-07-18 05:07:37.314847+03
32025	73	-1	960	2020-07-18 05:16:05.116244+03
32026	54	-2	3470	2020-07-18 05:20:22.720275+03
32027	58	-2	2830	2020-07-18 05:25:25.104552+03
32028	25	-2	1100	2020-07-18 05:37:33.635354+03
32029	12	-1	1650	2020-07-18 05:41:26.56617+03
32030	45	-1	1590	2020-07-18 05:43:30.136738+03
32031	10	-2	2080	2020-07-18 05:47:13.213884+03
32032	22	-1	1070	2020-07-18 05:55:33.376913+03
32033	42	-1	1790	2020-07-18 06:38:17.061846+03
32034	31	-1	1190	2020-07-18 06:39:06.8717+03
32035	91	-1	1620	2020-07-18 06:44:10.388336+03
32036	87	-1	2320	2020-07-18 07:04:32.509157+03
32037	39	-1	910	2020-07-18 07:11:03.839666+03
32038	76	-1	1070	2020-07-18 07:16:13.252248+03
32039	93	-1	1620	2020-07-18 08:08:59.859119+03
32040	56	-1	2460	2020-07-18 08:40:32.717001+03
32041	5	-1	1620	2020-07-18 09:09:38.30956+03
32042	60	-1	2700	2020-07-18 09:14:30.079217+03
32043	41	-1	830	2020-07-18 09:23:46.766666+03
32044	75	-1	830	2020-07-18 09:29:15.993899+03
32045	61	-1	1510	2020-07-18 09:33:44.070257+03
32046	79	-2	550	2020-07-18 10:18:31.78575+03
32047	14	-1	1350	2020-07-18 10:54:09.861096+03
32048	36	-2	630	2020-07-18 11:23:49.655234+03
32049	38	-1	1100	2020-07-18 11:33:03.389048+03
32050	1	-1	640	2020-07-18 11:52:00.892774+03
32051	88	-2	1270	2020-07-18 12:01:19.533341+03
32052	59	-2	1030	2020-07-18 12:23:26.118181+03
32053	93	-1	1620	2020-07-18 12:25:28.444869+03
32054	36	-1	630	2020-07-18 12:29:41.69178+03
32055	64	-1	970	2020-07-18 12:31:12.430197+03
32056	19	-1	1220	2020-07-18 12:37:55.771453+03
32057	60	-1	2700	2020-07-18 12:44:23.377802+03
32058	38	-1	1100	2020-07-18 13:01:00.590873+03
32059	18	-1	910	2020-07-18 13:08:37.138175+03
32060	37	-1	1290	2020-07-18 13:22:30.945783+03
32061	87	-1	2320	2020-07-18 13:34:07.134352+03
32062	13	-1	460	2020-07-18 13:56:01.073431+03
32063	43	-1	380	2020-07-18 14:02:28.910083+03
32064	73	-1	960	2020-07-18 14:06:22.783203+03
32065	14	-2	1350	2020-07-18 14:06:30.091683+03
32066	96	-1	1570	2020-07-18 14:22:20.549503+03
32067	83	-2	1230	2020-07-18 14:24:58.180913+03
32068	14	-1	1350	2020-07-18 14:25:04.175228+03
32069	15	-1	2830	2020-07-18 15:23:30.960383+03
32070	3	-3	660	2020-07-18 15:25:26.85942+03
32071	33	-2	900	2020-07-18 15:55:59.138979+03
32072	65	-1	490	2020-07-18 15:56:25.887665+03
32073	93	-1	1620	2020-07-18 16:19:02.398063+03
32074	38	-2	1100	2020-07-18 16:25:49.89862+03
32075	88	-1	1270	2020-07-18 17:26:14.999464+03
32076	56	-1	2460	2020-07-18 17:31:07.607927+03
32077	76	-1	1070	2020-07-18 17:48:41.460514+03
32078	33	-1	900	2020-07-18 18:01:32.384951+03
32079	16	-1	1380	2020-07-18 18:22:02.539477+03
32080	33	-1	900	2020-07-18 18:53:25.773882+03
32081	77	-1	640	2020-07-18 19:15:56.192986+03
32082	36	-2	630	2020-07-18 19:25:56.238409+03
32083	26	-2	390	2020-07-18 19:27:12.689928+03
32084	42	-2	1790	2020-07-18 19:30:31.494768+03
32085	54	-1	3470	2020-07-18 19:48:03.981047+03
32086	20	-2	830	2020-07-18 19:51:00.135921+03
32087	24	-1	950	2020-07-18 19:54:00.698462+03
32088	92	-1	630	2020-07-18 20:16:13.355686+03
32089	90	-1	1780	2020-07-18 20:39:33.668687+03
32090	39	-1	910	2020-07-18 20:51:18.103826+03
32091	83	-1	1230	2020-07-18 20:55:43.784071+03
32092	73	-1	960	2020-07-18 21:09:34.183735+03
32093	18	-2	910	2020-07-18 21:29:14.752391+03
32094	26	-1	390	2020-07-18 21:33:23.855907+03
32095	3	-1	660	2020-07-18 22:13:33.629404+03
32096	64	-1	970	2020-07-18 22:15:33.762846+03
32097	92	-1	630	2020-07-18 22:25:15.823758+03
32098	49	-1	970	2020-07-18 22:29:07.518319+03
32099	53	31	1388	2020-07-18 23:23:58.050291+03
32100	95	28	233	2020-07-18 23:32:26.549886+03
32101	53	-2	3120	2020-07-18 23:49:54.410065+03
32102	20	-1	830	2020-07-19 00:00:13.726565+03
32103	9	-1	2090	2020-07-19 00:17:33.250739+03
32104	57	-1	1900	2020-07-19 00:22:27.698328+03
32105	75	-1	830	2020-07-19 00:26:22.020652+03
32106	42	-2	1790	2020-07-19 01:05:40.669505+03
32107	32	-1	710	2020-07-19 01:20:42.900204+03
32108	87	-1	2320	2020-07-19 01:29:04.823228+03
32109	47	-1	1480	2020-07-19 01:37:32.087426+03
32110	67	-1	350	2020-07-19 01:38:19.683543+03
32111	36	-1	630	2020-07-19 01:47:14.914006+03
32112	4	-1	1420	2020-07-19 02:05:22.020468+03
32113	6	-2	980	2020-07-19 02:13:47.389845+03
32114	79	-2	550	2020-07-19 02:39:00.097512+03
32115	87	-1	2320	2020-07-19 02:46:29.011437+03
32116	51	-1	1310	2020-07-19 02:58:30.141005+03
32117	55	-1	3480	2020-07-19 03:00:49.110545+03
32118	73	-1	960	2020-07-19 03:18:12.0761+03
32119	37	-1	1290	2020-07-19 03:28:53.410871+03
32120	14	-1	1350	2020-07-19 03:36:38.817006+03
32121	47	-2	1480	2020-07-19 03:39:24.533471+03
32122	89	-2	1420	2020-07-19 04:04:44.100926+03
32123	76	-1	1070	2020-07-19 04:24:43.901735+03
32124	54	-1	3470	2020-07-19 04:40:09.152632+03
32125	69	-1	1100	2020-07-19 04:45:01.356478+03
32126	86	-1	910	2020-07-19 04:48:27.360966+03
32127	42	-1	1790	2020-07-19 05:06:17.910163+03
32128	37	-1	1290	2020-07-19 05:07:29.478228+03
32129	37	-1	1290	2020-07-19 05:08:53.425631+03
32130	88	-2	1270	2020-07-19 05:08:54.241933+03
32131	30	-1	1140	2020-07-19 05:13:27.709304+03
32132	79	-1	550	2020-07-19 05:14:04.904115+03
32133	37	-1	1290	2020-07-19 05:18:38.869679+03
32134	10	-1	2080	2020-07-19 06:10:50.355013+03
32135	32	-1	710	2020-07-19 06:22:53.090247+03
32136	67	-1	350	2020-07-19 06:31:16.524291+03
32137	41	-1	830	2020-07-19 07:13:09.419829+03
32138	96	-1	1570	2020-07-19 07:32:51.582149+03
32139	69	-1	1100	2020-07-19 07:39:04.746392+03
32140	37	-1	1290	2020-07-19 08:13:39.045117+03
32141	52	-1	1090	2020-07-19 08:18:40.314806+03
32142	54	-1	3470	2020-07-19 08:26:05.717+03
32143	92	-1	630	2020-07-19 09:07:40.264112+03
32144	39	-2	910	2020-07-19 09:17:24.897237+03
32145	49	-1	970	2020-07-19 09:19:20.171387+03
32146	73	-1	960	2020-07-19 09:34:25.230103+03
32147	68	-1	490	2020-07-19 09:38:54.498017+03
32148	65	-1	490	2020-07-19 10:24:08.906576+03
32149	6	-1	980	2020-07-19 10:38:01.979044+03
32150	32	-2	710	2020-07-19 11:00:02.898277+03
32151	47	-1	1480	2020-07-19 11:03:08.263889+03
32152	10	-1	2080	2020-07-19 11:26:32.999386+03
32153	79	-2	550	2020-07-19 12:03:07.715855+03
32154	86	-1	910	2020-07-19 12:07:42.232727+03
32155	13	-1	460	2020-07-19 12:16:15.913896+03
32156	81	-1	1620	2020-07-19 12:34:54.512227+03
32157	59	-1	1030	2020-07-19 12:38:29.204691+03
32158	17	-1	1500	2020-07-19 13:05:07.559783+03
32159	63	-1	1780	2020-07-19 13:15:20.407362+03
32160	20	-1	830	2020-07-19 13:18:52.253556+03
32161	84	-1	2700	2020-07-19 13:25:03.324091+03
32162	29	-1	1940	2020-07-19 13:48:25.904736+03
32163	70	-1	760	2020-07-19 13:58:03.748861+03
32164	49	-1	970	2020-07-19 14:09:52.55758+03
32165	57	-1	1900	2020-07-19 14:20:27.631412+03
32166	42	-1	1790	2020-07-19 14:56:38.909777+03
32167	95	-2	480	2020-07-19 15:35:07.586645+03
32168	86	32	365	2020-07-19 15:55:12.50315+03
32169	79	-2	550	2020-07-19 16:04:48.033276+03
32170	59	28	534	2020-07-19 16:07:06.400105+03
32171	93	-1	1620	2020-07-19 16:07:35.062407+03
32172	92	-1	630	2020-07-19 16:51:19.031113+03
32173	20	-2	830	2020-07-19 17:20:54.97663+03
32174	10	-1	2080	2020-07-19 17:51:50.080833+03
32175	56	-1	2460	2020-07-19 18:28:18.856481+03
32176	85	-2	730	2020-07-19 18:32:50.167483+03
32177	87	-2	2320	2020-07-19 18:37:27.735918+03
32178	88	-1	1270	2020-07-19 18:52:57.906255+03
32179	32	-1	710	2020-07-19 18:58:24.386417+03
32180	22	-1	1070	2020-07-19 19:01:27.753059+03
32181	49	-2	970	2020-07-19 19:21:26.337928+03
32182	21	-2	960	2020-07-19 19:22:56.456008+03
32183	35	-1	670	2020-07-19 19:49:15.976014+03
32184	35	-2	670	2020-07-19 19:55:44.91218+03
32185	68	-1	490	2020-07-19 20:41:34.531585+03
32186	73	-1	960	2020-07-19 20:43:50.233711+03
32187	56	-1	2460	2020-07-19 21:16:48.488541+03
32188	94	-2	1230	2020-07-19 21:23:04.534307+03
32189	71	-1	1030	2020-07-19 21:33:39.580118+03
32190	94	-1	1230	2020-07-19 22:03:33.318855+03
32191	94	-1	1230	2020-07-19 22:22:39.17012+03
32192	83	-1	1230	2020-07-19 22:26:47.562862+03
32193	14	-1	1350	2020-07-19 23:27:50.828209+03
32194	63	-1	1780	2020-07-19 23:38:44.115126+03
32195	24	-1	950	2020-07-19 23:42:46.358976+03
32196	7	-2	810	2020-07-20 01:04:46.007429+03
32197	68	-1	490	2020-07-20 01:43:05.03853+03
32198	89	-1	1420	2020-07-20 01:43:30.799724+03
32199	85	-1	730	2020-07-20 02:23:29.509053+03
32200	37	-1	1290	2020-07-20 02:29:28.118107+03
32201	46	-1	1270	2020-07-20 02:43:43.363523+03
32202	76	-1	1070	2020-07-20 03:12:06.844817+03
32203	7	27	337	2020-07-20 04:32:12.506743+03
32204	83	-3	1230	2020-07-20 04:36:00.354372+03
32205	37	-1	1290	2020-07-20 05:46:12.249414+03
32206	45	-2	1590	2020-07-20 06:02:08.407962+03
32207	42	-2	1790	2020-07-20 06:12:47.15654+03
32208	12	-1	1650	2020-07-20 06:38:19.069825+03
32209	10	-2	2080	2020-07-20 06:44:31.17329+03
32210	52	-1	1090	2020-07-20 06:56:33.518988+03
32211	52	31	566	2020-07-20 07:06:36.172918+03
32212	90	-2	1780	2020-07-20 07:27:40.684733+03
32213	13	-1	460	2020-07-20 07:38:01.292415+03
32214	69	-1	1100	2020-07-20 07:48:40.790043+03
32215	25	-1	1100	2020-07-20 07:52:36.326858+03
32216	14	-1	1350	2020-07-20 08:00:37.705312+03
32217	31	-1	1190	2020-07-20 08:05:12.540177+03
32218	25	-1	1100	2020-07-20 08:30:07.061767+03
32219	27	-1	880	2020-07-20 08:32:31.550783+03
32220	55	-1	3480	2020-07-20 08:53:09.928996+03
32221	48	-2	640	2020-07-20 09:02:30.789058+03
32222	6	-2	980	2020-07-20 09:32:05.684603+03
32223	43	-1	380	2020-07-20 09:37:12.351843+03
32224	80	-2	1120	2020-07-20 09:55:30.279695+03
32225	54	-1	3470	2020-07-20 10:02:38.593154+03
32226	14	-2	1350	2020-07-20 10:09:15.718999+03
32227	93	-2	1620	2020-07-20 11:36:21.644331+03
32228	33	-1	900	2020-07-20 11:48:34.418101+03
32229	77	-2	640	2020-07-20 11:57:05.763035+03
32230	4	-2	1420	2020-07-20 12:25:16.680313+03
32231	68	-1	490	2020-07-20 12:41:37.299045+03
32232	27	-1	880	2020-07-20 13:03:17.647274+03
32233	56	-1	2460	2020-07-20 13:09:13.237691+03
32234	13	-1	460	2020-07-20 13:10:53.358464+03
32235	64	-1	970	2020-07-20 13:11:59.227483+03
32236	87	-1	2320	2020-07-20 13:13:37.673553+03
32237	53	-1	3120	2020-07-20 13:17:13.611975+03
32238	90	-1	1780	2020-07-20 13:23:41.998147+03
32239	29	-1	1940	2020-07-20 13:25:28.810151+03
32240	17	-1	1500	2020-07-20 13:49:24.052737+03
32241	66	-1	690	2020-07-20 14:00:25.052676+03
32242	59	-2	1030	2020-07-20 14:13:18.531787+03
32243	53	-1	3120	2020-07-20 14:58:09.595382+03
32244	12	-1	1650	2020-07-20 15:21:36.936116+03
32245	35	-1	670	2020-07-20 15:24:34.794685+03
32246	95	-1	480	2020-07-20 15:38:37.245102+03
32247	93	-1	1620	2020-07-20 15:41:02.815805+03
32248	56	-2	2460	2020-07-20 15:43:18.519571+03
32249	31	-1	1190	2020-07-20 15:59:19.337067+03
32250	61	-2	1510	2020-07-20 16:08:08.714592+03
32251	93	-1	1620	2020-07-20 16:27:34.508769+03
32252	18	-1	910	2020-07-20 16:31:17.547744+03
32253	69	22	607	2020-07-20 16:35:41.67669+03
32254	56	-1	2460	2020-07-20 17:02:49.017204+03
32255	20	-1	830	2020-07-20 17:18:17.851166+03
32256	67	-1	350	2020-07-20 17:28:47.75819+03
32257	10	-1	2080	2020-07-20 17:52:42.620598+03
32258	35	-1	670	2020-07-20 17:56:58.396378+03
32259	6	-1	980	2020-07-20 18:01:36.918335+03
32260	49	-1	970	2020-07-20 18:12:57.378384+03
32261	64	-1	970	2020-07-20 18:15:34.189768+03
32262	37	-1	1290	2020-07-20 18:57:03.461489+03
32263	56	-1	2460	2020-07-20 19:12:31.326041+03
32264	77	-1	640	2020-07-20 19:31:21.96328+03
32265	37	-1	1290	2020-07-20 19:47:04.736144+03
32266	67	-1	350	2020-07-20 20:25:52.610931+03
32267	59	-2	1030	2020-07-20 20:39:19.357654+03
32268	18	40	440	2020-07-20 20:42:13.982126+03
32269	63	-1	1780	2020-07-20 20:42:16.401833+03
32270	6	-1	980	2020-07-20 21:07:34.758854+03
32271	29	-1	1940	2020-07-20 21:08:53.667977+03
32272	30	-1	1140	2020-07-20 21:09:26.439125+03
32273	57	-1	1900	2020-07-20 21:17:43.973663+03
32274	23	-1	4390	2020-07-20 21:37:26.312447+03
32275	86	-1	910	2020-07-20 21:49:28.733492+03
32276	83	-1	1230	2020-07-20 21:50:50.986543+03
32277	89	-1	1420	2020-07-20 21:58:03.6916+03
32278	89	-1	1420	2020-07-20 22:03:53.957434+03
32279	60	-1	2700	2020-07-20 22:11:16.40573+03
32280	73	-2	960	2020-07-20 22:30:31.247411+03
32281	88	-1	1270	2020-07-20 22:48:40.357971+03
32282	10	-1	2080	2020-07-20 23:05:03.547585+03
32283	24	-1	950	2020-07-20 23:14:57.310294+03
32284	76	-1	1070	2020-07-20 23:19:18.910409+03
32285	64	-1	970	2020-07-20 23:41:17.751218+03
32286	73	-1	960	2020-07-21 00:31:50.103267+03
32287	71	-1	1030	2020-07-21 00:54:40.422234+03
32288	60	-2	2700	2020-07-21 00:54:43.9969+03
32289	71	36	542	2020-07-21 01:12:45.502593+03
32290	76	-1	1070	2020-07-21 01:14:08.918726+03
32291	16	-1	1380	2020-07-21 01:15:35.1697+03
32292	67	-1	350	2020-07-21 01:24:52.988663+03
32293	96	-1	1570	2020-07-21 01:27:33.356048+03
32294	20	-1	830	2020-07-21 01:32:56.064845+03
32295	68	-1	490	2020-07-21 01:46:45.802078+03
32296	39	-1	910	2020-07-21 01:49:13.054733+03
32297	59	-1	1030	2020-07-21 02:20:40.552612+03
32298	9	-1	2090	2020-07-21 02:52:35.687948+03
32299	46	38	615	2020-07-21 03:02:30.270286+03
32300	73	-2	960	2020-07-21 03:15:22.300088+03
32301	15	-1	2830	2020-07-21 03:57:39.64759+03
32302	52	-1	1090	2020-07-21 04:24:40.948539+03
32303	71	-2	1030	2020-07-21 04:33:43.786155+03
32304	23	-2	4390	2020-07-21 04:43:55.388094+03
32305	19	-1	1220	2020-07-21 04:59:19.449621+03
32306	74	-2	1010	2020-07-21 05:15:28.946542+03
32307	15	-1	2830	2020-07-21 05:23:28.006394+03
32308	13	-1	460	2020-07-21 05:23:41.902386+03
32309	67	-2	350	2020-07-21 05:59:24.386011+03
32310	77	-1	640	2020-07-21 06:41:48.259466+03
32311	49	-2	970	2020-07-21 06:54:57.2335+03
32312	60	-1	2700	2020-07-21 07:45:55.667598+03
32313	73	-1	960	2020-07-21 07:49:52.783292+03
32314	43	-1	380	2020-07-21 08:07:39.148078+03
32315	18	-1	910	2020-07-21 08:10:55.74267+03
32316	50	-1	1140	2020-07-21 08:27:02.567468+03
32317	89	-1	1420	2020-07-21 09:21:41.909047+03
32318	32	-1	710	2020-07-21 09:21:54.063358+03
32319	53	-1	3120	2020-07-21 09:49:42.046191+03
32320	46	-1	1270	2020-07-21 10:09:04.183462+03
32321	59	-1	1030	2020-07-21 10:18:57.416072+03
32322	59	-1	1030	2020-07-21 10:39:16.587222+03
32323	73	22	468	2020-07-21 10:40:02.126747+03
32324	31	-1	1190	2020-07-21 10:44:01.816617+03
32325	51	-1	1310	2020-07-21 10:47:14.381861+03
32326	33	-1	900	2020-07-21 10:56:47.211448+03
32327	25	-1	1100	2020-07-21 11:07:49.414615+03
32328	56	-1	2460	2020-07-21 11:15:45.69765+03
32329	51	-1	1310	2020-07-21 12:20:02.335813+03
32330	9	-1	2090	2020-07-21 12:34:15.349021+03
32331	83	-1	1230	2020-07-21 12:47:16.098964+03
32332	24	-1	950	2020-07-21 12:52:34.720365+03
32333	91	-1	1620	2020-07-21 12:54:16.750848+03
32334	9	-1	2090	2020-07-21 13:07:22.446021+03
32335	9	-1	2090	2020-07-21 13:10:18.098644+03
32336	8	-1	1920	2020-07-21 13:23:03.325446+03
32337	12	-1	1650	2020-07-21 13:30:23.673754+03
32338	65	-1	490	2020-07-21 13:32:50.1835+03
32339	64	-1	970	2020-07-21 13:41:02.638174+03
32340	77	-1	640	2020-07-21 13:44:54.035623+03
32341	58	-1	2830	2020-07-21 13:59:49.165066+03
32342	44	-2	500	2020-07-21 14:01:27.532604+03
32343	18	-1	910	2020-07-21 14:19:42.087681+03
32344	65	-2	490	2020-07-21 15:24:48.302563+03
32345	20	-1	830	2020-07-21 15:36:07.913942+03
32346	2	-1	470	2020-07-21 16:31:14.248568+03
32347	10	32	1094	2020-07-21 16:39:09.796247+03
32348	29	-1	1940	2020-07-21 16:40:55.639764+03
32349	40	-1	1430	2020-07-21 16:43:51.406092+03
32350	52	-1	1090	2020-07-21 16:49:41.074855+03
32351	36	-1	630	2020-07-21 16:52:10.247554+03
32352	84	-2	2700	2020-07-21 16:52:57.027399+03
32353	27	-1	880	2020-07-21 17:15:15.386806+03
32354	57	-1	1900	2020-07-21 17:57:10.879157+03
32355	24	-2	950	2020-07-21 18:00:11.595778+03
32356	60	-1	2700	2020-07-21 18:08:42.039721+03
32357	95	-2	480	2020-07-21 18:26:07.067376+03
32358	46	-1	1270	2020-07-21 18:32:45.57189+03
32359	56	-1	2460	2020-07-21 19:07:34.174515+03
32360	29	-1	1940	2020-07-21 19:13:04.607984+03
32361	54	-1	3470	2020-07-21 19:42:20.494532+03
32362	70	-1	760	2020-07-21 19:43:27.475768+03
32363	76	-1	1070	2020-07-21 19:55:43.600756+03
32364	47	-1	1480	2020-07-21 20:10:20.822701+03
32365	10	-1	2080	2020-07-21 20:11:32.488649+03
32366	70	-1	760	2020-07-21 20:29:57.400078+03
32367	90	-1	1780	2020-07-21 20:32:43.376526+03
32368	91	-1	1620	2020-07-21 20:50:56.355143+03
32369	14	-1	1350	2020-07-21 21:45:54.123014+03
32370	79	-1	550	2020-07-21 22:20:22.530076+03
32371	24	-1	950	2020-07-21 22:41:30.130624+03
32372	73	-1	960	2020-07-21 23:12:43.702677+03
32373	61	-2	1510	2020-07-21 23:18:51.793047+03
32374	76	40	562	2020-07-21 23:25:09.720141+03
32375	10	-1	2080	2020-07-21 23:28:22.028251+03
32376	46	-1	1270	2020-07-21 23:30:04.37442+03
32377	70	-2	760	2020-07-22 00:02:17.228763+03
32378	90	-1	1780	2020-07-22 00:03:11.763788+03
32379	71	-1	1030	2020-07-22 01:06:01.272212+03
32380	13	-1	460	2020-07-22 01:10:28.982797+03
32381	14	-1	1350	2020-07-22 01:19:41.78033+03
32382	86	-2	910	2020-07-22 02:26:14.073266+03
32383	42	-1	1790	2020-07-22 02:32:19.45935+03
32384	71	-1	1030	2020-07-22 03:00:45.093918+03
32385	2	-1	470	2020-07-22 03:01:39.165052+03
32386	66	-2	690	2020-07-22 03:20:16.851849+03
32387	5	-1	1620	2020-07-22 03:40:04.654609+03
32388	73	-1	960	2020-07-22 03:51:43.732387+03
32389	34	-2	1550	2020-07-22 04:00:36.244352+03
32390	18	-1	910	2020-07-22 04:50:12.485218+03
32391	78	-1	900	2020-07-22 05:00:15.274255+03
32392	64	-1	970	2020-07-22 05:43:07.63345+03
32393	46	-1	1270	2020-07-22 05:43:29.701081+03
32394	17	-1	1500	2020-07-22 06:19:33.325381+03
32395	90	-1	1780	2020-07-22 06:26:48.111922+03
32396	29	-1	1940	2020-07-22 06:55:37.887465+03
32397	12	-1	1650	2020-07-22 06:57:17.799506+03
32398	37	-1	1290	2020-07-22 06:57:38.595063+03
32399	73	-1	960	2020-07-22 07:03:16.302842+03
32400	1	-1	640	2020-07-22 07:25:57.605221+03
32401	48	-1	640	2020-07-22 07:53:34.13693+03
32402	40	-2	1430	2020-07-22 08:00:02.19623+03
32403	57	-1	1900	2020-07-22 08:07:45.444837+03
32404	83	-2	1230	2020-07-22 08:58:00.478997+03
32405	96	-1	1570	2020-07-22 09:13:18.796497+03
32406	1	-2	640	2020-07-22 09:48:31.795836+03
32407	52	-1	1090	2020-07-22 09:56:19.923832+03
32408	22	-2	1070	2020-07-22 10:19:58.706595+03
32409	93	-1	1620	2020-07-22 10:26:28.675858+03
32410	42	-1	1790	2020-07-22 11:03:53.91246+03
32411	4	-1	1420	2020-07-22 11:13:13.390395+03
32412	23	-1	4390	2020-07-22 11:25:30.972095+03
32413	18	-1	910	2020-07-22 11:33:55.708339+03
32414	8	-1	1920	2020-07-22 12:03:01.174088+03
32415	95	-1	480	2020-07-22 12:04:28.757851+03
32416	14	-1	1350	2020-07-22 12:18:50.828898+03
32417	12	-1	1650	2020-07-22 12:55:29.690506+03
32418	88	-1	1270	2020-07-22 13:09:03.220739+03
32419	58	-1	2830	2020-07-22 13:18:50.604098+03
32420	48	-2	640	2020-07-22 13:23:33.981881+03
32421	92	-1	630	2020-07-22 13:30:21.857569+03
32422	75	-2	830	2020-07-22 13:34:34.647992+03
32423	77	-1	640	2020-07-22 13:48:45.831438+03
32424	84	-1	2700	2020-07-22 14:18:42.07414+03
32425	29	-2	1940	2020-07-22 14:55:01.887161+03
32426	57	-1	1900	2020-07-22 15:41:58.666612+03
32427	55	-1	3480	2020-07-22 15:42:20.822716+03
32428	90	-1	1780	2020-07-22 15:52:47.081351+03
32429	10	-1	2080	2020-07-22 16:04:21.988988+03
32430	35	-1	670	2020-07-22 16:04:28.680105+03
32431	80	-1	1120	2020-07-22 16:37:09.225382+03
32432	87	-1	2320	2020-07-22 17:02:55.79588+03
32433	69	-1	1100	2020-07-22 17:05:27.496069+03
32434	68	-1	490	2020-07-22 17:47:32.915923+03
32435	81	-1	1620	2020-07-22 17:52:30.163906+03
32436	78	24	434	2020-07-22 17:59:14.007281+03
32437	81	-1	1620	2020-07-22 18:02:08.976542+03
32438	47	-1	1480	2020-07-22 18:52:39.484208+03
32439	81	-2	1620	2020-07-22 19:03:24.109237+03
32440	16	-2	1380	2020-07-22 19:10:52.300774+03
32441	9	-2	2090	2020-07-22 19:14:02.366509+03
32442	28	-1	1860	2020-07-22 19:16:44.840127+03
32443	57	-2	1900	2020-07-22 19:30:14.408175+03
32444	37	-2	1290	2020-07-22 19:46:41.956532+03
32445	88	-1	1270	2020-07-22 20:03:36.546967+03
32446	30	-1	1140	2020-07-22 20:12:13.248872+03
32447	4	-1	1420	2020-07-22 20:14:01.486795+03
32448	37	-1	1290	2020-07-22 20:24:52.725549+03
32449	83	-1	1230	2020-07-22 20:31:57.845896+03
32450	84	-2	2700	2020-07-22 20:40:43.131245+03
32451	73	-1	960	2020-07-22 20:50:44.415298+03
32452	48	-1	640	2020-07-22 20:51:34.812561+03
32453	19	-1	1220	2020-07-22 20:51:54.830264+03
32454	1	-1	640	2020-07-22 20:55:10.815417+03
32455	87	-1	2320	2020-07-22 21:02:34.699311+03
32456	94	-1	1230	2020-07-22 21:08:36.024583+03
32457	48	-1	640	2020-07-22 21:09:04.146467+03
32458	91	-1	1620	2020-07-22 21:30:08.899449+03
32459	50	-1	1140	2020-07-22 21:52:45.248507+03
32460	40	-1	1430	2020-07-22 22:05:02.040075+03
32461	80	-1	1120	2020-07-22 22:16:14.945678+03
32462	13	-2	460	2020-07-22 22:21:16.056551+03
32463	24	-1	950	2020-07-22 22:26:33.452101+03
32464	63	-1	1780	2020-07-22 22:49:00.274215+03
32465	17	-1	1500	2020-07-22 22:59:38.528115+03
32466	49	-2	970	2020-07-22 23:03:27.135425+03
32467	5	32	713	2020-07-22 23:19:33.474185+03
32468	34	-1	1550	2020-07-22 23:48:32.437003+03
32469	50	22	511	2020-07-23 00:09:02.884146+03
32470	40	-1	1430	2020-07-23 00:16:38.156273+03
32471	77	-1	640	2020-07-23 00:17:52.3527+03
32472	80	-1	1120	2020-07-23 00:47:58.090946+03
32473	78	-1	900	2020-07-23 00:57:34.669938+03
32474	41	-1	830	2020-07-23 01:07:32.675411+03
32475	34	-1	1550	2020-07-23 01:08:59.907613+03
32476	81	-1	1620	2020-07-23 01:31:38.927931+03
32477	84	-1	2700	2020-07-23 02:12:45.70465+03
32478	44	-1	500	2020-07-23 02:22:28.768977+03
32479	53	-1	3120	2020-07-23 02:44:38.971741+03
32480	79	-2	550	2020-07-23 03:01:11.987792+03
32481	85	-1	730	2020-07-23 03:06:09.787717+03
32482	76	-1	1070	2020-07-23 03:20:54.04703+03
32483	6	-2	980	2020-07-23 04:00:37.163103+03
32484	12	-1	1650	2020-07-23 04:51:30.613725+03
32485	7	-1	810	2020-07-23 05:16:33.091271+03
32486	40	-1	1430	2020-07-23 05:38:22.051976+03
32487	95	-1	480	2020-07-23 05:41:46.689224+03
32488	19	-1	1220	2020-07-23 05:52:59.90398+03
32489	77	-1	640	2020-07-23 06:33:22.098858+03
32490	94	-1	1230	2020-07-23 06:33:30.907725+03
32491	15	-1	2830	2020-07-23 06:34:36.384226+03
32492	93	-1	1620	2020-07-23 06:56:55.279406+03
32493	12	-1	1650	2020-07-23 07:01:54.9854+03
32494	19	-1	1220	2020-07-23 07:26:46.041005+03
32495	63	-1	1780	2020-07-23 07:41:19.833043+03
32496	6	-1	980	2020-07-23 07:49:44.818341+03
32497	42	-1	1790	2020-07-23 08:34:51.520251+03
32498	37	-1	1290	2020-07-23 08:39:51.572307+03
32499	63	-1	1780	2020-07-23 08:47:06.736889+03
32500	70	-1	760	2020-07-23 09:05:34.574195+03
32501	69	-1	1100	2020-07-23 09:19:34.986799+03
32502	41	-1	830	2020-07-23 09:29:22.170017+03
32503	69	-1	1100	2020-07-23 09:41:29.357209+03
32504	86	-2	910	2020-07-23 09:54:50.949072+03
32505	47	-2	1480	2020-07-23 10:45:32.704987+03
32506	13	-1	460	2020-07-23 11:11:32.579343+03
32507	10	-1	2080	2020-07-23 11:22:35.112143+03
32508	49	-1	970	2020-07-23 11:28:12.258357+03
32509	96	-1	1570	2020-07-23 11:49:05.909249+03
32510	26	-1	390	2020-07-23 11:49:07.773268+03
32511	71	-1	1030	2020-07-23 12:18:49.236327+03
32512	95	-1	480	2020-07-23 12:37:52.671434+03
32513	81	-1	1620	2020-07-23 12:49:48.645749+03
32514	32	-1	710	2020-07-23 14:28:30.046032+03
32515	80	-2	1120	2020-07-23 14:32:37.799939+03
32516	9	-1	2090	2020-07-23 14:42:00.923994+03
32517	92	-1	630	2020-07-23 14:53:56.648865+03
32518	43	-1	380	2020-07-23 15:10:30.403585+03
32519	89	-1	1420	2020-07-23 15:16:57.907365+03
32520	86	-1	910	2020-07-23 15:31:47.198593+03
32521	52	-1	1090	2020-07-23 15:40:24.2225+03
32522	82	-1	560	2020-07-23 15:56:20.07647+03
32523	51	-2	1310	2020-07-23 15:58:18.105607+03
32524	8	-1	1920	2020-07-23 16:34:57.112129+03
32525	46	-1	1270	2020-07-23 17:31:25.078084+03
32526	37	-1	1290	2020-07-23 17:58:28.859906+03
32527	9	-1	2090	2020-07-23 18:13:13.735205+03
32528	50	-1	1140	2020-07-23 18:20:30.578315+03
32529	59	-1	1030	2020-07-23 18:21:01.27842+03
32530	44	-1	500	2020-07-23 19:32:22.383475+03
32531	96	-2	1570	2020-07-23 19:36:15.495243+03
32532	51	-1	1310	2020-07-23 20:12:35.035866+03
32533	39	-1	910	2020-07-23 20:18:26.854733+03
32534	83	-1	1230	2020-07-23 20:19:51.184342+03
32535	59	-1	1030	2020-07-23 20:51:33.994738+03
32536	67	-1	350	2020-07-23 20:55:25.765757+03
32537	29	-1	1940	2020-07-23 20:59:37.426485+03
32538	69	-1	1100	2020-07-23 21:02:30.065947+03
32539	14	34	719	2020-07-23 21:15:41.636636+03
32540	62	-1	1220	2020-07-23 21:22:57.385095+03
32541	23	-1	4390	2020-07-23 21:24:23.547721+03
32542	81	-1	1620	2020-07-23 21:26:04.281106+03
32543	49	-1	970	2020-07-23 21:36:15.798971+03
32544	88	-1	1270	2020-07-23 21:55:04.808932+03
32545	33	-1	900	2020-07-23 22:17:57.552719+03
32546	80	-1	1120	2020-07-23 22:33:10.418723+03
32547	24	-1	950	2020-07-23 22:53:43.996939+03
32548	54	-1	3470	2020-07-23 23:18:13.236244+03
32549	3	-2	660	2020-07-23 23:29:40.189865+03
32550	5	-1	1620	2020-07-23 23:32:40.957633+03
32551	20	-1	830	2020-07-23 23:43:37.400976+03
32552	34	-1	1550	2020-07-23 23:57:14.509145+03
32553	41	-2	830	2020-07-23 23:58:01.692049+03
32554	53	-1	3120	2020-07-24 00:21:00.239003+03
32555	64	-1	970	2020-07-24 00:54:27.335582+03
32556	60	-1	2700	2020-07-24 01:26:53.69359+03
32557	52	-1	1090	2020-07-24 01:36:27.816138+03
32558	94	-1	1230	2020-07-24 01:50:13.302916+03
32559	41	-1	830	2020-07-24 02:22:09.806929+03
32560	14	-1	1350	2020-07-24 02:37:50.128292+03
32561	36	-2	630	2020-07-24 02:47:41.724101+03
32562	4	-2	1420	2020-07-24 02:52:10.346874+03
32563	79	-2	550	2020-07-24 03:09:15.718596+03
32564	32	-1	710	2020-07-24 03:42:16.769434+03
32565	59	-1	1030	2020-07-24 04:00:45.897843+03
32566	40	-1	1430	2020-07-24 04:09:49.074921+03
32567	30	-1	1140	2020-07-24 04:45:58.512441+03
32568	21	-1	960	2020-07-24 04:57:28.769776+03
32569	38	-2	1100	2020-07-24 05:20:35.796585+03
32570	67	-1	350	2020-07-24 05:27:20.338592+03
32571	96	-2	1570	2020-07-24 05:41:54.973053+03
32572	39	33	411	2020-07-24 05:44:57.710149+03
32573	49	-1	970	2020-07-24 06:07:21.655711+03
32574	27	-1	880	2020-07-24 06:07:28.754492+03
32575	60	-1	2700	2020-07-24 06:09:30.263574+03
32576	7	-1	810	2020-07-24 06:12:02.369469+03
32577	82	-1	560	2020-07-24 06:19:04.585916+03
32578	30	-1	1140	2020-07-24 06:40:54.047763+03
32579	92	-1	630	2020-07-24 06:48:57.098047+03
32580	65	-2	490	2020-07-24 07:06:06.361916+03
32581	21	-2	960	2020-07-24 07:57:02.184334+03
32582	12	-2	1650	2020-07-24 08:06:18.700034+03
32583	42	-2	1790	2020-07-24 08:19:54.8433+03
32584	88	-1	1270	2020-07-24 08:23:10.109642+03
32585	87	-1	2320	2020-07-24 08:32:14.409645+03
32586	42	-1	1790	2020-07-24 08:37:44.480476+03
32587	48	-1	640	2020-07-24 08:37:51.149536+03
32588	21	-3	960	2020-07-24 08:38:06.734617+03
32589	34	-2	1550	2020-07-24 08:46:22.992518+03
32590	85	-1	730	2020-07-24 08:46:46.069995+03
32591	31	-2	1190	2020-07-24 09:22:35.03258+03
32592	77	-1	640	2020-07-24 10:31:25.162143+03
32593	84	-1	2700	2020-07-24 11:12:40.368938+03
32594	64	-1	970	2020-07-24 11:14:00.961366+03
32595	46	-1	1270	2020-07-24 11:20:49.997592+03
32596	37	-1	1290	2020-07-24 11:42:15.825969+03
32597	34	-1	1550	2020-07-24 11:44:54.900167+03
32598	94	-1	1230	2020-07-24 12:12:06.861174+03
32599	65	-2	490	2020-07-24 12:30:58.96967+03
32600	29	37	828	2020-07-24 12:32:26.91791+03
32601	57	-1	1900	2020-07-24 12:47:27.936626+03
32602	82	-1	560	2020-07-24 14:24:36.705523+03
32603	89	-1	1420	2020-07-24 14:44:21.094068+03
32604	41	-1	830	2020-07-24 14:52:55.269076+03
32605	32	-1	710	2020-07-24 15:18:27.704472+03
32606	21	22	518	2020-07-24 15:33:08.636248+03
32607	48	-1	640	2020-07-24 15:42:23.717413+03
32608	71	-1	1030	2020-07-24 15:46:45.269728+03
32609	35	-1	670	2020-07-24 16:27:14.35674+03
32610	50	-1	1140	2020-07-24 16:48:34.167956+03
32611	42	-1	1790	2020-07-24 16:50:39.26684+03
32612	49	-1	970	2020-07-24 16:52:55.225092+03
32613	34	-1	1550	2020-07-24 17:09:10.106189+03
32614	66	-2	690	2020-07-24 17:42:57.1972+03
32615	67	-1	350	2020-07-24 17:44:54.397872+03
32616	95	-2	480	2020-07-24 17:59:44.116637+03
32617	7	-1	810	2020-07-24 18:19:29.549096+03
32618	93	-1	1620	2020-07-24 19:02:35.707128+03
32619	13	-2	460	2020-07-24 19:16:52.284068+03
32620	11	-1	830	2020-07-24 19:33:46.089395+03
32621	91	-1	1620	2020-07-24 19:40:17.230282+03
32622	76	-1	1070	2020-07-24 19:40:21.768761+03
32623	27	-1	880	2020-07-24 19:43:56.882753+03
32624	50	-1	1140	2020-07-24 19:56:03.664573+03
32625	52	-2	1090	2020-07-24 20:20:22.692162+03
32626	18	-2	910	2020-07-24 20:49:01.88029+03
32627	41	27	374	2020-07-24 20:49:15.898231+03
32628	1	-1	640	2020-07-24 21:01:17.415884+03
32629	18	-1	910	2020-07-24 21:03:26.857101+03
32630	16	-1	1380	2020-07-24 21:22:30.725072+03
32631	70	-1	760	2020-07-24 21:31:18.103791+03
32632	86	-1	910	2020-07-24 21:39:25.336314+03
32633	49	-2	970	2020-07-24 21:44:51.873811+03
32634	17	-1	1500	2020-07-24 21:49:18.748008+03
32635	14	-1	1350	2020-07-24 21:49:48.731684+03
32636	1	-1	640	2020-07-24 21:49:49.035876+03
32637	27	-1	880	2020-07-24 21:53:01.705565+03
32638	57	-1	1900	2020-07-24 21:58:03.549212+03
32639	90	-1	1780	2020-07-24 22:19:16.877888+03
32640	71	-1	1030	2020-07-24 22:45:41.726617+03
32641	84	-1	2700	2020-07-24 22:56:04.349412+03
32642	65	-2	490	2020-07-24 23:17:56.218171+03
32643	90	-1	1780	2020-07-24 23:35:36.104211+03
32644	13	-1	460	2020-07-25 00:19:10.591942+03
32645	20	-2	830	2020-07-25 00:53:32.969793+03
32646	7	-2	810	2020-07-25 00:59:04.963395+03
32647	39	-1	910	2020-07-25 00:59:53.057682+03
32648	89	-1	1420	2020-07-25 01:47:07.22215+03
32649	65	-1	490	2020-07-25 02:06:46.325194+03
32650	43	-1	380	2020-07-25 02:12:55.174607+03
32651	29	-2	1940	2020-07-25 02:20:45.079123+03
32652	82	-1	560	2020-07-25 02:23:46.069838+03
32653	42	-1	1790	2020-07-25 03:40:10.972829+03
32654	91	-1	1620	2020-07-25 03:40:31.559532+03
32655	42	-1	1790	2020-07-25 03:41:48.919001+03
32656	56	-1	2460	2020-07-25 03:52:57.441297+03
32657	70	-1	760	2020-07-25 04:05:02.397179+03
32658	32	-1	710	2020-07-25 04:05:31.907811+03
32659	73	-1	960	2020-07-25 04:27:30.968549+03
32660	89	-2	1420	2020-07-25 04:47:47.583588+03
32661	2	-1	470	2020-07-25 05:10:36.716993+03
32662	83	-1	1230	2020-07-25 05:21:54.990707+03
32663	25	-1	1100	2020-07-25 05:54:18.988228+03
32664	29	-1	1940	2020-07-25 06:12:47.999248+03
32665	41	-1	830	2020-07-25 06:20:32.413304+03
32666	27	25	425	2020-07-25 06:26:28.971143+03
32667	39	-1	910	2020-07-25 06:26:53.9984+03
32668	76	-1	1070	2020-07-25 06:48:47.87599+03
32669	32	-1	710	2020-07-25 06:49:28.889386+03
32670	71	-1	1030	2020-07-25 06:50:14.196486+03
32671	66	9	323	2020-07-25 07:02:35.080848+03
32672	84	-1	2700	2020-07-25 07:17:10.436491+03
32673	86	-2	910	2020-07-25 07:22:33.490359+03
32674	12	-1	1650	2020-07-25 07:23:40.794028+03
32675	19	-1	1220	2020-07-25 07:28:11.702033+03
32676	76	-1	1070	2020-07-25 07:49:09.997692+03
32677	96	-1	1570	2020-07-25 08:09:49.177764+03
32678	19	-1	1220	2020-07-25 08:10:47.850552+03
32679	33	-1	900	2020-07-25 08:41:03.00706+03
32680	18	-1	910	2020-07-25 08:53:48.269656+03
32681	11	-1	830	2020-07-25 09:06:48.860549+03
32682	39	-2	910	2020-07-25 09:18:59.862867+03
32683	78	-1	900	2020-07-25 09:25:24.322044+03
32684	75	-1	830	2020-07-25 09:26:12.23908+03
32685	54	-2	3470	2020-07-25 09:47:30.264196+03
32686	77	-1	640	2020-07-25 10:27:08.487098+03
32687	80	-1	1120	2020-07-25 10:29:43.662199+03
32688	81	-1	1620	2020-07-25 10:42:12.877045+03
32689	95	-1	480	2020-07-25 10:42:29.793252+03
32690	90	-1	1780	2020-07-25 10:46:23.163653+03
32691	75	-1	830	2020-07-25 10:54:40.457824+03
32692	82	18	251	2020-07-25 11:28:12.628534+03
32693	45	-2	1590	2020-07-25 12:11:13.656298+03
32694	56	-2	2460	2020-07-25 12:16:05.147153+03
32695	55	-2	3480	2020-07-25 12:36:37.570474+03
32696	49	-1	970	2020-07-25 12:38:25.291736+03
32697	51	-2	1310	2020-07-25 13:26:05.321471+03
32698	29	-1	1940	2020-07-25 14:01:09.605757+03
32699	12	-1	1650	2020-07-25 14:44:31.673909+03
32700	75	-2	830	2020-07-25 15:21:12.252995+03
32701	54	-1	3470	2020-07-25 15:22:49.073928+03
32702	66	-2	690	2020-07-25 15:27:27.556471+03
32703	8	-1	1920	2020-07-25 15:51:18.119444+03
32704	80	-1	1120	2020-07-25 15:57:32.345445+03
32705	29	-1	1940	2020-07-25 16:06:40.936545+03
32706	96	-1	1570	2020-07-25 16:06:56.217805+03
32707	81	-1	1620	2020-07-25 16:07:17.317444+03
32708	96	-1	1570	2020-07-25 16:13:23.414659+03
32709	44	-1	500	2020-07-25 16:15:34.702816+03
32710	92	-1	630	2020-07-25 16:31:14.292948+03
32711	63	-1	1780	2020-07-25 16:34:40.624141+03
32712	86	-1	910	2020-07-25 16:37:36.524881+03
32713	47	-1	1480	2020-07-25 16:48:56.23278+03
32714	90	-1	1780	2020-07-25 16:52:39.193393+03
32715	34	-1	1550	2020-07-25 17:00:03.520468+03
32716	29	-2	1940	2020-07-25 17:22:30.529911+03
32717	14	-1	1350	2020-07-25 17:26:31.520567+03
32718	40	-1	1430	2020-07-25 17:34:46.026763+03
32719	90	-1	1780	2020-07-25 18:02:19.453532+03
32720	9	-1	2090	2020-07-25 18:08:10.130835+03
32721	14	-1	1350	2020-07-25 18:11:24.262584+03
32722	47	-1	1480	2020-07-25 18:12:44.682557+03
32723	24	-2	950	2020-07-25 18:17:13.926596+03
32724	74	-1	1010	2020-07-25 18:22:12.896789+03
32725	17	-1	1500	2020-07-25 18:53:32.062359+03
32726	20	-1	830	2020-07-25 19:24:47.302286+03
32727	29	-1	1940	2020-07-25 19:54:17.142369+03
32728	60	-1	2700	2020-07-25 20:04:59.349772+03
32729	14	-1	1350	2020-07-25 20:10:40.997064+03
32730	35	-1	670	2020-07-25 20:19:50.898957+03
32731	34	-1	1550	2020-07-25 20:38:00.861727+03
32732	14	-1	1350	2020-07-25 20:49:32.764066+03
32733	67	-2	350	2020-07-25 21:05:15.153926+03
32734	93	-2	1620	2020-07-25 21:37:10.822764+03
32735	20	-1	830	2020-07-25 21:52:19.280022+03
32736	76	-1	1070	2020-07-25 21:54:18.131003+03
32737	93	39	764	2020-07-25 22:43:39.870857+03
32738	52	-1	1090	2020-07-25 22:56:34.726173+03
32739	28	-1	1860	2020-07-25 23:20:32.373765+03
32740	76	-1	1070	2020-07-25 23:46:51.936822+03
32741	37	-1	1290	2020-07-25 23:49:07.738299+03
32742	90	-1	1780	2020-07-26 00:07:32.299231+03
32743	83	-1	1230	2020-07-26 00:24:52.370342+03
32744	11	-1	830	2020-07-26 01:44:31.374209+03
32745	31	-1	1190	2020-07-26 01:45:36.138494+03
32746	37	-1	1290	2020-07-26 01:52:27.985705+03
32747	63	-1	1780	2020-07-26 02:02:04.032421+03
32748	69	-2	1100	2020-07-26 02:23:24.475743+03
32749	31	-1	1190	2020-07-26 03:05:26.887443+03
32750	37	-1	1290	2020-07-26 03:09:57.543924+03
32751	56	-1	2460	2020-07-26 03:12:04.788773+03
32752	87	-1	2320	2020-07-26 03:51:54.079935+03
32753	35	-1	670	2020-07-26 03:56:52.666438+03
32754	84	-1	2700	2020-07-26 03:59:56.771615+03
32755	67	-2	350	2020-07-26 04:02:47.453008+03
32756	83	-1	1230	2020-07-26 04:11:48.339887+03
32757	95	-1	480	2020-07-26 04:42:37.51539+03
32758	37	29	557	2020-07-26 04:52:45.846266+03
32759	21	-1	960	2020-07-26 05:01:27.599074+03
32760	94	-1	1230	2020-07-26 05:28:48.087537+03
32761	49	-1	970	2020-07-26 05:32:07.547149+03
32762	77	-1	640	2020-07-26 05:36:35.944877+03
32763	6	-1	980	2020-07-26 06:19:00.560189+03
32764	44	-1	500	2020-07-26 06:26:01.182836+03
32765	13	-2	460	2020-07-26 06:42:15.435732+03
32766	60	-1	2700	2020-07-26 06:50:32.880638+03
32767	46	-1	1270	2020-07-26 07:01:08.816054+03
32768	55	-1	3480	2020-07-26 07:03:22.332308+03
32769	30	-2	1140	2020-07-26 07:20:23.819682+03
32770	6	-1	980	2020-07-26 07:53:44.092512+03
32771	48	-2	640	2020-07-26 08:05:56.904632+03
32772	27	-1	880	2020-07-26 08:25:35.087277+03
32773	87	-1	2320	2020-07-26 08:51:29.557358+03
32774	17	-2	1500	2020-07-26 08:59:11.055526+03
32775	88	-2	1270	2020-07-26 09:20:05.661319+03
32776	64	-1	970	2020-07-26 09:55:16.77622+03
32777	18	-1	910	2020-07-26 10:06:45.46766+03
32778	44	-1	500	2020-07-26 10:07:06.501758+03
32779	68	-1	490	2020-07-26 10:31:31.433561+03
32780	68	-2	490	2020-07-26 10:59:08.787649+03
32781	27	-1	880	2020-07-26 11:05:09.317241+03
32782	32	-1	710	2020-07-26 11:08:34.474212+03
32783	80	-1	1120	2020-07-26 11:12:24.110871+03
32784	28	-1	1860	2020-07-26 11:25:46.887615+03
32785	59	-1	1030	2020-07-26 12:24:00.794886+03
32786	29	-2	1940	2020-07-26 12:25:16.419025+03
32787	67	-1	350	2020-07-26 12:34:37.775837+03
32788	5	-1	1620	2020-07-26 12:47:38.684257+03
32789	10	-1	2080	2020-07-26 13:45:29.274867+03
32790	24	-1	950	2020-07-26 14:47:18.464013+03
32791	86	-1	910	2020-07-26 15:37:53.747938+03
32792	94	-1	1230	2020-07-26 16:03:41.616455+03
32793	29	-1	1940	2020-07-26 16:04:14.67862+03
32794	17	-1	1500	2020-07-26 16:10:25.81484+03
32795	26	-1	390	2020-07-26 16:16:14.099617+03
32796	88	28	637	2020-07-26 16:23:51.014662+03
32797	95	-1	480	2020-07-26 16:32:23.800111+03
32798	35	-1	670	2020-07-26 16:38:43.120459+03
32799	19	-1	1220	2020-07-26 16:43:37.436136+03
32800	5	-1	1620	2020-07-26 17:12:55.5004+03
32801	8	-1	1920	2020-07-26 17:29:31.34952+03
32802	73	-1	960	2020-07-26 17:41:34.6029+03
32803	24	-1	950	2020-07-26 18:05:36.686825+03
32804	22	-2	1070	2020-07-26 18:05:48.354013+03
32805	83	-1	1230	2020-07-26 18:09:31.147167+03
32806	17	-1	1500	2020-07-26 18:09:51.225578+03
32807	30	-1	1140	2020-07-26 18:17:11.020072+03
32808	88	-1	1270	2020-07-26 18:33:23.370946+03
32809	20	-1	830	2020-07-26 18:51:14.029265+03
32810	55	-1	3480	2020-07-26 19:54:03.875165+03
32811	91	-1	1620	2020-07-26 20:02:22.291345+03
32812	18	-1	910	2020-07-26 20:12:37.27331+03
32813	69	-1	1100	2020-07-26 20:18:25.770497+03
32814	67	-1	350	2020-07-26 20:35:01.605679+03
32815	45	-2	1590	2020-07-26 20:37:30.531218+03
32816	92	-1	630	2020-07-26 20:57:23.294638+03
32817	82	-1	560	2020-07-26 21:10:08.836286+03
32818	33	-1	900	2020-07-26 21:52:20.484631+03
32819	96	-2	1570	2020-07-26 22:17:00.95263+03
32820	96	-1	1570	2020-07-26 22:56:13.268367+03
32821	90	-1	1780	2020-07-26 22:59:50.680667+03
32822	77	-2	640	2020-07-26 23:03:48.889868+03
32823	95	-2	480	2020-07-26 23:10:13.041826+03
32824	87	-1	2320	2020-07-26 23:19:38.110216+03
32825	90	-1	1780	2020-07-26 23:23:36.050912+03
32826	39	-1	910	2020-07-26 23:44:07.202949+03
32827	74	-1	1010	2020-07-27 00:15:59.639423+03
32828	40	-1	1430	2020-07-27 00:21:13.585077+03
32829	10	-1	2080	2020-07-27 01:11:10.401034+03
32830	18	-1	910	2020-07-27 01:59:49.917839+03
32831	19	-2	1220	2020-07-27 02:03:36.266112+03
32832	70	-2	760	2020-07-27 02:08:49.172996+03
32833	50	-1	1140	2020-07-27 02:09:04.145374+03
32834	90	-1	1780	2020-07-27 02:36:53.726466+03
32835	10	-1	2080	2020-07-27 02:57:52.300556+03
32836	14	-2	1350	2020-07-27 03:16:41.691892+03
32837	46	-1	1270	2020-07-27 03:22:34.546592+03
32838	71	-1	1030	2020-07-27 03:29:10.228371+03
32839	2	-2	470	2020-07-27 03:39:17.640951+03
32840	91	-1	1620	2020-07-27 04:04:55.710994+03
32841	72	-1	620	2020-07-27 04:06:08.67684+03
32842	27	-1	880	2020-07-27 04:58:18.31724+03
32843	8	-1	1920	2020-07-27 05:17:22.638168+03
32844	96	29	931	2020-07-27 05:18:54.930455+03
32845	9	-1	2090	2020-07-27 06:04:25.830225+03
32846	81	-1	1620	2020-07-27 06:19:40.328912+03
32847	27	-3	880	2020-07-27 06:32:59.570764+03
32848	52	-1	1090	2020-07-27 06:54:12.368575+03
32849	22	-2	1070	2020-07-27 06:54:35.501368+03
32850	57	-2	1900	2020-07-27 07:07:24.973366+03
32851	16	11	742	2020-07-27 07:27:11.557609+03
32852	37	-1	1290	2020-07-27 07:39:58.200092+03
32853	95	-1	480	2020-07-27 07:54:26.973519+03
32854	95	-1	480	2020-07-27 08:09:57.288922+03
32855	5	-1	1620	2020-07-27 08:10:00.899183+03
32856	78	-1	900	2020-07-27 08:32:49.955663+03
32857	46	-1	1270	2020-07-27 08:40:34.425698+03
32858	35	-1	670	2020-07-27 08:45:00.67768+03
32859	72	-1	620	2020-07-27 09:15:46.388082+03
32860	67	-1	350	2020-07-27 09:46:33.65536+03
32861	63	-1	1780	2020-07-27 09:58:18.6654+03
32862	49	-1	970	2020-07-27 09:58:33.204904+03
32863	13	-1	460	2020-07-27 10:15:49.81559+03
32864	69	-1	1100	2020-07-27 10:35:26.82368+03
32865	9	-1	2090	2020-07-27 10:58:26.805146+03
32866	21	-1	960	2020-07-27 11:11:27.103597+03
32867	14	-1	1350	2020-07-27 11:12:42.127005+03
32868	3	-1	660	2020-07-27 11:19:29.039029+03
32869	22	-1	1070	2020-07-27 11:29:03.475738+03
32870	37	-2	1290	2020-07-27 11:38:32.098271+03
32871	34	-1	1550	2020-07-27 12:09:35.483858+03
32872	18	-2	910	2020-07-27 12:13:17.518713+03
32873	17	-1	1500	2020-07-27 12:56:37.795563+03
32874	25	-2	1100	2020-07-27 13:03:06.074653+03
32875	47	-1	1480	2020-07-27 13:29:18.627187+03
32876	59	-1	1030	2020-07-27 13:42:17.579543+03
32877	65	-2	490	2020-07-27 13:45:55.219289+03
32878	67	-1	350	2020-07-27 13:51:38.911064+03
32879	79	-1	550	2020-07-27 13:55:28.181309+03
32880	35	-1	670	2020-07-27 14:01:12.859492+03
32881	36	35	327	2020-07-27 14:14:24.319717+03
32882	95	-1	480	2020-07-27 14:34:04.96436+03
32883	87	-1	2320	2020-07-27 14:47:06.673809+03
32884	57	-1	1900	2020-07-27 14:48:35.325059+03
32885	5	-1	1620	2020-07-27 14:51:38.644802+03
32886	7	-1	810	2020-07-27 14:52:48.81074+03
32887	88	-1	1270	2020-07-27 14:53:31.31926+03
32888	17	-1	1500	2020-07-27 15:11:35.990992+03
32889	18	-1	910	2020-07-27 15:39:37.489765+03
32890	76	-1	1070	2020-07-27 15:51:27.918321+03
32891	33	-1	900	2020-07-27 15:52:38.265321+03
32892	89	-1	1420	2020-07-27 15:56:43.566976+03
32893	19	-1	1220	2020-07-27 15:57:44.237826+03
32894	88	-1	1270	2020-07-27 16:03:15.190627+03
32895	26	-1	390	2020-07-27 16:18:16.720849+03
32896	23	-1	4390	2020-07-27 16:54:08.667937+03
32897	78	-1	900	2020-07-27 17:00:23.553995+03
32898	47	-1	1480	2020-07-27 17:09:48.705899+03
32899	96	-2	1570	2020-07-27 17:41:40.669013+03
32900	34	-2	1550	2020-07-27 17:41:46.146028+03
32901	75	-2	830	2020-07-27 17:44:22.700027+03
32902	28	-1	1860	2020-07-27 17:57:20.235473+03
32903	52	-1	1090	2020-07-27 18:01:26.347203+03
32904	27	-1	880	2020-07-27 18:10:45.666559+03
32905	39	-2	910	2020-07-27 18:13:54.906323+03
32906	93	-1	1620	2020-07-27 18:22:02.294504+03
32907	73	-1	960	2020-07-27 18:23:29.073352+03
32908	29	-1	1940	2020-07-27 18:29:42.127507+03
32909	70	-2	760	2020-07-27 18:31:26.262471+03
32910	4	-1	1420	2020-07-27 19:03:39.474061+03
32911	66	-2	690	2020-07-27 19:05:28.073163+03
32912	49	-1	970	2020-07-27 20:05:15.39441+03
32913	29	-1	1940	2020-07-27 20:17:35.18225+03
32914	1	-2	640	2020-07-27 20:32:03.025568+03
32915	6	-2	980	2020-07-27 20:43:50.053652+03
32916	52	-1	1090	2020-07-27 20:45:34.544498+03
32917	84	-1	2700	2020-07-27 20:48:39.162899+03
32918	29	-1	1940	2020-07-27 20:49:12.752948+03
32919	13	-1	460	2020-07-27 21:06:13.916175+03
32920	20	-1	830	2020-07-27 21:19:42.033878+03
32921	32	-2	710	2020-07-27 21:24:48.319259+03
32922	51	-1	1310	2020-07-27 21:27:32.650509+03
32923	16	-2	1380	2020-07-27 21:32:20.31778+03
32924	1	-1	640	2020-07-27 23:03:07.901617+03
32925	71	-1	1030	2020-07-27 23:07:03.700819+03
32926	71	-1	1030	2020-07-27 23:24:22.650343+03
32927	56	-2	2460	2020-07-27 23:30:14.558486+03
32928	26	-1	390	2020-07-27 23:40:22.606821+03
32929	22	-1	1070	2020-07-27 23:42:30.312737+03
32930	31	-1	1190	2020-07-28 00:18:56.527861+03
32931	11	-1	830	2020-07-28 00:26:24.299595+03
32932	46	-1	1270	2020-07-28 00:36:43.608168+03
32933	94	-1	1230	2020-07-28 00:42:49.920197+03
32934	56	-1	2460	2020-07-28 00:48:29.123395+03
32935	81	-2	1620	2020-07-28 00:50:41.082886+03
32936	6	-1	980	2020-07-28 00:57:16.3574+03
32937	71	-2	1030	2020-07-28 01:08:59.447684+03
32938	45	-1	1590	2020-07-28 01:18:35.775558+03
32939	87	38	974	2020-07-28 01:19:22.760259+03
32940	41	-1	830	2020-07-28 01:30:16.85469+03
32941	70	32	410	2020-07-28 01:42:08.976597+03
32942	8	-1	1920	2020-07-28 01:45:11.513041+03
32943	32	-2	710	2020-07-28 01:47:50.308147+03
32944	17	-1	1500	2020-07-28 01:57:20.460556+03
32945	87	-1	2320	2020-07-28 02:35:15.702607+03
32946	48	-2	640	2020-07-28 02:52:08.524873+03
32947	59	-1	1030	2020-07-28 02:59:19.218635+03
32948	12	-1	1650	2020-07-28 03:08:46.53933+03
32949	53	-1	3120	2020-07-28 03:09:34.906153+03
32950	90	-1	1780	2020-07-28 03:15:22.665514+03
32951	29	-1	1940	2020-07-28 03:21:42.147029+03
32952	93	-1	1620	2020-07-28 03:42:54.716805+03
32953	74	-1	1010	2020-07-28 04:05:47.804129+03
32954	49	-1	970	2020-07-28 04:07:36.531865+03
32955	59	-1	1030	2020-07-28 04:44:48.205536+03
32956	67	-1	350	2020-07-28 04:45:46.310082+03
32957	8	-3	1920	2020-07-28 04:46:53.618326+03
32958	45	-1	1590	2020-07-28 04:50:03.449291+03
32959	6	-1	980	2020-07-28 04:58:03.999083+03
32960	5	-1	1620	2020-07-28 04:58:20.118087+03
32961	43	-1	380	2020-07-28 05:19:16.894321+03
32962	92	-1	630	2020-07-28 05:24:04.992772+03
32963	49	-1	970	2020-07-28 05:32:22.591491+03
32964	52	-1	1090	2020-07-28 05:32:53.926904+03
32965	76	-1	1070	2020-07-28 05:36:48.104222+03
32966	92	-1	630	2020-07-28 05:47:50.100622+03
32967	41	-1	830	2020-07-28 05:57:41.171839+03
32968	93	-2	1620	2020-07-28 06:09:26.576171+03
32969	91	-1	1620	2020-07-28 06:32:22.433769+03
32970	31	32	604	2020-07-28 06:44:21.882354+03
32971	50	-1	1140	2020-07-28 07:01:15.790622+03
32972	12	-1	1650	2020-07-28 07:03:36.586182+03
32973	27	-1	880	2020-07-28 07:03:50.691451+03
32974	86	-1	910	2020-07-28 07:18:20.335154+03
32975	35	-1	670	2020-07-28 07:32:03.853266+03
32976	80	-2	1120	2020-07-28 07:32:26.401747+03
32977	58	-1	2830	2020-07-28 07:38:16.063598+03
32978	81	-1	1620	2020-07-28 07:44:03.879578+03
32979	53	-2	3120	2020-07-28 08:22:23.14133+03
32980	69	-1	1100	2020-07-28 08:55:46.21606+03
32981	75	-1	830	2020-07-28 09:16:52.126243+03
32982	3	-1	660	2020-07-28 09:36:25.756047+03
32983	57	-1	1900	2020-07-28 10:28:48.888763+03
32984	46	-1	1270	2020-07-28 10:45:11.543098+03
32985	35	-1	670	2020-07-28 11:31:24.057735+03
32986	13	-1	460	2020-07-28 11:49:21.398184+03
32987	40	-1	1430	2020-07-28 12:05:17.508941+03
32988	49	-1	970	2020-07-28 12:12:24.949922+03
32989	49	-2	970	2020-07-28 12:32:50.162948+03
32990	21	-2	960	2020-07-28 12:51:52.287479+03
32991	20	-1	830	2020-07-28 12:57:56.437307+03
32992	78	-1	900	2020-07-28 13:05:56.502824+03
32993	43	-1	380	2020-07-28 14:22:03.576954+03
32994	72	-1	620	2020-07-28 14:29:50.932816+03
32995	34	-1	1550	2020-07-28 14:43:22.162198+03
32996	71	-1	1030	2020-07-28 14:52:59.273815+03
32997	19	-2	1220	2020-07-28 15:02:40.486547+03
32998	80	-1	1120	2020-07-28 15:14:01.287401+03
32999	57	-2	1900	2020-07-28 15:46:54.585384+03
33000	59	-1	1030	2020-07-28 15:48:39.463698+03
33001	64	-2	970	2020-07-28 15:53:30.265134+03
33002	27	-1	880	2020-07-28 16:04:48.744269+03
33003	14	-1	1350	2020-07-28 16:12:15.876318+03
33004	33	-1	900	2020-07-28 16:16:13.041428+03
33005	81	-1	1620	2020-07-28 16:29:54.035176+03
33006	48	-1	640	2020-07-28 16:40:16.917022+03
33007	14	-1	1350	2020-07-28 16:42:13.809832+03
33008	51	-1	1310	2020-07-28 16:53:55.152507+03
33009	22	-1	1070	2020-07-28 17:34:33.907081+03
33010	43	-1	380	2020-07-28 17:43:48.68229+03
33011	14	-1	1350	2020-07-28 18:03:12.271801+03
33012	28	-1	1860	2020-07-28 18:16:42.156221+03
33013	6	-1	980	2020-07-28 18:20:26.178021+03
33014	58	-1	2830	2020-07-28 18:25:48.652102+03
33015	94	-1	1230	2020-07-28 19:01:57.234639+03
33016	18	-1	910	2020-07-28 19:26:45.161199+03
33017	94	-1	1230	2020-07-28 19:40:21.322586+03
33018	71	-1	1030	2020-07-28 19:42:23.975429+03
33019	58	-2	2830	2020-07-28 19:58:03.094432+03
33020	86	-1	910	2020-07-28 20:16:53.105434+03
33021	41	-1	830	2020-07-28 20:19:22.62562+03
33022	51	-1	1310	2020-07-28 20:26:22.87265+03
33023	60	-1	2700	2020-07-28 20:50:47.897359+03
33024	60	-1	2700	2020-07-28 20:51:31.732553+03
33025	89	-1	1420	2020-07-28 20:52:40.552993+03
33026	12	-1	1650	2020-07-28 20:59:15.329247+03
33027	46	-1	1270	2020-07-28 21:36:58.629133+03
33028	34	-1	1550	2020-07-28 21:51:37.577555+03
33029	10	-1	2080	2020-07-28 21:58:39.255028+03
33030	3	22	368	2020-07-28 22:34:52.215662+03
33031	4	-2	1420	2020-07-28 22:42:35.766277+03
33032	19	-1	1220	2020-07-28 22:48:34.297006+03
33033	64	-1	970	2020-07-28 23:10:01.987085+03
33034	85	-1	730	2020-07-28 23:32:11.225732+03
33035	51	-1	1310	2020-07-28 23:33:51.527862+03
33036	91	-2	1620	2020-07-28 23:56:59.423844+03
33037	78	-1	900	2020-07-29 00:14:16.784292+03
33038	41	-1	830	2020-07-29 00:23:49.623817+03
33039	57	-1	1900	2020-07-29 00:54:16.965046+03
33040	34	-1	1550	2020-07-29 01:04:33.558364+03
33041	57	-1	1900	2020-07-29 01:06:38.745443+03
33042	21	-1	960	2020-07-29 01:13:54.98692+03
33043	22	-1	1070	2020-07-29 01:36:22.146326+03
33044	43	-2	380	2020-07-29 01:58:26.92214+03
33045	79	-1	550	2020-07-29 02:06:39.945674+03
33046	56	-1	2460	2020-07-29 02:21:02.527743+03
33047	47	-1	1480	2020-07-29 02:38:44.228893+03
33048	15	-1	2830	2020-07-29 03:32:06.674749+03
33049	56	32	1142	2020-07-29 03:46:54.391125+03
33050	19	-1	1220	2020-07-29 04:08:03.269697+03
33051	52	-2	1090	2020-07-29 04:09:11.210516+03
33052	83	-1	1230	2020-07-29 04:11:12.246674+03
33053	51	-1	1310	2020-07-29 04:36:19.750423+03
33054	16	-1	1380	2020-07-29 04:43:23.600395+03
33055	82	-1	560	2020-07-29 04:48:01.23004+03
33056	18	-1	910	2020-07-29 04:48:35.352449+03
33057	95	-1	480	2020-07-29 04:53:01.528687+03
33058	10	-1	2080	2020-07-29 06:06:49.595286+03
33059	80	-1	1120	2020-07-29 06:33:55.196853+03
33060	32	-1	710	2020-07-29 06:48:32.358185+03
33061	87	-1	2320	2020-07-29 06:53:12.741435+03
33062	14	-1	1350	2020-07-29 07:19:13.158254+03
33063	9	-1	2090	2020-07-29 07:19:26.402441+03
33064	48	-1	640	2020-07-29 07:24:53.201357+03
33065	10	-1	2080	2020-07-29 07:39:04.170929+03
33066	76	-1	1070	2020-07-29 07:39:35.293495+03
33067	13	-1	460	2020-07-29 07:43:07.215834+03
33068	64	-1	970	2020-07-29 08:09:24.776154+03
33069	75	-1	830	2020-07-29 08:37:11.971339+03
33070	3	-2	660	2020-07-29 08:45:42.186318+03
33071	70	-1	760	2020-07-29 08:46:00.699821+03
33072	84	-1	2700	2020-07-29 09:08:03.631149+03
33073	82	-1	560	2020-07-29 09:09:29.090075+03
33074	71	-1	1030	2020-07-29 09:15:37.380956+03
33075	22	-1	1070	2020-07-29 09:16:00.349876+03
33076	94	-2	1230	2020-07-29 09:26:28.187912+03
33077	66	-1	690	2020-07-29 09:31:44.698734+03
33078	72	-2	620	2020-07-29 09:32:07.013684+03
33079	77	-1	640	2020-07-29 09:33:46.128058+03
33080	30	-2	1140	2020-07-29 09:45:58.344059+03
33081	86	-1	910	2020-07-29 10:07:21.017589+03
33082	4	-1	1420	2020-07-29 10:09:41.317366+03
33083	96	-1	1570	2020-07-29 10:37:44.096903+03
33084	22	-2	1070	2020-07-29 10:39:31.971885+03
33085	6	-1	980	2020-07-29 11:14:52.190032+03
33086	59	-1	1030	2020-07-29 11:29:55.052451+03
33087	39	-1	910	2020-07-29 11:58:08.943591+03
33088	16	-1	1380	2020-07-29 12:26:15.008257+03
33089	24	-1	950	2020-07-29 12:27:29.295769+03
33090	90	-1	1780	2020-07-29 12:46:09.780153+03
33091	20	38	384	2020-07-29 12:53:26.48428+03
33092	36	-1	630	2020-07-29 13:17:06.309059+03
33093	65	-1	490	2020-07-29 13:59:43.548653+03
33094	46	-2	1270	2020-07-29 14:20:18.715235+03
33095	9	-1	2090	2020-07-29 14:55:35.25586+03
33096	20	-1	830	2020-07-29 14:56:49.724258+03
33097	75	-1	830	2020-07-29 15:17:48.827387+03
33098	77	-1	640	2020-07-29 15:28:32.821467+03
33099	93	-1	1620	2020-07-29 15:32:12.890567+03
33100	11	-1	830	2020-07-29 16:02:06.353899+03
33101	8	-1	1920	2020-07-29 16:02:11.059283+03
33102	48	-1	640	2020-07-29 16:04:06.807778+03
33103	29	-1	1940	2020-07-29 16:10:29.960047+03
33104	20	-1	830	2020-07-29 16:13:35.842609+03
33105	89	-1	1420	2020-07-29 16:25:43.451627+03
33106	74	-1	1010	2020-07-29 17:12:43.024886+03
33107	37	-2	1290	2020-07-29 17:15:57.964866+03
33108	75	-1	830	2020-07-29 17:17:15.822004+03
33109	36	-1	630	2020-07-29 17:23:44.05629+03
33110	41	-1	830	2020-07-29 17:43:48.21718+03
33111	86	-1	910	2020-07-29 17:46:31.130535+03
33112	4	-1	1420	2020-07-29 18:28:13.672365+03
33113	74	-2	1010	2020-07-29 18:31:31.160248+03
33114	35	-1	670	2020-07-29 18:51:12.908751+03
33115	58	-1	2830	2020-07-29 18:53:16.029812+03
33116	1	-1	640	2020-07-29 18:56:29.451542+03
33117	67	-1	350	2020-07-29 18:57:26.016922+03
33118	16	-1	1380	2020-07-29 18:57:48.002533+03
33119	8	-1	1920	2020-07-29 19:01:41.419377+03
33120	4	-1	1420	2020-07-29 19:05:22.405404+03
33121	8	-1	1920	2020-07-29 19:08:37.580397+03
33122	92	-1	630	2020-07-29 19:21:11.477921+03
33123	83	-1	1230	2020-07-29 19:35:30.377184+03
33124	24	21	462	2020-07-29 19:45:50.897368+03
33125	80	-1	1120	2020-07-29 19:47:17.467527+03
33126	30	-1	1140	2020-07-29 19:58:24.868657+03
33127	71	-1	1030	2020-07-29 20:17:10.032996+03
33128	54	-1	3470	2020-07-29 20:22:56.430028+03
33129	16	-1	1380	2020-07-29 20:27:10.007033+03
33130	87	-1	2320	2020-07-29 20:29:27.385319+03
33131	20	-1	830	2020-07-29 20:56:32.143108+03
33132	59	-1	1030	2020-07-29 20:59:14.549259+03
33133	57	-1	1900	2020-07-29 21:15:28.097863+03
33134	15	-1	2830	2020-07-29 21:28:42.505279+03
33135	33	-2	900	2020-07-29 21:37:07.884583+03
33136	41	-2	830	2020-07-29 21:38:07.307693+03
33137	60	-1	2700	2020-07-29 21:39:20.056649+03
33138	21	-1	960	2020-07-29 21:46:01.442442+03
33139	56	-1	2460	2020-07-29 22:08:28.47471+03
33140	67	-3	350	2020-07-29 22:23:41.708497+03
33141	81	-1	1620	2020-07-29 22:27:47.402344+03
33142	73	-1	960	2020-07-29 22:29:40.361585+03
33143	18	-1	910	2020-07-29 22:47:42.288112+03
33144	63	-1	1780	2020-07-29 22:50:55.070413+03
33145	48	-1	640	2020-07-29 22:55:02.551332+03
33146	27	-1	880	2020-07-29 23:00:48.555893+03
33147	60	-2	2700	2020-07-29 23:02:05.284326+03
33148	94	24	510	2020-07-29 23:03:28.955037+03
33149	75	27	408	2020-07-29 23:12:40.475501+03
33150	26	-1	390	2020-07-29 23:19:29.704723+03
33151	34	-1	1550	2020-07-29 23:19:55.989266+03
33152	35	-1	670	2020-07-29 23:39:33.844654+03
33153	20	-1	830	2020-07-30 00:02:47.112831+03
33154	91	-1	1620	2020-07-30 00:30:26.777429+03
33155	79	-1	550	2020-07-30 00:32:33.529379+03
33156	16	-1	1380	2020-07-30 00:45:33.527089+03
33157	59	-2	1030	2020-07-30 00:47:01.209363+03
33158	89	-1	1420	2020-07-30 01:12:01.277642+03
33159	40	-1	1430	2020-07-30 01:34:16.988183+03
33160	44	-2	500	2020-07-30 01:45:57.935377+03
33161	87	-1	2320	2020-07-30 02:07:54.114332+03
33162	30	-1	1140	2020-07-30 02:19:42.381245+03
33163	55	-2	3480	2020-07-30 02:23:16.31139+03
33164	81	-2	1620	2020-07-30 02:36:36.163461+03
33165	11	-1	830	2020-07-30 02:39:05.87466+03
33166	91	25	875	2020-07-30 02:55:20.360241+03
33167	49	-1	970	2020-07-30 03:06:41.835743+03
33168	71	-1	1030	2020-07-30 03:32:39.124778+03
33169	72	7	303	2020-07-30 03:33:07.418135+03
33170	6	-1	980	2020-07-30 03:48:23.09003+03
33171	50	-1	1140	2020-07-30 03:52:39.38841+03
33172	37	-1	1290	2020-07-30 04:12:38.686827+03
33173	30	-1	1140	2020-07-30 04:18:29.534667+03
33174	33	-2	900	2020-07-30 04:52:59.510535+03
33175	74	-1	1010	2020-07-30 05:42:50.383012+03
33176	31	-1	1190	2020-07-30 05:44:06.449867+03
33177	52	-1	1090	2020-07-30 05:47:20.126988+03
33178	8	-1	1920	2020-07-30 05:55:05.600531+03
33179	23	-1	4390	2020-07-30 06:15:18.725814+03
33180	41	-1	830	2020-07-30 06:31:59.995518+03
33181	39	-1	910	2020-07-30 06:33:56.440012+03
33182	64	-1	970	2020-07-30 06:51:38.184957+03
33183	67	-1	350	2020-07-30 06:55:40.550647+03
33184	27	-1	880	2020-07-30 07:28:19.106426+03
33185	12	-1	1650	2020-07-30 08:09:48.448025+03
33186	59	-2	1030	2020-07-30 08:18:22.866158+03
33187	28	-1	1860	2020-07-30 08:25:31.522218+03
33188	4	-1	1420	2020-07-30 08:52:27.926093+03
33189	40	-1	1430	2020-07-30 08:54:20.920872+03
33190	5	-1	1620	2020-07-30 09:13:00.00534+03
33191	61	-1	1510	2020-07-30 09:13:13.649113+03
33192	79	17	259	2020-07-30 09:20:30.707551+03
33193	39	-1	910	2020-07-30 09:53:15.333207+03
33194	68	-1	490	2020-07-30 09:55:14.501048+03
33195	55	-1	3480	2020-07-30 10:03:39.080055+03
33196	15	-1	2830	2020-07-30 11:17:49.703051+03
33197	19	-2	1220	2020-07-30 11:47:50.655826+03
33198	14	-1	1350	2020-07-30 11:56:13.717094+03
33199	82	-1	560	2020-07-30 11:58:05.981305+03
33200	67	-1	350	2020-07-30 12:05:17.642658+03
33201	2	-1	470	2020-07-30 12:28:08.724372+03
33202	84	-1	2700	2020-07-30 12:47:54.446639+03
33203	73	-1	960	2020-07-30 12:54:05.622232+03
33204	56	-2	2460	2020-07-30 12:55:28.560408+03
33205	5	-1	1620	2020-07-30 13:00:11.397888+03
33206	25	-1	1100	2020-07-30 13:08:39.351817+03
33207	67	-1	350	2020-07-30 13:11:09.306878+03
33208	44	-1	500	2020-07-30 13:12:27.609516+03
33209	60	-2	2700	2020-07-30 13:12:41.72591+03
33210	30	-1	1140	2020-07-30 13:18:58.486003+03
33211	49	-1	970	2020-07-30 13:23:01.230743+03
33212	70	-1	760	2020-07-30 13:38:58.167868+03
33213	76	-1	1070	2020-07-30 13:53:32.199891+03
33214	13	-1	460	2020-07-30 13:59:32.100962+03
33215	7	-2	810	2020-07-30 14:18:54.241078+03
33216	24	-2	950	2020-07-30 14:28:00.085121+03
33217	57	-2	1900	2020-07-30 14:37:27.791545+03
33218	18	-1	910	2020-07-30 15:12:04.839436+03
33219	54	-1	3470	2020-07-30 15:28:26.539582+03
33220	42	-1	1790	2020-07-30 16:07:01.087295+03
33221	52	-1	1090	2020-07-30 16:46:50.704161+03
33222	13	-1	460	2020-07-30 16:46:51.185598+03
33223	56	-1	2460	2020-07-30 16:54:23.274803+03
33224	28	-1	1860	2020-07-30 17:05:06.988007+03
33225	84	-1	2700	2020-07-30 18:10:03.39523+03
33226	31	-1	1190	2020-07-30 18:24:58.845348+03
33227	44	-1	500	2020-07-30 18:27:06.745214+03
33228	69	-1	1100	2020-07-30 18:29:52.131593+03
33229	84	-1	2700	2020-07-30 19:05:27.7873+03
33230	95	-1	480	2020-07-30 19:26:00.664248+03
33231	69	-1	1100	2020-07-30 19:41:26.305131+03
33232	46	-1	1270	2020-07-30 19:54:50.271452+03
33233	62	-1	1220	2020-07-30 20:23:43.028687+03
33234	10	-1	2080	2020-07-30 20:41:42.654735+03
33235	53	-1	3120	2020-07-30 21:00:56.988631+03
33236	56	-1	2460	2020-07-30 21:04:04.889415+03
33237	1	-1	640	2020-07-30 21:36:58.572659+03
33238	61	-1	1510	2020-07-30 21:40:31.246312+03
33239	53	-1	3120	2020-07-30 21:43:44.108504+03
33240	30	-1	1140	2020-07-30 21:45:12.351777+03
33241	96	-1	1570	2020-07-30 22:42:20.184553+03
33242	30	-1	1140	2020-07-30 22:45:29.956953+03
33243	14	-1	1350	2020-07-30 22:45:58.732652+03
33244	51	-1	1310	2020-07-30 23:04:55.200081+03
33245	21	-1	960	2020-07-30 23:41:32.738196+03
33246	70	-2	760	2020-07-30 23:47:54.052836+03
33247	17	35	847	2020-07-31 00:04:42.264623+03
33248	30	-1	1140	2020-07-31 00:23:37.437567+03
33249	94	-1	1230	2020-07-31 00:45:59.717839+03
33250	37	-1	1290	2020-07-31 00:56:02.027986+03
33251	60	-1	2700	2020-07-31 01:11:38.015645+03
33252	49	-1	970	2020-07-31 01:24:07.459437+03
33253	15	-1	2830	2020-07-31 01:26:29.445299+03
33254	64	-2	970	2020-07-31 01:51:17.09389+03
33255	6	-1	980	2020-07-31 01:52:08.917663+03
33256	14	-1	1350	2020-07-31 01:53:09.045467+03
33257	36	-1	630	2020-07-31 01:53:19.994451+03
33258	49	-2	970	2020-07-31 02:34:29.301839+03
33259	95	-1	480	2020-07-31 02:39:09.540673+03
33260	37	-1	1290	2020-07-31 03:23:48.196351+03
33261	11	-1	830	2020-07-31 03:24:33.143099+03
33262	82	-1	560	2020-07-31 03:29:52.548396+03
33263	71	-2	1030	2020-07-31 03:37:54.55739+03
33264	65	-2	490	2020-07-31 04:22:08.751469+03
33265	69	-1	1100	2020-07-31 04:29:33.948482+03
33266	88	-1	1270	2020-07-31 04:47:54.253605+03
33267	74	-1	1010	2020-07-31 04:49:54.756927+03
33268	23	-1	4390	2020-07-31 04:51:24.528023+03
33269	86	-1	910	2020-07-31 04:52:17.369996+03
33270	37	-2	1290	2020-07-31 05:36:49.704672+03
33271	79	-1	550	2020-07-31 05:42:04.758532+03
33272	93	-1	1620	2020-07-31 05:51:32.891987+03
33273	29	-1	1940	2020-07-31 06:33:37.067751+03
33274	36	-1	630	2020-07-31 06:40:15.244509+03
33275	42	-1	1790	2020-07-31 07:03:38.295521+03
33276	50	-2	1140	2020-07-31 07:13:02.946888+03
33277	54	-1	3470	2020-07-31 07:15:44.80338+03
33278	78	-1	900	2020-07-31 07:44:32.456323+03
33279	75	-1	830	2020-07-31 07:54:18.451285+03
33280	52	-1	1090	2020-07-31 08:02:11.109993+03
33281	81	-1	1620	2020-07-31 08:03:45.747972+03
33282	53	-1	3120	2020-07-31 08:05:29.27606+03
33283	33	-1	900	2020-07-31 08:09:09.591831+03
33284	2	14	213	2020-07-31 08:32:40.275151+03
33285	10	-2	2080	2020-07-31 08:38:37.404306+03
33286	66	-1	690	2020-07-31 08:42:43.860832+03
33287	90	31	793	2020-07-31 08:46:16.971854+03
33288	79	-1	550	2020-07-31 09:24:29.093264+03
33289	95	-1	480	2020-07-31 09:25:50.661408+03
33290	18	-1	910	2020-07-31 09:26:37.299323+03
33291	51	-1	1310	2020-07-31 09:43:07.495164+03
33292	41	-1	830	2020-07-31 09:48:18.363974+03
33293	10	-1	2080	2020-07-31 09:59:37.270279+03
33294	82	-1	560	2020-07-31 10:15:08.156247+03
33295	13	-1	460	2020-07-31 10:36:17.106976+03
33296	96	-2	1570	2020-07-31 10:39:39.856852+03
33297	18	-1	910	2020-07-31 10:43:45.252116+03
33298	28	20	1026	2020-07-31 10:47:27.597043+03
33299	71	-1	1030	2020-07-31 10:57:49.663121+03
33300	54	-1	3470	2020-07-31 11:19:12.061669+03
33301	46	-2	1270	2020-07-31 11:31:01.216763+03
33302	47	-1	1480	2020-07-31 11:31:19.229198+03
33303	62	-2	1220	2020-07-31 11:50:41.669525+03
33304	33	-1	900	2020-07-31 12:03:40.430805+03
33305	9	-1	2090	2020-07-31 12:23:57.008453+03
33306	50	-2	1140	2020-07-31 12:27:54.849346+03
33307	23	-1	4390	2020-07-31 12:41:54.834802+03
33308	23	-1	4390	2020-07-31 12:48:54.822288+03
33309	26	-1	390	2020-07-31 12:58:09.378834+03
33310	64	-1	970	2020-07-31 12:58:41.890782+03
33311	29	-1	1940	2020-07-31 13:47:09.342969+03
33312	83	-1	1230	2020-07-31 13:47:35.692473+03
33313	62	-1	1220	2020-07-31 13:52:17.831086+03
33314	22	-1	1070	2020-07-31 13:53:45.208603+03
33315	94	-1	1230	2020-07-31 14:09:02.022846+03
33316	94	-1	1230	2020-07-31 14:31:36.314973+03
33317	10	-1	2080	2020-07-31 14:36:18.884273+03
33318	77	-1	640	2020-07-31 14:44:10.679289+03
33319	59	-1	1030	2020-07-31 15:25:12.982824+03
33320	75	-1	830	2020-07-31 15:38:42.974957+03
33321	81	-1	1620	2020-07-31 15:41:12.972854+03
33322	57	-1	1900	2020-07-31 15:53:45.002397+03
33323	33	-1	900	2020-07-31 16:05:53.254086+03
33324	51	29	640	2020-07-31 17:01:05.12078+03
33325	31	-1	1190	2020-07-31 17:02:49.213566+03
33326	36	-2	630	2020-07-31 17:04:40.537163+03
33327	35	-1	670	2020-07-31 17:05:29.200644+03
33328	82	-2	560	2020-07-31 17:08:47.913145+03
33329	32	-1	710	2020-07-31 17:16:16.98747+03
33330	90	-1	1780	2020-07-31 17:20:53.850036+03
33331	81	-1	1620	2020-07-31 18:02:41.209644+03
33332	83	-1	1230	2020-07-31 18:22:13.018819+03
33333	34	-1	1550	2020-07-31 19:04:07.566791+03
33334	36	-1	630	2020-07-31 19:05:14.970797+03
33335	22	-1	1070	2020-07-31 19:05:40.353218+03
33336	12	-1	1650	2020-07-31 19:30:04.367566+03
33337	87	-1	2320	2020-07-31 20:01:15.790622+03
33338	26	-1	390	2020-07-31 20:29:07.283736+03
33339	96	-2	1570	2020-07-31 20:43:49.235107+03
33340	69	-2	1100	2020-07-31 20:57:56.820122+03
33341	76	-1	1070	2020-07-31 21:16:18.26577+03
33342	37	-1	1290	2020-07-31 21:20:51.719054+03
33343	39	-1	910	2020-07-31 21:36:44.843136+03
33344	56	-1	2460	2020-07-31 21:40:29.803169+03
33345	20	-1	830	2020-07-31 21:54:56.989907+03
33346	94	-1	1230	2020-07-31 22:24:29.351542+03
33347	57	-1	1900	2020-07-31 22:29:13.748775+03
33348	76	-1	1070	2020-07-31 22:34:09.867909+03
33349	19	-1	1220	2020-07-31 22:59:02.559467+03
33350	96	-1	1570	2020-07-31 23:05:46.005507+03
33351	2	-1	470	2020-07-31 23:14:28.815592+03
33352	9	-1	2090	2020-07-31 23:50:36.656572+03
33353	25	-1	1100	2020-07-31 23:53:46.846025+03
33354	3	-1	660	2020-08-01 00:03:25.513964+03
33355	60	-2	2700	2020-08-01 00:13:16.871429+03
33356	48	-1	640	2020-08-01 00:14:00.397042+03
33357	38	-1	1100	2020-08-01 00:34:02.1095+03
33358	84	-2	2700	2020-08-01 00:36:26.757766+03
33359	49	-1	970	2020-08-01 00:44:05.98696+03
33360	37	-1	1290	2020-08-01 01:23:07.937339+03
33361	64	-1	970	2020-08-01 01:41:59.152593+03
33362	55	-1	3480	2020-08-01 01:46:37.544365+03
33363	21	-1	960	2020-08-01 01:51:48.824516+03
33364	85	-1	730	2020-08-01 01:57:08.449307+03
33365	75	-1	830	2020-08-01 02:08:17.801359+03
33366	70	-1	760	2020-08-01 02:38:11.911661+03
33367	47	-1	1480	2020-08-01 02:53:21.199363+03
33368	13	-1	460	2020-08-01 03:14:55.231986+03
33369	38	-1	1100	2020-08-01 03:28:45.933696+03
33370	48	-1	640	2020-08-01 03:30:39.987593+03
33371	94	-1	1230	2020-08-01 03:44:15.518848+03
33372	17	-3	1500	2020-08-01 03:51:08.760467+03
33373	13	-1	460	2020-08-01 03:55:18.068131+03
33374	55	-1	3480	2020-08-01 04:01:10.794193+03
33375	36	-1	630	2020-08-01 04:03:43.684219+03
33376	73	-1	960	2020-08-01 04:30:55.140166+03
33377	5	-1	1620	2020-08-01 05:35:47.977905+03
33378	78	-2	900	2020-08-01 06:15:16.205331+03
33379	74	-1	1010	2020-08-01 06:41:51.620341+03
33380	14	-2	1350	2020-08-01 06:59:34.91602+03
33381	88	-2	1270	2020-08-01 07:02:08.878641+03
33382	90	-2	1780	2020-08-01 07:17:13.00263+03
33383	16	-2	1380	2020-08-01 07:20:55.413497+03
33384	44	-1	500	2020-08-01 07:41:09.0135+03
33385	81	-1	1620	2020-08-01 07:48:15.025462+03
33386	6	-2	980	2020-08-01 07:58:06.800684+03
33387	59	-1	1030	2020-08-01 08:16:47.271119+03
33388	78	-1	900	2020-08-01 08:18:20.448164+03
33389	28	-1	1860	2020-08-01 08:19:25.855496+03
33390	90	-1	1780	2020-08-01 08:31:50.550675+03
33391	33	-1	900	2020-08-01 08:40:25.340279+03
33392	33	-1	900	2020-08-01 08:40:56.560294+03
33393	56	-2	2460	2020-08-01 08:50:04.115872+03
33394	47	-1	1480	2020-08-01 09:27:41.67514+03
33395	42	-1	1790	2020-08-01 09:40:17.085027+03
33396	5	-1	1620	2020-08-01 09:45:30.153908+03
33397	56	-1	2460	2020-08-01 10:10:03.437866+03
33398	29	-1	1940	2020-08-01 10:12:32.850717+03
33399	44	-1	500	2020-08-01 10:16:55.135613+03
33400	79	-1	550	2020-08-01 10:30:31.021057+03
33401	30	-1	1140	2020-08-01 10:39:01.142247+03
33402	18	-1	910	2020-08-01 11:04:38.996647+03
33403	7	-2	810	2020-08-01 11:33:02.335337+03
33404	12	-1	1650	2020-08-01 11:44:30.899283+03
33405	73	-2	960	2020-08-01 11:53:55.129335+03
33406	9	-1	2090	2020-08-01 12:01:31.331792+03
33407	34	-1	1550	2020-08-01 12:06:45.314519+03
33408	38	-1	1100	2020-08-01 12:35:00.656356+03
33409	48	-1	640	2020-08-01 12:48:04.36485+03
33410	78	-1	900	2020-08-01 12:48:47.482389+03
33411	46	-1	1270	2020-08-01 12:51:54.709269+03
33412	15	-1	2830	2020-08-01 14:02:49.680186+03
33413	63	-1	1780	2020-08-01 14:19:00.445383+03
33414	45	-1	1590	2020-08-01 14:39:00.639853+03
33415	62	-2	1220	2020-08-01 15:26:46.977834+03
33416	10	-1	2080	2020-08-01 15:26:54.225569+03
33417	58	-1	2830	2020-08-01 15:54:44.799921+03
33418	51	-1	1310	2020-08-01 16:08:25.189023+03
33419	5	-1	1620	2020-08-01 16:11:16.974305+03
33420	23	-1	4390	2020-08-01 16:29:00.796656+03
33421	23	27	1997	2020-08-01 16:39:27.998492+03
33422	46	-1	1270	2020-08-01 16:50:04.78005+03
33423	45	-3	1590	2020-08-01 17:09:43.331989+03
33424	6	26	565	2020-08-01 17:12:59.725435+03
33425	29	-1	1940	2020-08-01 17:16:27.940132+03
33426	53	-1	3120	2020-08-01 17:17:10.797203+03
33427	69	-1	1100	2020-08-01 17:24:18.228766+03
33428	26	-1	390	2020-08-01 17:39:09.420236+03
33429	56	-1	2460	2020-08-01 17:51:39.24448+03
33430	12	-1	1650	2020-08-01 18:03:48.355084+03
33431	29	-1	1940	2020-08-01 18:10:52.738467+03
33432	32	-1	710	2020-08-01 18:44:14.319909+03
33433	25	16	455	2020-08-01 19:11:01.96816+03
33434	18	-1	910	2020-08-01 19:14:39.649434+03
33435	57	-1	1900	2020-08-01 19:26:14.001175+03
33436	76	-1	1070	2020-08-01 19:32:51.799977+03
33437	91	-1	1620	2020-08-01 19:36:09.565716+03
33438	64	-1	970	2020-08-01 19:51:13.273123+03
33439	17	-1	1500	2020-08-01 19:53:13.983451+03
33440	83	-1	1230	2020-08-01 20:39:31.23016+03
33441	44	-2	500	2020-08-01 20:46:58.335309+03
33442	86	-1	910	2020-08-01 21:07:56.730137+03
33443	36	-1	630	2020-08-01 21:12:27.915481+03
33444	7	-2	810	2020-08-01 21:22:51.317135+03
33445	76	-1	1070	2020-08-01 21:23:13.777708+03
33446	42	-1	1790	2020-08-01 21:24:42.532763+03
33447	53	-2	3120	2020-08-01 22:02:14.536069+03
33448	20	-1	830	2020-08-01 22:18:43.489816+03
33449	58	-1	2830	2020-08-01 22:22:39.388333+03
33450	65	-2	490	2020-08-01 22:23:56.512996+03
33451	49	-1	970	2020-08-01 22:39:04.418695+03
33452	30	-1	1140	2020-08-01 23:09:03.298804+03
33453	34	-1	1550	2020-08-01 23:11:46.020116+03
33454	92	-1	630	2020-08-01 23:21:09.599641+03
33455	26	-1	390	2020-08-01 23:43:25.167489+03
33456	62	-1	1220	2020-08-01 23:45:21.090914+03
33457	96	-3	1570	2020-08-02 00:36:44.476404+03
33458	19	29	603	2020-08-02 00:47:01.309908+03
33459	94	-1	1230	2020-08-02 00:54:10.096462+03
33460	47	-1	1480	2020-08-02 01:35:02.683864+03
33461	10	-1	2080	2020-08-02 01:35:06.600661+03
33462	62	-2	1220	2020-08-02 01:57:18.130079+03
33463	48	-1	640	2020-08-02 02:01:04.128395+03
33464	60	-1	2700	2020-08-02 02:39:37.333377+03
33465	51	-1	1310	2020-08-02 02:45:00.193627+03
33466	41	-2	830	2020-08-02 04:48:32.052374+03
33467	61	-1	1510	2020-08-02 04:52:52.620997+03
33468	71	-1	1030	2020-08-02 05:03:47.114419+03
33469	49	-1	970	2020-08-02 05:16:16.010245+03
33470	85	-1	730	2020-08-02 05:20:10.842835+03
33471	22	-1	1070	2020-08-02 05:24:49.717317+03
33472	67	-1	350	2020-08-02 05:31:53.961876+03
33473	47	-1	1480	2020-08-02 05:37:04.249565+03
33474	70	-1	760	2020-08-02 05:44:25.601265+03
33475	36	-1	630	2020-08-02 05:55:19.16665+03
33476	34	-1	1550	2020-08-02 06:18:31.908538+03
33477	90	-1	1780	2020-08-02 06:26:06.356888+03
33478	22	-1	1070	2020-08-02 06:39:52.0017+03
33479	25	-1	1100	2020-08-02 06:46:54.172326+03
33480	12	-1	1650	2020-08-02 06:49:05.875638+03
33481	88	-1	1270	2020-08-02 06:59:25.762659+03
33482	92	-1	630	2020-08-02 07:00:46.128204+03
33483	8	-1	1920	2020-08-02 07:11:46.141083+03
33484	80	-1	1120	2020-08-02 07:53:07.42745+03
33485	80	-1	1120	2020-08-02 08:00:16.577054+03
33486	22	-1	1070	2020-08-02 08:01:13.112704+03
33487	71	-2	1030	2020-08-02 08:16:03.740947+03
33488	60	-2	2700	2020-08-02 08:43:05.54483+03
33489	67	-2	350	2020-08-02 09:04:22.37575+03
33490	19	-2	1220	2020-08-02 09:04:47.740014+03
33491	37	-1	1290	2020-08-02 09:18:00.069608+03
33492	76	-1	1070	2020-08-02 09:33:49.806692+03
33493	11	-2	830	2020-08-02 09:34:39.334206+03
33494	56	-2	2460	2020-08-02 09:53:28.617403+03
33495	33	26	492	2020-08-02 10:10:16.480367+03
33496	4	-1	1420	2020-08-02 10:18:37.883356+03
33497	44	-3	500	2020-08-02 10:25:43.149819+03
33498	34	-1	1550	2020-08-02 11:02:50.297912+03
33499	41	-1	830	2020-08-02 11:21:31.427331+03
33500	57	33	1074	2020-08-02 11:28:33.163837+03
33501	60	-1	2700	2020-08-02 11:46:25.062089+03
33502	86	-1	910	2020-08-02 12:27:59.138651+03
33503	30	-1	1140	2020-08-02 12:29:38.714425+03
33504	96	-1	1570	2020-08-02 12:37:50.27994+03
33505	39	-1	910	2020-08-02 12:45:59.510831+03
33506	45	-1	1590	2020-08-02 12:47:32.936517+03
33507	19	-1	1220	2020-08-02 13:00:48.276668+03
33508	5	-2	1620	2020-08-02 13:04:23.690898+03
33509	4	-2	1420	2020-08-02 13:06:49.303339+03
33510	23	-1	4390	2020-08-02 13:15:08.235467+03
33511	37	-1	1290	2020-08-02 13:41:17.901416+03
33512	95	-1	480	2020-08-02 14:36:15.50149+03
33513	94	-1	1230	2020-08-02 14:48:12.547616+03
33514	12	-1	1650	2020-08-02 14:57:19.88109+03
33515	6	-1	980	2020-08-02 15:01:21.964866+03
33516	4	-1	1420	2020-08-02 15:15:54.846545+03
33517	34	-1	1550	2020-08-02 15:28:32.295442+03
33518	81	27	874	2020-08-02 15:39:15.689165+03
33519	86	-1	910	2020-08-02 15:46:28.960795+03
33520	47	-2	1480	2020-08-02 16:01:59.965027+03
33521	56	-1	2460	2020-08-02 16:11:43.263578+03
33522	29	-1	1940	2020-08-02 16:31:38.531402+03
33523	71	-1	1030	2020-08-02 16:36:41.342919+03
33524	96	-1	1570	2020-08-02 16:48:55.872664+03
33525	70	-1	760	2020-08-02 17:07:39.240112+03
33526	82	-1	560	2020-08-02 17:12:20.329638+03
33527	59	-1	1030	2020-08-02 17:30:54.422952+03
33528	29	-2	1940	2020-08-02 17:37:09.969707+03
33529	12	-1	1650	2020-08-02 17:40:23.329542+03
33530	58	-2	2830	2020-08-02 17:43:23.382587+03
33531	94	-1	1230	2020-08-02 18:08:05.946072+03
33532	82	-1	560	2020-08-02 18:13:12.815271+03
33533	18	-1	910	2020-08-02 19:27:26.848912+03
33534	58	-1	2830	2020-08-02 19:51:09.821126+03
33535	15	-1	2830	2020-08-02 20:00:39.81748+03
33536	36	-1	630	2020-08-02 20:36:12.883363+03
33537	21	-2	960	2020-08-02 21:21:21.237408+03
33538	10	-1	2080	2020-08-02 21:22:58.254752+03
33539	47	-2	1480	2020-08-02 21:50:07.581974+03
33540	61	-1	1510	2020-08-02 21:53:04.756065+03
33541	8	-1	1920	2020-08-02 21:55:34.867305+03
33542	85	-1	730	2020-08-02 22:06:49.020721+03
33543	52	-1	1090	2020-08-02 23:24:24.091712+03
33544	16	-1	1380	2020-08-02 23:55:32.745606+03
33545	22	-1	1070	2020-08-03 00:06:57.37294+03
33546	17	-1	1500	2020-08-03 00:07:39.649853+03
33547	49	-1	970	2020-08-03 00:08:14.328429+03
33548	28	-1	1860	2020-08-03 00:31:48.277986+03
33549	36	-1	630	2020-08-03 00:33:53.586744+03
33550	36	-1	630	2020-08-03 00:48:42.529288+03
33551	65	-1	490	2020-08-03 01:04:15.671757+03
33552	12	-1	1650	2020-08-03 01:09:36.488882+03
33553	78	-1	900	2020-08-03 01:17:04.569333+03
33554	88	-1	1270	2020-08-03 01:18:06.069826+03
33555	51	-1	1310	2020-08-03 01:57:00.115056+03
33556	49	-2	970	2020-08-03 02:02:51.717234+03
33557	80	-1	1120	2020-08-03 02:11:31.614176+03
33558	53	-1	3120	2020-08-03 02:28:42.219084+03
33559	8	-1	1920	2020-08-03 02:49:19.918456+03
33560	96	-1	1570	2020-08-03 03:00:22.527234+03
33561	2	-1	470	2020-08-03 03:00:24.417072+03
33562	41	-1	830	2020-08-03 03:12:21.249547+03
33563	35	-1	670	2020-08-03 03:16:48.667041+03
33564	42	40	1046	2020-08-03 03:24:49.524943+03
33565	79	-2	550	2020-08-03 03:44:59.576216+03
33566	88	-1	1270	2020-08-03 03:48:52.389317+03
33567	88	-2	1270	2020-08-03 04:23:16.338935+03
33568	54	-1	3470	2020-08-03 04:59:34.217825+03
33569	63	-1	1780	2020-08-03 05:39:58.739027+03
33570	22	-1	1070	2020-08-03 06:02:45.040854+03
33571	6	-1	980	2020-08-03 06:58:16.218899+03
33572	65	-1	490	2020-08-03 07:02:55.580271+03
33573	42	-1	1790	2020-08-03 07:06:58.890306+03
33574	56	-2	2460	2020-08-03 07:16:38.451793+03
33575	85	-1	730	2020-08-03 07:20:29.302335+03
33576	51	-1	1310	2020-08-03 07:31:11.836913+03
33577	71	-1	1030	2020-08-03 07:47:31.469197+03
33578	86	-1	910	2020-08-03 07:48:02.879977+03
33579	9	-1	2090	2020-08-03 07:49:43.98007+03
33580	71	-1	1030	2020-08-03 07:54:30.584318+03
33581	43	-1	380	2020-08-03 08:19:39.25274+03
33582	59	-1	1030	2020-08-03 09:40:53.016164+03
33583	25	-1	1100	2020-08-03 09:43:35.880098+03
33584	96	-1	1570	2020-08-03 09:45:54.907458+03
33585	73	-1	960	2020-08-03 09:50:27.8803+03
33586	33	-1	900	2020-08-03 10:02:05.512045+03
33587	4	-1	1420	2020-08-03 10:39:12.879133+03
33588	24	-1	950	2020-08-03 10:44:43.330851+03
33589	10	-1	2080	2020-08-03 11:13:50.660783+03
33590	14	-1	1350	2020-08-03 11:22:18.777872+03
33591	73	-1	960	2020-08-03 11:30:23.891986+03
33592	12	-1	1650	2020-08-03 12:20:11.55669+03
33593	42	-1	1790	2020-08-03 12:21:43.075789+03
33594	13	-1	460	2020-08-03 13:02:52.347087+03
33595	78	-1	900	2020-08-03 13:12:03.241277+03
33596	16	-1	1380	2020-08-03 13:13:55.588013+03
33597	13	-1	460	2020-08-03 13:24:58.627727+03
33598	68	-1	490	2020-08-03 14:00:49.143452+03
33599	9	-1	2090	2020-08-03 14:06:16.597359+03
33600	65	17	288	2020-08-03 14:10:43.439058+03
33601	51	-2	1310	2020-08-03 14:19:24.14084+03
33602	18	-1	910	2020-08-03 14:47:38.957521+03
33603	60	-1	2700	2020-08-03 14:53:12.46251+03
33604	6	-1	980	2020-08-03 14:56:59.929411+03
33605	83	-1	1230	2020-08-03 15:19:30.857983+03
33606	33	-1	900	2020-08-03 16:12:47.904761+03
33607	21	-1	960	2020-08-03 16:13:20.223176+03
33608	81	-1	1620	2020-08-03 16:35:48.270269+03
33609	68	-1	490	2020-08-03 16:55:43.546912+03
33610	14	-1	1350	2020-08-03 17:04:11.325586+03
33611	6	-1	980	2020-08-03 17:16:24.525151+03
33612	10	-2	2080	2020-08-03 17:26:39.754092+03
33613	19	-2	1220	2020-08-03 18:04:16.562646+03
33614	15	-2	2830	2020-08-03 18:08:23.519648+03
33615	87	-2	2320	2020-08-03 18:20:51.150343+03
33616	36	-1	630	2020-08-03 18:56:03.789271+03
33617	8	-2	1920	2020-08-03 18:58:13.679986+03
33618	29	-1	1940	2020-08-03 19:09:58.221483+03
33619	96	-1	1570	2020-08-03 19:25:44.384237+03
33620	40	-1	1430	2020-08-03 19:27:36.187745+03
33621	78	-1	900	2020-08-03 19:47:40.994203+03
33622	31	-1	1190	2020-08-03 19:55:56.134886+03
33623	80	-1	1120	2020-08-03 20:02:04.691559+03
33624	72	-1	620	2020-08-03 20:04:16.024364+03
33625	96	-1	1570	2020-08-03 21:09:28.855195+03
33626	88	-1	1270	2020-08-03 21:33:48.427443+03
33627	42	-1	1790	2020-08-03 21:39:13.101781+03
33628	36	-1	630	2020-08-03 22:04:46.11203+03
33629	47	-1	1480	2020-08-03 22:08:31.823224+03
33630	12	-1	1650	2020-08-03 22:23:56.119197+03
33631	65	-1	490	2020-08-03 22:26:13.591566+03
33632	48	-1	640	2020-08-03 22:47:19.017065+03
33633	81	-1	1620	2020-08-03 23:25:10.988439+03
33634	56	-1	2460	2020-08-03 23:38:04.413052+03
33635	64	-1	970	2020-08-03 23:55:05.273477+03
33636	20	-1	830	2020-08-04 00:31:13.456854+03
33637	84	-1	2700	2020-08-04 00:39:54.465327+03
33638	56	-1	2460	2020-08-04 01:53:33.532845+03
33639	48	-1	640	2020-08-04 01:56:19.70213+03
33640	77	-1	640	2020-08-04 02:20:32.966144+03
33641	25	-1	1100	2020-08-04 02:23:38.159657+03
33642	39	-1	910	2020-08-04 02:32:17.849503+03
33643	89	-1	1420	2020-08-04 02:33:04.761388+03
33644	12	-1	1650	2020-08-04 02:51:49.735849+03
33645	28	-2	1860	2020-08-04 02:55:44.142956+03
33646	40	-1	1430	2020-08-04 03:08:57.939691+03
33647	42	-1	1790	2020-08-04 03:09:31.580782+03
33648	29	-1	1940	2020-08-04 03:13:50.70413+03
33649	13	-1	460	2020-08-04 03:53:06.296823+03
33650	89	-1	1420	2020-08-04 04:49:01.906941+03
33651	85	-1	730	2020-08-04 04:59:15.80225+03
33652	9	-1	2090	2020-08-04 05:03:01.752589+03
33653	45	-1	1590	2020-08-04 05:18:42.799521+03
33654	73	-2	960	2020-08-04 05:20:20.991217+03
33655	18	-2	910	2020-08-04 05:26:53.433343+03
33656	10	-1	2080	2020-08-04 05:54:54.716125+03
33657	45	-1	1590	2020-08-04 06:38:40.18694+03
33658	2	-1	470	2020-08-04 06:42:03.22043+03
33659	4	-2	1420	2020-08-04 07:25:01.958903+03
33660	17	-1	1500	2020-08-04 07:49:49.869332+03
33661	17	-2	1500	2020-08-04 07:58:22.800085+03
33662	46	-1	1270	2020-08-04 08:11:26.934308+03
33663	54	-1	3470	2020-08-04 08:28:24.414746+03
33664	71	-1	1030	2020-08-04 08:35:28.947587+03
33665	32	-1	710	2020-08-04 09:12:41.941327+03
33666	74	-2	1010	2020-08-04 09:45:16.776046+03
33667	20	-1	830	2020-08-04 09:49:01.718495+03
33668	27	-1	880	2020-08-04 09:54:03.712776+03
33669	91	-2	1620	2020-08-04 10:15:22.036233+03
33670	12	-1	1650	2020-08-04 10:15:41.079957+03
33671	35	-1	670	2020-08-04 10:33:06.417797+03
33672	76	-2	1070	2020-08-04 10:38:09.462461+03
33673	59	-1	1030	2020-08-04 10:41:59.881434+03
33674	90	-1	1780	2020-08-04 10:44:21.092137+03
33675	38	-1	1100	2020-08-04 10:46:17.134113+03
33676	68	-1	490	2020-08-04 11:47:56.899777+03
33677	22	-2	1070	2020-08-04 12:00:17.756393+03
33678	76	-1	1070	2020-08-04 12:20:27.751572+03
33679	3	-1	660	2020-08-04 12:40:43.424215+03
33680	48	27	382	2020-08-04 13:02:58.458707+03
33681	13	35	191	2020-08-04 13:37:59.391381+03
33682	87	-1	2320	2020-08-04 15:25:03.382365+03
33683	8	-1	1920	2020-08-04 15:37:28.691091+03
33684	84	36	1235	2020-08-04 16:22:58.095986+03
33685	51	-1	1310	2020-08-04 16:32:45.170817+03
33686	7	-2	810	2020-08-04 17:24:40.800466+03
33687	41	-3	830	2020-08-04 17:37:05.699235+03
33688	4	-1	1420	2020-08-04 18:14:34.170525+03
33689	4	-1	1420	2020-08-04 18:21:24.381812+03
33690	88	-1	1270	2020-08-04 18:39:31.546761+03
33691	69	-1	1100	2020-08-04 18:58:01.363874+03
33692	3	-3	660	2020-08-04 19:01:14.713575+03
33693	85	-1	730	2020-08-04 19:31:05.416594+03
33694	82	-1	560	2020-08-04 20:07:56.288869+03
33695	32	-1	710	2020-08-04 20:15:05.705767+03
33696	31	-1	1190	2020-08-04 21:03:26.445771+03
33697	59	-1	1030	2020-08-04 21:07:01.890685+03
33698	72	-1	620	2020-08-04 21:16:06.287815+03
33699	77	-1	640	2020-08-04 21:19:47.915214+03
33700	89	-1	1420	2020-08-04 21:24:14.151261+03
33701	48	-1	640	2020-08-04 21:25:49.776751+03
33702	91	-1	1620	2020-08-04 21:30:14.119212+03
33703	90	-1	1780	2020-08-04 21:40:20.623372+03
33704	18	-1	910	2020-08-04 21:43:35.936423+03
33705	6	-1	980	2020-08-04 21:57:21.3588+03
33706	65	-1	490	2020-08-04 22:16:03.076797+03
33707	29	-1	1940	2020-08-04 22:24:11.515376+03
33708	90	-2	1780	2020-08-04 22:27:43.778315+03
33709	56	-1	2460	2020-08-04 22:38:08.71364+03
33710	22	-2	1070	2020-08-04 22:41:36.108243+03
33711	57	-1	1900	2020-08-04 22:51:06.122722+03
33712	36	-1	630	2020-08-04 23:30:05.396954+03
33713	35	-1	670	2020-08-04 23:37:29.430085+03
33714	68	-1	490	2020-08-05 00:04:40.170357+03
33715	56	-1	2460	2020-08-05 00:23:26.746951+03
33716	12	-1	1650	2020-08-05 00:25:52.597901+03
33717	36	-2	630	2020-08-05 00:28:41.118834+03
33718	10	-2	2080	2020-08-05 00:31:18.606913+03
33719	6	-1	980	2020-08-05 00:33:40.583104+03
33720	68	-2	490	2020-08-05 01:32:53.24368+03
33721	44	-1	500	2020-08-05 02:36:52.536984+03
33722	80	-1	1120	2020-08-05 02:48:01.441439+03
33723	64	-1	970	2020-08-05 03:08:36.901709+03
33724	54	-1	3470	2020-08-05 03:11:40.531132+03
33725	42	-1	1790	2020-08-05 03:27:15.131801+03
33726	10	-1	2080	2020-08-05 03:48:10.11404+03
33727	90	-1	1780	2020-08-05 03:52:49.955823+03
33728	54	-3	3470	2020-08-05 04:08:03.196457+03
33729	54	-1	3470	2020-08-05 04:56:39.688373+03
33730	36	-1	630	2020-08-05 05:02:45.219823+03
33731	11	-1	830	2020-08-05 05:23:49.332043+03
33732	33	-2	900	2020-08-05 05:23:58.682665+03
33733	29	-1	1940	2020-08-05 05:31:35.228206+03
33734	3	-2	660	2020-08-05 05:50:50.896659+03
33735	26	-1	390	2020-08-05 05:58:24.19012+03
33736	7	-1	810	2020-08-05 07:54:54.939254+03
33737	70	-1	760	2020-08-05 07:56:19.302983+03
33738	70	-1	760	2020-08-05 07:56:53.182724+03
33739	10	-1	2080	2020-08-05 08:04:42.132986+03
33740	65	-1	490	2020-08-05 08:18:53.233369+03
33741	41	-2	830	2020-08-05 08:44:23.835955+03
33742	14	-1	1350	2020-08-05 09:00:28.566876+03
33743	39	-1	910	2020-08-05 09:05:58.97096+03
33744	71	-1	1030	2020-08-05 09:09:41.648098+03
33745	35	-1	670	2020-08-05 09:43:06.548082+03
33746	25	-1	1100	2020-08-05 09:48:56.779859+03
33747	64	-1	970	2020-08-05 09:55:33.544553+03
33748	41	-1	830	2020-08-05 09:59:32.50305+03
33749	37	-1	1290	2020-08-05 10:00:42.518364+03
33750	67	-1	350	2020-08-05 10:21:54.593703+03
33751	43	-1	380	2020-08-05 10:53:53.893705+03
33752	29	-1	1940	2020-08-05 11:04:17.635017+03
33753	96	-1	1570	2020-08-05 11:09:19.186304+03
33754	95	-1	480	2020-08-05 11:40:42.379848+03
33755	67	-2	350	2020-08-05 11:45:41.380023+03
33756	12	-1	1650	2020-08-05 11:49:52.677248+03
33757	13	-1	460	2020-08-05 11:52:33.177288+03
33758	54	-2	3470	2020-08-05 12:16:16.363726+03
33759	2	-1	470	2020-08-05 12:18:59.084215+03
33760	57	-1	1900	2020-08-05 12:25:18.677119+03
33761	44	-2	500	2020-08-05 12:29:50.446164+03
33762	5	-1	1620	2020-08-05 13:04:16.767597+03
33763	52	-1	1090	2020-08-05 13:25:51.53287+03
33764	45	28	755	2020-08-05 13:33:13.555912+03
33765	40	-1	1430	2020-08-05 13:47:31.463854+03
33766	49	-1	970	2020-08-05 14:14:27.250701+03
33767	95	-1	480	2020-08-05 14:24:43.878259+03
33768	89	-1	1420	2020-08-05 14:38:54.283274+03
33769	14	-1	1350	2020-08-05 14:47:31.510519+03
33770	44	-1	500	2020-08-05 14:51:43.02649+03
33771	20	-1	830	2020-08-05 15:12:54.088169+03
33772	64	-1	970	2020-08-05 15:21:02.573441+03
33773	87	-1	2320	2020-08-05 15:46:28.290224+03
33774	44	-1	500	2020-08-05 15:54:13.085608+03
33775	77	-2	640	2020-08-05 16:35:54.746473+03
33776	68	-1	490	2020-08-05 16:50:43.059333+03
33777	5	-2	1620	2020-08-05 16:55:23.389946+03
33778	87	-1	2320	2020-08-05 17:14:59.758072+03
33779	94	-1	1230	2020-08-05 17:38:06.822976+03
33780	54	-1	3470	2020-08-05 17:56:33.502046+03
33781	35	-1	670	2020-08-05 17:56:45.213491+03
33782	7	-1	810	2020-08-05 18:08:11.955923+03
33783	58	26	1157	2020-08-05 18:32:15.471189+03
33784	42	-1	1790	2020-08-05 18:41:36.809822+03
33785	56	-3	2460	2020-08-05 18:53:10.334524+03
33786	28	-2	1860	2020-08-05 19:13:34.628935+03
33787	58	-2	2830	2020-08-05 19:16:50.636078+03
33788	87	-1	2320	2020-08-05 19:33:18.783054+03
33789	20	-2	830	2020-08-05 19:59:04.396444+03
33790	50	-1	1140	2020-08-05 21:01:27.514735+03
33791	39	-1	910	2020-08-05 21:01:58.307536+03
33792	31	-2	1190	2020-08-05 21:03:52.702504+03
33793	78	-1	900	2020-08-05 22:16:05.94867+03
33794	13	-1	460	2020-08-05 22:18:52.734215+03
33795	87	-1	2320	2020-08-05 22:41:43.382238+03
33796	88	-2	1270	2020-08-05 22:53:49.538497+03
33797	69	-1	1100	2020-08-05 23:03:08.542449+03
33798	12	-1	1650	2020-08-05 23:14:31.518898+03
33799	91	-1	1620	2020-08-05 23:24:42.982321+03
33800	74	-1	1010	2020-08-05 23:38:15.839665+03
33801	71	-1	1030	2020-08-05 23:48:59.609794+03
33802	86	-1	910	2020-08-05 23:59:47.031278+03
33803	81	-1	1620	2020-08-06 00:21:21.045639+03
33804	49	-1	970	2020-08-06 00:31:56.581103+03
33805	54	-1	3470	2020-08-06 01:01:29.456918+03
33806	42	-1	1790	2020-08-06 01:55:06.747289+03
33807	70	-1	760	2020-08-06 01:55:35.316527+03
33808	9	-1	2090	2020-08-06 02:22:04.447719+03
33809	29	-1	1940	2020-08-06 02:38:53.270356+03
33810	11	19	382	2020-08-06 03:21:32.002797+03
33811	36	-1	630	2020-08-06 03:21:45.697277+03
33812	47	-1	1480	2020-08-06 03:22:26.062502+03
33813	53	-1	3120	2020-08-06 03:36:59.648814+03
33814	39	-2	910	2020-08-06 03:39:21.77738+03
33815	65	-1	490	2020-08-06 03:50:09.173742+03
33816	50	-1	1140	2020-08-06 04:21:12.204857+03
33817	81	-2	1620	2020-08-06 04:29:34.445285+03
33818	9	-1	2090	2020-08-06 04:51:04.089316+03
33819	17	-1	1500	2020-08-06 04:57:05.460683+03
33820	46	-1	1270	2020-08-06 04:58:12.810626+03
33821	6	-1	980	2020-08-06 05:22:00.561613+03
33822	37	-1	1290	2020-08-06 05:24:45.328271+03
33823	96	-1	1570	2020-08-06 05:28:05.776641+03
33824	5	-1	1620	2020-08-06 05:46:21.825423+03
33825	74	-1	1010	2020-08-06 05:46:46.323913+03
33826	1	-1	640	2020-08-06 05:47:19.151138+03
33827	77	-1	640	2020-08-06 05:52:38.806428+03
33828	33	-1	900	2020-08-06 05:59:37.035552+03
33829	85	-1	730	2020-08-06 06:00:47.309807+03
33830	73	-1	960	2020-08-06 06:25:35.323371+03
33831	19	-1	1220	2020-08-06 06:27:08.428047+03
33832	3	-1	660	2020-08-06 06:29:13.620268+03
33833	4	-1	1420	2020-08-06 06:33:14.529863+03
33834	17	-1	1500	2020-08-06 06:36:18.178738+03
33835	50	-1	1140	2020-08-06 07:01:14.214589+03
33836	76	-1	1070	2020-08-06 07:03:04.524154+03
33837	60	-1	2700	2020-08-06 07:09:59.405403+03
33838	39	-1	910	2020-08-06 07:15:35.538355+03
33839	32	-2	710	2020-08-06 07:17:08.603794+03
33840	87	-1	2320	2020-08-06 07:42:43.349867+03
33841	64	-1	970	2020-08-06 07:52:01.903243+03
33842	6	-1	980	2020-08-06 08:13:48.752012+03
33843	40	-2	1430	2020-08-06 08:16:22.521805+03
33844	30	-1	1140	2020-08-06 08:29:28.757499+03
33845	22	-1	1070	2020-08-06 08:52:46.11684+03
33846	56	-1	2460	2020-08-06 08:54:59.319912+03
33847	87	-1	2320	2020-08-06 09:12:50.540696+03
33848	39	-1	910	2020-08-06 09:14:29.075701+03
33849	43	-1	380	2020-08-06 09:49:05.431267+03
33850	21	-1	960	2020-08-06 09:51:06.26359+03
33851	44	-1	500	2020-08-06 10:12:15.599764+03
33852	29	-1	1940	2020-08-06 10:15:52.200064+03
33853	20	-1	830	2020-08-06 10:20:01.56091+03
33854	35	-1	670	2020-08-06 10:32:41.934667+03
33855	87	-1	2320	2020-08-06 10:48:00.349079+03
33856	48	-2	640	2020-08-06 11:24:10.327513+03
33857	61	-1	1510	2020-08-06 11:24:56.179964+03
33858	84	-1	2700	2020-08-06 11:51:08.270543+03
33859	29	-2	1940	2020-08-06 11:57:02.687059+03
33860	55	-1	3480	2020-08-06 12:12:38.620137+03
33861	92	-2	630	2020-08-06 12:45:30.951155+03
33862	72	-2	620	2020-08-06 13:25:19.063055+03
33863	87	-2	2320	2020-08-06 13:47:09.51025+03
33864	54	-1	3470	2020-08-06 14:22:10.436624+03
33865	24	-1	950	2020-08-06 14:22:36.135913+03
33866	30	-1	1140	2020-08-06 14:30:05.762765+03
33867	29	-1	1940	2020-08-06 14:41:05.804657+03
33868	11	-2	830	2020-08-06 14:41:36.556799+03
33869	77	-1	640	2020-08-06 14:56:59.67088+03
33870	48	-1	640	2020-08-06 15:17:50.306265+03
33871	30	-1	1140	2020-08-06 15:51:09.602943+03
33872	1	-1	640	2020-08-06 15:54:35.337541+03
33873	95	-2	480	2020-08-06 16:35:34.232574+03
33874	69	-1	1100	2020-08-06 16:38:10.037336+03
33875	43	-1	380	2020-08-06 16:44:25.375393+03
33876	52	-1	1090	2020-08-06 16:50:52.300338+03
33877	62	-1	1220	2020-08-06 16:55:39.801717+03
33878	33	-2	900	2020-08-06 16:59:39.048182+03
33879	10	-2	2080	2020-08-06 17:08:37.791843+03
33880	59	-1	1030	2020-08-06 17:24:21.934337+03
33881	32	-2	710	2020-08-06 17:48:58.658957+03
33882	40	-2	1430	2020-08-06 17:56:13.145568+03
33883	20	-1	830	2020-08-06 18:12:25.093568+03
33884	40	-2	1430	2020-08-06 18:15:45.533412+03
33885	85	-1	730	2020-08-06 18:37:15.775833+03
33886	88	-1	1270	2020-08-06 18:45:04.339493+03
33887	95	-1	480	2020-08-06 19:00:40.113795+03
33888	46	-1	1270	2020-08-06 19:15:32.019343+03
33889	25	-1	1100	2020-08-06 19:31:51.611956+03
33890	51	-1	1310	2020-08-06 20:40:23.863506+03
33891	87	-1	2320	2020-08-06 20:50:17.701916+03
33892	10	-1	2080	2020-08-06 21:00:25.055272+03
33893	13	-1	460	2020-08-06 21:17:52.459915+03
33894	79	-1	550	2020-08-06 22:09:58.730586+03
33895	49	-1	970	2020-08-06 23:50:32.45382+03
33896	58	-2	2830	2020-08-06 23:56:06.533144+03
33897	1	-2	640	2020-08-07 00:00:24.737721+03
33898	83	-2	1230	2020-08-07 00:11:39.255359+03
33899	95	29	288	2020-08-07 00:54:44.412125+03
33900	68	20	261	2020-08-07 01:09:35.194536+03
33901	62	-1	1220	2020-08-07 01:12:31.359379+03
33902	71	-1	1030	2020-08-07 01:18:19.253649+03
33903	78	-2	900	2020-08-07 01:39:00.313398+03
33904	58	-1	2830	2020-08-07 01:48:37.93257+03
33905	64	27	516	2020-08-07 02:03:14.704217+03
33906	35	-2	670	2020-08-07 02:14:25.253048+03
33907	82	-1	560	2020-08-07 02:21:01.845534+03
33908	71	-1	1030	2020-08-07 02:32:21.097729+03
33909	57	-2	1900	2020-08-07 02:37:04.239643+03
33910	96	-1	1570	2020-08-07 02:49:12.699123+03
33911	53	-1	3120	2020-08-07 02:50:36.54972+03
33912	76	-1	1070	2020-08-07 03:30:15.338146+03
33913	11	-1	830	2020-08-07 04:11:33.892131+03
33914	67	28	180	2020-08-07 04:29:26.17301+03
33915	54	28	1746	2020-08-07 04:41:53.008031+03
33916	64	-1	970	2020-08-07 04:54:19.681676+03
33917	85	-1	730	2020-08-07 05:04:49.790646+03
33918	19	-1	1220	2020-08-07 05:16:01.286173+03
33919	76	-1	1070	2020-08-07 05:35:56.40012+03
33920	89	-1	1420	2020-08-07 05:37:49.342974+03
33921	87	-1	2320	2020-08-07 05:39:36.766876+03
33922	86	-1	910	2020-08-07 05:48:19.068664+03
33923	40	-1	1430	2020-08-07 05:53:05.282446+03
33924	6	-2	980	2020-08-07 06:06:31.127192+03
33925	54	-1	3470	2020-08-07 06:10:52.436847+03
33926	64	-2	970	2020-08-07 06:20:00.770272+03
33927	28	-1	1860	2020-08-07 06:25:49.239973+03
33928	33	-1	900	2020-08-07 06:52:56.93873+03
33929	76	-1	1070	2020-08-07 07:01:30.355652+03
33930	71	-2	1030	2020-08-07 07:31:41.479796+03
33931	89	-2	1420	2020-08-07 07:32:03.655756+03
33932	92	26	263	2020-08-07 07:42:23.700895+03
33933	18	-1	910	2020-08-07 07:43:42.552679+03
33934	35	-1	670	2020-08-07 08:12:43.261679+03
33935	51	-1	1310	2020-08-07 08:23:55.420135+03
33936	61	-1	1510	2020-08-07 08:47:32.920004+03
33937	42	-2	1790	2020-08-07 09:06:37.803328+03
33938	12	42	805	2020-08-07 09:41:29.363093+03
33939	61	-2	1510	2020-08-07 10:13:51.7202+03
33940	49	33	414	2020-08-07 10:31:11.93872+03
33941	46	-1	1270	2020-08-07 10:50:27.924325+03
33942	87	-1	2320	2020-08-07 11:52:50.007566+03
33943	22	-1	1070	2020-08-07 12:18:57.485555+03
33944	75	-1	830	2020-08-07 12:44:15.159073+03
33945	32	-1	710	2020-08-07 12:52:34.949503+03
33946	4	-2	1420	2020-08-07 12:56:30.998694+03
33947	38	39	653	2020-08-07 13:48:44.89504+03
33948	14	-1	1350	2020-08-07 13:50:25.270446+03
33949	92	-2	630	2020-08-07 14:01:20.511014+03
33950	78	-2	900	2020-08-07 14:05:59.344619+03
33951	14	-1	1350	2020-08-07 14:26:52.941893+03
33952	55	-1	3480	2020-08-07 14:27:54.881147+03
33953	28	-3	1860	2020-08-07 15:47:24.64664+03
33954	8	-1	1920	2020-08-07 15:48:19.262005+03
33955	48	-1	640	2020-08-07 16:05:45.333988+03
33956	24	-1	950	2020-08-07 16:25:16.437099+03
33957	71	-1	1030	2020-08-07 17:28:17.205828+03
33958	58	-1	2830	2020-08-07 17:32:35.581052+03
33959	81	-1	1620	2020-08-07 18:26:27.791808+03
33960	54	-2	3470	2020-08-07 19:07:42.894334+03
33961	47	52	600	2020-08-07 19:09:37.167926+03
33962	64	-1	970	2020-08-07 19:14:31.439558+03
33963	39	-1	910	2020-08-07 19:16:22.928899+03
33964	73	-1	960	2020-08-07 19:29:33.925249+03
33965	92	-1	630	2020-08-07 19:32:13.803573+03
33966	6	-1	980	2020-08-07 20:07:25.418325+03
33967	24	-1	950	2020-08-07 20:37:41.976067+03
33968	64	-1	970	2020-08-07 20:39:04.003492+03
33969	88	-1	1270	2020-08-07 20:39:39.61359+03
33970	46	-1	1270	2020-08-07 21:11:18.102587+03
33971	58	-2	2830	2020-08-07 21:16:18.369354+03
33972	38	-1	1100	2020-08-07 21:27:09.229655+03
33973	20	-1	830	2020-08-07 21:27:44.52514+03
33974	80	-1	1120	2020-08-07 22:04:22.879703+03
33975	5	-2	1620	2020-08-07 22:05:30.757173+03
33976	77	-1	640	2020-08-07 22:57:06.261527+03
33977	64	-2	970	2020-08-07 22:57:07.956067+03
33978	20	-1	830	2020-08-07 23:14:07.846645+03
33979	16	11	797	2020-08-07 23:17:56.690739+03
33980	18	-2	910	2020-08-07 23:40:03.908517+03
33981	31	-1	1190	2020-08-08 00:04:20.707318+03
33982	58	-1	2830	2020-08-08 00:04:29.33698+03
33983	84	-1	2700	2020-08-08 00:06:10.318901+03
33984	86	-1	910	2020-08-08 00:30:21.491237+03
33985	62	15	662	2020-08-08 00:33:18.764344+03
33986	59	28	577	2020-08-08 00:40:47.459634+03
33987	70	-1	760	2020-08-08 00:45:11.001718+03
33988	94	-2	1230	2020-08-08 00:53:07.025677+03
33989	20	-2	830	2020-08-08 00:53:11.835045+03
33990	46	-2	1270	2020-08-08 00:58:46.240682+03
33991	6	-1	980	2020-08-08 00:59:07.549481+03
33992	10	-1	2080	2020-08-08 01:04:49.952342+03
33993	24	-1	950	2020-08-08 01:13:26.089241+03
33994	35	-1	670	2020-08-08 01:17:59.712353+03
33995	47	-1	1480	2020-08-08 01:26:35.053724+03
33996	19	-1	1220	2020-08-08 01:27:58.105135+03
33997	43	-1	380	2020-08-08 01:53:25.941774+03
33998	90	-1	1780	2020-08-08 01:54:31.726368+03
33999	88	-1	1270	2020-08-08 02:00:02.65247+03
34000	38	-2	1100	2020-08-08 02:18:50.192683+03
34001	82	-2	560	2020-08-08 02:25:38.730248+03
34002	71	-1	1030	2020-08-08 02:33:47.403434+03
34003	93	-1	1620	2020-08-08 02:37:29.029373+03
34004	28	-1	1860	2020-08-08 03:41:37.487598+03
34005	56	-2	2460	2020-08-08 03:43:57.481062+03
34006	38	-2	1100	2020-08-08 03:49:13.031964+03
34007	20	-1	830	2020-08-08 03:52:28.696127+03
34008	94	-1	1230	2020-08-08 03:57:55.023165+03
34009	78	-1	900	2020-08-08 04:09:07.090602+03
34010	39	-1	910	2020-08-08 04:36:46.946697+03
34011	93	-1	1620	2020-08-08 05:40:48.697622+03
34012	32	-1	710	2020-08-08 06:07:28.222528+03
34013	47	-1	1480	2020-08-08 06:18:33.927448+03
34014	8	-1	1920	2020-08-08 07:41:41.092744+03
34015	92	-1	630	2020-08-08 08:00:09.594101+03
34016	37	-1	1290	2020-08-08 08:03:16.298333+03
34017	35	-1	670	2020-08-08 08:41:26.018902+03
34018	71	35	508	2020-08-08 08:56:31.940215+03
34019	81	-1	1620	2020-08-08 09:06:17.923068+03
34020	47	-1	1480	2020-08-08 09:27:25.232706+03
34021	31	-2	1190	2020-08-08 09:38:42.389246+03
34022	10	-1	2080	2020-08-08 09:47:19.700495+03
34023	44	-1	500	2020-08-08 09:50:10.009375+03
34024	8	-1	1920	2020-08-08 09:59:09.028642+03
34025	42	-1	1790	2020-08-08 10:13:01.358844+03
34026	62	-1	1220	2020-08-08 10:19:08.234623+03
34027	69	-1	1100	2020-08-08 10:38:07.381285+03
34028	40	-1	1430	2020-08-08 10:45:36.893646+03
34029	68	-1	490	2020-08-08 10:52:19.723894+03
34030	34	31	861	2020-08-08 10:57:24.191773+03
34031	29	-1	1940	2020-08-08 10:58:51.250747+03
34032	94	-1	1230	2020-08-08 11:03:35.15679+03
34033	75	-2	830	2020-08-08 11:10:51.275375+03
34034	45	-2	1590	2020-08-08 11:13:26.698046+03
34035	73	-1	960	2020-08-08 11:20:29.525078+03
34036	96	-1	1570	2020-08-08 11:34:15.381764+03
34037	61	-1	1510	2020-08-08 11:41:09.311659+03
34038	29	-1	1940	2020-08-08 12:04:42.737092+03
34039	46	-1	1270	2020-08-08 12:13:56.618671+03
34040	33	-1	900	2020-08-08 12:18:25.491253+03
34041	9	26	979	2020-08-08 12:20:36.281266+03
34042	59	-1	1030	2020-08-08 12:40:48.138093+03
34043	18	-1	910	2020-08-08 12:56:27.398072+03
34044	68	-2	490	2020-08-08 13:05:25.561897+03
34045	14	-2	1350	2020-08-08 13:08:27.565225+03
34046	19	-1	1220	2020-08-08 13:18:13.016056+03
34047	29	-1	1940	2020-08-08 13:24:08.90112+03
34048	24	-1	950	2020-08-08 13:42:05.089772+03
34049	92	-1	630	2020-08-08 13:53:55.440638+03
34050	53	-2	3120	2020-08-08 14:16:01.404538+03
34051	20	-2	830	2020-08-08 14:16:56.15784+03
34052	69	-1	1100	2020-08-08 14:22:37.349403+03
34053	73	-1	960	2020-08-08 14:44:51.174325+03
34054	75	-3	830	2020-08-08 14:48:32.148556+03
34055	53	-1	3120	2020-08-08 15:08:20.622404+03
34056	16	-2	1380	2020-08-08 16:04:46.215489+03
34057	75	-1	830	2020-08-08 16:34:46.090121+03
34058	52	-1	1090	2020-08-08 17:17:34.748029+03
34059	28	-1	1860	2020-08-08 17:43:18.154891+03
34060	74	19	414	2020-08-08 17:43:29.209541+03
34061	84	-2	2700	2020-08-08 17:56:00.092223+03
34062	19	-1	1220	2020-08-08 18:17:09.461911+03
34063	21	-1	960	2020-08-08 18:20:17.366334+03
34064	10	-1	2080	2020-08-08 18:27:21.690942+03
34065	18	-1	910	2020-08-08 19:00:56.877476+03
34066	13	-1	460	2020-08-08 19:29:24.313202+03
34067	47	-1	1480	2020-08-08 19:40:13.045013+03
34068	33	-2	900	2020-08-08 19:41:59.155661+03
34069	72	-2	620	2020-08-08 19:50:41.652236+03
34070	10	33	1005	2020-08-08 19:51:37.413394+03
34071	74	-1	1010	2020-08-08 19:54:07.68213+03
34072	48	-2	640	2020-08-08 20:33:56.203802+03
34073	40	31	772	2020-08-08 20:52:47.845591+03
34074	76	-1	1070	2020-08-08 21:03:53.990253+03
34075	92	-1	630	2020-08-08 21:12:14.290504+03
34076	47	-1	1480	2020-08-08 21:40:26.480485+03
34077	86	-1	910	2020-08-08 21:42:19.738528+03
34078	89	-1	1420	2020-08-08 21:50:08.739256+03
34079	77	-2	640	2020-08-08 22:18:25.319414+03
34080	5	-2	1620	2020-08-08 22:21:14.358557+03
34081	12	-1	1650	2020-08-08 22:22:54.449964+03
34082	34	-1	1550	2020-08-08 22:27:45.842711+03
34083	59	-1	1030	2020-08-08 22:39:30.051933+03
34084	17	-1	1500	2020-08-08 23:10:56.394118+03
34085	7	-1	810	2020-08-08 23:53:58.502726+03
34086	41	-2	830	2020-08-09 00:13:00.489816+03
34087	48	-2	640	2020-08-09 00:28:09.916567+03
34088	60	-1	2700	2020-08-09 00:35:56.404189+03
34089	68	-1	490	2020-08-09 00:48:36.762269+03
34090	48	-1	640	2020-08-09 00:49:02.089147+03
34091	77	-1	640	2020-08-09 01:02:23.234079+03
34092	82	-2	560	2020-08-09 01:37:24.912227+03
34093	76	-1	1070	2020-08-09 01:44:20.2351+03
34094	8	-2	1920	2020-08-09 01:45:01.601495+03
34095	70	-1	760	2020-08-09 02:04:53.934601+03
34096	49	-1	970	2020-08-09 02:05:46.34454+03
34097	14	-1	1350	2020-08-09 02:08:27.551351+03
34098	82	-1	560	2020-08-09 02:30:16.81064+03
34099	72	-1	620	2020-08-09 02:31:57.885359+03
34100	47	-1	1480	2020-08-09 02:32:17.355522+03
34101	46	-1	1270	2020-08-09 02:45:59.021128+03
34102	20	-1	830	2020-08-09 02:46:54.194786+03
34103	60	-2	2700	2020-08-09 02:47:38.993928+03
34104	8	-1	1920	2020-08-09 03:22:05.638185+03
34105	89	-1	1420	2020-08-09 03:55:08.131911+03
34106	78	-1	900	2020-08-09 04:00:59.264661+03
34107	69	-1	1100	2020-08-09 04:25:41.621272+03
34108	8	-1	1920	2020-08-09 04:55:44.043477+03
34109	87	-1	2320	2020-08-09 04:57:39.009625+03
34110	81	-1	1620	2020-08-09 05:14:33.464713+03
34111	27	-1	880	2020-08-09 05:33:45.326662+03
34112	36	-1	630	2020-08-09 05:35:23.424898+03
34113	11	-1	830	2020-08-09 05:48:16.529482+03
34114	76	-1	1070	2020-08-09 06:14:49.521463+03
34115	30	-1	1140	2020-08-09 06:35:20.606367+03
34116	61	-1	1510	2020-08-09 06:37:27.572872+03
34117	28	-1	1860	2020-08-09 07:07:22.443142+03
34118	89	-1	1420	2020-08-09 07:26:09.715504+03
34119	82	-1	560	2020-08-09 07:36:50.305228+03
34120	42	-1	1790	2020-08-09 08:42:07.794714+03
34121	39	-1	910	2020-08-09 08:42:31.614564+03
34122	7	-1	810	2020-08-09 08:55:32.605311+03
34123	72	10	361	2020-08-09 09:04:33.63019+03
34124	25	-1	1100	2020-08-09 09:22:43.5136+03
34125	34	-2	1550	2020-08-09 09:58:41.333156+03
34126	47	-2	1480	2020-08-09 10:19:21.770811+03
34127	13	-1	460	2020-08-09 10:29:04.054069+03
34128	23	-1	4390	2020-08-09 10:31:33.768146+03
34129	76	-2	1070	2020-08-09 10:34:54.003391+03
34130	45	-1	1590	2020-08-09 11:02:12.554762+03
34131	89	-1	1420	2020-08-09 11:20:16.74966+03
34132	13	-1	460	2020-08-09 11:23:12.872011+03
34133	70	-1	760	2020-08-09 11:32:45.763396+03
34134	6	-1	980	2020-08-09 11:38:48.917629+03
34135	67	-3	350	2020-08-09 11:39:22.149263+03
34136	29	42	838	2020-08-09 12:00:49.289557+03
34137	35	-2	670	2020-08-09 12:03:48.326239+03
34138	86	-1	910	2020-08-09 12:18:24.454728+03
34139	34	-1	1550	2020-08-09 12:36:25.765827+03
34140	45	-1	1590	2020-08-09 13:08:32.26183+03
34141	15	-1	2830	2020-08-09 13:44:24.574169+03
34142	67	-1	350	2020-08-09 13:46:07.155838+03
34143	71	-2	1030	2020-08-09 13:55:03.685044+03
34144	63	-1	1780	2020-08-09 14:15:28.230918+03
34145	76	-1	1070	2020-08-09 14:18:51.821738+03
34146	76	-1	1070	2020-08-09 14:19:12.9263+03
34147	32	-1	710	2020-08-09 14:19:57.405577+03
34148	56	-1	2460	2020-08-09 14:34:28.121897+03
34149	65	-1	490	2020-08-09 14:43:38.791712+03
34150	73	-1	960	2020-08-09 14:52:37.748482+03
34151	8	30	1118	2020-08-09 15:01:37.359842+03
34152	81	-1	1620	2020-08-09 15:42:53.881495+03
34153	52	-1	1090	2020-08-09 15:53:57.622293+03
34154	61	-1	1510	2020-08-09 15:54:07.771225+03
34155	38	-1	1100	2020-08-09 16:06:17.732745+03
34156	33	-1	900	2020-08-09 16:15:01.753652+03
34157	96	-1	1570	2020-08-09 16:23:54.675013+03
34158	87	-1	2320	2020-08-09 16:29:44.470189+03
34159	35	30	322	2020-08-09 16:31:39.432819+03
34160	39	-1	910	2020-08-09 16:52:03.887179+03
34161	26	-1	390	2020-08-09 16:56:32.886668+03
34162	43	-1	380	2020-08-09 17:08:39.941777+03
34163	88	-1	1270	2020-08-09 17:13:03.403388+03
34164	45	-1	1590	2020-08-09 17:39:03.256087+03
34165	13	-1	460	2020-08-09 17:41:35.183971+03
34166	42	-1	1790	2020-08-09 17:50:36.670387+03
34167	14	-1	1350	2020-08-09 17:53:54.103635+03
34168	94	-1	1230	2020-08-09 18:08:57.408907+03
34169	61	-1	1510	2020-08-09 18:35:52.129856+03
34170	29	-1	1940	2020-08-09 18:50:02.508798+03
34171	46	-1	1270	2020-08-09 18:56:21.969162+03
34172	32	-1	710	2020-08-09 19:05:11.093123+03
34173	43	-1	380	2020-08-09 20:14:50.657392+03
34174	53	-1	3120	2020-08-09 20:25:03.078162+03
34175	37	-1	1290	2020-08-09 20:26:30.726078+03
34176	71	-1	1030	2020-08-09 20:37:42.584274+03
34177	25	-1	1100	2020-08-09 21:03:18.979655+03
34178	13	-1	460	2020-08-09 21:20:42.336579+03
34179	70	-1	760	2020-08-09 22:14:49.637583+03
34180	75	-1	830	2020-08-09 22:17:06.199063+03
34181	33	-1	900	2020-08-09 22:59:19.321761+03
34182	1	-1	640	2020-08-10 00:11:27.187407+03
34183	58	-2	2830	2020-08-10 00:49:19.518049+03
34184	52	-1	1090	2020-08-10 00:49:54.359306+03
34185	1	-1	640	2020-08-10 00:54:06.302611+03
34186	49	-1	970	2020-08-10 01:29:34.672302+03
34187	77	29	382	2020-08-10 01:30:39.723841+03
34188	28	-1	1860	2020-08-10 01:45:00.239917+03
34189	42	-1	1790	2020-08-10 02:05:00.865998+03
34190	83	-1	1230	2020-08-10 02:13:32.275823+03
34191	78	-2	900	2020-08-10 02:19:54.997186+03
34192	10	-1	2080	2020-08-10 02:42:09.558592+03
34193	55	-1	3480	2020-08-10 02:54:02.254476+03
34194	19	-2	1220	2020-08-10 03:03:04.259091+03
34195	69	-2	1100	2020-08-10 03:09:39.576531+03
34196	40	-1	1430	2020-08-10 03:09:42.444622+03
34197	56	-1	2460	2020-08-10 03:11:53.467695+03
34198	71	-1	1030	2020-08-10 03:17:24.783616+03
34199	4	-1	1420	2020-08-10 03:17:25.186154+03
34200	62	-1	1220	2020-08-10 03:20:11.536087+03
34201	36	-1	630	2020-08-10 03:48:57.655067+03
34202	61	-1	1510	2020-08-10 04:05:28.379687+03
34203	20	-1	830	2020-08-10 04:29:38.824199+03
34204	53	-1	3120	2020-08-10 05:32:40.045158+03
34205	15	-1	2830	2020-08-10 05:38:16.334571+03
34206	74	-1	1010	2020-08-10 05:42:37.847126+03
34207	63	-1	1780	2020-08-10 06:32:10.625398+03
34208	41	-1	830	2020-08-10 06:59:34.57517+03
34209	95	-1	480	2020-08-10 07:00:37.573853+03
34210	70	-2	760	2020-08-10 07:31:41.417905+03
34211	1	-1	640	2020-08-10 08:28:55.922842+03
34212	37	-1	1290	2020-08-10 08:46:58.002253+03
34213	93	-1	1620	2020-08-10 08:49:04.783264+03
34214	61	-1	1510	2020-08-10 08:55:09.276386+03
34215	70	-2	760	2020-08-10 08:59:48.438257+03
34216	81	-1	1620	2020-08-10 09:24:10.531473+03
34217	48	-1	640	2020-08-10 09:49:22.315696+03
34218	20	-1	830	2020-08-10 10:05:42.719618+03
34219	8	-1	1920	2020-08-10 11:02:01.893048+03
34220	93	-1	1620	2020-08-10 11:22:47.713232+03
34221	26	-1	390	2020-08-10 11:31:11.46596+03
34222	85	-3	730	2020-08-10 11:41:32.552357+03
34223	62	-1	1220	2020-08-10 11:52:59.148315+03
34224	95	-2	480	2020-08-10 12:03:02.740453+03
34225	6	-1	980	2020-08-10 12:35:37.259964+03
34226	89	-1	1420	2020-08-10 12:48:16.008663+03
34227	87	-1	2320	2020-08-10 13:10:23.959091+03
34228	10	-1	2080	2020-08-10 13:38:58.21591+03
34229	49	-2	970	2020-08-10 13:40:31.055721+03
34230	45	-1	1590	2020-08-10 14:26:36.095556+03
34231	43	-1	380	2020-08-10 15:01:35.869547+03
34232	30	-1	1140	2020-08-10 15:29:20.512919+03
34233	8	-1	1920	2020-08-10 15:50:56.094316+03
34234	89	-1	1420	2020-08-10 15:56:10.646685+03
34235	11	-1	830	2020-08-10 16:06:37.589402+03
34236	77	-1	640	2020-08-10 16:32:21.146485+03
34237	50	-1	1140	2020-08-10 16:44:22.166249+03
34238	87	-1	2320	2020-08-10 16:58:25.044289+03
34239	34	-1	1550	2020-08-10 17:17:02.706327+03
34240	48	-2	640	2020-08-10 17:18:54.228611+03
34241	2	-1	470	2020-08-10 17:35:28.661861+03
34242	11	-1	830	2020-08-10 17:36:15.865971+03
34243	49	-1	970	2020-08-10 17:58:11.21946+03
34244	32	-1	710	2020-08-10 18:31:52.01475+03
34245	89	-1	1420	2020-08-10 18:33:05.115899+03
34246	15	-1	2830	2020-08-10 18:39:20.526639+03
34247	35	-1	670	2020-08-10 18:57:06.522556+03
\.
SELECT setval('operations_operation_id_seq', 34247, true);

